@@ -7,7 +7,7 @@
 # Original by slaven@rezic.de, modified by jhi.
 #
 
-use strict;
+
 
 use ExtUtils::MakeMaker;
 use File::Compare;
@@ -15,17 +15,17 @@ use File::Find;
 use File::Spec::Functions < qw(rel2abs abs2rel catfile catdir curdir);
 
 for (@ARGV[[@(0, 1)]]) {
-    die "$0: '$_' does not look like Perl directory\n"
+    die "$^PROGRAM_NAME: '$_' does not look like Perl directory\n"
 	unless -f catfile($_, "perl.h") && -d catdir($_, "Porting");
 }
 
 my $dir2 = rel2abs(@ARGV[1]);
-chdir @ARGV[0] or die "$0: chdir '@ARGV[0]' failed: $!\n";
+chdir @ARGV[0] or die "$^PROGRAM_NAME: chdir '@ARGV[0]' failed: $^OS_ERROR\n";
 
 # Files to skip from the check for one reason or another,
 # usually because they pull in their version from some other file.
 my %skip;
- <%skip{[@('./lib/Exporter/Heavy.pm')]} = ();
+ %skip{[@('./lib/Exporter/Heavy.pm')]} = @();
 
 my @wanted;
 find(
@@ -49,5 +49,5 @@ find(
 			   defined $version2 &&
                            $version1 eq $version2
 		} }, < curdir);
-print < map { $_, "\n" } sort @wanted;
+print \*STDOUT, < map { $_, "\n" }, sort @wanted;
 
