@@ -3,12 +3,10 @@
                 # we build the new one
 
 BEGIN {
-  push @INC, 'lib';
+  push $^INCLUDE_PATH, 'lib';
   require 'regen_lib.pl';
 }
 
-use strict;
-
 #
 # See database of global and static function prototypes in embed.fnc
 # This is used to generate prototype headers under various configurations,
@@ -16,33 +14,28 @@ use strict;
 # implicit interpreter context argument.
 #
 
-open IN, "<", "embed.fnc" or die $!;
+open my $in_fh, "<", "embed.fnc" or die $^OS_ERROR;
 
 # walk table providing an array of components in each line to
 # subroutine, printing the result
-sub walk_table (&@) {
-    my $function = shift;
-    my $filename = shift || '-';
-    my $leader = shift;
-    my $trailer = shift;
+sub walk_table ($function, $filename, ?$leader, ?$trailer) {
+    $filename ||= '-';
     my $F;
-    local *F;
     if (ref $filename) {	# filehandle
 	$F = $filename;
     }
     else {
 	safer_unlink $filename;
 	$F = safer_open($filename);
-	binmode F;
-	$F = \*F;
+	binmode $F;
     }
-    print $F $leader if $leader;
-    seek IN, 0, 0;		# so we may restart
-    while ( ~< *IN) {
+    print $F, $leader if $leader;
+    seek $in_fh, 0, 0;		# so we may restart
+    while ( ~< $in_fh) {
 	chomp;
 	next if m/^:/;
 	while (s|\\\s*$||) {
-	    $_ .= ~< *IN;
+	    $_ .= ~< $in_fh;
 	    chomp;
 	}
 	s/\s+$//;
@@ -54,11 +47,11 @@ sub walk_table (&@) {
 	    @args = split m/\s*\|\s*/, $_;
 	}
 	s/\b(NN|NULLOK)\b\s+//g for  @args;
-	print $F < $function->(< @args);
+	print $F, $function->(< @args);
     }
-    print $F $trailer if $trailer;
+    print $F, $trailer if $trailer;
     unless (ref $filename) {
-	close $F or die "Error closing $filename: $!";
+	close $F or die "Error closing $filename: $^OS_ERROR";
     }
 }
 
@@ -69,8 +62,7 @@ my %seenfuncs;
 
 my $curheader = "Unknown section";
 
-sub autodoc ($$) { # parse a file and extract documentation info
-    my($fh,$file) = < @_;
+sub autodoc($fh, $file) { # parse a file and extract documentation info
     my($in, $doc, $line);
 FUNC:
     while (defined($in = ~< $fh)) {
@@ -82,7 +74,7 @@ FUNC:
 	if ($in =~ m/^=for\s+apidoc\s+(.*?)\s*\n/) {
 	    my $proto = $1;
 	    $proto = "||$proto" unless $proto =~ m/\|/;
-	    my($flags, $ret, $name, < @args) = < split m/\|/, $proto;
+	    my @($flags, $ret, $name, @< @args) = split m/\|/, $proto;
 	    my $docs = "";
 DOC:
 	    while (defined($doc = ~< $fh)) {
@@ -97,14 +89,14 @@ DOC:
 	    $docs = "\n$docs" if $docs and $docs !~ m/^\n/;
 	    if ($flags =~ m/m/) {
 		if ($flags =~ m/A/) {
-		    %apidocs{$curheader}{$name} = \@($flags, $docs, $ret, $file, < @args);
+		    %apidocs{+$curheader}{+$name} = \@($flags, $docs, $ret, $file, < @args);
 		}
 		else {
-		    %gutsdocs{$curheader}{$name} = \@($flags, $docs, $ret, $file, < @args);
+		    %gutsdocs{+$curheader}{+$name} = \@($flags, $docs, $ret, $file, < @args);
 		}
 	    }
 	    else {
-		%docfuncs{$name} = \@($flags, $docs, $ret, $file, $curheader, < @args);
+		%docfuncs{+$name} = \@($flags, $docs, $ret, $file, $curheader, < @args);
 	    }
 	    if (defined $doc) {
 		if ($doc =~ m/^=(?:for|head)/) {
@@ -118,9 +110,8 @@ DOC:
     }
 }
 
-sub docout ($$$) { # output the docs for one function
-    my($fh, $name, $docref) = < @_;
-    my($flags, $docs, $ret, $file, < @args) = < @$docref;
+sub docout($fh, $name, $docref) { # output the docs for one function
+    my @($flags, $docs, $ret, $file, @< @args) = @$docref;
     $name =~ s/\s*$//;
 
     $docs .= "NOTE: this function is experimental and may change or be
@@ -128,78 +119,75 @@ removed without notice.\n\n" if $flags =~ m/x/;
     $docs .= "NOTE: the perl_ form of this function is deprecated.\n\n"
 	if $flags =~ m/p/;
 
-    print $fh "=item $name\nX<$name>\n$docs";
+    print $fh, "=item $name\nX<$name>\n$docs";
 
     if ($flags =~ m/U/) { # no usage
 	# nothing
     } elsif ($flags =~ m/s/) { # semicolon ("dTHR;")
-	print $fh "\t\t$name;\n\n";
+	print $fh, "\t\t$name;\n\n";
     } elsif ($flags =~ m/n/) { # no args
-	print $fh "\t$ret\t$name\n\n";
+	print $fh, "\t$ret\t$name\n\n";
     } else { # full usage
-	print $fh "\t$ret\t$name";
-	print $fh "(" . join(", ", @args) . ")";
-	print $fh "\n\n";
+	print $fh, "\t$ret\t$name";
+	print $fh, "(" . join(", ", @args) . ")";
+	print $fh, "\n\n";
     }
-    print $fh "=for hackers\nFound in file $file\n\n";
+    print $fh, "=for hackers\nFound in file $file\n\n";
 }
 
-sub readonly_header (*) {
-    my $fh = shift;
-    print $fh <<"_EOH_";
+sub readonly_header($fh) {
+    print $fh, <<"_EOH_";
 -*- buffer-read-only: t -*-
 
 !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
-This file is built by $0 extracting documentation from the C source
+This file is built by $^PROGRAM_NAME extracting documentation from the C source
 files.
 
 _EOH_
 }
 
-sub readonly_footer (*) {
-    my $fh = shift;
-    print $fh <<'_EOF_';
+sub readonly_footer($fh) {
+    print $fh, <<'_EOF_';
 =cut
 
  ex: set ro:
 _EOF_
 }
 
-my $file;
 # glob() picks up docs from extra .c or .h files that may be in unclean
 # development trees.
 my $MANIFEST = do {
-  local ($/, *FH);
-  open FH, "<", "MANIFEST" or die "Can't open MANIFEST: $!";
-  ~< *FH;
+  local $^INPUT_RECORD_SEPARATOR = undef;
+  open my $fh, "<", "MANIFEST" or die "Can't open MANIFEST: $^OS_ERROR";
+  ~< $fh;
 };
 
-for $file (@(($MANIFEST =~ m/^(\S+\.c)\t/gm), ($MANIFEST =~ m/^(\S+\.h)\t/gm))) {
-    open F, "<", $file or die "Cannot open $file for docs: $!\n";
+for my $file (@(($MANIFEST =~ m/^(\S+\.c)\t/gm), ($MANIFEST =~ m/^(\S+\.h)\t/gm))) {
+    open my $fh, "<", $file or die "Cannot open $file for docs: $^OS_ERROR\n";
     $curheader = "Functions in file $file\n";
-    autodoc(\*F,$file);
-    close F or die "Error closing $file: $!\n";
+    autodoc($fh, $file);
+    close $fh or die "Error closing $file: $^OS_ERROR\n";
 }
 
 safer_unlink "pod/perlapi.pod";
 my $doc = safer_open("pod/perlapi.pod");
 
-walk_table {	# load documented functions into appropriate hash
+walk_table sub {	# load documented functions into appropriate hash
     if ((nelems @_) +> 1) {
-	my($flags, $retval, $func, < @args) = < @_;
+	my @($flags, $retval, $func, @< @args) = @_;
 	return "" unless $flags =~ m/d/;
 	$func =~ s/\t//g; $flags =~ s/p//; # clean up fields from embed.pl
 	$retval =~ s/\t//;
 	my $docref = delete %docfuncs{$func};
-	%seenfuncs{$func} = 1;
+	%seenfuncs{+$func} = 1;
 	if ($docref and nelems @$docref) {
 	    if ($flags =~ m/A/) {
 		$docref->[0].="x" if $flags =~ m/M/;
-		%apidocs{$docref->[4]}{$func} =
+		%apidocs{+$docref->[4]}{+$func} =
 		    \@($docref->[0] . 'A', $docref->[1], $retval, $docref->[3],
 			< @args);
 	    } else {
-		%gutsdocs{$docref->[4]}{$func} =
+		%gutsdocs{+$docref->[4]}{+$func} =
 		    \@($docref->[0], $docref->[1], $retval, $docref->[3], < @args);
 	    }
 	}
@@ -208,7 +196,7 @@ walk_table {	# load documented functions into appropriate hash
 	}
     }
     return "";
-} $doc;
+}, $doc;
 
 for (sort keys %docfuncs) {
     # Have you used a full for apidoc or just a func name?
@@ -218,7 +206,7 @@ for (sort keys %docfuncs) {
 
 readonly_header($doc);
 
-print $doc <<'_EOB_';
+print $doc, <<'_EOB_';
 =head1 NAME
 
 perlapi - autogenerated documentation for the perl public API
@@ -241,19 +229,18 @@ The listing is alphabetical, case insensitive.
 
 _EOB_
 
-my $key;
 # case insensitive sort, with fallback for determinacy
-for $key (sort { uc($a) cmp uc($b) || $a cmp $b } keys %apidocs) {
-    my $section = %apidocs{$key}; 
-    print $doc "\n=head1 $key\n\n=over 8\n\n";
+for my $key (sort { uc($a) cmp uc($b) || $a cmp $b }, keys %apidocs) {
+    my $section = %apidocs{$key};
+    print $doc, "\n=head1 $key\n\n=over 8\n\n";
     # Again, fallback for determinacy
-    for my $key (sort { uc($a) cmp uc($b) || $a cmp $b } keys %$section) {
-        docout($doc, $key, $section->{$key});
+    for my $key (sort { uc($a) cmp uc($b) || $a cmp $b }, keys $section) {
+        docout($doc, $key, $section{$key});
     }
-    print $doc "\n=back\n";
+    print $doc, "\n=back\n";
 }
 
-print $doc <<'_EOE_';
+print $doc, <<'_EOE_';
 
 =head1 AUTHORS
 
@@ -282,7 +269,7 @@ safer_close($doc);
 safer_unlink "pod/perlintern.pod";
 my $guts = safer_open("pod/perlintern.pod");
 readonly_header($guts);
-print $guts <<'END';
+print $guts, <<'END';
 =head1 NAME
 
 perlintern - autogenerated documentation of purely B<internal>
@@ -298,16 +285,16 @@ B<they are not for use in extensions>!
 
 END
 
-for $key (sort { uc($a) cmp uc($b); } keys %gutsdocs) {
+for my $key (sort { uc($a) cmp uc($b); }, keys %gutsdocs) {
     my $section = %gutsdocs{$key}; 
-    print $guts "\n=head1 $key\n\n=over 8\n\n";
-    for my $key (sort { uc($a) cmp uc($b); } keys %$section) {
-        docout($guts, $key, $section->{$key});
+    print $guts, "\n=head1 $key\n\n=over 8\n\n";
+    for my $key (sort { uc($a) cmp uc($b); }, keys $section) {
+        docout($guts, $key, $section{$key});
     }
-    print $guts "\n=back\n";
+    print $guts, "\n=back\n";
 }
 
-print $guts <<'END';
+print $guts, <<'END';
 
 =head1 AUTHORS
 
