@@ -43,14 +43,13 @@ our $Deparse    //= 0;
 # names must have leading $ sign stripped. begin the name with *
 # to cause output of arrays and hashes rather than refs.
 #
-sub new {
-  my($c, $v, $n) = < @_;
+sub new($c, $v, ?$n) {
 
   die "Usage:  PACKAGE->new(ARRAYREF, [ARRAYREF])" 
     unless (defined($v) && (ref($v) eq 'ARRAY'));
   $n = \@() unless (defined($n) && (ref($v) eq 'ARRAY'));
 
-  my($s) = \%( 
+  my $s = \%( 
              level      => 0,           # current recursive depth
 	     indent     => $Indent,     # various styles of indenting
 	     pad	=> $Pad,        # all lines prefixed by this string
@@ -77,13 +76,13 @@ sub new {
 	   );
 
   if ($Indent +> 0) {
-    $s->{xpad} = "  ";
-    $s->{sep} = "\n";
+    $s->{+xpad} = "  ";
+    $s->{+sep} = "\n";
   }
   return bless($s, $c);
 }
 
-{
+do {
   # Packed numeric addresses take less memory. Plus pack is faster than sprintf
   *init_refaddr_format = sub {};
 
@@ -91,29 +90,28 @@ sub new {
     require Scalar::Util;
     pack "J", Scalar::Util::refaddr(shift);
   };
-}
+};
 
 #
 # add-to or query the table of already seen references
 #
-sub Seen {
-  my($s, $g) = < @_;
+sub Seen($s, $g) {
   if (defined($g) && (ref($g) eq 'HASH'))  {
     init_refaddr_format();
     my($k, $v, $id);
-    while (($k, $v) = each %$g) {
+    while (@($k, $v) =@( each %$g)) {
       if (defined $v and ref $v) {
 	$id = format_refaddr($v);
 	if ($k =~ m/^[*](.*)$/) {
-	  $k = (ref $v eq 'ARRAY') ? ( "\\\@" . $1 ) :
-	       (ref $v eq 'HASH')  ? ( "\\\%" . $1 ) :
-	       (ref $v eq 'CODE')  ? ( "\\\&" . $1 ) :
+	  $k = (ref $v eq 'ARRAY') ?? ( "\\\@" . $1 ) !!
+	       (ref $v eq 'HASH')  ?? ( "\\\%" . $1 ) !!
+	       (ref $v eq 'CODE')  ?? ( "\\\&" . $1 ) !!
 				     (   "\$" . $1 ) ;
 	}
 	elsif ($k !~ m/^\$/) {
 	  $k = "\$" . $k;
 	}
-	$s->{seen}->{$id} = \@($k, $v);
+	$s->{seen}->{+$id} = \@($k, $v);
       }
       else {
 	warn "Only refs supported, ignoring non-ref item \$$k";
@@ -122,40 +120,38 @@ sub Seen {
     return $s;
   }
   else {
-    return map { < @$_ } values %{$s->{seen}};
+    return map { < @$_ }, values %{$s->{seen}};
   }
 }
 
 #
 # set or query the values to be dumped
 #
-sub Values {
-  my($s, $v) = < @_;
+sub Values($s, $v) {
   if (defined($v) && (ref($v) eq 'ARRAY'))  {
-    $s->{todump} = \ @$v;        # make a copy
+    $s->{+todump} = \ @$v;        # make a copy
     return $s;
   }
   else {
-    return @{$s->{todump}};
+    return @{$s->{?todump}};
   }
 }
 
 #
 # set or query the names of the values to be dumped
 #
-sub Names {
-  my($s, $n) = < @_;
+sub Names($s, $n) {
   if (defined($n) && (ref($n) eq 'ARRAY'))  {
-    $s->{names} = \ @$n;         # make a copy
+    $s->{+names} = \ @$n;         # make a copy
     return $s;
   }
   else {
-    return @{$s->{names}};
+    return @{$s->{?names}};
   }
 }
 
 sub Dump {
-    return &Dumpperl;
+    return &Dumpperl( < @_ );
 }
 
 #
@@ -164,24 +160,24 @@ sub Dump {
 #
 our @post;
 sub Dumpperl {
-  my($s) = shift;
-  my(@out, $val, $name);
-  my($i) = 0;
+  my $s = shift;
+  my(@out, $name);
+  my $i = 0;
   local(@post);
   init_refaddr_format();
 
   $s = $s->new(< @_) unless ref $s;
 
-  for $val ( @{$s->{todump}}) {
+  for my $val ( @{$s->{todump}}) {
     my $out = "";
     @post = @();
-    $name = $s->{names}->[$i++];
+    $name = $s->{names}->[?$i++];
     if (defined $name) {
       if ($name =~ m/^[*](.*)$/) {
 	if (defined $val) {
-	  $name = (ref::svtype($val) eq 'ARRAY') ? ( '@' . $1 ) :
-		  (ref::svtype($val) eq 'HASH')  ? ( '%' . $1 ) :
-		  (ref::svtype($val) eq 'CODE')  ? ( '*' . $1 ) :
+	  $name = (ref::svtype($val) eq 'ARRAY') ?? ( '@' . $1 ) !!
+		  (ref::svtype($val) eq 'HASH')  ?? ( '%' . $1 ) !!
+		  (ref::svtype($val) eq 'CODE')  ?? ( '*' . $1 ) !!
                                                    ( '$' . $1 ) ;
 	}
 	else {
@@ -193,7 +189,7 @@ sub Dumpperl {
       }
     }
     else {
-      $name = "\$" . $s->{varname} . $i;
+      $name = "\$" . $s->{?varname} . $i;
     }
 
     # Ensure hash iterator is reset
@@ -202,16 +198,16 @@ sub Dumpperl {
     }
 
     my $valstr;
-    {
-      local($s->{apad}) = $s->{apad};
-      $s->{apad} .= ' ' x (length($name) + 3) if $s->{indent} +>= 2;
+    do {
+      local($s->{+apad}) = $s->{?apad};
+      $s->{+apad} .= ' ' x (length($name) + 3) if $s->{?indent} +>= 2;
       $valstr = $s->_dump($val, $name);
-    }
+    };
 
-    $valstr = "$name = " . $valstr . ';' if (nelems @post) or !$s->{terse};
-    $out .= $s->{pad} . $valstr . $s->{sep};
-    $out .= $s->{pad} . join(';' . $s->{sep} . $s->{pad}, @post) 
-      . ';' . $s->{sep} if (nelems @post);
+    $valstr = "$name = " . $valstr . ';' if (nelems @post) or !$s->{?terse};
+    $out .= $s->{?pad} . $valstr . $s->{?sep};
+    $out .= $s->{?pad} . join(';' . $s->{?sep} . $s->{?pad}, @post) 
+      . ';' . $s->{?sep} if (nelems @post);
 
     push @out, $out;
   }
@@ -240,7 +236,7 @@ sub _dump {
     my $rval = \@_[1];
     my $reftype = ref $$rval;
     $out = "";
-    $ipad = $s->{xpad} x $s->{level};
+    $ipad = $s->{?xpad} x $s->{?level};
 
     my $realtype = ref::svtype($$rval);
     if ($reftype) {
@@ -249,15 +245,15 @@ sub _dump {
         # Call the freezer method if it's specified and the object has the
         # method.  Trap errors and warn() instead of die()ing, like the XS
         # implementation.
-        my $freezer = $s->{freezer};
+        my $freezer = $s->{?freezer};
         if ($freezer and UNIVERSAL::can($val, $freezer)) {
             try { $val->?$freezer() };
-            warn "WARNING(Freezer method call failed): {$@->message}" if $@;
+            warn "WARNING(Freezer method call failed): $($^EVAL_ERROR->message)" if $^EVAL_ERROR;
         }
 
         require Scalar::Util;
         $realpack = Scalar::Util::blessed($val);
-        $realtype = $realpack ? Scalar::Util::reftype($val) : ref $val;
+        $realtype = $realpack ?? Scalar::Util::reftype($val) !! ref $val;
         my $id = format_refaddr($val);
 
         # if it has a name, we need to either look it up, or keep a tab
@@ -266,9 +262,9 @@ sub _dump {
             # keep a tab on it so that we dont fall into recursive pit
             if (exists $s->{seen}->{$id}) {
                 #	if ($s->{expdepth} < $s->{level}) {
-                if ($s->{purity} and $s->{level} +> 0) {
-                    $out = ($realtype eq 'HASH')  ? '\%()' :
-                      ($realtype eq 'ARRAY') ? '\@()' :
+                if ($s->{?purity} and $s->{?level} +> 0) {
+                    $out = ($realtype eq 'HASH')  ?? '\%()' !!
+                      ($realtype eq 'ARRAY') ?? '\@()' !!
                         'do{my $o}' ;
                     push @post, $name . " = " . $s->{seen}->{$id}->[0];
                 } else {
@@ -286,9 +282,9 @@ sub _dump {
                 #        }
             } else {
                 # store our name
-                $s->{seen}->{$id} = \@( (($name =~ m/^[@%]/)     ? ('\' . $name ) :
+                $s->{seen}->{+$id} = \@( (($name =~ m/^[@%]/)     ?? ('\' . $name ) !!
 			     ($realtype eq 'CODE' and
-			      $name =~ m/^[*](.*)$/) ? ('\&' . $1 )   :
+			      $name =~ m/^[*](.*)$/) ?? ('\&' . $1 )   !!
                                          $name          ),
                                         $val );
             }
@@ -304,20 +300,20 @@ sub _dump {
         # if we have reached maximum depth, return the string
         # representation of the thing we are currently examining
         # at this depth (i.e., 'Foo=ARRAY(0xdeadbeef)'). 
-        if (!$s->{purity}
-            and $s->{maxdepth} +> 0
-            and $s->{level} +>= $s->{maxdepth}) {
+        if (!$s->{?purity}
+            and $s->{?maxdepth} +> 0
+            and $s->{?level} +>= $s->{?maxdepth}) {
             return dump::view($val);
         }
 
         # we have a blessed ref
         if ($realpack and !$no_bless) {
-            $out = $s->{'bless'} . '( ';
-            $blesspad = $s->{apad};
-            $s->{apad} .= '       ' if ($s->{indent} +>= 2);
+            $out = $s->{?'bless'} . '( ';
+            $blesspad = $s->{?apad};
+            $s->{+apad} .= '       ' if ($s->{?indent} +>= 2);
         }
 
-        $s->{level}++;
+        $s->{+level}++;
 
         if ($is_regex) {
             my $pat;
@@ -345,10 +341,10 @@ sub _dump {
 
         if ($realpack and !$no_bless) { # we have a blessed ref
             $out .= ', ' . _quote($realpack) . ' )';
-            $out .= '->' . $s->{toaster} . '()'  if $s->{toaster} ne '';
-            $s->{apad} = $blesspad;
+            $out .= '->' . $s->{?toaster} . '()'  if $s->{?toaster} ne '';
+            $s->{+apad} = $blesspad;
         }
-        $s->{level}--;
+        $s->{+level}--;
     }
     elsif ($realtype eq 'REF') {
         if ($realpack) {
@@ -380,14 +376,13 @@ sub _dump {
             }
             else {
                 #warn "[>\\$name]\n";
-                $s->{seen}->{$id} = \@("\\$name", $rval);
+                $s->{seen}->{+$id} = \@("\\$name", $rval);
             }
         }
 
-        if ($s->{purity}) {
-            my $k;
-            local ($s->{level}) = 0;
-            for $k (qw(SCALAR ARRAY HASH)) {
+        if ($s->{?purity}) {
+            local ($s->{+level}) = 0;
+            for my $k (qw(SCALAR ARRAY HASH)) {
                 my $gval = *$rval{$k};
                 next unless defined $gval;
                 next if $k eq "SCALAR" && ! defined $$gval;  # always there
@@ -395,7 +390,7 @@ sub _dump {
                 # _dump can push into @post, so we hold our place using $postlen
                 my $postlen = scalar nelems @post;
                 @post[$postlen] = "\*$sname = ";
-                local ($s->{apad}) = " " x length(@post[$postlen]) if $s->{indent} +>= 2;
+                local ($s->{+apad}) = " " x length(@post[$postlen]) if $s->{?indent} +>= 2;
                 @post[$postlen] .= $s->_dump($gval, "\*$sname\{$k\}");
             }
         }
@@ -405,7 +400,7 @@ sub _dump {
           if ($id) {
               # if we made it this far, $id was added to seen list at current
               # level, so remove it to get deep copies
-              if ($s->{deepcopy}) {
+              if ($s->{?deepcopy}) {
                   delete($s->{seen}->{$id});
               }
               elsif ($name) {
@@ -414,33 +409,33 @@ sub _dump {
           }
     }
     elsif ($realtype eq 'ARRAY') {
-        my($v, $pad, $mname);
-        my($i) = 0;
+        my($pad, $mname);
+        my $i = 0;
         $out .= '@(';
-        $pad = $s->{sep} . $s->{pad} . $s->{apad};
+        $pad = $s->{?sep} . $s->{?pad} . $s->{?apad};
         $mname = $name . '->';
         $mname .= '->' if $mname =~ m/^\*.+\{[A-Z]+\}$/;
-        for $v ( @$rval) {
+        for my $v ( @$rval) {
             $sname = $mname . '[' . $i . ']';
-            $out .= $pad . $ipad . '#' . $i if $s->{indent} +>= 3;
+            $out .= $pad . $ipad . '#' . $i if $s->{?indent} +>= 3;
             $out .= $pad . $ipad . $s->_dump($v, $sname);
             $out .= "," if $i++ +< (nelems @$rval) -1;
         }
-        $out .= $pad . ($s->{xpad} x ($s->{level} - 1)) if $i;
+        $out .= $pad . ($s->{?xpad} x ($s->{?level} - 1)) if $i;
         $out .= ')';
     }
     elsif ($realtype eq 'HASH') {
         my($k, $v, $pad, $lpad, $mname, $pair);
         $out .= '%(';
-        $pad = $s->{sep} . $s->{pad} . $s->{apad};
-        $lpad = $s->{apad};
-        $pair = $s->{pair};
+        $pad = $s->{?sep} . $s->{?pad} . $s->{?apad};
+        $lpad = $s->{?apad};
+        $pair = $s->{?pair};
         $mname = $name . '->';
         $mname .= '->' if $mname =~ m/^\*.+\{[A-Z]+\}$/;
-        my ($sortkeys, $keys, $key) = ($s->{sortkeys});
+        my @($sortkeys, ?$keys, ?$key) = @($s->{?sortkeys});
         if ($sortkeys) {
-            if (ref($s->{sortkeys}) eq 'CODE') {
-                $keys = $s->{sortkeys}->($rval);
+            if (ref($s->{?sortkeys}) eq 'CODE') {
+                $keys = $s->{?sortkeys}->($rval);
                 unless (ref($keys) eq 'ARRAY') {
                     warn "Sortkeys subroutine did not return ARRAYREF";
                     $keys = \@();
@@ -449,35 +444,35 @@ sub _dump {
                 $keys = \ sort keys %$rval;
             }
         }
-        while (($k, $v) = ! $sortkeys ? (each %$rval) :
-               (nelems @$keys) ? ($key = shift(@$keys), $rval->{$key}) :
-               () ) {
+        while (@(?$k, ?$v) = ! $sortkeys ?? @(each %$rval) !!
+               (nelems @$keys) ?? @(($key = shift(@$keys)), $rval->{?$key}) !!
+               @() ) {
             my $nk = $s->_dump($k, "");
-            $nk = $1 if !$s->{quotekeys} and $nk =~ m/^[\"\']([A-Za-z_]\w*)[\"\']$/;
+            $nk = $1 if !$s->{?quotekeys} and $nk =~ m/^[\"\']([A-Za-z_]\w*)[\"\']$/;
             $sname = $mname . '{' . $nk . '}';
             $out .= $pad . $ipad . $nk . $pair;
 
             # temporarily alter apad
-            $s->{apad} .= (" " x (length($nk) + 4)) if $s->{indent} +>= 2;
-            $out .= $s->_dump($rval->{$k}, $sname) . ",";
-            $s->{apad} = $lpad if $s->{indent} +>= 2;
+            $s->{+apad} .= (" " x (length($nk) + 4)) if $s->{?indent} +>= 2;
+            $out .= $s->_dump($rval->{?$k}, $sname) . ",";
+            $s->{+apad} = $lpad if $s->{?indent} +>= 2;
         }
         if (substr($out, -1) eq ',') {
             chop $out;
-            $out .= $pad . ($s->{xpad} x ($s->{level} - 1));
+            $out .= $pad . ($s->{?xpad} x ($s->{?level} - 1));
         }
         $out .= ')';
     }
     elsif ($realtype eq 'CODE') {
-        if ($s->{deparse}) {
+        if ($s->{?deparse}) {
             require B::Deparse;
             my $sub =  'sub ' . (B::Deparse->new)->coderef2text($rval);
-            my $pad    =  $s->{sep} . $s->{pad} . $s->{apad} . $s->{xpad} x ($s->{level} - 1);
-            $sub    =~ s/\n/{$pad}/gs;
+            my $pad    =  $s->{?sep} . $s->{?pad} . $s->{?apad} . $s->{?xpad} x ($s->{?level} - 1);
+            $sub    =~ s/\n/$pad/gs;
             $out   .=  $sub;
         } else {
             $out .= 'sub { "DUMMY" }';
-            warn "Encountered CODE ref, using dummy placeholder" if $s->{purity};
+            warn "Encountered CODE ref, using dummy placeholder" if $s->{?purity};
         }
     }
     elsif ($realtype eq 'PLAINVALUE') {
@@ -485,9 +480,9 @@ sub _dump {
             $out .= $$rval;
         }
         else {				 # string
-            if ($s->{useqq} or $$rval =~ m/[\x[80]-\x[FF]]/) {
+            if ($s->{?useqq} or $$rval =~ m/[\x[80]-\x[FF]]/) {
                 # Fall back to qq if there's Unicode
-                $out .= qquote($$rval, $s->{useqq});
+                $out .= qquote($$rval, $s->{?useqq});
             }
             else {
                 $out .= _quote($$rval);
@@ -518,104 +513,89 @@ sub DumperX {
 
 sub Dumpf { return Data::Dumper->Dump(< @_) }
 
-sub Dumpp { print < Data::Dumper->Dump(< @_) }
+sub Dumpp { print $^STDOUT, < Data::Dumper->Dump(< @_) }
 
 #
 # reset the "seen" cache 
 #
 sub Reset {
-  my($s) = shift;
-  $s->{seen} = \%();
+  my@($s) =@( shift);
+  $s->{+seen} = \%();
   return $s;
 }
 
-sub Indent {
-  my($s, $v) = < @_;
+sub Indent($s, $v) {
   if (defined($v)) {
     if ($v == 0) {
-      $s->{xpad} = "";
-      $s->{sep} = "";
+      $s->{+xpad} = "";
+      $s->{+sep} = "";
     }
     else {
-      $s->{xpad} = "  ";
-      $s->{sep} = "\n";
+      $s->{+xpad} = "  ";
+      $s->{+sep} = "\n";
     }
-    $s->{indent} = $v;
+    $s->{+indent} = $v;
     return $s;
   }
   else {
-    return $s->{indent};
+    return $s->{?indent};
   }
 }
 
-sub Pair {
-    my($s, $v) = < @_;
-    defined($v) ? do { ($s->{pair} = $v); return $s} : $s->{pair};
+sub Pair($s, ?$v) {
+    defined($v) ?? do { ($s->{+pair} = $v); return $s} !! $s->{?pair};
 }
 
-sub Pad {
-  my($s, $v) = < @_;
-  defined($v) ? do { ($s->{pad} = $v); return $s} : $s->{pad};
+sub Pad($s, $v) {
+  defined($v) ?? do { ($s->{+pad} = $v); return $s} !! $s->{?pad};
 }
 
-sub Varname {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{varname} = $v); return $s} : $s->{varname};
+sub Varname($s, $v) {
+  defined($v) ?? do {($s->{+varname} = $v); return $s} !! $s->{?varname};
 }
 
-sub Purity {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{purity} = $v); return $s} : $s->{purity};
+sub Purity($s, $v) {
+  defined($v) ?? do {($s->{+purity} = $v); return $s} !! $s->{?purity};
 }
 
-sub Useqq {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{useqq} = $v); return $s} : $s->{useqq};
+sub Useqq($s, $v) {
+  defined($v) ?? do {($s->{+useqq} = $v); return $s} !! $s->{?useqq};
 }
 
-sub Terse {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{terse} = $v); return $s} : $s->{terse};
+sub Terse($s, $v) {
+  defined($v) ?? do {($s->{+terse} = $v); return $s} !! $s->{?terse};
 }
 
-sub Freezer {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{freezer} = $v); return $s} : $s->{freezer};
+sub Freezer($s, $v) {
+  defined($v) ?? do {($s->{+freezer} = $v); return $s} !! $s->{?freezer};
 }
 
-sub Toaster {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{toaster} = $v); return $s} : $s->{toaster};
+sub Toaster($s, $v) {
+  defined($v) ?? do {($s->{+toaster} = $v); return $s} !! $s->{?toaster};
 }
 
-sub Deepcopy {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{deepcopy} = $v); return $s} : $s->{deepcopy};
+sub Deepcopy($s, $v) {
+  defined($v) ?? do {($s->{+deepcopy} = $v); return $s} !! $s->{?deepcopy};
 }
 
-sub Quotekeys {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{quotekeys} = $v); return $s} : $s->{quotekeys};
+sub Quotekeys($s, $v) {
+  defined($v) ?? do {($s->{+quotekeys} = $v); return $s} !! $s->{?quotekeys};
 }
 
-sub Bless {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{'bless'} = $v); return $s} : $s->{'bless'};
+sub Bless($s, $v) {
+  defined($v) ?? do {($s->{+'bless'} = $v); return $s} !! $s->{?'bless'};
 }
 
-sub Maxdepth {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{'maxdepth'} = $v); return $s} : $s->{'maxdepth'};
+sub Maxdepth($s, $v) {
+  defined($v) ?? do {($s->{+'maxdepth'} = $v); return $s} !! $s->{?'maxdepth'};
 }
 
-sub Sortkeys {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{'sortkeys'} = $v); return $s} : $s->{'sortkeys'};
+sub Sortkeys($s, $v) {
+  defined($v) ?? do {($s->{+'sortkeys'} = $v); return $s} !! $s->{?'sortkeys'};
 }
 
-sub Deparse {
-  my($s, $v) = < @_;
-  defined($v) ? do {($s->{'deparse'} = $v); return $s} : $s->{'deparse'};
+sub Deparse($s, $v) {
+  defined($v) ?? do {($s->{+'deparse'} = $v); return $s} !! $s->{?'deparse'};
 }
 
 # used by qquote below
@@ -633,20 +613,20 @@ my %esc = %(
 sub qquote {
   local($_) = shift;
   s/([\\\"\@\$\{\}])/\\$1/g;
-  my $bytes; { use bytes; $bytes = length }
-  s/([^\x[00]-\x[7f]])/{'\x'.sprintf("[\%02x]",ord($1))}/g if $bytes +> length;
+  my $bytes; do { use bytes; $bytes = length };
+  s/([^\x[00]-\x[7f]])/$('\x'.sprintf("[\%02x]",ord($1)))/g if $bytes +> length;
   return qq("$_") unless 
     m/[^ !"\#\$%&'()*+,\-.\/0-9:;<=>?\@A-Z[\\\]^_`a-z{|}~]/;  # fast exit
 
   my $high = shift || "";
-  s/([\a\b\t\n\f\r\e])/%esc{$1}/g;
+  s/([\a\b\t\n\f\r\e])/%esc{?$1}/g;
 
     # no need for 3 digits in escape for these
-    s/([\0-\037])(?!\d)/{'\'.sprintf('%o',ord($1))}/g;
-    s/([\0-\037\177])/{'\'.sprintf('\%03o',ord($1))}/g;
+    s/([\0-\037])(?!\d)/$('\'.sprintf('%o',ord($1)))/g;
+    s/([\0-\037\177])/$('\'.sprintf('\%03o',ord($1)))/g;
     # all but last branch below not supported --BEHAVIOR SUBJECT TO CHANGE--
     if ($high eq "iso8859") {
-      s/([\200-\240])/{'\'.sprintf('%o',ord($1))}/g;
+      s/([\200-\240])/$('\'.sprintf('%o',ord($1)))/g;
     } elsif ($high eq "utf8") {
 #     use utf8;
 #     $str =~ s/([^\040-\176])/sprintf "\\x{%04x}", ord($1)/ge;
@@ -654,7 +634,7 @@ sub qquote {
         # leave it as it is
     } else {
         use utf8;
-        s/([^\040-\176])/{sprintf "\\x\{\%04x\}", ord($1)}/g;
+        s/([^\040-\176])/$(sprintf "\\x\{\%04x\}", ord($1))/g;
     }
 
   return qq("$_");
