@@ -1,6 +1,5 @@
 package Hash::Util;
 
-use strict;
 use warnings;
 use warnings::register;
 use Scalar::Util < qw(reftype);
@@ -28,16 +27,9 @@ our @EXPORT_OK  = qw(
                     );
 our $VERSION    = 0.07;
 require DynaLoader;
-local @ISA = qw(DynaLoader);
+local @ISA = qw(DynaLoader Exporter);
 Hash::Util->bootstrap($VERSION);
 
-sub import {
-    my $class = shift;
-    unshift @_, $class;
-    goto &Exporter::import;
-}
-
-
 =head1 NAME
 
 Hash::Util - A selection of general-utility hash subroutines
@@ -128,29 +120,27 @@ Both routines return a reference to the hash operated on.
 
 =cut
 
-sub lock_ref_keys {
-    my($hash, < @keys) = < @_;
-
-    Internals::hv_clear_placeholders %$hash;
+sub lock_ref_keys($hash, @< @keys) {
+    Internals::hv_clear_placeholders(\%$hash);
     if( (nelems @keys) ) {
-        my %keys = %( < map { ($_ => 1) } @keys );
-        my %original_keys = %( < map { ($_ => 1) } keys %$hash );
+        my %keys = %( < @+: map { @($_ => 1) }, @keys );
+        my %original_keys = %( < @+: map { @($_ => 1) }, keys %$hash );
         foreach my $k (keys %original_keys) {
             die "Hash has key '$k' which is not in the new key set"
-              unless %keys{$k};
+              unless %keys{?$k};
         }
 
         foreach my $k ( @keys) {
-            $hash->{$k} = undef unless exists $hash->{$k};
+            $hash->{+$k} = undef unless exists $hash->{$k};
         }
-        Internals::SvREADONLY %$hash, 1;
+        Internals::HvRESTRICTED(\%$hash, 1);
 
         foreach my $k ( @keys) {
-            delete $hash->{$k} unless %original_keys{$k};
+            delete $hash->{$k} unless %original_keys{?$k};
         }
     }
     else {
-        Internals::SvREADONLY %$hash, 1;
+        Internals::HvRESTRICTED %$hash, 1;
     }
 
     return $hash;
@@ -159,12 +149,12 @@ sub lock_ref_keys {
 sub unlock_ref_keys {
     my $hash = shift;
 
-    Internals::SvREADONLY %$hash, 0;
+    Internals::HvRESTRICTED %$hash, 0;
     return $hash;
 }
 
-sub   lock_keys (\%;@) {   lock_ref_keys(< @_) }
-sub unlock_keys (\%)   { unlock_ref_keys(< @_) }
+sub   lock_keys {   lock_ref_keys(< @_) }
+sub unlock_keys { unlock_ref_keys(< @_) }
 
 =item B<lock_keys_plus>
 
@@ -181,22 +171,21 @@ Returns a reference to %hash
 =cut
 
 
-sub lock_ref_keys_plus {
-    my ($hash,< @keys)=< @_;
+sub lock_ref_keys_plus($hash,@< @keys) {
     my @delete;
     Internals::hv_clear_placeholders(%$hash);
     foreach my $key ( @keys) {
         unless (exists($hash->{$key})) {
-            $hash->{$key}=undef;
+            $hash->{+$key}=undef;
             push @delete,$key;
         }
     }
-    Internals::SvREADONLY(%$hash,1);
+    Internals::HvRESTRICTED(%$hash,1);
     delete %{$hash}{[@delete]};
     return $hash
 }
 
-sub lock_keys_plus(\%;@) { lock_ref_keys_plus(< @_) }
+sub lock_keys_plus { lock_ref_keys_plus(< @_) }
 
 
 =item B<lock_value>
@@ -216,25 +205,23 @@ Returns a reference to the %hash.
 
 =cut
 
-sub lock_ref_value {
-    my($hash, $key) = < @_;
+sub lock_ref_value($hash, $key) {
     # I'm doubtful about this warning, as it seems not to be true.
     # Marking a value in the hash as RO is useful, regardless
     # of the status of the hash itself.
     warn "Cannot usefully lock values in an unlocked hash"
-      if !Internals::SvREADONLY(%$hash) && warnings::enabled;
-    Internals::SvREADONLY $hash->{$key}, 1;
+      if !Internals::HvRESTRICTED(%$hash) && warnings::enabled;
+    Internals::SvREADONLY($hash->{?$key}, 1);
     return $hash
 }
 
-sub unlock_ref_value {
-    my($hash, $key) = < @_;
-    Internals::SvREADONLY $hash->{$key}, 0;
+sub unlock_ref_value($hash, $key) {
+    Internals::SvREADONLY($hash->{?$key}, 0);
     return $hash
 }
 
-sub   lock_value (\%$) {   lock_ref_value(< @_) }
-sub unlock_value (\%$) { unlock_ref_value(< @_) }
+sub   lock_value {   lock_ref_value(< @_) }
+sub unlock_value { unlock_ref_value(< @_) }
 
 
 =item B<lock_hash>
@@ -280,8 +267,8 @@ sub unlock_hashref {
     return $hash;
 }
 
-sub   lock_hash (\%) {   lock_hashref(< @_) }
-sub unlock_hash (\%) { unlock_hashref(< @_) }
+sub   lock_hash {   lock_hashref(< @_) }
+sub unlock_hash { unlock_hashref(< @_) }
 
 =item B<lock_hash_recurse>
 
@@ -315,7 +302,7 @@ sub lock_hashref_recurse {
         if (reftype($value) eq 'HASH') {
             lock_hashref_recurse($value);
         }
-        Internals::SvREADONLY($value,1);
+        Internals::HvRESTRICTED($value,1);
     }
     return $hash
 }
@@ -327,14 +314,14 @@ sub unlock_hashref_recurse {
         if (reftype($value) eq 'HASH') {
             unlock_hashref_recurse($value);
         }
-        Internals::SvREADONLY($value,1);
+        Internals::HvRESTRICTED($value,1);
     }
     unlock_ref_keys($hash);
     return $hash;
 }
 
-sub   lock_hash_recurse (\%) {   lock_hashref_recurse(< @_) }
-sub unlock_hash_recurse (\%) { unlock_hashref_recurse(< @_) }
+sub   lock_hash_recurse($hashref) {   lock_hashref_recurse($hashref) }
+sub unlock_hash_recurse($hashref) { unlock_hashref_recurse($hashref) }
 
 
 =item B<hash_unlocked>
@@ -347,10 +334,10 @@ Returns true if the hash and its keys are unlocked.
 
 sub hashref_unlocked {
     my $hash=shift;
-    return Internals::SvREADONLY($hash)
+    return Internals::HvRESTRICTED($hash)
 }
 
-sub hash_unlocked(\%) { hashref_unlocked(< @_) }
+sub hash_unlocked($hashref) { hashref_unlocked($hashref) }
 
 =for demerphqs_editor
 sub legal_ref_keys{}
@@ -359,8 +346,8 @@ sub all_keys{}
 
 =cut
 
-sub legal_keys(\%) { legal_ref_keys(< @_)  }
-sub hidden_keys(\%){ hidden_ref_keys(< @_) }
+sub legal_keys($hashref) { legal_ref_keys($hashref)  }
+sub hidden_keys($hashref){ hidden_ref_keys($hashref) }
 
 =item B<legal_keys>
 
