@@ -3,7 +3,7 @@
 package IO;
 
 use XSLoader ();
-use strict;
+
 use warnings;
 
 our $VERSION = "1.23_01";
@@ -15,10 +15,10 @@ sub import {
     warnings::warnif('deprecated', qq{Parameterless "use IO" deprecated})
         if (nelems @_) == 0 ;
     
-    my @l = @( (nelems @_) ? < @_ : < qw(Handle Seekable File Socket Dir) );
+    my @l = @( (nelems @_) ?? < @_ !! < qw(Handle Seekable File Socket Dir) );
 
-    eval join("", map { "require IO::" . @(m/(\w+)/)[0] . ";\n" } @l)
-	or die $@;
+    eval join("", map { "require IO::" . @(m/(\w+)/)[0] . ";\n" }, @l)
+	or die $^EVAL_ERROR;
 }
 
 1;
