@@ -124,10 +124,8 @@ Derived from FileHandle.pm by Graham Barr E<lt>F<gbarr@pobox.com>E<gt>.
 
 =cut
 
-use strict;
 our($VERSION, @EXPORT, @EXPORT_OK, @ISA);
 use Symbol;
-use SelectSaver;
 use IO::Seekable;
 use File::Spec;
 
@@ -142,7 +140,7 @@ $VERSION = "1.14";
 try {
     # Make all Fcntl O_XXX constants available for importing
     require Fcntl;
-    my @O = grep m/^O_/, @Fcntl::EXPORT;
+    my @O = grep { m/^O_/ }, @Fcntl::EXPORT;
     Fcntl->import(< @O);  # first we import what we want to export
     push(@EXPORT, < @O);
 };
@@ -170,9 +168,9 @@ sub new {
 
 sub open {
     (nelems @_) +>= 2 && (nelems @_) +<= 4 or die 'usage: $fh->open(FILENAME [,MODE [,PERMS]])';
-    my ($fh, $file) = < @_;
+    my @($fh, $file, ...) =  @_;
     if ((nelems @_) +> 2) {
-	my ($mode, $perms) = < @_[[@(2, 3)]];
+	my @($mode, $perms) =  @_[[@(2, 3)]];
 	if ($mode =~ m/^\d+$/) {
 	    defined $perms or $perms = 0666;
 	    return sysopen($fh, $file, $mode, $perms);
@@ -194,7 +192,7 @@ sub open {
 sub binmode {
     ( (nelems @_) == 1 or (nelems @_) == 2 ) or die 'usage $fh->binmode([LAYER])';
 
-    my($fh, $layer) = < @_;
+    my @($fh, ?$layer) =  @_;
 
     return binmode $$fh unless $layer;
     return binmode $$fh, $layer;
