@@ -7,7 +7,6 @@
 
 package IO::Poll;
 
-use strict;
 use IO::Handle;
 use Exporter ();
 our(@ISA, @EXPORT_OK, @EXPORT, $VERSION);
@@ -50,12 +49,12 @@ sub mask {
     if ((nelems @_)) {
 	my $mask = shift;
 	if($mask) {
-	  $self->[0]->{$fd}->{$io} = $mask; # the error events are always returned
-	  $self->[1]->{$fd}      = 0;     # output mask
-	  $self->[2]->{$io}      = $io;   # remember handle
+	  $self->[0]->{+$fd}->{+$io} = $mask; # the error events are always returned
+	  $self->[1]->{+$fd}      = 0;     # output mask
+	  $self->[2]->{+$io}      = $io;   # remember handle
 	} else {
           delete $self->[0]->{$fd}->{$io};
-          unless(%{$self->[0]->{$fd}}) {
+          unless(%{$self->[0]->{?$fd}}) {
             # We no longer have any handles for this FD
             delete $self->[1]->{$fd};
             delete $self->[0]->{$fd};
@@ -65,32 +64,31 @@ sub mask {
     }
     
     return unless exists $self->[0]->{$fd} and exists $self->[0]->{$fd}->{$io};
-	return $self->[0]->{$fd}->{$io};
+	return $self->[0]->{$fd}->{?$io};
 }
 
 
-sub poll {
-    my($self,$timeout) = < @_;
+sub poll($self,$timeout) {
 
     $self->[1] = \%();
 
     my($fd,$mask,$iom);
     my @poll = @( () );
 
-    while(($fd,$iom) = each %{$self->[0]}) {
+    while(@(?$fd,?$iom) =@( each %{$self->[0]})) {
 	$mask   = 0;
 	$mask  ^|^= $_ for values(%$iom);
 	push(@poll,$fd => $mask);
     }
 
-    my $ret = (nelems @poll) ? _poll(defined($timeout) ? $timeout * 1000 : -1,< @poll) : 0;
+    my $ret = (nelems @poll) ?? _poll(defined($timeout) ?? $timeout * 1000 !! -1,< @poll) !! 0;
 
     return $ret
 	unless $ret +> 0;
 
     while((nelems @poll)) {
-	my($fd,$got) = splice(@poll,0,2);
-	$self->[1]->{$fd} = $got if $got;
+	my @($fd,$got) = @: splice(@poll,0,2);
+	$self->[1]->{+$fd} = $got if $got;
     }
 
     return $ret;  
@@ -102,8 +100,8 @@ sub events {
     my $fd = fileno($io);
     $io = dump::view($io);
     exists $self->[1]->{$fd} and exists $self->[0]->{$fd}->{$io} 
-                ? $self->[1]->{$fd} ^&^ ($self->[0]->{$fd}->{$io}^|^POLLHUP^|^POLLERR^|^POLLNVAL)
-	: 0;
+                ?? $self->[1]->{?$fd} ^&^ ($self->[0]->{$fd}->{?$io}^|^POLLHUP^|^POLLERR^|^POLLNVAL)
+	!! 0;
 }
 
 sub remove {
@@ -120,10 +118,10 @@ sub handles {
     my($fd,$ev,$io,$mask);
     my @handles = @( () );
 
-    while(($fd,$ev) = each %{$self->[1]}) {
-	while (($io,$mask) = each %{$self->[0]->{$fd}}) {
+    while(@($fd,$ev) =@( each %{$self->[1]})) {
+	while (@($io,$mask) =@( each %{$self->[0]->{$fd}})) {
 	    $mask ^|^= POLLHUP^|^POLLERR^|^POLLNVAL;  # must allow these
-	    push @handles,$self->[2]->{$io} if ($ev ^&^ $mask) ^&^ $events;
+	    push @handles,$self->[2]->{?$io} if ($ev ^&^ $mask) ^&^ $events;
 	}
     }
     return @handles;
