@@ -1,7 +1,6 @@
 package IO::Uncompress::Inflate ;
 # for RFC1950
-
-use strict ;
+ 
 use warnings;
 use bytes;
 
@@ -60,7 +59,7 @@ sub ckMagic
     my $magic ;
     $self->smartReadExact(\$magic, ZLIB_HEADER_SIZE);
 
-    *$self->{HeaderPending} = $magic ;
+    *$self->{+HeaderPending} = $magic ;
 
     return $self->HeaderError("Header size is " . 
                                         ZLIB_HEADER_SIZE . " bytes") 
@@ -70,7 +69,7 @@ sub ckMagic
     return undef
         if ! $self->isZlibMagic($magic) ;
                       
-    *$self->{Type} = 'rfc1950';
+    *$self->{+Type} = 'rfc1950';
     return $magic;
 }
 
@@ -88,9 +87,9 @@ sub chkTrailer
     my $trailer = shift;
 
     my $ADLER32 = unpack("N", $trailer) ;
-    *$self->{Info}->{ADLER32} = $ADLER32;    
+    *$self->{Info}->{+ADLER32} = $ADLER32;    
     return $self->TrailerError("CRC mismatch")
-        if *$self->{Strict} && $ADLER32 != *$self->{Uncomp}->adler32() ;
+        if *$self->{?Strict} && $ADLER32 != *$self->{Uncomp}->adler32() ;
 
     return STATUS_OK;
 }
@@ -110,7 +109,7 @@ sub isZlibMagic
     return $self->HeaderError("CRC mismatch.")
         if $hdr % 31 != 0 ;
 
-    my ($CMF, $FLG) = unpack "C C", $buffer;
+    my @($CMF, $FLG) =@( unpack "C C", $buffer);
     my $cm =    bits($CMF, ZLIB_CMF_CM_OFFSET,    ZLIB_CMF_CM_BITS) ;
 
     # Only Deflate supported
@@ -136,9 +135,8 @@ sub bits
 }
 
 
-sub _readDeflateHeader
-{
-    my ($self, $buffer) = < @_ ;
+sub _readDeflateHeader($self, $buffer)
+{ 
 
 #    if (! $buffer) {
 #        $self->smartReadExact(\$buffer, ZLIB_HEADER_SIZE);
@@ -153,7 +151,7 @@ sub _readDeflateHeader
 #            if ! isZlibMagic($buffer) ;
 #    }
                                         
-    my ($CMF, $FLG) = unpack "C C", $buffer;
+    my @($CMF, $FLG) =@( unpack "C C", $buffer);
     my $FDICT = bits($FLG, ZLIB_FLG_FDICT_OFFSET,  ZLIB_FLG_FDICT_BITS ),
 
     my $cm = bits($CMF, ZLIB_CMF_CM_OFFSET, ZLIB_CMF_CM_BITS) ;
@@ -168,7 +166,7 @@ sub _readDeflateHeader
         $DICTID = unpack("N", $buffer) ;
     }
 
-    *$self->{Type} = 'rfc1950';
+    *$self->{+Type} = 'rfc1950';
 
     return \%(
         'Type'          => 'rfc1950',
