@@ -6,8 +6,7 @@
 
 package List::Util;
 
-use strict;
-use vars < qw(@ISA @EXPORT_OK $VERSION $XS_VERSION $TESTING_PERL_ONLY);
+our (@ISA, @EXPORT_OK, $VERSION, $XS_VERSION, $TESTING_PERL_ONLY);
 require Exporter;
 
 @ISA        = qw(Exporter);
