@@ -2,8 +2,7 @@ package MIME::Base64;
 
 # $Id: Base64.pm,v 3.11 2005/11/29 20:59:55 gisle Exp $
 
-use strict;
-use vars < qw(@ISA @EXPORT $VERSION);
+our (@ISA, @EXPORT, $VERSION);
 
 require Exporter;
 @ISA = qw(Exporter);
