@@ -2,8 +2,7 @@ package MIME::QuotedPrint;
 
 # $Id: QuotedPrint.pm,v 3.7 2005/11/29 20:49:46 gisle Exp $
 
-use strict;
-use vars < qw(@ISA @EXPORT $VERSION);
+our (@ISA, @EXPORT, $VERSION);
 
 require Exporter;
 @ISA = qw(Exporter);
