@@ -7,6 +7,6 @@ my $d = "d " x 100;
 my $e = "e " x 100;
 my $f = "f " x 100;
 
-print < form
+print $^STDOUT, < form
 	 '{:[[[[} {:[[[[} {:[[[[} {:[[[[[[[[[} {:[[[[[[[[[} {:[[[[}',
 	 $a,	  $b,     $c,	  $a,	       $b,          $a;
