@@ -11,6 +11,6 @@ use Perl6::Form;
 $data = "You can play no part but Pyramus;\n"
 	  . "for Pyramus is a sweet-faced man;  ";
 
-print form {break=>\&break_word}, "|\{[[[[[\}|", $data;
+print form \%(break=>\&break_word), "|\{[[[[[\}|", $data;
 
 
