@@ -6,14 +6,14 @@ my @items = @( ~< *DATA );
 s/\\n/\n/g for  @items;
 s/\\r/\r/g for  @items;
 
-print < form
+print $^STDOUT, < form
 	\%(bullet=>'<>'),
 	 "<> \{:[[[[[[[[[[[[[[[[[[:\}    <> \{:[[[[[[[[[[[[[[[[[[:\}",
 		 \@items,                     \@items;
 
 my $items = join "", @items;
 
-print < form
+print $^STDOUT, < form
 	 "-----------------------",
      \%(bullet=>'<>'),
 	 "<> \{:[[[[[[[[[[[[[[[[[[:\}    <> \{:[[[[[[[[[[[[[[[[[[:\}",
