@@ -5,7 +5,7 @@ $hor_label  = "Time";
 @data = ~< *DATA;
 
 print form
-   {single=>'='},
+   \%(single=>'='),
    '     ^                                        ',
    ' = = | {""""""""""""""""""""""""""""""""""""} ', @vert_label, \@data,
    '     +--------------------------------------->',
