@@ -13,7 +13,7 @@ my %page = %(
 	feed   => ('_'x72)."\n",
 );
 
-print < form \%(page=>\%page),
+print $^STDOUT, < form \%(page=>\%page),
 	 '{]]]]]}  {"{*}"}  {[[[[[}',
 	 \1..nelems @text, \@text,  \1..nelems @text;
 
