@@ -12,13 +12,13 @@ print < form \%( ws=>qr/\s/, page=>\%(header=>"Report",
            "= [\{[[[[[[[[[[[[[[[[[[[[]]]]]]]]]]\}]",
 		   \@( ~< *DATA),
            "= [\{[[[[[[[[[[[[[[[[[[[[]]]]]]]]]]\}]",
-		   \@(1..100),
+		   \1..100,
 		   \%(page=>\%(length => 12, number=>100)),
            "= [\{[[[[[[[[[[[[[[[[[[[[]]]]]]]]]]\}]",
-		   \@(101..200),
+		   \101..200,
 		   \%(page=>\%()),
            "= [\{[[[[[[[[[[[[[[[[[[[[]]]]]]]]]]\}]",
-		   \@(201..280),
+		   \201..280,
 
 
 __DATA__
