@@ -5,7 +5,7 @@ $x = "the    firstest    field    is    here and         there";
 $y = "     the second field is here";
 @z = qw(heyah hey heyah hey heyah hey);
 
-print form \%(out=>\*STDERR, single=>"=", ws=>qr/[^\S\n]+/,
+print form \%(out=>$^STDERR, single=>"=", ws=>qr/[^\S\n]+/,
 	  # layout=>'across'
 	 ),
       "= hi [\{:[[[[:\}] there [\{:>>\}] you \{:III:\}\{]][[\} -> \{]]].[[\}",
