@@ -1,14 +1,14 @@
 use Perl6::Form;
 
-print < form \%(single=>'^'),\%(single=>'='),\%(single=>'_'),
+print $^STDOUT, < form \%(single=>'^'),\%(single=>'='),\%(single=>'_'),
 		   '~~~~~~~~~',
 		   '^ _ = _ ^', <
 		   qw(Like round and orient perls),
 		   '~~~~~~~~~';
 
-print "\n--------------------------\n\n";
+print $^STDOUT, "\n--------------------------\n\n";
 
-print < form \%(single=>'='),
+print $^STDOUT, < form \%(single=>'='),
            '   ^',
            ' = | {""""""""""""""""""""""""""""""""""""}',
 			 "Height",
