@@ -14,14 +14,14 @@ EOTEXT
 
 # Default (no squeezing)...
 
-print < form
+print $^STDOUT, < form
 	 "| \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\} |",
 	    $eulogy, "","";
 
 
 # Squeeze all whitespace...
 
-print < form
+print $^STDOUT, < form
 	 \%(ws=>qr/\s+/),
      "| \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\} |",
 	    $eulogy, "","";
@@ -29,14 +29,14 @@ print < form
 
 # Squeeze all whitespace except newlines...
 
-print < form
+print $^STDOUT, < form
 	 \%(ws=>qr/[^\S\n]+/),
      "| \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\} |",
 	    $eulogy, "","";
 
 # Squeeze even harder before punctuation
 
-print < form
+print $^STDOUT, < form
 	 \%(ws=>qr/[^\S\n]+ ([,.!])?/x),
      "| \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\} |",
 	    $eulogy, "","";
@@ -44,7 +44,7 @@ print < form
 
 # Form is smart enough not to squeeze zero-width matches...
 
-print < form
+print $^STDOUT, < form
 	 \%(ws=>qr/\s*/),
      "| \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\} |",
 	    $eulogy, "","";
