@@ -1,7 +1,6 @@
 package Time::HiRes;
 
-use strict;
-use vars < qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
+our ($VERSION, $XS_VERSION, @ISA, @EXPORT, @EXPORT_OK);
 
 require Exporter;
 require DynaLoader;
@@ -29,13 +28,13 @@ $XS_VERSION = $VERSION;
 sub import {
     my $this = shift;
     for my $i (@_) {
-	if (($i eq 'clock_getres'    && !&d_clock_getres)    ||
-	    ($i eq 'clock_gettime'   && !&d_clock_gettime)   ||
-	    ($i eq 'clock_nanosleep' && !&d_clock_nanosleep) ||
-	    ($i eq 'clock'           && !&d_clock)           ||
-	    ($i eq 'nanosleep'       && !&d_nanosleep)       ||
-	    ($i eq 'usleep'          && !&d_usleep)          ||
-	    ($i eq 'ualarm'          && !&d_ualarm)) {
+	if (($i eq 'clock_getres'    && !&d_clock_getres( < @_ ))    ||
+	    ($i eq 'clock_gettime'   && !&d_clock_gettime( < @_ ))   ||
+	    ($i eq 'clock_nanosleep' && !&d_clock_nanosleep( < @_ )) ||
+	    ($i eq 'clock'           && !&d_clock( < @_ ))           ||
+	    ($i eq 'nanosleep'       && !&d_nanosleep( < @_ ))       ||
+	    ($i eq 'usleep'          && !&d_usleep( < @_ ))          ||
+	    ($i eq 'ualarm'          && !&d_ualarm( < @_ ))) {
 	    require Carp;
 	    Carp::croak("Time::HiRes::$i(): unimplemented in this platform");
 	}
@@ -47,9 +46,7 @@ Time::HiRes->bootstrap();
 
 # Preloaded methods go here.
 
-sub tv_interval {
-    # probably could have been done in C
-    my ($a, $b) = < @_;
+sub tv_interval($a, ?$b) {
     $b = \@( < gettimeofday() ) unless defined($b);
     (@{$b}[0] - @{$a}[0]) + ((@{$b}[1] - @{$a}[1]) / 1_000_000);
 }
