@@ -34,7 +34,7 @@ to the test script.
 use base < qw/ DynaLoader Exporter /;
 
 
-use vars < qw/ $VERSION @EXPORT /;
+our ($VERSION, @EXPORT);
 
 $VERSION = '0.02';
 
@@ -63,9 +63,8 @@ $VERSION = '0.02';
 	   T_PV
 	   T_PTR_IN T_PTR_OUT
 	   T_PTRREF_IN T_PTRREF_OUT
-	   T_REF_IV_REF
-	   T_REF_IV_PTR_IN T_REF_IV_PTR_OUT
-	   T_PTROBJ_IN T_PTROBJ_OUT
+	   T_REF_IV_PTR_OUT
+	   T_PTROBJ_OUT
 	   T_OPAQUE_IN T_OPAQUE_OUT T_OPAQUE_array
 	   T_OPAQUEPTR_IN T_OPAQUEPTR_OUT T_OPAQUEPTR_OUT_short
            T_OPAQUEPTR_IN_struct T_OPAQUEPTR_OUT_struct
