@@ -6,15 +6,15 @@ our $count;
 
 m/foo/ and $count++;
 
-{
+do {
     no re 'debug';
     m/bar/ and $count++;
-    {
+    do {
         use re 'debug';
         m/baz/ and $count++;
-    }
+    };
     m/bop/ and $count++;
-}
+};
 
 m/fip/ and $count++;
 
@@ -26,6 +26,6 @@ use re 'debug';
 my $var='zoo|liz|zap';
 m/($var)/ or $count++;
 
-print "Count=$count\n";
+print $^STDOUT, "Count=$count\n";
 
 
