@@ -1,7 +1,6 @@
 # Carp::Heavy uses some variables in common with Carp.
 package Carp;
 
-use strict;
 
 =head1 NAME
 
@@ -29,10 +28,10 @@ use Carp;  our $VERSION = $Carp::VERSION;
 our (%CarpInternal, %Internal);
 
 # disable these by default, so they can live w/o require Carp
-%CarpInternal{Carp}++;
-%CarpInternal{warnings}++;
-%Internal{Exporter}++;
-%Internal{'Exporter::Heavy'}++;
+%CarpInternal{+Carp}++;
+%CarpInternal{+warnings}++;
+%Internal{+Exporter}++;
+%Internal{+'Exporter::Heavy'}++;
 
 
 our ($CarpLevel, $MaxArgNums, $MaxEvalLen, $MaxArgLen, $Verbose);
@@ -48,7 +47,7 @@ sub  longmess_real {
     # by one.  Other code began calling longmess and expecting this
     # behaviour, so the replacement has to emulate that behaviour.
     my $call_pack = caller();
-    if (%Internal{$call_pack} or %CarpInternal{$call_pack}) {
+    if (%Internal{?$call_pack} or %CarpInternal{?$call_pack}) {
       return longmess_heavy(< @_);
     }
     else {
@@ -69,17 +68,17 @@ sub caller_info {
   my $i = shift(@_) + 1;
   package DB;
   my %call_info;
- <  %call_info{[
+   %call_info{[
     qw(pack file line sub has_args wantarray evaltext is_require)
-  ]} = caller($i);
+  ]} = @: caller($i);
   
-  unless (defined %call_info{pack}) {
+  unless (defined %call_info{?pack}) {
     return ();
   }
 
   my $sub_name = Carp::get_subname(\%call_info);
-  if (%call_info{has_args}) {
-    my @args = map { Carp::format_arg($_)} @DB::args;
+  if (%call_info{?has_args}) {
+    my @args = map { Carp::format_arg($_)}, @DB::args;
     if ($MaxArgNums and (nelems @args) +> $MaxArgNums) { # More than we want to show?
       splice @args, $MaxArgNums;
       push @args, '...';
@@ -87,7 +86,7 @@ sub caller_info {
     # Push the args onto the subroutine
     $sub_name .= '(' . join (', ', @args) . ')';
   }
-  %call_info{sub_name} = $sub_name;
+  %call_info{+sub_name} = $sub_name;
   return %call_info;
 }
 
@@ -108,17 +107,17 @@ sub format_arg {
 sub get_status {
     my $cache = shift;
     my $pkg = shift;
-    $cache->{$pkg} ||= \@(\%($pkg => $pkg), \trusts_directly($pkg));
-    return @{$cache->{$pkg}};
+    $cache->{+$pkg} ||= \@(\%($pkg => $pkg), \trusts_directly($pkg));
+    return @{$cache->{?$pkg}};
 }
 
 # Takes the info from caller() and figures out the name of
 # the sub/require/eval
 sub get_subname {
   my $info = shift;
-  if (defined($info->{evaltext})) {
-    my $eval = $info->{evaltext};
-    if ($info->{is_require}) {
+  if (defined($info->{?evaltext})) {
+    my $eval = $info->{?evaltext};
+    if ($info->{?is_require}) {
       return "require $eval";
     }
     else {
@@ -127,7 +126,7 @@ sub get_subname {
     }
   }
 
-  return ($info->{sub} eq '(eval)') ? 'try {...}' : $info->{sub};
+  return (($info->{?sub}||'') eq '(eval)') ?? 'try {...}' !! $info->{?sub};
 }
 
 # Figures out what call (from the point of view of the caller)
@@ -135,7 +134,7 @@ sub get_subname {
 sub long_error_loc {
   my $i;
   my $lvl = $CarpLevel;
-  {
+  do {
     my $pkg = caller(++$i);
     unless(defined($pkg)) {
       # This *shouldn't* happen.
@@ -149,10 +148,10 @@ sub long_error_loc {
         return 2;
       }
     }
-    redo if %CarpInternal{$pkg};
+    redo if %CarpInternal{?$pkg};
     redo unless 0 +> --$lvl;
-    redo if %Internal{$pkg};
-  }
+    redo if %Internal{?$pkg};
+  };
   return $i - 1;
 }
 
@@ -165,8 +164,7 @@ sub longmess_heavy {
 
 # Returns a full stack backtrace starting from where it is
 # told.
-sub ret_backtrace {
-  my ($i, < @error) = < @_;
+sub ret_backtrace($i, @< @error) {
   my $mess;
   my $err = join '', @error;
   $i++;
@@ -178,17 +176,16 @@ sub ret_backtrace {
   }
 
   my %i = %( < caller_info($i) );
-  $mess = "$err at %i{file} line %i{line}$tid_msg\n";
+  $mess = "$err at %i{?file} line %i{?line}$tid_msg\n";
 
   while (my %i = %( < caller_info(++$i) )) {
-      $mess .= "\t%i{sub_name} called at %i{file} line %i{line}$tid_msg\n";
+      $mess .= "\t$(%i{?sub_name}//'(unnamed sub)') called at %i{?file} line %i{?line}$tid_msg\n";
   }
   
   return $mess;
 }
 
-sub ret_summary {
-  my ($i, < @error) = < @_;
+sub ret_summary($i, @< @error) {
   my $err = join '', @error;
   $i++;
 
@@ -199,7 +196,7 @@ sub ret_summary {
   }
 
   my %i = %( < caller_info($i) );
-  return "$err at %i{file} line %i{line}$tid_msg\n";
+  return "$err at %i{?file} line %i{?line}$tid_msg\n";
 }
 
 
@@ -210,18 +207,18 @@ sub short_error_loc {
   my $cache = \%();
   my $i = 1;
   my $lvl = $CarpLevel;
-  {
+  do {
     my $called = caller($i++);
     my $caller = caller($i);
 
     return 0 unless defined($caller); # What happened?
-    redo if %Internal{$caller};
-    redo if %CarpInternal{$caller};
-    redo if %CarpInternal{$called};
+    redo if %Internal{?$caller};
+    redo if %CarpInternal{?$caller};
+    redo if %CarpInternal{?$called};
     redo if trusts($called, $caller, $cache);
     redo if trusts($caller, $called, $cache);
     redo unless 0 +> --$lvl;
-  }
+  };
   return $i - 1;
 }
 
@@ -258,15 +255,15 @@ sub trusts {
     my $child = shift;
     my $parent = shift;
     my $cache = shift;
-    my ($known, $partial) = < get_status($cache, $child);
+    my @($known, $partial) =  get_status($cache, $child);
     # Figure out consequences until we have an answer
     while ((nelems @$partial) and not exists $known->{$parent}) {
         my $anc = shift @$partial;
         next if exists $known->{$anc};
-        $known->{$anc}++;
-        my ($anc_knows, $anc_partial) = < get_status($cache, $anc);
+        $known->{+$anc}++;
+        my @($anc_knows, $anc_partial) =  get_status($cache, $anc);
         my @found = keys %$anc_knows;
- <        %$known{[ @found]} = ();
+         %$known{[ @found]} = @();
         push @$partial, < @$anc_partial;
     }
     return exists $known->{$parent};
@@ -275,11 +272,10 @@ sub trusts {
 # Takes a package and gives a list of those trusted directly
 sub trusts_directly {
     my $class = shift;
-    no strict 'refs';
     no warnings 'once'; 
     return (nelems @{*{Symbol::fetch_glob("$class\::CARP_NOT")}})
-      ? @{*{Symbol::fetch_glob("$class\::CARP_NOT")}}
-      : @{*{Symbol::fetch_glob("$class\::ISA")}};
+      ?? @{*{Symbol::fetch_glob("$class\::CARP_NOT")}}
+      !! @{*{Symbol::fetch_glob("$class\::ISA")}};
 }
 
 1;
