@@ -1,5 +1,5 @@
 package ExtUtils::Constant;
-use vars < qw (@ISA $VERSION @EXPORT_OK %EXPORT_TAGS);
+our (@ISA, $VERSION, @EXPORT_OK, %EXPORT_TAGS);
 $VERSION = 0.20;
 
 =head1 NAME
@@ -91,7 +91,7 @@ C<undef>.  The value of the macro is not needed.
 =cut
 
 use warnings;
-use strict;
+
 
 use Exporter;
 use ExtUtils::Constant::Utils < qw(C_stringify);
@@ -104,7 +104,7 @@ use ExtUtils::Constant::XS < qw(%XS_Constant %XS_TypeSet);
 	C_constant WriteConstants WriteMakefileSnippet
 ) );
 
-@EXPORT_OK = @{ %EXPORT_TAGS{'all'} };
+@EXPORT_OK = @{ %EXPORT_TAGS{?'all'} };
 
 =item constant_types
 
@@ -117,9 +117,7 @@ sub constant_types {
   ExtUtils::Constant::XS->header();
 }
 
-sub C_constant {
-  my ($package, $subname, $default_type, $what, $indent, $breakout, < @items)
-    = < @_;
+sub C_constant($package, $subname, $default_type, $what, $indent, $breakout, @< @items) {
   ExtUtils::Constant::XS->C_constant(\%(package => $package, subname => $subname,
                                         default_type => $default_type,
                                         types => $what, indent => $indent,
@@ -156,10 +154,9 @@ sub XS_constant {
 
   if (!ref $what) {
     # Convert line of the form IV,UV,NV to hash
-    $what = \%( < map {$_ => 1} split m/,\s*/, ($what) );
+    $what = \%( < @+: map { @: $_ => 1}, split m/,\s*/, ($what) );
   }
   my $params = ExtUtils::Constant::XS->params ($what);
-  my $type;
 
   my $xs = <<"EOT";
 void
@@ -174,17 +171,17 @@ $subname(sv)
         int		type;
 EOT
 
-  if ($params->{IV}) {
+  if ($params->{?IV}) {
     $xs .= "	IV		iv;\n";
   } else {
     $xs .= "	/* IV\t\tiv;\tUncomment this if you need to return IVs */\n";
   }
-  if ($params->{NV}) {
+  if ($params->{?NV}) {
     $xs .= "	NV		nv;\n";
   } else {
     $xs .= "	/* NV\t\tnv;\tUncomment this if you need to return NVs */\n";
   }
-  if ($params->{PV}) {
+  if ($params->{?PV}) {
     $xs .= "	const char	*pv;\n";
   } else {
     $xs .=
@@ -200,17 +197,17 @@ EOT
     PPCODE:
 EOT
 
-  if ($params->{IV} xor $params->{NV}) {
+  if ($params->{?IV} xor $params->{?NV}) {
     $xs .= << "EOT";
         /* Change this to $C_subname(aTHX_ s, len, &iv, &nv);
            if you need to return both NVs and IVs */
 EOT
   }
   $xs .= "	type = $C_subname(aTHX_ s, len";
-  $xs .= ', &iv' if $params->{IV};
-  $xs .= ', &nv' if $params->{NV};
-  $xs .= ', &pv' if $params->{PV};
-  $xs .= ', &sv' if $params->{SV};
+  $xs .= ', &iv' if $params->{?IV};
+  $xs .= ', &nv' if $params->{?NV};
+  $xs .= ', &pv' if $params->{?PV};
+  $xs .= ', &sv' if $params->{?SV};
   $xs .= ");\n";
 
   # If anyone is insane enough to suggest a package name containing %
@@ -234,24 +231,24 @@ EOT
           break;
 EOT
 
-  foreach $type (sort keys %XS_Constant) {
+  foreach my $type (sort keys %XS_Constant) {
     # '' marks utf8 flag needed.
     next if $type eq '';
-    $xs .= "\t/* Uncomment this if you need to return {$type}s\n"
-      unless $what->{$type};
+    $xs .= "\t/* Uncomment this if you need to return $($type)s\n"
+      unless $what->{?$type};
     $xs .= "        case PERL_constant_IS$type:\n";
-    if (length %XS_Constant{$type}) {
+    if (length %XS_Constant{?$type}) {
       $xs .= << "EOT";
           EXTEND(SP, 1);
           PUSHs(&PL_sv_undef);
-          %XS_Constant{$type};
+          %XS_Constant{?$type};
 EOT
     } else {
       # Do nothing. return (), which will be correctly interpreted as
       # (undef, undef)
     }
     $xs .= "          break;\n";
-    unless ($what->{$type}) {
+    unless ($what->{?$type}) {
       chop $xs; # Yes, another need for chop not chomp.
       $xs .= " */\n";
     }
@@ -284,26 +281,26 @@ C<XS_FILE> are recognised.
 
 sub WriteMakefileSnippet {
   my %args = %( < @_ );
-  my $indent = %args{INDENT} || 2;
+  my $indent = %args{?INDENT} || 2;
 
   my $result = <<"EOT";
 ExtUtils::Constant::WriteConstants(
-                                   NAME         => '%args{NAME}',
+                                   NAME         => '%args{?NAME}',
                                    NAMES        => \\\@names,
-                                   DEFAULT_TYPE => '%args{DEFAULT_TYPE}',
+                                   DEFAULT_TYPE => '%args{?DEFAULT_TYPE}',
                                    PROXYSUBS    => 1,
 EOT
   foreach (qw (C_FILE XS_FILE)) {
     next unless exists %args{$_};
     $result .= sprintf "                                   \%-12s => '\%s',\n",
-      $_, %args{$_};
+      $_, %args{?$_};
   }
   $result .= <<'EOT';
                                 );
 EOT
 
-  $result =~ s/^/{' 'x$indent}/gm;
-  return ExtUtils::Constant::XS->dump_names(\%(default_type=>%args{DEFAULT_TYPE},
+  $result =~ s/^/$(' 'x$indent)/gm;
+  return ExtUtils::Constant::XS->dump_names(\%(default_type=>%args{?DEFAULT_TYPE},
                                                indent=>$indent,),
 					    < @{%args{NAMES}})
     . $result;
@@ -385,35 +382,35 @@ sub WriteConstants {
      DEFAULT_TYPE => 'IV',
      < @_);
 
-  %ARGS{C_SUBNAME} ||= %ARGS{SUBNAME}; # No-one sane will have C_SUBNAME eq '0'
+  %ARGS{+C_SUBNAME} ||= %ARGS{?SUBNAME}; # No-one sane will have C_SUBNAME eq '0'
 
-  die "Module name not specified" unless length %ARGS{NAME};
+  die "Module name not specified" unless length %ARGS{?NAME};
 
-  my $c_fh = %ARGS{C_FH};
+  my $c_fh = %ARGS{?C_FH};
   if (!$c_fh) {
-      open $c_fh, ">", "%ARGS{C_FILE}" or die "Can't open %ARGS{C_FILE}: $!";
+      open $c_fh, ">", "%ARGS{?C_FILE}" or die "Can't open %ARGS{?C_FILE}: $^OS_ERROR";
   }
 
-  my $xs_fh = %ARGS{XS_FH};
+  my $xs_fh = %ARGS{?XS_FH};
   if (!$xs_fh) {
-      open $xs_fh, ">", "%ARGS{XS_FILE}" or die "Can't open %ARGS{XS_FILE}: $!";
+      open $xs_fh, ">", "%ARGS{?XS_FILE}" or die "Can't open %ARGS{?XS_FILE}: $^OS_ERROR";
   }
 
   # As this subroutine is intended to make code that isn't edited, there's no
   # need for the user to specify any types that aren't found in the list of
   # names.
   
-  if (%ARGS{PROXYSUBS}) {
+  if (%ARGS{?PROXYSUBS}) {
       require ExtUtils::Constant::ProxySubs;
-      %ARGS{C_FH} = $c_fh;
-      %ARGS{XS_FH} = $xs_fh;
+      %ARGS{+C_FH} = $c_fh;
+      %ARGS{+XS_FH} = $xs_fh;
       ExtUtils::Constant::ProxySubs->WriteConstants(< %ARGS);
   } else {
       die "Ony ProxySubs are supported";
   }
 
-  close $c_fh or warn "Error closing %ARGS{C_FILE}: $!" unless %ARGS{C_FH};
-  close $xs_fh or warn "Error closing %ARGS{XS_FILE}: $!" unless %ARGS{XS_FH};
+  close $c_fh or warn "Error closing %ARGS{?C_FILE}: $^OS_ERROR" unless %ARGS{?C_FH};
+  close $xs_fh or warn "Error closing %ARGS{?XS_FILE}: $^OS_ERROR" unless %ARGS{?XS_FH};
 }
 
 1;
