@@ -1,7 +1,6 @@
 package ExtUtils::Constant::Base;
 
-use strict;
-use vars < qw($VERSION);
+our ($VERSION);
 use Text::Wrap;
 use ExtUtils::Constant::Utils < qw(C_stringify perl_stringify);
 $VERSION = '0.04';
@@ -65,19 +64,17 @@ sub macro_from_item {
   1;
 }
 
-sub macro_to_ifdef {
-    my ($self, $macro) = < @_;
+sub macro_to_ifdef($self, $macro) {
     if (ref $macro) {
 	return $macro->[0];
     }
     if (defined $macro && $macro ne "" && $macro ne "1") {
-	return $macro ? "#ifdef $macro\n" : "#if 0\n";
+	return $macro ?? "#ifdef $macro\n" !! "#if 0\n";
     }
     return "";
 }
 
-sub macro_to_endif {
-    my ($self, $macro) = < @_;
+sub macro_to_endif($self, $macro) {
 
     if (ref $macro) {
 	return $macro->[1];
@@ -110,11 +107,8 @@ the front of I<name>).
 
 =cut
 
-sub memEQ_clause {
-#    if (memEQ(name, "thingy", 6)) {
-  # Which could actually be a character comparison or even ""
-  my ($self, $args) = < @_;
-  my ($name, $checked_at, $indent) = < %{$args}{[qw(name checked_at indent)]};
+sub memEQ_clause($self, $args) {
+  my @($name, $checked_at, $indent) =  %{$args}{[qw(name checked_at indent)]};
   $indent = ' ' x ($indent || 4);
   my $front_chop;
   if (ref $checked_at) {
@@ -202,10 +196,9 @@ I<default_types> and the I<ITEM>s.
 
 =cut
 
-sub dump_names {
-  my ($self, $args, < @items) = < @_;
-  my ($default_type, $what, $indent, $declare_types)
-    = < %{$args}{[qw(default_type what indent declare_types)]};
+sub dump_names($self, $args, @< @items) {
+  my @($default_type, $what, $indent, $declare_types)
+    =  %{$args}{[qw(default_type what indent declare_types)]};
   $indent = ' ' x ($indent || 0);
 
   my $result;
@@ -213,22 +206,22 @@ sub dump_names {
   foreach ( @items) {
     my $type;
     if (ref $_) {
-      $type = $_->{type} || $default_type;
-      die "No more utf8 flag" if ($_->{utf8});
+      $type = $_->{?type} || $default_type;
+      die "No more utf8 flag" if ($_->{?utf8});
     } else {
       $_ = \%(name=>$_);
       $type = $default_type;
     }
-    %used_types{$type}++;
+    %used_types{+$type}++;
     if ($type eq $default_type
-        and length $_->{name}
-        and ($_->{name} =~ m/^\w+$/)
-        and !defined ($_->{macro}) and !defined ($_->{value})
-        and !defined ($_->{default}) and !defined ($_->{pre})
-        and !defined ($_->{post}) and !defined ($_->{def_pre})
-        and !defined ($_->{def_post}) and !defined ($_->{weight})) {
+        and length $_->{?name}
+        and ($_->{?name} =~ m/^\w+$/)
+        and !defined ($_->{?macro}) and !defined ($_->{?value})
+        and !defined ($_->{?default}) and !defined ($_->{?pre})
+        and !defined ($_->{?post}) and !defined ($_->{?def_pre})
+        and !defined ($_->{?def_post}) and !defined ($_->{?weight})) {
       # It's the default type, and the name consists only of A-Za-z0-9_
-      push @simple, $_->{name};
+      push @simple, $_->{?name};
     } else {
       push @complex, $_;
     }
@@ -237,7 +230,7 @@ sub dump_names {
   if (!defined $declare_types) {
     # Do they pass in any types we weren't already using?
     foreach (keys %$what) {
-      next if %used_types{$_};
+      next if %used_types{?$_};
       $declare_types++; # Found one in $what that wasn't used.
       last; # And one is enough to terminate this loop
     }
@@ -251,16 +244,16 @@ sub dump_names {
   $result .= wrap ($indent . "my \@names = (qw(",
 		   $indent . "               ", join (" ", sort @simple) . ")");
   if ((nelems @complex)) {
-    foreach my $item (sort {$a->{name} cmp $b->{name}} @complex) {
-      my $name = perl_stringify $item->{name};
+    foreach my $item (sort {$a->{?name} cmp $b->{?name}}, @complex) {
+      my $name = perl_stringify $item->{?name};
       my $line = ",\n$indent            \{name=>\"$name\"";
-      $line .= ", type=>\"$item->{type}\"" if defined $item->{type};
+      $line .= ", type=>\"$item->{?type}\"" if defined $item->{?type};
       foreach my $thing (qw (macro value default pre post def_pre def_post)) {
-        my $value = $item->{$thing};
+        my $value = $item->{?$thing};
         if (defined $value) {
           if (ref $value) {
             $line .= ", $thing=>[\""
-              . join ('", "', map { <perl_stringify $_} @$value) . '"]';
+              . join ('", "', map { <perl_stringify $_}, @$value) . '"]';
           } else {
             $line .= ", $thing=>\"" . perl_stringify($value) . "\"";
           }
@@ -294,8 +287,8 @@ of a block, so variables may be defined in it.
 sub assign {
   my $self = shift;
   my $args = shift;
-  my ($indent, $type, $pre, $post, $item)
-      = < %{$args}{[qw(indent type pre post item)]};
+  my @($indent, $type, $pre, $post, $item)
+      =  %{$args}{[qw(indent type pre post item)]};
   $post ||= '';
   my $clause;
   my $close;
@@ -312,7 +305,7 @@ sub assign {
   die "Can't generate code for type $type"
     unless $self->valid_type($type);
 
-  $clause .= join '', map {"$indent$_\n"}
+  $clause .= join '', map {"$indent$_\n"},
  @(    $self->assignment_clause_for_type(\%(type=>$type,item=>$item), < @_));
   chomp $post;
   if (length $post) {
@@ -334,19 +327,11 @@ of spaces to indent, defaulting to 6.
 
 =cut
 
-sub return_clause {
+sub return_clause($self, $args, $item) {
+  my $indent = $args->{?indent};
 
-##ifdef thingy
-#      *iv_return = thingy;
-#      return PERL_constant_ISIV;
-##else
-#      return PERL_constant_NOTDEF;
-##endif
-  my ($self, $args, $item) = < @_;
-  my $indent = $args->{indent};
-
-  my ($name, $value, $default, $pre, $post, $def_pre, $def_post, $type)
-    = < %$item{[qw (name value default pre post def_pre def_post type)]};
+  my @($name, $value, $default, $pre, $post, $def_pre, $def_post, $type)
+    =  %$item{[qw (name value default pre post def_pre def_post type)]};
   $value = $name unless defined $value;
   my $macro = $self->macro_from_item($item);
   $indent = ' ' x ($indent || 6);
@@ -362,7 +347,7 @@ sub return_clause {
   #      return PERL_constant_ISIV;
   $clause
     .= $self->assign (\%(indent=>$indent, type=>$type, pre=>$pre, post=>$post,
-		       item=>$item), ref $value ? < @$value : $value);
+		       item=>$item), ref $value ?? < @$value !! $value);
 
   if (defined $macro && $macro ne "" && $macro ne "1") {
     ##else
@@ -373,7 +358,7 @@ sub return_clause {
       my $notdef = $self->return_statement_for_notdef();
       $clause .= "$indent$notdef\n" if defined $notdef;
     } else {
-      my @default = @( ref $default ? < @$default : $default );
+      my @default = @( ref $default ?? < @$default !! $default );
       $type = shift @default;
       $clause .= $self->assign (\%(indent=>$indent, type=>$type, pre=>$pre,
 				 post=>$post, item=>$item), < @default);
@@ -385,17 +370,15 @@ sub return_clause {
   return $clause;
 }
 
-sub match_clause {
-  # $offset defined if we have checked an offset.
-  my ($self, $args, $item) = < @_;
-  my ($offset, $indent) = < %{$args}{[qw(checked_at indent)]};
+sub match_clause($self, $args, $item) {
+  my @($offset, $indent) =  %{$args}{[qw(checked_at indent)]};
   $indent = ' ' x ($indent || 4);
   my $body = '';
   my ($no, $yes, $either, $name, $inner_indent);
   if (ref $item eq 'ARRAY') {
-      die("utf8 removed '$item->[0]->{name}' - '$item->[1]->{name}'");
+      die("utf8 removed '$item->[0]->{?name}' - '$item->[1]->{?name}'");
   } else {
-    $name = $item->{name};
+    $name = $item->{?name};
     $inner_indent = $indent;
   }
 
@@ -431,15 +414,14 @@ each call).
 
 =cut
 
-sub switch_clause {
-  my ($self, $args, $namelen, $items, < @items) = < @_;
-  my ($indent, $comment) = < %{$args}{[qw(indent comment)]};
+sub switch_clause($self, $args, $namelen, $items, @< @items) {
+  my @($indent, $comment) =  %{$args}{[qw(indent comment)]};
   $indent = ' ' x ($indent || 2);
 
   local $Text::Wrap::huge = 'overflow';
   local $Text::Wrap::columns = 80;
 
-  my @names = sort map {$_->{name}} @items;
+  my @names = sort map {$_->{?name}}, @items;
   my $leader = $indent . '/* ';
   my $follower = ' ' x length $leader;
   my $body = $indent . "/* Names all of length $namelen.  */\n";
@@ -466,7 +448,7 @@ sub switch_clause {
   # Prefer the last character over the others. (As it lets us shorten the
   # memEQ clause at no cost).
   foreach my $i (@($namelen - 1, < 0 .. ($namelen - 2))) {
-    my ($min, $max) = (^~^0, 0);
+    my @($min, $max) = @(^~^0, 0);
     my %spread;
     foreach ( @names) {
       my $char = substr $_, $i, 1;
@@ -498,10 +480,10 @@ sub switch_clause {
       @best = @($rms, $max - $min, $i, \%spread);
     }
   }
-  die "Internal error. Failed to pick a switch point for {join ' ',@names}"
+  die "Internal error. Failed to pick a switch point for $(join ' ',@names)"
     unless defined @best[2];
   # use Data::Dumper; print Dumper (@best);
-  my ($offset, $best) = < @best[[@(2,3)]];
+  my @($offset, $best) =  @best[[@(2,3)]];
   $body .= $indent . "/* Offset $offset gives the best switch position.  */\n";
 
   my $do_front_chop = $offset == 0 && $namelen +> 2;
@@ -518,15 +500,15 @@ sub switch_clause {
     foreach my $thisone (sort {
 	# Deal with the case of an item actually being an array ref to 1 or 2
 	# hashrefs. Don't assign to $a or $b, as they're aliases to the orignal
-	my $l = ref $a eq 'ARRAY' ? ($a->[0]) : $a;
-	my $r = ref $b eq 'ARRAY' ? ($b->[0]) : $b;
+	my $l = ref $a eq 'ARRAY' ?? ($a->[0]) !! $a;
+	my $r = ref $b eq 'ARRAY' ?? ($b->[0]) !! $b;
 	# Sort by weight first
-	($r->{weight} || 0) <+> ($l->{weight} || 0)
+	($r->{?weight} || 0) <+> ($l->{?weight} || 0)
 	    # Sort equal weights by name
-	    or $l->{name} cmp $r->{name}}
+	    or $l->{?name} cmp $r->{?name}},
 			 # If this looks evil, maybe it is.  $items is a
 			 # hashref, and we're doing a hash slice on it
-			 %{$items}{[ @{$best->{$char}}]}) {
+			 %{$items}{[ @{$best->{?$char}}]}) {
       # warn "You are here";
       if ($do_front_chop) {
         $body .= $self->match_clause (\%(indent => 2 + length $indent,
@@ -624,32 +606,32 @@ sub normalise_items
 	my ($name, $item);
         if (ref $orig) {
             # Make a copy which is a normalised version of the ref passed in.
-            $name = $orig->{name};
-            my ($type, $macro, $value) = < %$orig{[qw (type macro value)]};
+            $name = $orig->{?name};
+            my @($type, $macro, $value) =  %$orig{[qw (type macro value)]};
             $type ||= $default_type;
-            $what->{$type} = 1;
+            $what->{+$type} = 1;
             $item = \%(name=>$name, type=>$type);
-            $item->{macro} = $macro if defined $macro and (ref $macro or $macro ne $name);
-            $item->{value} = $value if defined $value and (ref $value or $value ne $name);
+            $item->{+macro} = $macro if defined $macro and (ref $macro or $macro ne $name);
+            $item->{+value} = $value if defined $value and (ref $value or $value ne $name);
             foreach my $key (qw(default pre post def_pre def_post weight
                                 not_constant)) {
-                my $value = $orig->{$key};
-                $item->{$key} = $value if defined $value;
+                my $value = $orig->{?$key};
+                $item->{+$key} = $value if defined $value;
                 # warn "$key $value";
             }
         } else {
             $name = $orig;
             $item = \%(name=>$name, type=>$default_type);
-            $what->{$default_type} = 1;
+            $what->{+$default_type} = 1;
         }
-        warn +(ref ($self) || $self)
-          . "doesn't know how to handle values of type $_ used in macro $name"
+        warn( (ref ($self) || $self)
+          . "doesn't know how to handle values of type $_ used in macro $name")
             unless $self->valid_type ($item->{type});
 
-        $item->{name} = $name;
-        $items->{$name} = $item;
+        $item->{+name} = $name;
+        $items->{+$name} = $item;
         # We have need for the utf8 flag.
-        $what->{''} = 1;
+        $what->{+''} = 1;
 
       push @new_items, $item;
     }
@@ -766,9 +748,8 @@ example C<constant_5> for names 5 characters long.  The default I<breakout> is
 # As you can see it now performs this function during recursion by being a
 # scalar reference.
 
-sub C_constant {
-  my ($self, $args, < @items) = < @_;
-  my ($package, $subname, $default_type, $what, $indent, $breakout) = <
+sub C_constant($self, $args, @< @items) {
+  my @($package, $subname, $default_type, $what, $indent, $breakout) = 
     %{$args}{[qw(package subname default_type types indent breakout)]};
   $package ||= 'Foo';
   $subname ||= 'constant';
@@ -780,14 +761,14 @@ sub C_constant {
   if (ref $breakout) {
     # We are called recursively. We trust @items to be normalised, $what to
     # be a hashref, and pinch %$items from our parent to save recalculation.
-    ($namelen, $items) = < @$breakout;
+    @($namelen, $items) =  @$breakout;
   } else {
     $items = \%();
     $breakout ||= 3;
     $default_type ||= $self->default_type();
     if (!ref $what) {
       # Convert line of the form IV,UV,NV to hash
-      $what = \%(< map {$_ => 1} split m/,\s*/, ($what || ''));
+      $what = \%(< @+: map {@: $_ => 1}, split m/,\s*/, ($what || ''));
       # Figure out what types we're dealing with, and assign all unknowns to the
       # default type
     }
@@ -827,15 +808,15 @@ sub C_constant {
     # Need to group names of the same length
     my @by_length;
     foreach ( @items) {
-      push @{@by_length[length $_->{name}]}, $_;
+      push @{@by_length[+ length $_->{?name}]}, $_;
     }
     foreach my $i (0 .. ((nelems @by_length)-1)) {
       next unless @by_length[$i];	# None of this length
       $body .= "  case $i:\n";
       if ((nelems @{@by_length[$i]}) == 1) {
         my $only_thing = @by_length[$i]->[0];
-        if ($only_thing->{utf8}) {
-          if ($only_thing->{utf8} eq 'yes') {
+        if ($only_thing->{?utf8}) {
+          if ($only_thing->{?utf8} eq 'yes') {
             # With utf8 on flag item is passed in element 0
             $body .= $self->match_clause (undef, \@($only_thing));
           } else {
@@ -853,17 +834,17 @@ sub C_constant {
         # of the names of this length.
         my $what = \%();
         foreach ( @{@by_length[$i]}) {
-          $what->{$_->{type}} = 1;
-          $what->{''} = 1 if $_->{utf8};
+          $what->{+$_->{?type}} = 1;
+          $what->{+''} = 1 if $_->{?utf8};
         }
         $params = $self->params ($what);
         push @subs, < $self->C_constant (\%(package=>$package,
-					subname=>"{$subname}_$i",
+					subname=>"$($subname)_$i",
 					default_type => $default_type,
 					types => $what, indent => $indent,
 					breakout => \@($i, $items)),
 				       < @{@by_length[$i]});
-        $body .= "    return {$subname}_$i ("
+        $body .= "    return $($subname)_$i ("
 	  # Eg "aTHX_ "
 	  . $self->C_constant_prefix_param($params)
 	    # Probably "name"
