@@ -1,9 +1,8 @@
 package ExtUtils::Constant::ProxySubs;
 
-use strict;
-use vars < qw($VERSION @ISA %type_to_struct %type_from_struct %type_to_sv
-	    %type_to_C_value %type_is_a_problem %type_num_args
-	    %type_temporary);
+our ($VERSION, @ISA, %type_to_struct, %type_from_struct, %type_to_sv
+	,    %type_to_C_value, %type_is_a_problem, %type_num_args
+	,    %type_temporary);
 require ExtUtils::Constant::XS;
 use ExtUtils::Constant::Utils < qw(C_stringify);
 use ExtUtils::Constant::XS < qw(%XS_TypeSet);
@@ -60,8 +59,8 @@ $VERSION = '0.06';
      );
 
 sub type_to_C_value {
-    my ($self, $type) = < @_;
-    return %type_to_C_value{$type} || sub {return map {ref $_ ? < @$_ : $_} @_ };
+    my @($self, $type) =  @_;
+    return %type_to_C_value{?$type} || sub {return @+: map {ref $_ ?? @$_ !! @($_) }, @_ };
 }
 
 # TODO - figure out if there is a clean way for the type_to_sv code to
@@ -79,16 +78,15 @@ sub type_to_C_value {
      PV => \@('const char *'),
      PVN => \@('const char *', 'STRLEN'),
      );
-%type_temporary{$_} = \@($_) foreach qw(IV UV NV);
+%type_temporary{+$_} = \@($_) foreach qw(IV UV NV);
      
-while (my ($type, $value) = each %XS_TypeSet) {
-    %type_num_args{$type}
-	= defined $value ? ref $value ? scalar nelems @$value : 1 : 0;
+while (my @(?$type, ?$value) =@( each %XS_TypeSet)) {
+    %type_num_args{+$type}
+	= defined $value ?? ref $value ?? scalar nelems @$value !! 1 !! 0;
 }
-%type_num_args{''} = 0;
+%type_num_args{+''} = 0;
 
-sub partition_names {
-    my ($self, $default_type, < @items) = < @_;
+sub partition_names($self, $default_type, @< @items) {
     my (%found, @notfound, @trouble);
 
     while (my $item = shift @items) {
@@ -97,36 +95,35 @@ sub partition_names {
 	    # If we find a default value, convert it into a regular item and
 	    # append it to the queue of items to process
 	    my $default_item = \%(< %$item);
-	    $default_item->{invert_macro} = 1;
-	    $default_item->{pre} = delete $item->{def_pre};
-	    $default_item->{post} = delete $item->{def_post};
-	    $default_item->{type} = shift @$default;
-	    $default_item->{value} = $default;
+	    $default_item->{+invert_macro} = 1;
+	    $default_item->{+pre} = delete $item->{def_pre};
+	    $default_item->{+post} = delete $item->{def_post};
+	    $default_item->{+type} = shift @$default;
+	    $default_item->{+value} = $default;
 	    push @items, $default_item;
 	} else {
 	    # It can be "not found" unless it's the default (invert the macro)
 	    # or the "macro" is an empty string (ie no macro)
-	    push @notfound, $item unless $item->{invert_macro}
+	    push @notfound, $item unless $item->{?invert_macro}
 		or !$self->macro_to_ifdef( $self->macro_from_item($item));
 	}
 
-	if ($item->{pre} or $item->{post} or $item->{not_constant}
-	    or %type_is_a_problem{$item->{type}}) {
+	if ($item->{?pre} or $item->{?post} or $item->{?not_constant}
+	    or %type_is_a_problem{?$item->{?type}}) {
 	    push @trouble, $item;
 	} else {
-	    push @{%found{$item->{type}}}, $item;
+	    push @{%found{+$item->{?type}}}, $item;
 	}
     }
     # use Data::Dumper; print Dumper \%found;
     return @(\%found, \@notfound, \@trouble);
 }
 
-sub boottime_iterator {
-    my ($self, $type, $iterator, $hash, $subname) = < @_;
-    my $extractor = %type_from_struct{$type};
+sub boottime_iterator($self, $type, $iterator, $hash, $subname) {
+    my $extractor = %type_from_struct{?$type};
     die "Can't find extractor code for type $type"
 	unless defined $extractor;
-    my $generator = %type_to_sv{$type};
+    my $generator = %type_to_sv{?$type};
     die "Can't find generator code for type $type"
 	unless defined $generator;
 
@@ -141,11 +138,10 @@ sub boottime_iterator {
 EOBOOT
 }
 
-sub name_len_value_macro {
-    my ($self, $item) = < @_;
-    my $name = $item->{name};
-    my $value = $item->{value};
-    $value = $item->{name} unless defined $value;
+sub name_len_value_macro($self, $item) {
+    my $name = $item->{?name};
+    my $value = $item->{?value};
+    $value = $item->{?name} unless defined $value;
 
     my $namelen = length $name;
     $name = C_stringify($name);
@@ -158,12 +154,12 @@ sub WriteConstants {
     my $self = shift;
     my $ARGS = \%(< @_);
 
-    my ($c_fh, $xs_fh, $c_subname, $xs_subname, $default_type, $package)
-	= < %{$ARGS}{[qw(C_FH XS_FH C_SUBNAME XS_SUBNAME DEFAULT_TYPE NAME)]};
+    my @($c_fh, $xs_fh, $c_subname, $xs_subname, $default_type, $package)
+	=  %{$ARGS}{[qw(C_FH XS_FH C_SUBNAME XS_SUBNAME DEFAULT_TYPE NAME)]};
 
-    my $options = $ARGS->{PROXYSUBS};
+    my $options = $ARGS->{?PROXYSUBS};
     $options = \%() unless ref $options;
-    my $explosives = $options->{croak_on_read};
+    my $explosives = $options->{?croak_on_read};
 
     $xs_subname ||= 'constant';
 
@@ -184,16 +180,16 @@ sub WriteConstants {
     # Everything that doesn't have a default needs alternative code for
     # "I'm missing"
     # And everything that has pre or post code ends up in a private block
-    my ($found, $notfound, $trouble)
-	= < $self->partition_names($default_type, < @items);
+    my @($found, $notfound, $trouble)
+	=  $self->partition_names($default_type, < @items);
 
     my $pthx = $self->C_constant_prefix_param_defintion();
     my $athx = $self->C_constant_prefix_param();
     my $symbol_table = C_stringify($package);
 
-    print $c_fh $self->header(), <<"EOADD";
+    print $c_fh, $self->header(), <<"EOADD";
 static void
-{$c_subname}_add_symbol($pthx HV *hash, const char *name, I32 namelen, SV *value) \{
+$($c_subname)_add_symbol($pthx HV *hash, const char *name, I32 namelen, SV *value) \{
         ENTER;
         SAVESPTR(PL_curstash);
         HVcpREPLACE(PL_curstash, hash);
@@ -203,7 +199,7 @@ static void
 
 EOADD
 
-    print $c_fh $explosives ? <<"EXPLODE" : "\n";
+    print $c_fh, $explosives ?? <<"EXPLODE" !! "\n";
 
 static int
 Im_sorry_Dave(pTHX_ SV *sv, MAGIC *mg)
@@ -227,14 +223,14 @@ static MGVTBL not_defined_vtbl = \{
 
 EXPLODE
 
-    {
+    do {
         my $key = $symbol_table;
         # Just seems tidier (and slightly more space efficient) not to have keys
         # such as Fcntl::
         $key =~ s/::$//;
         my $key_len = length $key;
 
-        print $c_fh <<"MISSING";
+        print $c_fh, <<"MISSING";
 
 #ifndef SYMBIAN
 
@@ -271,9 +267,9 @@ get_missing_hash(pTHX) \{
 
 MISSING
 
-    }
+    };
 
-    print $xs_fh <<"EOBOOT";
+    print $xs_fh, <<"EOBOOT";
 BOOT:
   \{
 #ifdef dTHX
@@ -281,27 +277,27 @@ BOOT:
 #endif
     HV *symbol_table = gv_stashpvn("$symbol_table", $(length $symbol_table), GV_ADD);
 #ifndef SYMBIAN
-    HV *{$c_subname}_missing;
+    HV *$($c_subname)_missing;
 #endif
 EOBOOT
 
     my %iterator;
 
-    $found->{''}
-        = \ map {\%(< %$_, type=>'', invert_macro => 1)} @$notfound;
+    $found->{+''}
+        = \ map {\%(< %$_, type=>'', invert_macro => 1)}, @$notfound;
 
     foreach my $type (sort keys %$found) {
-	my $struct = %type_to_struct{$type};
+	my $struct = %type_to_struct{?$type};
 	my $type_to_value = $self->type_to_C_value($type);
-	my $number_of_args = %type_num_args{$type};
+	my $number_of_args = %type_num_args{?$type};
 	die "Can't find structure definition for type $type"
 	    unless defined $struct;
 
-	my $struct_type = $type ? lc($type) . '_s' : 'notfound_s';
-	print $c_fh "struct $struct_type $struct;\n";
+	my $struct_type = $type ?? lc($type) . '_s' !! 'notfound_s';
+	print $c_fh, "struct $struct_type $struct;\n";
 
-	my $array_name = 'values_for_' . ($type ? lc $type : 'notfound');
-	print $xs_fh <<"EOBOOT";
+	my $array_name = 'values_for_' . ($type ?? lc $type !! 'notfound');
+	print $xs_fh, <<"EOBOOT";
 
     static const struct $struct_type $array_name\[] =
       \{
@@ -309,56 +305,56 @@ EOBOOT
 
 
 	foreach my $item ( @{$found->{$type}}) {
-            my ($name, $namelen, $value, $macro)
-                 = < $self->name_len_value_macro($item);
+            my @($name, $namelen, $value, $macro)
+                 =  $self->name_len_value_macro($item);
 
 	    my $ifdef = $self->macro_to_ifdef($macro);
-	    if (!$ifdef && $item->{invert_macro}) {
+	    if (!$ifdef && $item->{?invert_macro}) {
 		carp("Attempting to supply a default for '$name' which has no conditional macro");
 		next;
 	    }
-	    print $xs_fh $ifdef;
-	    if ($item->{invert_macro}) {
-		print $xs_fh
+	    print $xs_fh, $ifdef;
+	    if ($item->{?invert_macro}) {
+		print $xs_fh,
 		    "        /* This is the default value: */\n" if $type;
-		print $xs_fh "#else\n";
+		print $xs_fh, "#else\n";
 	    }
-	    print $xs_fh "        \{ ", join (', ', @( "\"$name\"", $namelen, 
+	    print $xs_fh, "        \{ ", join (', ', @( "\"$name\"", $namelen, 
                                               < &$type_to_value($value))), " \},\n",
 						 $self->macro_to_endif($macro);
 	}
 
 
     # Terminate the list with a NULL
-	print $xs_fh "        \{ NULL, 0", (", 0" x $number_of_args), " \} \};\n";
+	print $xs_fh, "        \{ NULL, 0", (", 0" x $number_of_args), " \} \};\n";
 
-	%iterator{$type} = "value_for_" . ($type ? lc $type : 'notfound');
+	%iterator{+$type} = "value_for_" . ($type ?? lc $type !! 'notfound');
 
-	print $xs_fh <<"EOBOOT";
-	const struct $struct_type *%iterator{$type} = $array_name;
+	print $xs_fh, <<"EOBOOT";
+	const struct $struct_type *%iterator{?$type} = $array_name;
 EOBOOT
     }
 
     delete $found->{''};
 
-    print $xs_fh <<"EOBOOT";
+    print $xs_fh, <<"EOBOOT";
 #ifndef SYMBIAN
-	{$c_subname}_missing = get_missing_hash(aTHX);
+	$($c_subname)_missing = get_missing_hash(aTHX);
 #endif
 EOBOOT
 
     my $add_symbol_subname = $c_subname . '_add_symbol';
     foreach my $type (sort keys %$found) {
-	print $xs_fh $self->boottime_iterator($type, %iterator{$type}, 
+	print $xs_fh, $self->boottime_iterator($type, %iterator{?$type}, 
 					      'symbol_table',
 					      $add_symbol_subname);
     }
 
-    print $xs_fh <<"EOBOOT";
+    print $xs_fh, <<"EOBOOT";
 	while (value_for_notfound->name) \{
 EOBOOT
 
-    print $xs_fh $explosives ? <<"EXPLODE" : << "DONT";
+    print $xs_fh, $explosives ?? <<"EXPLODE" !! << "DONT";
 	    SV *tripwire = newSV(0);
 	    
 	    sv_magicext(tripwire, 0, PERL_MAGIC_ext, &not_defined_vtbl, 0, 0);
@@ -375,78 +371,76 @@ EOBOOT
 	    $add_symbol_subname($athx symbol_table, value_for_notfound->name,
 				value_for_notfound->namelen, tripwire);
 EXPLODE
-            SV* namesv = sv_2mortal(newSVpvn("{$symbol_table}::", $(length($symbol_table) + 2)));
+            SV* namesv = sv_2mortal(newSVpvn("$($symbol_table)::", $(length($symbol_table) + 2)));
             sv_catpvn(namesv, value_for_notfound->name, value_for_notfound->namelen);
 	    GV *gv = gv_fetchsv(namesv, GV_ADD, SVt_PVCV);
 	    if (!gv) \{
 		Perl_croak(aTHX_
-			   "Couldn't add key '{$package_sprintf_safe}::\%s'",
+			   "Couldn't add key '$($package_sprintf_safe)::\%s'",
 			   value_for_notfound->name);
 	    \}
-            GV* notfoundgv = gv_fetchmethod(aTHX_  symbol_table, "constant_not_found");
-            if (!notfoundgv || ! GvCV(notfoundgv)) \{
+            CV* notfoundcv = gv_fetchmethod(aTHX_  symbol_table, "constant_not_found");
+            if (!notfoundcv) \{
 		Perl_croak(aTHX_ "'constant_not_found' could not be found");
             \}
-            sv_setsv((SV*)gv, sv_2mortal(newRV_inc((SV*)GvCV(notfoundgv))));
+            sv_setsv((SV*)gv, sv_2mortal(newRV_inc(cvTsv(notfoundcv))));
 #ifndef SYMBIAN
-	    if (!hv_store({$c_subname}_missing, value_for_notfound->name,
-			  value_for_notfound->namelen, &PL_sv_yes, 0))
-		Perl_croak($athx "Couldn't add key '\%s' to missing_hash",
-			   value_for_notfound->name);
+	    hv_store($($c_subname)_missing, value_for_notfound->name,
+			  value_for_notfound->namelen, &PL_sv_yes, 0);
 #endif
 DONT
 
-    print $xs_fh <<"EOBOOT";
+    print $xs_fh, <<"EOBOOT";
 
 	    ++value_for_notfound;
 	\}
 EOBOOT
 
     foreach my $item ( @$trouble) {
-        my ($name, $namelen, $value, $macro)
-	    = < $self->name_len_value_macro($item);
+        my @($name, $namelen, $value, $macro)
+	    =  $self->name_len_value_macro($item);
         my $ifdef = $self->macro_to_ifdef($macro);
-        my $type = $item->{type};
+        my $type = $item->{?type};
 	my $type_to_value = $self->type_to_C_value($type);
 
-        print $xs_fh $ifdef;
-	if ($item->{invert_macro}) {
-	    print $xs_fh
+        print $xs_fh, $ifdef;
+	if ($item->{?invert_macro}) {
+	    print $xs_fh,
 		 "        /* This is the default value: */\n" if $type;
-	    print $xs_fh "#else\n";
+	    print $xs_fh, "#else\n";
 	}
-	my $generator = %type_to_sv{$type};
+	my $generator = %type_to_sv{?$type};
 	die "Can't find generator code for type $type"
 	    unless defined $generator;
 
-	print $xs_fh "        \{\n";
+	print $xs_fh, "        \{\n";
 	# We need to use a temporary value because some really troublesome
 	# items use C pre processor directives in their values, and in turn
 	# these don't fit nicely in the macro-ised generator functions
 	my $counter = 0;
-	printf $xs_fh "            \%s temp\%d;\n", $_, $counter++
+	printf $xs_fh, "            \%s temp\%d;\n", $_, $counter++
 	    foreach  @{%type_temporary{$type}};
 
-	print $xs_fh "            $item->{pre}\n" if $item->{pre};
+	print $xs_fh, "            $item->{?pre}\n" if $item->{?pre};
 
 	# And because the code in pre might be both declarations and
 	# statements, we can't declare and assign to the temporaries in one.
 	$counter = 0;
-	printf $xs_fh "            temp\%d = \%s;\n", $counter++, $_
+	printf $xs_fh, "            temp\%d = \%s;\n", $counter++, $_
 	    foreach  &$type_to_value($value);
 
-	my @tempvarnames = map {sprintf 'temp%d', $_} 0 .. $counter - 1;
-	printf $xs_fh <<"EOBOOT", $name, &$generator(<@tempvarnames);
-	    {$c_subname}_add_symbol($athx symbol_table, "\%s",
+	my @tempvarnames = map {sprintf 'temp%d', $_}, 0 .. $counter - 1;
+	printf $xs_fh, <<"EOBOOT", $name, &$generator(<@tempvarnames);
+	    $($c_subname)_add_symbol($athx symbol_table, "\%s",
 				    $namelen, \%s);
 EOBOOT
-	print $xs_fh "        $item->{post}\n" if $item->{post};
-	print $xs_fh "        \}\n";
+	print $xs_fh, "        $item->{?post}\n" if $item->{?post};
+	print $xs_fh, "        \}\n";
 
-        print $xs_fh $self->macro_to_endif($macro);
+        print $xs_fh, $self->macro_to_endif($macro);
     }
 
-    print $xs_fh <<EOBOOT;
+    print $xs_fh, <<EOBOOT;
     /* As we've been creating subroutines, we better invalidate any cached
        methods  */
     ++PL_sub_generation;
@@ -459,7 +453,7 @@ constant_not_found()
 
 EOBOOT
 
-    print $xs_fh $explosives ? <<"EXPLODE" : <<"DONT";
+    print $xs_fh, $explosives ?? <<"EXPLODE" !! <<"DONT";
 
 void
 $xs_subname(sv)
@@ -482,8 +476,8 @@ $xs_subname(sv)
 #ifdef SYMBIAN
 	sv = newSVpvf("\%"SVf" is not a valid $package_sprintf_safe macro", sv);
 #else
-	HV *{$c_subname}_missing = get_missing_hash(aTHX);
-	if (hv_exists({$c_subname}_missing, s, (I32)len)) \{
+	HV *$($c_subname)_missing = get_missing_hash(aTHX);
+	if (hv_exists($($c_subname)_missing, s, (I32)len)) \{
 	    sv = newSVpvf("Your vendor has not defined $package_sprintf_safe macro \%" SVf
 			  ", used", sv);
 	\} else \{
