@@ -1,6 +1,5 @@
 package ExtUtils::MM_AIX;
 
-use strict;
 our $VERSION = '6.44';
 
 require ExtUtils::MM_Unix;
@@ -33,30 +32,29 @@ Define DL_FUNCS and DL_VARS and write the *.exp files.
 
 =cut
 
-sub dlsyms {
-    my($self,< %attribs) = < @_;
+sub dlsyms($self,%< %attribs) {
 
     return '' unless $self->needs_linking();
 
-    my($funcs) = %attribs{DL_FUNCS} || $self->{DL_FUNCS} || \%();
-    my($vars)  = %attribs{DL_VARS} || $self->{DL_VARS} || \@();
-    my($funclist)  = %attribs{FUNCLIST} || $self->{FUNCLIST} || \@();
+    my@($funcs) = %attribs{?DL_FUNCS} || $self->{?DL_FUNCS} || \%();
+    my@($vars)  = %attribs{?DL_VARS} || $self->{?DL_VARS} || \@();
+    my@($funclist)  = %attribs{?FUNCLIST} || $self->{?FUNCLIST} || \@();
     my(@m);
 
     push(@m,"
-dynamic :: $self->{BASEEXT}.exp
+dynamic :: $self->{?BASEEXT}.exp
 
-") unless $self->{SKIPHASH}->{'dynamic'}; # dynamic and static are subs, so...
+") unless $self->{SKIPHASH}->{?'dynamic'}; # dynamic and static are subs, so...
 
     push(@m,"
-static :: $self->{BASEEXT}.exp
+static :: $self->{?BASEEXT}.exp
 
-") unless $self->{SKIPHASH}->{'static'};  # we avoid a warning if we tick them
+") unless $self->{SKIPHASH}->{?'static'};  # we avoid a warning if we tick them
 
     push(@m,"
-$self->{BASEEXT}.exp: Makefile.PL
+$self->{?BASEEXT}.exp: Makefile.PL
 ",q|	$(PERLRUN) -e 'use ExtUtils::Mksymlists; \
-	Mksymlists("NAME" => "|,$self->{NAME},'", "DL_FUNCS" => ', <
+	Mksymlists("NAME" => "|,$self->{?NAME},'", "DL_FUNCS" => ', <
 	neatvalue($funcs), ', "FUNCLIST" => ', < neatvalue($funclist),
 	', "DL_VARS" => ', < neatvalue($vars), q|);'
 |);
