@@ -1,10 +1,9 @@
 package ExtUtils::MM_VOS;
 
-use strict;
 our $VERSION = '6.44';
 
 require ExtUtils::MM_Unix;
-our @ISA = @( qw(ExtUtils::MM_Unix) );
+our @ISA = qw(ExtUtils::MM_Unix);
 
 
 =head1 NAME
@@ -32,7 +31,7 @@ Cleanup VOS core files
 =cut
 
 sub extra_clean_files {
-    return @(qw(*.kp));
+    return qw(*.kp);
 }
 
 
