@@ -1,15 +1,14 @@
 package ExtUtils::MY;
 
-use strict;
 require ExtUtils::MM;
 
 our $VERSION = 6.44;
-our @ISA = @( qw(ExtUtils::MM) );
+our @ISA = qw(ExtUtils::MM);
 
-{
+do {
     package MY;
-    our @ISA = @( qw(ExtUtils::MY) );
-}
+    our @ISA = qw(ExtUtils::MY);
+};
 
 sub DESTROY {}
 
