@@ -1,13 +1,11 @@
 package ExtUtils::MakeMaker::Config;
 
-use strict;
-
 our $VERSION = '6.44';
 
-use Config ();
+use Config < qw(config_value config_keys);
 
 # Give us an overridable config.
-our %Config = %( < %Config::Config );
+our %Config = %+: map { %: $_ => config_value($_) }, config_keys();
 
 sub import {
     my $caller = caller;
