@@ -1,8 +1,7 @@
 package ExtUtils::Packlist;
 
-use strict;
-use Config;
-use vars < qw($VERSION $Relocations);
+use Config < qw(config_value config_keys);
+our ($VERSION, $Relocations);
 $VERSION = '1.43';
 $VERSION = eval $VERSION;
 
@@ -35,181 +34,124 @@ time relative to $^X, and generates a regexp that matches them
 sub __find_relocations
 {
     my %paths;
-    while (my ($raw_key, $raw_val) = each %Config) {
+    for my $raw_key (keys config_keys) {
+        my $raw_val = config_value($raw_key);
 	my $exp_key = $raw_key . "exp";
-	next unless exists %Config{$exp_key};
+	next unless defined config_value($exp_key);
 	next unless $raw_val =~ m!\.\.\./!;
-	%paths{%Config{$exp_key}}++;
+	%paths{+config_value($exp_key)}++;
     }
     # Longest prefixes go first in the alternatives
-    my $alternations = join "|", map {quotemeta $_}
-    sort {length $b <+> length $a} keys %paths;
+    my $alternations = join "|", map {quotemeta $_},
+    sort {length $b <+> length $a}, keys %paths;
     qr/^($alternations)/o;
 }
 
-sub new($$)
+sub new($class, ?$packfile)
 {
-    my ($class, $packfile) = < @_;
     $class = ref($class) || $class;
-    my %self;
-    tie(%self, $class, $packfile);
-    return (bless(\%self, $class));
-}
 
-sub TIEHASH
-{
-    my ($class, $packfile) = < @_;
-    my $self = \%( packfile => $packfile );
+    my $self = \%( packfile => $packfile,
+                   data => %(),
+               );
     bless($self, $class);
+
     $self->read($packfile) if (defined($packfile) && -f $packfile);
-    return ($self);
+
+    return $self;
 }
 
-sub STORE
+sub read($self, ?$packfile)
 {
-    @_[0]->{data}->{@_[1]} = @_[2];
-}
 
-sub FETCH
-{
-    return @_[0]->{data}->{@_[1]};
-}
+    if (defined($packfile)) { $self->{packfile} = $packfile; }
+    else { $packfile = $self->{packfile}; }
+    die("No packlist filename specified") if (! defined($packfile));
 
-sub FIRSTKEY
-{
-    keys(%{@_[0]->{data}});
-    return each(%{@_[0]->{data}});
-}
-
-sub NEXTKEY
-{
-    return each(%{@_[0]->{data}});
-}
-
-sub EXISTS
-{
-    return exists(@_[0]->{data}->{@_[1]});
-}
-
-sub DELETE
-{
-    return delete(@_[0]->{data}->{@_[1]});
-}
-
-sub CLEAR
-{
-    %{@_[0]->{data}} = %( () );
-}
-
-sub DESTROY
-{
-}
-
-sub read($;$)
-{
-my ($self, $packfile) = < @_;
-$self = tied(%$self) || $self;
-
-if (defined($packfile)) { $self->{packfile} = $packfile; }
-else { $packfile = $self->{packfile}; }
-die("No packlist filename specified") if (! defined($packfile));
-my $fh = mkfh();
-open($fh, "<", "$packfile") || die("Can't open file $packfile: $!");
-$self->{data} = \%();
-my ($line);
-while (defined($line = ~< $fh))
-   {
-   chomp $line;
-   my ($key, $data) = $line;
-   if ($key =~ m/^(.*?)( \w+=.*)$/)
+    my $fh = mkfh();
+    open($fh, "<", "$packfile") || die("Can't open file $packfile: $^OS_ERROR");
+    $self->{data} = %();
+    my ($line);
+    while (defined($line = ~< $fh))
       {
-      $key = $1;
-      $data = \%( < map { < split('=', $_) } split(' ', $2));
+        chomp $line;
+        my $key = $line;
+        my $data;
+        if ($key =~ m/^(.*?)( \w+=.*)$/)
+          {
+            $key = $1;
+            $data = \%( < @+: map { split('=', $_) }, split(' ', $2));
 
-      if (%Config{userelocatableinc} && $data->{relocate_as})
-      {
-	  require File::Spec;
-	  require Cwd;
-	  my ($vol, $dir) = < File::Spec->splitpath($packfile);
-	  my $newpath = File::Spec->catpath($vol, $dir, $data->{relocate_as});
-	  $key = Cwd::realpath($newpath);
-      }
-         }
-   $key =~ s!/\./!/!g;   # Some .packlists have spurious '/./' bits in the paths
-      $self->{data}->{$key} = $data;
-      }
-close($fh);
+            if (config_value("userelocatableinc") && $data->{?relocate_as})
+              {
+                require File::Spec;
+                require Cwd;
+                my @($vol, $dir) =  File::Spec->splitpath($packfile);
+                my $newpath = File::Spec->catpath($vol, $dir, $data->{relocate_as});
+                $key = Cwd::realpath($newpath);
+            }
+        }
+        $key =~ s!/\./!/!g;   # Some .packlists have spurious '/./' bits in the paths
+        $self->{data}{+$key} = $data;
+    }
+    close($fh);
 }
 
-sub write($;$)
-{
-my ($self, $packfile) = < @_;
-$self = tied(%$self) || $self;
-if (defined($packfile)) { $self->{packfile} = $packfile; }
-else { $packfile = $self->{packfile}; }
-die("No packlist filename specified") if (! defined($packfile));
-my $fh = mkfh();
-open($fh, ">", "$packfile") || die("Can't open file $packfile: $!");
-foreach my $key (sort(keys(%{$self->{data} || \%()})))
-   {
-       my $data = $self->{data}->{$key};
-       if (%Config{userelocatableinc}) {
-	   $Relocations ||= __find_relocations();
-	   if ($packfile =~ $Relocations) {
-	       # We are writing into a subdirectory of a run-time relocated
-	       # path. Figure out if the this file is also within a subdir.
-	       my $prefix = $1;
-	       if (File::Spec->no_upwards( <File::Spec->abs2rel($key, $prefix)))
-	       {
-		   # The relocated path is within the found prefix
-		   my $packfile_prefix;
-		   (undef, $packfile_prefix)
-		       = < File::Spec->splitpath($packfile);
+sub write($self, ?$packfile)
+  {
+    if (defined($packfile)) { $self->{packfile} = $packfile; }
+    else { $packfile = $self->{packfile}; }
+    die("No packlist filename specified") if (! defined($packfile));
+    my $fh = mkfh();
+    open($fh, ">", "$packfile") || die("Can't open file $packfile: $^OS_ERROR");
+    foreach my $key (sort(keys($self->{data}))) {
+        my $data = $self->{data}{$key};
+        if (config_value("userelocatableinc")) {
+            $Relocations ||= __find_relocations();
+            if ($packfile =~ $Relocations) {
+                # We are writing into a subdirectory of a run-time relocated
+                # path. Figure out if the this file is also within a subdir.
+                my $prefix = $1;
+                if (File::Spec->no_upwards( <File::Spec->abs2rel($key, $prefix))) {
+                    # The relocated path is within the found prefix
+                    my @(_, $packfile_prefix) = File::Spec->splitpath($packfile);
 
-		   my $relocate_as
-		       = File::Spec->abs2rel($key, $packfile_prefix);
+                    my $relocate_as
+                      = File::Spec->abs2rel($key, $packfile_prefix);
 
-		   if (!ref $data) {
-		       $data = \%();
-		   }
-		   $data->{relocate_as} = $relocate_as;
-	       }
-	   }
-       }
-   print $fh ("$key");
-   if (ref($data))
-      {
-      foreach my $k (sort(keys(%$data)))
-         {
-         print $fh (" $k=$data->{$k}");
-         }
-      }
-   print $fh ("\n");
-   }
-close($fh);
+                    if (!ref $data) {
+                        $data = \%();
+                    }
+                    $data->{+relocate_as} = $relocate_as;
+                }
+            }
+        }
+        print $fh, ("$key");
+        if (ref($data)) {
+            foreach my $k (sort(keys(%$data))) {
+                print $fh, (" $k=$data->{$k}");
+            }
+        }
+        print $fh, ("\n");
+    }
+    close($fh);
 }
 
-sub validate($;$)
-{
-my ($self, $remove) = < @_;
-$self = tied(%$self) || $self;
-my @missing;
-foreach my $key (sort(keys(%{$self->{data}})))
-   {
-   if (! -e $key)
-      {
-      push(@missing, $key);
-      delete($self->{data}->{$key}) if ($remove);
-      }
-   }
-return @(@missing);
+sub validate($self, ?$remove)
+  {
+    my @missing;
+    foreach my $key (sort(keys($self->{data}))) {
+        if (! -e $key) {
+            push(@missing, $key);
+            delete($self->{data}{$key}) if ($remove);
+        }
+    }
+    return @(@missing);
 }
 
-sub packlist_file($)
-{
-my ($self) = < @_;
-$self = tied(%$self) || $self;
-return @($self->{packfile});
+sub packlist_file($self)
+  {
+    return @($self->{?packfile});
 }
 
 1;
@@ -297,7 +239,6 @@ Here's C<modrm>, a little utility to cleanly remove an installed module.
 
     #!/usr/local/bin/perl -w
 
-    use strict;
     use IO::Dir;
     use ExtUtils::Packlist;
     use ExtUtils::Installed;
