@@ -1,7 +1,7 @@
 package XSTest;
 
 require DynaLoader;
-our @ISA = @( qw(Exporter DynaLoader) );
+our @ISA = qw(Exporter DynaLoader);
 our $VERSION = '0.01';
 XSTest->bootstrap($VERSION);
 
