@@ -1,6 +1,5 @@
 package ExtUtils::testlib;
 
-use strict;
 use warnings;
 
 our $VERSION = 6.44;
@@ -8,22 +7,22 @@ our $VERSION = 6.44;
 use Cwd;
 use File::Spec;
 
-# So the tests can chdir around and not break @INC.
+# So the tests can chdir around and not break $^INCLUDE_PATH.
 # We use getcwd() because otherwise rel2abs will blow up under taint
-# mode pre-5.8.  We detaint is so @INC won't be tainted.  This is
+# mode pre-5.8.  We detaint is so $^INCLUDE_PATH won't be tainted.  This is
 # no worse, and probably better, than just shoving an untainted, 
-# relative "blib/lib" onto @INC.
+# relative "blib/lib" onto $^INCLUDE_PATH.
 my $cwd;
 BEGIN {
-    ($cwd) = getcwd() =~ m/(.*)/;
+    @($cwd) = @: getcwd() =~ m/(.*)/;
 }
-use lib < map { File::Spec->rel2abs($_, $cwd) } qw(blib/arch blib/lib);
+use lib < map { File::Spec->rel2abs($_, $cwd) }, qw(blib/arch blib/lib);
 1;
 __END__
 
 =head1 NAME
 
-ExtUtils::testlib - add blib/* directories to @INC
+ExtUtils::testlib - add blib/* directories to $^INCLUDE_PATH
 
 =head1 SYNOPSIS
 
@@ -37,5 +36,5 @@ desirable to test it bypassing C<make test>. By adding
     use ExtUtils::testlib;
 
 to a test program the intermediate directories used by C<make> are
-added to @INC.
+added to $^INCLUDE_PATH.
 
