@@ -7,7 +7,6 @@
 
 package File::Copy;
 
-use strict;
 use warnings;
 use File::Spec;
 use Config;
@@ -28,20 +27,19 @@ require Exporter;
 $Too_Big = 1024 * 1024 * 2;
 
 my $macfiles;
-if ($^O eq 'MacOS') {
+if ($^OS_NAME eq 'MacOS') {
 	$macfiles = try { require Mac::MoreFiles };
 	warn 'Mac::MoreFiles could not be loaded; using non-native syscopy'
-		if $@ && $^W;
+		if $^EVAL_ERROR && $^WARNING;
 }
 
-sub _catname {
-    my($from, $to) = < @_;
+sub _catname($from, $to) {
     if (not defined &basename) {
 	require File::Basename;
 	File::Basename->import('basename');
     }
 
-    if ($^O eq 'MacOS') {
+    if ($^OS_NAME eq 'MacOS') {
 	# a partial dir name that's valid only in the cwd (e.g. 'tmp')
 	$to = ':' . $to if $to !~ m/:/;
     }
@@ -65,15 +63,15 @@ sub copy {
     my $to = shift;
 
     my $from_a_handle = (ref($from)
-			 ? (ref($from) eq 'GLOB'
+			 ?? (ref($from) eq 'GLOB'
 			    || UNIVERSAL::isa($from, 'GLOB')
                             || UNIVERSAL::isa($from, 'IO::Handle'))
-			 : (ref(\$from) eq 'GLOB'));
+			 !! (ref(\$from) eq 'GLOB'));
     my $to_a_handle =   (ref($to)
-			 ? (ref($to) eq 'GLOB'
+			 ?? (ref($to) eq 'GLOB'
 			    || UNIVERSAL::isa($to, 'GLOB')
                             || UNIVERSAL::isa($to, 'IO::Handle'))
-			 : (ref(\$to) eq 'GLOB'));
+			 !! (ref(\$to) eq 'GLOB'));
 
     if (_eq($from, $to)) { # works for references, too
 	warn("'$from' and '$to' are identical (not copied)");
@@ -82,8 +80,9 @@ sub copy {
         return 1;
     }
 
-    if (((%Config{d_symlink} && %Config{d_readlink}) || %Config{d_link}) &&
-	!($^O eq 'MSWin32' || $^O eq 'os2')) {
+    if (( (config_value("d_symlink") && config_value("d_readlink"))
+            || config_value("d_link"))
+          && !($^OS_NAME eq 'MSWin32' || $^OS_NAME eq 'os2')) {
 	my @fs = @( stat($from) );
 	if ((nelems @fs)) {
 	    my @ts = @( stat($to) );
@@ -100,16 +99,16 @@ sub copy {
 
     if (defined &syscopy && !$Syscopy_is_copy
 	&& !$to_a_handle
-	&& !($from_a_handle && $^O eq 'os2' )	# OS/2 cannot handle handles
-	&& !($from_a_handle && $^O eq 'mpeix')	# and neither can MPE/iX.
-	&& !($from_a_handle && $^O eq 'MSWin32')
-	&& !($from_a_handle && $^O eq 'MacOS')
-	&& !($from_a_handle && $^O eq 'NetWare')
+	&& !($from_a_handle && $^OS_NAME eq 'os2' )	# OS/2 cannot handle handles
+	&& !($from_a_handle && $^OS_NAME eq 'mpeix')	# and neither can MPE/iX.
+	&& !($from_a_handle && $^OS_NAME eq 'MSWin32')
+	&& !($from_a_handle && $^OS_NAME eq 'MacOS')
+	&& !($from_a_handle && $^OS_NAME eq 'NetWare')
        )
     {
 	my $copy_to = $to;
 
-        if ($^O eq 'VMS' && -e $from) {
+        if ($^OS_NAME eq 'VMS' && -e $from) {
 
             if (! -d $to && ! -d $from) {
 
@@ -119,7 +118,7 @@ sub copy {
                 # So add a '.' for a null extension.
 
                 $copy_to = VMS::Filespec::vmsify($to);
-                my ($vol, $dirs, $file) = < File::Spec->splitpath($copy_to);
+                my @($vol, $dirs, $file) =  File::Spec->splitpath($copy_to);
                 $file = $file . '.' unless ($file =~ m/(?<!\^)\./);
                 $copy_to = File::Spec->catpath($vol, $dirs, $file);
 
@@ -134,25 +133,49 @@ sub copy {
     my $closefrom = 0;
     my $closeto = 0;
     my ($size, $status, $r, $buf);
-    local($\) = '';
+    local($^OUTPUT_RECORD_SEPARATOR) = '';
 
     my $from_h;
+    my $to_h;
+
+    my $fail_open1 = sub { return 0; };
+    my $fail_open2 =
+      sub {
+          if ($closefrom) {
+              $status = $^OS_ERROR;
+              $^OS_ERROR = 0;
+              close $from_h;
+              $^OS_ERROR = $status unless $^OS_ERROR;
+          }
+          return $fail_open1->();
+      };
+    # All of these contortions try to preserve error messages...
+    my $fail_inner =
+      sub {
+          if ($closeto) {
+              $status = $^OS_ERROR;
+              $^OS_ERROR = 0;
+              close $to_h;
+              $^OS_ERROR = $status unless $^OS_ERROR;
+          }
+          return $fail_open2->();
+      };
+
     if ($from_a_handle) {
        $from_h = $from;
     } else {
 	$from = _protect($from) if $from =~ m/^\s/s;
-       open($from_h, "<", "$from\0") or goto fail_open1;
-       binmode $from_h or die "($!,$^E)";
+       open($from_h, "<", "$from\0") or return $fail_open1->();
+       binmode $from_h or die "($^OS_ERROR,$^EXTENDED_OS_ERROR)";
 	$closefrom = 1;
     }
 
-    my $to_h;
     if ($to_a_handle) {
        $to_h = $to;
     } else {
 	$to = _protect($to) if $to =~ m/^\s/s;
-       open($to_h,">", "$to\0") or goto fail_open2;
-       binmode $to_h or die "($!,$^E)";
+       open($to_h,">", "$to\0") or return $fail_open2->();
+       binmode $to_h or die "($^OS_ERROR,$^EXTENDED_OS_ERROR)";
 	$closeto = 1;
     }
 
@@ -160,52 +183,36 @@ sub copy {
 	$size = shift(@_) + 0;
 	die("Bad buffer size for copy: $size\n") unless ($size +> 0);
     } else {
-	$size = tied(*$from_h) ? 0 : -s $from_h || 0;
+	$size = -s $from_h || 0;
 	$size = 1024 if ($size +< 512);
 	$size = $Too_Big if ($size +> $Too_Big);
     }
 
-    $! = 0;
-    for (;;) {
+    $^OS_ERROR = 0;
+    while (1) {
 	my ($r, $w, $t);
        defined($r = sysread($from_h, $buf, $size))
-	    or goto fail_inner;
+	    or return $fail_inner->();
 	last unless $r;
-	for ($w = 0; $w +< $r; $w += $t) {
-           $t = syswrite($to_h, $buf, $r - $w, $w)
-		or goto fail_inner;
+	$w = 0;
+        while ($w +< $r) {
+            $t = syswrite($to_h, $buf, $r - $w, $w)
+              or return $fail_inner->();
+            $w += $t;
 	}
     }
 
-    close($to_h) || goto fail_open2 if $closeto;
-    close($from_h) || goto fail_open1 if $closefrom;
+    close($to_h) || return $fail_open2->() if $closeto;
+    close($from_h) || return $fail_open1->() if $closefrom;
 
     # Use this idiom to avoid uninitialized value warning.
     return 1;
-
-    # All of these contortions try to preserve error messages...
-  fail_inner:
-    if ($closeto) {
-	$status = $!;
-	$! = 0;
-       close $to_h;
-	$! = $status unless $!;
-    }
-  fail_open2:
-    if ($closefrom) {
-	$status = $!;
-	$! = 0;
-       close $from_h;
-	$! = $status unless $!;
-    }
-  fail_open1:
-    return 0;
 }
 
 sub move {
     die("Usage: move(FROM, TO) ") unless (nelems @_) == 2;
 
-    my($from,$to) = < @_;
+    my@($from,$to) =  @_;
 
     my($fromsz,$tosz1,$tomt1,$tosz2,$tomt2,$sts,$ossts);
 
@@ -213,15 +220,15 @@ sub move {
 	$to = _catname($from, $to);
     }
 
-    ($tosz1,$tomt1) = < @(stat($to))[[@: 7,9]];
+    @($tosz1,$tomt1) =  @(stat($to))[[@: 7,9]];
     $fromsz = -s $from;
-    if ($^O eq 'os2' and defined $tosz1 and defined $fromsz) {
+    if ($^OS_NAME eq 'os2' and defined $tosz1 and defined $fromsz) {
       # will not rename with overwrite
       unlink $to;
     }
 
     my $rename_to = $to;
-    if (-$^O eq 'VMS' && -e $from) {
+    if ($^OS_NAME eq 'VMS' && -e $from) {
 
         if (! -d $to && ! -d $from) {
             # VMS has sticky defaults on extensions, which means that
@@ -230,7 +237,7 @@ sub move {
             # So add a '.' for a null extension.
 
             $rename_to = VMS::Filespec::vmsify($to);
-            my ($vol, $dirs, $file) = < File::Spec->splitpath($rename_to);
+            my @($vol, $dirs, $file) =  File::Spec->splitpath($rename_to);
             $file = $file . '.' unless ($file =~ m/(?<!\^)\./);
             $rename_to = File::Spec->catpath($vol, $dirs, $file);
 
@@ -244,28 +251,28 @@ sub move {
     # Did rename return an error even though it succeeded, because $to
     # is on a remote NFS file system, and NFS lost the server's ack?
     return 1 if defined($fromsz) && !-e $from &&           # $from disappeared
-                (($tosz2,$tomt2) = < @(stat($to))[[@:7,9]]) &&    # $to's there
+                (@($tosz2,$tomt2) =  @(stat($to))[[@:7,9]]) &&    # $to's there
                   ((!defined $tosz1) ||			   #  not before or
 		   ($tosz1 != $tosz2 or $tomt1 != $tomt2)) &&  #   was changed
                 $tosz2 == $fromsz;                         # it's all there
 
-    ($tosz1,$tomt1) = < @(stat($to))[[@:7,9]];  # just in case rename did something
+    @($tosz1,$tomt1) =  @(stat($to))[[@:7,9]];  # just in case rename did something
 
-    {
-        local $@;
+    do {
+        local $^EVAL_ERROR = undef;
         try {
             copy($from,$to) or die;
-            my($atime, $mtime) = < @(stat($from))[[8..9]];
+            my@($atime, $mtime) =  @(stat($from))[[8..9]];
             utime($atime, $mtime, $to);
             unlink($from)   or die;
         };
-        return 1 unless $@;
-    }
-    ($sts,$ossts) = ($! + 0, $^E + 0);
+        return 1 unless $^EVAL_ERROR;
+    };
+    @($sts,$ossts) = @($^OS_ERROR + 0, $^EXTENDED_OS_ERROR + 0);
 
-    ($tosz2,$tomt2) = (< @(stat($to))[[@:7,9]],0,0) if defined $tomt1;
+    @($tosz2,$tomt2, ...) = @(< @(stat($to))[[@:7,9]],0,0) if defined $tomt1;
     unlink($to) if !defined($tomt1) or $tomt1 != $tomt2 or $tosz1 != $tosz2;
-    ($!,$^E) = ($sts,$ossts);
+    @($^OS_ERROR,$^EXTENDED_OS_ERROR) = @($sts,$ossts);
     return 0;
 }
 
@@ -273,7 +280,7 @@ sub move {
 *mv = \&move;
 
 
-if ($^O eq 'MacOS') {
+if ($^OS_NAME eq 'MacOS') {
     *_protect = sub { MacPerl::MakeFSSpec(@_[0]) };
 } else {
     *_protect = sub { "./@_[0]" };
@@ -281,16 +288,16 @@ if ($^O eq 'MacOS') {
 
 # &syscopy is an XSUB under OS/2
 unless (defined &syscopy) {
-    if ($^O eq 'VMS') {
+    if ($^OS_NAME eq 'VMS') {
 	*syscopy = \&rmscopy;
-    } elsif ($^O eq 'mpeix') {
+    } elsif ($^OS_NAME eq 'mpeix') {
 	*syscopy = sub {
 	    return 0 unless (nelems @_) == 2;
 	    # Use the MPE cp program in order to
 	    # preserve MPE file attributes.
 	    return system('/bin/cp', '-f', @_[0], @_[1]) == 0;
 	};
-    } elsif ($^O eq 'MSWin32' && defined &DynaLoader::boot_DynaLoader) {
+    } elsif ($^OS_NAME eq 'MSWin32' && defined &DynaLoader::boot_DynaLoader) {
 	# Win32::CopyFile() fill only work if we can load Win32.xs
 	*syscopy = sub {
 	    return 0 unless (nelems @_) == 2;
@@ -298,15 +305,15 @@ unless (defined &syscopy) {
 	};
     } elsif ($macfiles) {
 	*syscopy = sub {
-	    my($from, $to) = < @_;
+	    my@($from, $to) =  @_;
 	    my($dir, $toname);
 
 	    return 0 unless -e $from;
 
 	    if ($to =~ m/(.*:)([^:]+):?$/) {
-		($dir, $toname) = ($1, $2);
+		@($dir, $toname) = @($1, $2);
 	    } else {
-		($dir, $toname) = (":", $to);
+		@($dir, $toname) = @(":", $to);
 	    }
 
 	    unlink($to);
@@ -331,7 +338,7 @@ File::Copy - Copy files or filehandles
 	use File::Copy;
 
 	copy("file1","file2") or die "Copy failed: $!";
-	copy("Copy.pm",\*STDOUT);
+	copy("Copy.pm",$^STDOUT);
 	move("/dev1/fileA","/dev2/fileB");
 
 	use File::Copy "cp";
