@@ -1,11 +1,11 @@
 package File::Fetch;
 
-use strict;
-use FileHandle;
+use IO::File;
 use File::Copy;
 use File::Spec;
 use File::Spec::Unix;
 use File::Basename <              qw[dirname];
+use signals;
 
 use Cwd <                         qw[cwd];
 use Carp <                        qw[carp];
@@ -15,12 +15,11 @@ use Params::Check <               qw[check];
 use Module::Load::Conditional <   qw[can_load];
 use Locale::Maketext::Simple    Style => 'gettext';
 
-use vars <    qw[ $VERBOSE $PREFER_BIN $FROM_EMAIL $USER_AGENT
-                $BLACKLIST $METHOD_FAIL $VERSION $METHODS
-                $FTP_PASSIVE $TIMEOUT $DEBUG $WARN
-            ];
+our ($VERBOSE, $PREFER_BIN, $FROM_EMAIL, $USER_AGENT,
+     $BLACKLIST, $METHOD_FAIL, $VERSION, $METHODS,
+     $FTP_PASSIVE, $TIMEOUT, $DEBUG, $WARN);
 
-use constant QUOTE  => do { $^O eq 'MSWin32' ? q["] : q['] };            
+use constant QUOTE  => do { $^OS_NAME eq 'MSWin32' ?? q["] !! q['] };            
             
 
 $VERSION        = '0.14';
@@ -44,14 +43,14 @@ $METHODS = \%(
 );
 
 ### silly warnings ###
-local $Params::Check::VERBOSE               = 1;
-local $Params::Check::VERBOSE               = 1;
-local $Module::Load::Conditional::VERBOSE   = 0;
-local $Module::Load::Conditional::VERBOSE   = 0;
+local $Params::Check::VERBOSE                = 1;
+local $Params::Check::VERBOSE                = 1;
+local $Module::Load::Conditional::VERBOSE    = 0;
+local $Module::Load::Conditional::VERBOSE    = 0;
 
 ### see what OS we are on, important for file:// uris ###
-use constant ON_WIN         => ($^O eq 'MSWin32');
-use constant ON_VMS         => ($^O eq 'VMS');                                
+use constant ON_WIN         => ($^OS_NAME eq 'MSWin32');
+use constant ON_VMS         => ($^OS_NAME eq 'VMS');                                
 use constant ON_UNIX        => (!ON_WIN and !ON_VMS);
 use constant HAS_VOL        => (ON_WIN or ON_VMS);
 use constant HAS_SHARE      => (ON_WIN);
@@ -141,7 +140,7 @@ result of $ff->output_file will be used.
 ### Object & Accessors ###
 ##########################
 
-{
+do {
     ### template for new() and autogenerated accessors ###
     my $Tmpl = \%(
         scheme          => \%( default => 'http' ),
@@ -156,11 +155,10 @@ result of $ff->output_file will be used.
     );
     
     for my $method ( keys %$Tmpl ) {
-        no strict 'refs';
         *{Symbol::fetch_glob($method)} = sub {
                         my $self = shift;
-                        $self->{$method} = @_[0] if (nelems @_);
-                        return $self->{$method};
+                        $self->{+$method} = @_[0] if (nelems @_);
+                        return $self->{?$method};
                     }
     }
     
@@ -185,7 +183,7 @@ result of $ff->output_file will be used.
         
         return $args;
     }    
-}
+};
 
 =item $ff->output_file
 
@@ -327,20 +325,20 @@ sub _parse_uri {
 
     ### find the scheme ###
     $uri            =~ s|^(\w+)://||;
-    $href->{scheme} = $1;
+    $href->{+scheme} = $1;
 
     ### See rfc 1738 section 3.10
     ### http://www.faqs.org/rfcs/rfc1738.html
     ### And wikipedia for more on windows file:// urls
     ### http://en.wikipedia.org/wiki/File://
-    if( $href->{scheme} eq 'file' ) {
+    if( $href->{?scheme} eq 'file' ) {
         
         my @parts = split '/',$uri;
 
         ### file://hostname/...
         ### file://hostname/...
         ### normalize file://localhost with file:///
-        $href->{host} = @parts[0] || '';
+        $href->{+host} = @parts[0] || '';
 
         ### index in @parts where the path components begin;
         my $index = 1;  
@@ -348,8 +346,8 @@ sub _parse_uri {
         ### file:////hostname/sharename/blah.txt        
         if ( HAS_SHARE and not length @parts[0] and not length @parts[1] ) {
             
-            $href->{host}   = @parts[2] || '';  # avoid warnings
-            $href->{share}  = @parts[3] || '';  # avoid warnings        
+            $href->{+host}   = @parts[2] || '';  # avoid warnings
+            $href->{+share}  = @parts[3] || '';  # avoid warnings        
 
             $index          = 4         # index after the share
 
@@ -361,33 +359,33 @@ sub _parse_uri {
             ### this code comes from dmq's patch, but:
             ### XXX if volume is empty, wouldn't that be an error? --kane
             ### if so, our file://localhost test needs to be fixed as wel            
-            $href->{vol}    = @parts[1] || '';
+            $href->{+vol}    = @parts[1] || '';
 
             ### correct D| style colume descriptors
-            $href->{vol}    =~ s/\A([A-Z])\|\z/$1:/i if ON_WIN;
+            $href->{+vol}    =~ s/\A([A-Z])\|\z/$1:/i if ON_WIN;
 
             $index          = 2;        # index after the volume
         } 
 
         ### rebuild the path from the leftover parts;
-        $href->{path} = join '/', @( '', splice( @parts, $index, ((nelems @parts)-1) ));
+        $href->{+path} = join '/', @( '', splice( @parts, $index, ((nelems @parts)-1) ));
 
-    } else { <
+    } else { 
         ### using anything but qw() in hash slices may produce warnings 
         ### in older perls :-(
-        %{$href}{[qw(host path) ]} = $uri =~ m|([^/]*)(/.*)$|s;
+        %{$href}{[qw(host path) ]} = @: $uri =~ m|([^/]*)(/.*)$|s;
     }
 
     ### split the path into file + dir ###
-    {   my @parts = File::Spec::Unix->splitpath( delete $href->{path} );
-        $href->{path} = @parts[1];
-        $href->{file} = @parts[2];
-    }
+    do {   my @parts = File::Spec::Unix->splitpath( delete $href->{path} );
+        $href->{+path} = @parts[1];
+        $href->{+file} = @parts[2];
+    };
 
     ### host will be empty if the target was 'localhost' and the 
     ### scheme was 'file'
-    $href->{host} = '' if   ($href->{host}      eq 'localhost') and
-                            ($href->{scheme}    eq 'file');
+    $href->{+host} = '' if   ($href->{?host}      eq 'localhost') and
+                            ($href->{?scheme}    eq 'file');
 
     return $href;
 }
@@ -417,16 +415,16 @@ sub fetch {
     unless( -d $to ) {
         try { mkpath( $to ) };
 
-        return $self->_error( <loc("Could not create path '\%1'",$to)) if $@;
+        return $self->_error( <loc("Could not create path '\%1'",$to)) if $^EVAL_ERROR;
     }
 
     ### set passive ftp if required ###
-    local %ENV{FTP_PASSIVE} = $FTP_PASSIVE;
+    local env::var('FTP_PASSIVE' ) = $FTP_PASSIVE;
 
     ### we dont use catfile on win32 because if we are using a cygwin tool
     ### under cmd.exe they wont understand windows style separators.
-    my $out_to = ON_WIN ? $to.'/'.$self->output_file 
-                        : File::Spec->catfile( $to, < $self->output_file );
+    my $out_to = ON_WIN ?? $to.'/'.$self->output_file 
+                        !! File::Spec->catfile( $to, < $self->output_file );
     
     for my $method (  @{ $METHODS->{$self->scheme} } ) {
         my $sub =  '_'.$method.'_fetch';
@@ -438,10 +436,10 @@ sub fetch {
         }
 
         ### method is blacklisted ###
-        next if grep { lc $_ eq $method } @$BLACKLIST;
+        next if grep { lc $_ eq $method }, @$BLACKLIST;
 
         ### method is known to fail ###
-        next if $METHOD_FAIL->{$method};
+        next if $METHOD_FAIL->{?$method};
 
         ### there's serious issues with IPC::Run and quoting of command
         ### line arguments. using quotes in the wrong place breaks things,
@@ -460,7 +458,7 @@ sub fetch {
                      "but it was not created",$method,$file));
 
                 ### mark the failure ###
-                $METHOD_FAIL->{$method} = 1;
+                $METHOD_FAIL->{+$method} = 1;
 
                 next;
 
@@ -512,7 +510,7 @@ sub _lwp_fetch {
 
         ### special rules apply for file:// uris ###
         $uri->scheme( < $self->scheme );
-        $uri->host( $self->scheme eq 'file' ? '' : < $self->host );
+        $uri->host( $self->scheme eq 'file' ?? '' !! < $self->host );
         $uri->userinfo("anonymous:$FROM_EMAIL") if $self->scheme ne 'file';
 
         ### set up the useragent object
@@ -535,7 +533,7 @@ sub _lwp_fetch {
         }
 
     } else {
-        $METHOD_FAIL->{'lwp'} = 1;
+        $METHOD_FAIL->{+'lwp'} = 1;
         return;
     }
 }
@@ -561,7 +559,7 @@ sub _netftp_fetch {
         my @options =$self->host;
         push(@options, Timeout => $TIMEOUT) if $TIMEOUT;
         unless( $ftp = Net::FTP->new( < @options ) ) {
-            return $self->_error( <loc("Ftp creation failed: \%1",$@));
+            return $self->_error( <loc("Ftp creation failed: \%1",$^EVAL_ERROR));
         }
 
         ### login ###
@@ -589,7 +587,7 @@ sub _netftp_fetch {
         return $target;
 
     } else {
-        $METHOD_FAIL->{'netftp'} = 1;
+        $METHOD_FAIL->{+'netftp'} = 1;
         return;
     }
 }
@@ -621,8 +619,8 @@ sub _wget_fetch {
         push @$cmd, '--output-document', 
                     ### DO NOT quote things for IPC::Run, it breaks stuff.
                     $IPC::Cmd::USE_IPC_RUN
-                        ? ($to, < $self->uri)
-                        : (QUOTE. $to .QUOTE, QUOTE. $self->uri .QUOTE);
+                        ?? ($to, < $self->uri)
+                        !! (QUOTE. $to .QUOTE, QUOTE. $self->uri .QUOTE);
 
         ### shell out ###
         my $captured;
@@ -640,7 +638,7 @@ sub _wget_fetch {
         return $to;
 
     } else {
-        $METHOD_FAIL->{'wget'} = 1;
+        $METHOD_FAIL->{+'wget'} = 1;
         return;
     }
 }
@@ -660,12 +658,12 @@ sub _ftp_fetch {
     ### see if we have a ftp binary ###
     if( my $ftp = can_run('ftp') ) {
 
-        my $fh = FileHandle->new;
+        my $fh = IO::File->new;
 
-        local %SIG{CHLD} = 'IGNORE';
+        local signals::handler("CHLD") = 'IGNORE';
 
         unless ($fh->open("|$ftp -n")) {
-            return $self->_error( <loc("\%1 creation failed: \%2", $ftp, $!));
+            return $self->_error( <loc("\%1 creation failed: \%2", $ftp, $^OS_ERROR));
         }
 
         my @dialog = @(
@@ -702,7 +700,7 @@ sub _lynx_fetch {
     if( my $lynx = can_run('lynx') ) {
 
         unless( IPC::Cmd->can_capture_buffer ) {
-            $METHOD_FAIL->{'lynx'} = 1;
+            $METHOD_FAIL->{+'lynx'} = 1;
 
             return $self->_error( <loc( 
                 "Can not capture buffers. Can not use '\%1' to fetch files",
@@ -710,9 +708,9 @@ sub _lynx_fetch {
         }            
 
         ### write to the output file ourselves, since lynx ass_u_mes to much
-        my $local = FileHandle->new(">$to")
+        my $local = IO::File->new(">", "$to")
                         or return $self->_error( <loc(
-                            "Could not open '\%1' for writing: \%2",$to,$!));
+                            "Could not open '\%1' for writing: \%2",$to,$^OS_ERROR));
 
         ### dump to stdout ###
         my $cmd = \@(
@@ -725,8 +723,8 @@ sub _lynx_fetch {
 
         ### DO NOT quote things for IPC::Run, it breaks stuff.
         push @$cmd, $IPC::Cmd::USE_IPC_RUN
-                        ? < $self->uri
-                        : QUOTE. $self->uri .QUOTE;
+                        ?? < $self->uri
+                        !! QUOTE. $self->uri .QUOTE;
 
 
         ### shell out ###
@@ -752,7 +750,7 @@ sub _lynx_fetch {
         return $to;
 
     } else {
-        $METHOD_FAIL->{'lynx'} = 1;
+        $METHOD_FAIL->{+'lynx'} = 1;
         return;
     }
 }
@@ -784,8 +782,8 @@ sub _ncftp_fetch {
                                     # remote path to the file
             ### DO NOT quote things for IPC::Run, it breaks stuff.
             $IPC::Cmd::USE_IPC_RUN
-                        ? < File::Spec::Unix->catdir( < $self->path, < $self->file )
-                        : QUOTE. File::Spec::Unix->catdir( < 
+                        ?? < File::Spec::Unix->catdir( < $self->path, < $self->file )
+                        !! QUOTE. File::Spec::Unix->catdir( < 
                                         $self->path, < $self->file ) .QUOTE
             
         );
@@ -802,7 +800,7 @@ sub _ncftp_fetch {
         return $to;
 
     } else {
-        $METHOD_FAIL->{'ncftp'} = 1;
+        $METHOD_FAIL->{+'ncftp'} = 1;
         return;
     }
 }
@@ -837,8 +835,8 @@ sub _curl_fetch {
         push @$cmd, '--fail', '--location', '--output', 
                     ### DO NOT quote things for IPC::Run, it breaks stuff.
                     $IPC::Cmd::USE_IPC_RUN
-                        ? ($to, < $self->uri)
-                        : (QUOTE. $to .QUOTE, QUOTE. $self->uri .QUOTE);
+                        ?? ($to, < $self->uri)
+                        !! (QUOTE. $to .QUOTE, QUOTE. $self->uri .QUOTE);
 
         my $captured;
         unless(run( command => $cmd,
@@ -852,7 +850,7 @@ sub _curl_fetch {
         return $to;
 
     } else {
-        $METHOD_FAIL->{'curl'} = 1;
+        $METHOD_FAIL->{+'curl'} = 1;
         return;
     }
 }
@@ -918,9 +916,9 @@ sub _file_fetch {
     my $rv = try { File::Copy::copy( $remote, $to ) };
 
     ### something went wrong ###
-    if( !$rv or $@ ) {
+    if( !$rv or $^EVAL_ERROR ) {
         return $self->_error( <loc("Could not copy '\%1' to '\%2': \%3 \%4",
-                             $remote, $to, $!, $@));
+                             $remote, $to, $^OS_ERROR, $^EVAL_ERROR));
     }
 
     return $to;
@@ -948,8 +946,8 @@ sub _rsync_fetch {
 
         ### DO NOT quote things for IPC::Run, it breaks stuff.
         push @$cmd, $IPC::Cmd::USE_IPC_RUN
-                        ? ( <$self->uri, $to)
-                        : (QUOTE. $self->uri .QUOTE, QUOTE. $to .QUOTE);
+                        ?? ( <$self->uri, $to)
+                        !! (QUOTE. $self->uri .QUOTE, QUOTE. $to .QUOTE);
 
         my $captured;
         unless(run( command => $cmd,
@@ -958,13 +956,13 @@ sub _rsync_fetch {
         ) {
 
             return $self->_error( <loc("Command \%1 failed: \%2", 
-                "{join ' ',@$cmd}" || '', $captured || ''));
+                "$(join ' ',@$cmd)" || '', $captured || ''));
         }
 
         return $to;
 
     } else {
-        $METHOD_FAIL->{'rsync'} = 1;
+        $METHOD_FAIL->{+'rsync'} = 1;
         return;
     }
 }
@@ -993,7 +991,7 @@ sub _error {
     $self->_error_msg_long( < Carp::longmess($error) );
     
     if( $WARN ) {
-        carp $DEBUG ? < $self->_error_msg_long : < $self->_error_msg;
+        carp $DEBUG ?? < $self->_error_msg_long !! < $self->_error_msg;
     }
 
     return;
@@ -1001,7 +999,7 @@ sub _error {
 
 sub error {
     my $self = shift;
-    return shift() ? $self->_error_msg_long : $self->_error_msg;
+    return shift() ?? $self->_error_msg_long !! $self->_error_msg;
 }
 
 
