@@ -1,7 +1,7 @@
 package File::Spec::Functions;
 
 use File::Spec;
-use strict;
+
 
 our (@ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS, $VERSION);
 
@@ -38,7 +38,6 @@ require Exporter;
 
 foreach my $meth ( @( < @EXPORT, < @EXPORT_OK )) {
     my $sub = File::Spec->can($meth);
-    no strict 'refs';
     *{Symbol::fetch_glob($meth)} = sub {&$sub('File::Spec', < @_)};
 }
 
