@@ -1,7 +1,6 @@
 package File::Spec::OS2;
 
-use strict;
-use vars < qw(@ISA $VERSION);
+our (@ISA, $VERSION);
 require File::Spec::Unix;
 
 $VERSION = '3.2701';
@@ -16,13 +15,12 @@ sub case_tolerant {
     return 1;
 }
 
-sub file_name_is_absolute {
-    my ($self,$file) = < @_;
+sub file_name_is_absolute($self,$file) {
     return scalar($file =~ m{^([a-z]:)?[\\/]}is);
 }
 
 sub path {
-    my $path = %ENV{PATH};
+    my $path = env::var('PATH');
     $path =~ s:\\:/:g;
     my @path = split(';',$path);
     foreach ( @path) { $_ = '.' if $_ eq '' }
@@ -37,7 +35,7 @@ sub _cwd {
 my $tmpdir;
 sub tmpdir {
     return $tmpdir if defined $tmpdir;
-    my @d = %ENV{[qw(TMPDIR TEMP TMP)]};	# function call could autovivivy
+    my @d = map { env::var($_) }, qw(TMPDIR TEMP TMP);
     $tmpdir = @_[0]->_tmpdir( < @d, '/tmp', '/'  );
 }
 
@@ -52,11 +50,10 @@ sub catdir {
     return $self->canonpath(join('', @args));
 }
 
-sub canonpath {
-    my ($self,$path) = < @_;
+sub canonpath($self,?$path) {
     return unless defined $path;
 
-    $path =~ s/^([a-z]:)/{lc($1)}/s;
+    $path =~ s/^([a-z]:)/$(lc($1))/s;
     $path =~ s|\\|/|g;
     $path =~ s|([^/])/+|$1/|g;                  # xx////xx  -> xx/xx
     $path =~ s|(/\.)+/|/|g;                     # xx/././xx -> xx/xx
@@ -69,9 +66,8 @@ sub canonpath {
 }
 
 
-sub splitpath {
-    my ($self,$path, $nofile) = < @_;
-    my ($volume,$directory,$file) = ('','','');
+sub splitpath($self,$path, ?$nofile) {
+    my @($volume,$directory,$file) = @('','','');
     if ( $nofile ) {
         $path =~ 
             m{^( (?:[a-zA-Z]:|(?:\\\\|//)[^\\/]+[\\/][^\\/]+)? ) 
@@ -98,14 +94,12 @@ sub splitpath {
 }
 
 
-sub splitdir {
-    my ($self,$directories) = < @_ ;
+sub splitdir($self,$directories) { 
     split m|[\\/]|, $directories, -1;
 }
 
 
-sub catpath {
-    my ($self,$volume,$directory,$file) = < @_;
+sub catpath($self,$volume,$directory,$file) {
 
     # If it's UNC, make sure the glue separator is there, reusing
     # whatever separator is first in the $volume
@@ -123,7 +117,7 @@ sub catpath {
          $file   =~ m@[^\\/]@
        ) {
         $volume =~ m@([\\/])@ ;
-        my $sep = $1 ? $1 : '/' ;
+        my $sep = $1 ?? $1 !! '/' ;
         $volume .= $sep ;
     }
 
@@ -133,8 +127,7 @@ sub catpath {
 }
 
 
-sub abs2rel {
-    my($self,$path,$base) = < @_;
+sub abs2rel($self,$path,$base) {
 
     # Clean up $path
     if ( ! $self->file_name_is_absolute( $path ) ) {
@@ -153,8 +146,8 @@ sub abs2rel {
     }
 
     # Split up paths
-    my ( $path_volume, $path_directories, $path_file ) = < $self->splitpath( $path, 1 ) ;
-    my ( $base_volume, $base_directories ) = < $self->splitpath( $base, 1 ) ;
+    my @( $path_volume, $path_directories, $path_file ) =  $self->splitpath( $path, 1 ) ;
+    my @( $base_volume, $base_directories, _ ) =  $self->splitpath( $base, 1 ) ;
     return $path unless $path_volume eq $base_volume;
 
     # Now, remove all leading components that are the same
@@ -196,8 +189,7 @@ sub abs2rel {
 }
 
 
-sub rel2abs {
-    my ($self,$path,$base ) = < @_;
+sub rel2abs($self,$path,?$base) {
 
     if ( ! $self->file_name_is_absolute( $path ) ) {
 
@@ -211,10 +203,10 @@ sub rel2abs {
             $base = $self->canonpath( $base ) ;
         }
 
-        my ( $path_directories, $path_file ) =
-            < ($self->splitpath( $path, 1 ))[[1..2]] ;
+        my @( $path_directories, $path_file ) =
+             ($self->splitpath( $path, 1 ))[[1..2]] ;
 
-        my ( $base_volume, $base_directories ) = <
+        my @( $base_volume, $base_directories ) = 
             $self->splitpath( $base, 1 ) ;
 
         $path = $self->catpath( 
