@@ -1,12 +1,10 @@
 package File::Spec::VMS;
 
-use strict;
-use vars < qw(@ISA $VERSION);
 require File::Spec::Unix;
 
-$VERSION = '3.2701';
+our $VERSION = '3.2701';
 
-@ISA = qw(File::Spec::Unix);
+our @ISA = qw(File::Spec::Unix);
 
 use File::Basename;
 use VMS::Filespec;
@@ -34,7 +32,7 @@ Removes redundant portions of file specifications according to VMS syntax.
 =cut
 
 sub canonpath {
-    my($self,$path) = <@_;
+    my @($self,?$path) = @_;
 
     return undef unless defined $path;
 
@@ -90,12 +88,12 @@ cases (e.g. elements other than the first being absolute filespecs).
 sub catdir {
     my $self = shift;
     my $dir = pop;
-    my @dirs = @( < grep {defined() && length()} @_ );
+    my @dirs = grep {defined() && length()}, @_ ;
 
     my $rslt;
     if (@dirs) {
-	my $path = ((nelems @dirs) == 1) ? @dirs[0] : $self->catdir(< @dirs);
-	my ($spath,$sdir) = ($path,$dir);
+	my $path = ((nelems @dirs) == 1) ?? @dirs[0] !! $self->catdir(< @dirs);
+	my @($spath,$sdir) = @($path,$dir);
 	$spath =~ s/\.dir\Z(?!\n)//; $sdir =~ s/\.dir\Z(?!\n)//; 
 	$sdir = $self->eliminate_macros($sdir) unless $sdir =~ m/^[\w\-]+\Z(?!\n)/s;
 	$rslt = $self->fixpath($self->eliminate_macros($spath)."/$sdir",1);
@@ -124,11 +122,11 @@ VMS-syntax file specification.
 sub catfile {
     my $self = shift;
     my $file = $self->canonpath(pop());
-    my @files = @(< grep {defined() && length()} @_);
+    my @files = @(< grep {defined() && length()}, @_);
 
     my $rslt;
     if (@files) {
-	my $path = ((nelems @files) == 1) ? @files[0] : $self->catdir(<@files);
+	my $path = ((nelems @files) == 1) ?? @files[0] !! $self->catdir(<@files);
 	my $spath = $path;
 	$spath =~ s/\.dir\Z(?!\n)//;
 	if ($spath =~ m/^[^\)\]\/:>]+\)\Z(?!\n)/s && basename($file) eq $file) {
@@ -136,10 +134,10 @@ sub catfile {
 	}
 	else {
 	    $rslt = $self->eliminate_macros($spath);
-	    $rslt = vmsify($rslt.((defined $rslt) && ($rslt ne '') ? '/' : '').unixify($file));
+	    $rslt = vmsify($rslt.((defined $rslt) && ($rslt ne '') ?? '/' !! '').unixify($file));
 	}
     }
-    else { $rslt = (defined($file) && length($file)) ? vmsify($file) : ''; }
+    else { $rslt = (defined($file) && length($file)) ?? vmsify($file) !! ''; }
     return $self->canonpath($rslt);
 }
 
@@ -190,7 +188,7 @@ is tainted, it is not used.
 my $tmpdir;
 sub tmpdir {
     return $tmpdir if defined $tmpdir;
-    $tmpdir = @_[0]->_tmpdir( 'sys$scratch:', %ENV{TMPDIR} );
+    $tmpdir = @_[0]->_tmpdir( 'sys$scratch:', env::var('TMPDIR') );
 }
 
 =item updir (override)
@@ -222,7 +220,7 @@ to C<split> string value of C<%ENV{'PATH'}>.
 
 sub path {
     my (@dirs,$dir,$i);
-    while ($dir = %ENV{'DCL$PATH;' . $i++}) { push(@dirs,$dir); }
+    while ($dir = env::var('DCL$PATH;' . $i++)) { push(@dirs,$dir); }
     return < @dirs;
 }
 
@@ -233,9 +231,9 @@ Checks for VMS directory spec as well as Unix separators.
 =cut
 
 sub file_name_is_absolute {
-    my ($self,$file) = <@_;
+    my @($self,$file) = @_;
     # If it's a logical name, expand it.
-    $file = %ENV{$file} while $file =~ m/^[\w\$\-]+\Z(?!\n)/s && %ENV{$file};
+    $file = env::var($file) while $file =~ m/^[\w\$\-]+\Z(?!\n)/s && env::var($file);
     return scalar($file =~ m!^/!s             ||
 		  $file =~ m![<\[][^.\-\]>]!  ||
 		  $file =~ m/:[^<\[]/);
@@ -248,8 +246,8 @@ Splits using VMS syntax.
 =cut
 
 sub splitpath {
-    my($self,$path) = <@_;
-    my($dev,$dir,$file) = ('','','');
+    my @($self,$path) = @_;
+    my @($dev,$dir,$file) = @('','','');
 
     vmsify($path) =~ m/(.+:)?([\[<].*[\]>])?(.*)/s;
     return @($1 || '',$2 || '',$3);
@@ -262,7 +260,7 @@ Split dirspec using VMS syntax.
 =cut
 
 sub splitdir {
-    my($self,$dirspec) = <@_;
+    my @($self,$dirspec) = @_;
     my @dirs = @();
     return @dirs if ( (!defined $dirspec) || ('' eq $dirspec) );
     $dirspec =~ s/</[/g;
@@ -294,12 +292,12 @@ Construct a complete filespec using VMS syntax
 =cut
 
 sub catpath {
-    my($self,$dev,$dir,$file) = <@_;
+    my @($self,$dev,$dir,$file) = @_;
     
     # We look for a volume in $dev, then in $dir, but not both
-    my ($dir_volume, $dir_dir, $dir_file) = $self->splitpath($dir);
+    my @($dir_volume, $dir_dir, $dir_file) = $self->splitpath($dir);
     $dev = $dir_volume unless length $dev;
-    $dir = length $dir_file ? $self->catfile($dir_dir, $dir_file) : $dir_dir;
+    $dir = length $dir_file ?? $self->catfile($dir_dir, $dir_file) !! $dir_dir;
     
     if ($dev =~ m|^/+([^/]+)|) { $dev = "$1:"; }
     else { $dev .= ':' unless $dev eq '' or $dev =~ m/:\Z(?!\n)/; }
@@ -319,9 +317,9 @@ Use VMS syntax when converting filespecs.
 sub abs2rel {
     my $self = shift;
     return vmspath(File::Spec::Unix::abs2rel( $self, < @_ ))
-        if grep m{/}, @_;
+        if grep { m{/} }, @_;
 
-    my($path,$base) = < @_;
+    my @($path,$base) = @_;
     $base = $self->_cwd() unless defined $base and length $base;
 
     for (@(\$path, \$base)) { $$_ = $self->canonpath($$_) }
@@ -336,11 +334,12 @@ sub abs2rel {
     # and we do not even try to call $parse() or consult %ENV for $trnlnm()
     # (this module needs to run on non VMS platforms after all).
     
-    my ($path_volume, $path_directories, $path_file) = $self->splitpath($path);
-    my ($base_volume, $base_directories, $base_file) = $self->splitpath($base);
+    my @($path_volume, $path_directories, $path_file) = $self->splitpath($path);
+    my @($base_volume, $base_directories, $base_file) = $self->splitpath($base);
     return $path unless lc($path_volume) eq lc($base_volume);
 
-    for ($path, $base) { $_ = $self->rel2abs($_) }
+    $path = $self->rel2abs($path);
+    $base = $self->rel2abs($base);
 
     # Now, remove all leading components that are the same
     my @pathchunks = $self->splitdir( $path_directories );
@@ -379,12 +378,12 @@ Use VMS syntax when converting filespecs.
 
 sub rel2abs {
     my $self = shift ;
-    my ($path,$base ) = < @_;
+    my @($path,$base ) = @_;
     return undef unless defined $path;
     if ($path =~ m/\//) {
 	$path = ( -d $path || $path =~ m/\/\z/  # educated guessing about
-		   ? vmspath($path)             # whether it's a directory
-		   : vmsify($path) );
+		   ?? vmspath($path)             # whether it's a directory
+		   !! vmsify($path) );
     }
     $base = vmspath($base) if defined $base && $base =~ m/\//;
     # Clean up and split up $path
@@ -401,10 +400,10 @@ sub rel2abs {
         }
 
         # Split up paths
-        my ( $path_directories, $path_file ) =
-            < ($self->splitpath( $path ))[[1..2]] ;
+        my @( $path_directories, $path_file ) =
+            ($self->splitpath( $path ))[[1..2]] ;
 
-        my ( $base_volume, $base_directories ) =
+        my @( $base_volume, $base_directories ) =
             $self->splitpath( $base ) ;
 
         $path_directories = '' if $path_directories eq '[]' ||
@@ -433,12 +432,12 @@ sub rel2abs {
 # Please consider these two methods deprecated.  Do not patch them,
 # patch the ones in ExtUtils::MM_VMS instead.
 sub eliminate_macros {
-    my($self,$path) = <@_;
+    my @($self,$path) = @_;
     return '' unless (defined $path) && ($path ne '');
     $self = \%() unless ref $self;
 
     if ($path =~ m/\s/) {
-      return join ' ', map { $self->eliminate_macros($_) } split m/\s+/, $path;
+      return join ' ', map { $self->eliminate_macros($_) }, split m/\s+/, $path;
     }
 
     my $npath = unixify($path);
@@ -448,7 +447,7 @@ sub eliminate_macros {
     # perform m##g in scalar context so it acts as an iterator
     while ($npath =~ m#(.*?)\$\((\S+?)\)(.*)#gs) { 
         if ($self->{$2}) {
-            ($head,$macro,$tail) = ($1,$2,$3);
+            @($head,$macro,$tail) = @($1,$2,$3);
             if (ref $self->{$macro}) {
                 if (ref $self->{$macro} eq 'ARRAY') {
                     $macro = join ' ', <@{$self->{$macro}};
@@ -464,20 +463,20 @@ sub eliminate_macros {
             $npath = "$head$macro$tail";
         }
     }
-    if ($complex) { $npath =~ s#\cB(.*?)\cB#\${$1}#gs; }
+    if ($complex) { $npath =~ s#\cB(.*?)\cB#\$$1#gs; }
     $npath;
 }
 
 # Deprecated.  See the note above for eliminate_macros().
 sub fixpath {
-    my($self,$path,$force_path) = @_;
+    my @($self,$path,$force_path) = @_;
     return '' unless $path;
     $self = bless \%() unless ref $self;
     my($fixedpath,$prefix,$name);
 
     if ($path =~ m/\s/) {
       return join ' ',
-             map { $self->fixpath($_,$force_path) }
+             map { $self->fixpath($_,$force_path) },
 	     split m/\s+/, $path;
     }
 
@@ -489,11 +488,11 @@ sub fixpath {
             $fixedpath = vmsify($self->eliminate_macros($path));
         }
     }
-    elsif ((($prefix,$name) = ($path =~ m#^\$\(([^\)]+)\)(.+)#s)) && $self->{$prefix}) {
+    elsif ((@($prefix,$name) = @($path =~ m#^\$\(([^\)]+)\)(.+)#s)) && $self->{$prefix}) {
         my($vmspre) = $self->eliminate_macros("\$($prefix)");
         # is it a dir or just a name?
-        $vmspre = ($vmspre =~ m|/| or $prefix =~ m/DIR\Z(?!\n)/) ? vmspath($vmspre) : '';
-        $fixedpath = ($vmspre ? $vmspre : $self->{$prefix}) . $name;
+        $vmspre = ($vmspre =~ m|/| or $prefix =~ m/DIR\Z(?!\n)/) ?? vmspath($vmspre) !! '';
+        $fixedpath = ($vmspre ?? $vmspre !! $self->{$prefix}) . $name;
         $fixedpath = vmspath($fixedpath) if $force_path;
     }
     else {
