@@ -2,21 +2,21 @@
 # Time-stamp: "2004-06-20 21:47:55 ADT"
 
 package I18N::LangTags::Detect;
-use strict;
 
-use vars < qw( @ISA $VERSION $MATCH_SUPERS $USING_LANGUAGE_TAGS
-             $USE_LITERALS $MATCH_SUPERS_TIGHTLY);
+
+our (@ISA, $VERSION, $MATCH_SUPERS, $USING_LANGUAGE_TAGS,
+     $USE_LITERALS, $MATCH_SUPERS_TIGHTLY);
 
 BEGIN { unless(defined &DEBUG) { *DEBUG = sub () {0} } }
  # define the constant 'DEBUG' at compile-time
 
 $VERSION = "1.03";
-@ISA = @( () );
+@ISA = @();
 use I18N::LangTags < qw(alternate_language_tags locale2language_tag);
 
-sub _uniq { my %seen; return grep(!(%seen{$_}++), @_); }
+sub _uniq { my %seen; return grep( {!(%seen{+$_}++) }, @_); }
 sub _normalize {
-  my(@languages) = map lc($_), grep $_, map {; $_, < alternate_language_tags($_) } @_;
+  my @languages = map { lc($_) }, grep { $_ }, @+: map { @: $_, < alternate_language_tags($_) }, @_;
   return _uniq(< @languages);
 }
 
@@ -31,28 +31,28 @@ sub ambient_langprefs { # always returns things untainted
   my $base_class = @_[0];
   
   return $base_class->http_accept_langs
-   if length( %ENV{'REQUEST_METHOD'} || '' ); # I'm a CGI
+   if length( env::var('REQUEST_METHOD') || '' ); # I'm a CGI
        # it's off in its own routine because it's complicated
 
   # Not running as a CGI: try to puzzle out from the environment
   my @languages;
 
   foreach my $envname (qw( LANGUAGE LC_ALL LC_MESSAGES LANG )) {
-    next unless %ENV{$envname};
-    DEBUG and print "Noting \$$envname: %ENV{$envname}\n";
+    next unless env::var($envname);
+    DEBUG and print $^STDOUT, "Noting \$$envname: $(env::var($envname))\n";
     push @languages,
-      < map locale2language_tag($_),
+      < map { locale2language_tag($_) },
         # if it's a lg tag, fine, pass thru (untainted)
         # if it's a locale ID, try converting to a lg tag (untainted),
         # otherwise nix it.
 
       split m/[,:]/,
-      %ENV{$envname}
+      env::var($envname)
     ;
     last; # first one wins
   }
   
-  if(%ENV{'IGNORE_WIN32_LOCALE'}) {
+  if(env::var('IGNORE_WIN32_LOCALE')) {
     # no-op
   } elsif(&_try_use('Win32::Locale')) {
     # If we have that module installed...
@@ -70,7 +70,7 @@ sub http_accept_langs {
   # Hm.  Should I just move this into I18N::LangTags at some point?
   no integer;
 
-  my $in = ((nelems @_) +> 1) ? @_[1] : %ENV{'HTTP_ACCEPT_LANGUAGE'};
+  my $in = ((nelems @_) +> 1) ?? @_[1] !! env::var('HTTP_ACCEPT_LANGUAGE');
   # (always ends up untainting)
 
   return() unless defined $in and length $in;
@@ -107,15 +107,15 @@ sub http_accept_langs {
        $
       /sx
     ;
-    $q = (defined $2 and length $2) ? $2 : 1;
+    $q = (defined $2 and length $2) ?? $2 !! 1;
     #print "$1 with q=$q\n";
-    push @{ %pref{$q} }, lc $1;
+    push @{ %pref{+$q} }, lc $1;
   }
 
   return _normalize(
     # Read off %pref, in descending key order...
-    < map < @{%pref{$_}},
-    sort {$b <+> $a}
+    < @+: map { @{%pref{?$_}} },
+    sort {$b <+> $a},
     keys %pref
   );
 }
@@ -127,25 +127,25 @@ my %tried = %( () );
 
 sub _try_use {   # Basically a wrapper around "require Modulename"
   # "Many men have tried..."  "They tried and failed?"  "They tried and died."
-  return %tried{@_[0]} if exists %tried{@_[0]};  # memoization
+  return %tried{?@_[0]} if exists %tried{@_[0]};  # memoization
 
   my $module = @_[0];   # ASSUME sane module name!
-  { no strict 'refs';
-    return @(%tried{$module} = 1)
+  do {
+    return @(%tried{+$module} = 1)
      if defined(%{*{Symbol::fetch_glob($module . "::Lexicon")}}) or defined(@{*{Symbol::fetch_glob($module . "::ISA")}});
     # weird case: we never use'd it, but there it is!
-  }
+  };
 
-  print " About to use $module ...\n" if DEBUG;
-  {
+  print $^STDOUT, " About to use $module ...\n" if DEBUG;
+  do {
     eval "require $module"; # used to be "use $module", but no point in that.
-  }
-  if($@) {
-    print "Error using $module \: $@\n" if DEBUG +> 1;
-    return %tried{$module} = 0;
+  };
+  if($^EVAL_ERROR) {
+    print $^STDOUT, "Error using $module \: $^EVAL_ERROR\n" if DEBUG +> 1;
+    return (%tried{+$module} = 0);
   } else {
-    print " OK, $module is used\n" if DEBUG;
-    return %tried{$module} = 1;
+    print $^STDOUT, " OK, $module is used\n" if DEBUG;
+    return (%tried{+$module} = 1);
   }
 }
 
