@@ -1,17 +1,15 @@
 package IPC::Cmd;
 
-use strict;
+our (@ISA, $VERSION, @EXPORT_OK, $VERBOSE, $DEBUG,
+     $USE_IPC_RUN, $USE_IPC_OPEN3, $WARN);
 
 BEGIN {
 
-    use constant IS_VMS   => $^O eq 'VMS'                       ? 1 : 0;    
-    use constant IS_WIN32 => $^O eq 'MSWin32'                   ? 1 : 0;
-    use constant IS_WIN98 => (IS_WIN32 and !Win32::IsWinNT())   ? 1 : 0;
+    use constant IS_VMS   => $^OS_NAME eq 'VMS'                       ?? 1 !! 0;    
+    use constant IS_WIN32 => $^OS_NAME eq 'MSWin32'                   ?? 1 !! 0;
+    use constant IS_WIN98 => (IS_WIN32 and !Win32::IsWinNT())   ?? 1 !! 0;
 
     use Exporter    ();
-    use vars <        qw[ @ISA $VERSION @EXPORT_OK $VERBOSE $DEBUG
-                        $USE_IPC_RUN $USE_IPC_OPEN3 $WARN
-                    ];
 
     $VERSION        = '0.40_1';
     $VERBOSE        = 0;
@@ -132,7 +130,7 @@ sub can_use_ipc_open3   {
     ### ipc::open3 works on every platform, but it can't capture buffers
     ### on win32 :(
     return unless can_load(
-        modules => \%( < map {$_ => '0.0'} qw|IPC::Open3 IO::Select Symbol| ),
+        modules => \%( < @+: map { @: $_ => '0.0'}, qw|IPC::Open3 IO::Select Symbol| ),
         verbose => ($WARN && $verbose),
     );
     
@@ -177,7 +175,7 @@ sub can_run {
 
     # a lot of VMS executables have a symbol defined
     # check those first
-    if ( $^O eq 'VMS' ) {
+    if ( $^OS_NAME eq 'VMS' ) {
         require VMS::DCLsym;
         my $syms = VMS::DCLsym->new;
         return $command if scalar $syms->getsym( uc $command );
@@ -191,10 +189,10 @@ sub can_run {
         return MM->maybe_command($command);
 
     } else {
-        for my $dir (@(
-            ( <split m/\Q%Config::Config{path_sep}\E/, %ENV{PATH}),
-            File::Spec->curdir)
-        ) {           
+        for my $dir (@:
+            < split(m/\Q$(Config::config_value('path_sep'))\E/, env::var('PATH')),
+            File::Spec->curdir
+        ) {
             my $abs = File::Spec->catfile($dir, $command);
             return $abs if $abs = MM->maybe_command($abs);
         }
@@ -308,7 +306,7 @@ sub run {
         return;
     };        
 
-    print < loc("Running [\%1]...\n", (ref $cmd ? "{join ' ',@$cmd}" : $cmd)) if $verbose;
+    print $^STDOUT, < loc("Running [\%1]...\n", (ref $cmd ?? "$(join ' ',@$cmd)" !! $cmd)) if $verbose;
 
     ### did the user pass us a buffer to fill or not? if so, set this
     ### flag so we know what is expected of us
@@ -324,7 +322,7 @@ sub run {
         my $buf = shift;
         return unless defined $buf;
         
-        print STDOUT $buf if $verbose;
+        print $^STDOUT, $buf if $verbose;
         push @buffer,   $buf;
         push @buff_out, $buf;
     };
@@ -334,14 +332,14 @@ sub run {
         my $buf = shift;
         return unless defined $buf;
         
-        print STDERR $buf if $verbose;
+        print $^STDERR, $buf if $verbose;
         push @buffer,   $buf;
         push @buff_err, $buf;
     };
     
 
     ### flag to indicate we have a buffer captured
-    my $have_buffer = __PACKAGE__->can_capture_buffer ? 1 : 0;
+    my $have_buffer = __PACKAGE__->can_capture_buffer ?? 1 !! 0;
     
     ### flag indicating if the subcall went ok
     my $ok;
@@ -365,7 +363,7 @@ sub run {
         ### in case there are pipes in there;
         ### IPC::Open3 will call exec and exec will do the right thing 
         $ok = __PACKAGE__->_open3_run( 
-                                ( ref $cmd ? "{join ' ',@$cmd}" : $cmd ),
+                                ( ref $cmd ?? "$(join ' ',@$cmd)" !! $cmd ),
                                 $_out_handler, $_err_handler, $verbose 
                             );
         
@@ -373,7 +371,7 @@ sub run {
     } else {
         __PACKAGE__->_debug( "# Using system(). Have buffer: $have_buffer" )
             if $DEBUG;
-        $ok = __PACKAGE__->_system_run( (ref $cmd ? "{join ' ',@$cmd}" : $cmd), $verbose );
+        $ok = __PACKAGE__->_system_run( (ref $cmd ?? "$(join ' ',@$cmd)" !! $cmd), $verbose );
     }
     
     ### fill the buffer;
@@ -382,8 +380,8 @@ sub run {
     ### return a list of flags and buffers (if available) in list
     ### context, or just a simple 'ok' in scalar
     return $have_buffer
-                    ?  @($ok, $?, \@buffer, \@buff_out, \@buff_err)
-                    :  @($ok, $? );
+                    ??  @($ok, $^CHILD_ERROR, \@buffer, \@buff_out, \@buff_err)
+                    !!  @($ok, $^CHILD_ERROR );
 }
 
 sub _open3_run { 
@@ -411,16 +409,16 @@ sub _open3_run {
     ### We'll do the same for STDOUT and STDERR. It works without
     ### duping them on non-unix derivatives, but not on win32.
     my @fds_to_dup = @( IS_WIN32 && !$verbose 
-                            ? < qw[STDIN STDOUT STDERR] 
-                            : < qw[STDIN]
+                            ?? < qw[STDIN STDOUT STDERR] 
+                            !! < qw[STDIN]
                         );
     __PACKAGE__->__dup_fds( < @fds_to_dup );
     
 
     my $pid = IPC::Open3::open3(
-                    '<&STDIN',
-                    (IS_WIN32 ? '>&STDOUT' : $kidout),
-                    (IS_WIN32 ? '>&STDERR' : $kiderror),
+                    (@: '<&', $^STDIN),
+                    (IS_WIN32 ?? (@: '>&', $^STDOUT) !! $kidout),
+                    (IS_WIN32 ?? (@: '>&', $^STDERR) !! $kiderror),
                     $cmd
                 );
 
@@ -428,12 +426,12 @@ sub _open3_run {
     ### we never get the input.. so jump through
     ### some hoops to do it :(
     my $selector = IO::Select->new(
-                        (IS_WIN32 ? \*STDERR : $kiderror), 
-                        \*STDIN,   
-                        (IS_WIN32 ? \*STDOUT : $kidout)     
-                    );              
+                        (IS_WIN32 ?? $^STDERR !! $kiderror), 
+                        $^STDIN,   
+                        (IS_WIN32 ?? $^STDOUT !! $kidout)     
+                    );
 
-    (\*STDOUT)->autoflush(1);   (\*STDERR)->autoflush(1);   (\*STDIN)->autoflush(1);
+    ($^STDOUT)->autoflush(1);   ($^STDERR)->autoflush(1);   ($^STDIN)->autoflush(1);
     $kidout->autoflush(1)   if UNIVERSAL::can($kidout,   'autoflush');
     $kiderror->autoflush(1) if UNIVERSAL::can($kiderror, 'autoflush');
 
@@ -452,7 +450,7 @@ sub _open3_run {
             ### see perldoc -f sysread: it returns undef on error,
             ### so bail out.
             if( not defined $len ) {
-                warn( <loc("Error reading from process: \%1", $!));
+                warn( <loc("Error reading from process: \%1", $^OS_ERROR));
                 last OUTER;
             }
             
@@ -476,7 +474,7 @@ sub _open3_run {
     ### this current perl process!
     __PACKAGE__->__reopen_fds( < @fds_to_dup );
     
-    return if $?;   # some error occurred
+    return if $^CHILD_ERROR;   # some error occurred
     return 1;
 }
 
@@ -526,10 +524,10 @@ sub _ipc_run {
                          } else {
                             \ split m/ +/
                          }
-                    } split( m/\s*([<>|&])\s*/, $cmd );
+                    }, split( m/\s*([<>|&])\s*/, $cmd );
     }
  
-    ### if there's a pipe in the command, *STDIN needs to 
+    ### if there's a pipe in the command, $^STDIN needs to 
     ### be inserted *BEFORE* the pipe, to work on win32
     ### this also works on *nix, so we should do it when possible
     ### this should *also* work on multiple pipes in the command
@@ -541,19 +539,19 @@ sub _ipc_run {
     #         ### only add STDIN the first time..
     #         my $i;
     #         @command = map { ($_ eq '|' && not $i++) 
-    #                             ? ( \*STDIN, $_ ) 
+    #                             ? ( $^STDIN, $_ ) 
     #                             : $_ 
     #                         } @command; 
     #     } else {
-    #         push @command, \*STDIN;
+    #         push @command, $^STDIN;
     #     }
   
  
-    # \*STDIN is already included in the @command, see a few lines up
+    # $^STDIN is already included in the @command, see a few lines up
     return IPC::Run::run(   < @command, 
-                            fileno(STDOUT).'>',
+                            fileno($^STDOUT).'>',
                             $_out_handler,
-                            fileno(STDERR).'>',
+                            fileno($^STDERR).'>',
                             $_err_handler
                         );
 }
@@ -563,7 +561,7 @@ sub _system_run {
     my $cmd     = shift;
     my $verbose = shift || 0;
 
-    my @fds_to_dup = @( $verbose ? () : < qw[STDOUT STDERR] );
+    my @fds_to_dup = @( $verbose ?? () !! < qw[STDOUT STDERR] );
     __PACKAGE__->__dup_fds( < @fds_to_dup );
     
     ### system returns 'true' on failure -- the exit code of the cmd
@@ -571,17 +569,17 @@ sub _system_run {
     
     __PACKAGE__->__reopen_fds( < @fds_to_dup );
     
-    return if $?;
+    return if $^CHILD_ERROR;
     return 1;
 }
 
-{   use File::Spec;
+do {   use File::Spec;
     use Symbol;
 
     my %Map = %(
-        STDOUT => \@( <qw|>&|, \*STDOUT, Symbol::gensym() ),
-        STDERR => \@( <qw|>&|, \*STDERR, Symbol::gensym() ),
-        STDIN  => \@( <qw|<&|, \*STDIN,  Symbol::gensym() ),
+        STDOUT => \@( <qw|>&|, $^STDOUT, Symbol::gensym() ),
+        STDERR => \@( <qw|>&|, $^STDERR, Symbol::gensym() ),
+        STDIN  => \@( <qw|<&|, $^STDIN,  Symbol::gensym() ),
     );
 
     ### dups FDs and stores them in a cache
@@ -589,17 +587,17 @@ sub _system_run {
         my $self    = shift;
         my @fds     = @_;
 
-        __PACKAGE__->_debug( "# Closing the following fds: {join ' ',@fds}" ) if $DEBUG;
+        __PACKAGE__->_debug( "# Closing the following fds: $(join ' ',@fds)" ) if $DEBUG;
 
         for my $name (  @fds ) {
-            my($redir, $fh, $glob) = < @{%Map{$name}} or (
+            my@($redir, $fh, $glob) =  @{%Map{?$name}} or (
                 Carp::carp( <loc("No such FD: '\%1'", $name)), next );
             
             ### MUST use the 2-arg version of open for dup'ing for 
             ### 5.6.x compatibilty. 5.8.x can use 3-arg open
             ### see perldoc5.6.2 -f open for details            
             open $glob, $redir, fileno($fh) or (
-                        Carp::carp( <loc("Could not dup '$name': \%1", $!)),
+                        Carp::carp( <loc("Could not dup '$name': \%1", $^OS_ERROR)),
                         return
                     );        
                 
@@ -607,7 +605,7 @@ sub _system_run {
             ### just dup it
             if( $redir eq '>&' ) {
                 open( $fh, ">", '' . File::Spec->devnull ) or (
-                    Carp::carp( <loc("Could not reopen '$name': \%1", $!)),
+                    Carp::carp( <loc("Could not reopen '$name': \%1", $^OS_ERROR)),
                     return
                 );
             }
@@ -621,14 +619,14 @@ sub _system_run {
         my $self    = shift;
         my @fds     = @_;
 
-        __PACKAGE__->_debug( "# Reopening the following fds: {join ' ',@fds}" ) if $DEBUG;
+        __PACKAGE__->_debug( "# Reopening the following fds: $(join ' ',@fds)" ) if $DEBUG;
 
         for my $name (  @fds ) {
-            my($redir, $fh, $glob) = < @{%Map{$name}} or (
+            my@($redir, $fh, $glob) =  @{%Map{?$name}} or (
                 Carp::carp( <loc("No such FD: '\%1'", $name)), next );
 
             open( $fh, $redir, fileno($glob) ) or (
-                    Carp::carp( <loc("Could not restore '$name': \%1", $!)),
+                    Carp::carp( <loc("Could not restore '$name': \%1", $^OS_ERROR)),
                     return
                 ); 
            
@@ -638,7 +636,7 @@ sub _system_run {
         return 1;                
     
     }
-}    
+};    
 
 sub _debug {
     my $self    = shift;
