@@ -2,9 +2,9 @@
 # Time-stamp: "2004-03-30 16:33:31 AST"
 
 package Locale::Maketext;
-use strict;
-use vars < qw( @ISA $VERSION $MATCH_SUPERS $USING_LANGUAGE_TAGS
-             $USE_LITERALS $MATCH_SUPERS_TIGHTLY);
+
+our (@ISA, $VERSION, $MATCH_SUPERS, $USING_LANGUAGE_TAGS,
+     $USE_LITERALS, $MATCH_SUPERS_TIGHTLY);
 use Carp ();
 use I18N::LangTags v0.30 ();
 
@@ -31,8 +31,7 @@ my %isa_scan = %( () );
 
 ###########################################################################
 
-sub quant {
-  my($handle, $num, < @forms) = < @_;
+sub quant($handle, $num, @< @forms) {
 
   return $num if (nelems @forms) == 0; # what should this mean?
   return @forms[2] if (nelems @forms) +> 2 and $num == 0; # special zeroth case
@@ -44,23 +43,21 @@ sub quant {
 }
 
 
-sub numerate {
- # return this lexical item in a form appropriate to this number
-  my($handle, $num, < @forms) = < @_;
+sub numerate($handle, $num, @< @forms) {
   my $s = ($num == 1);
 
   return '' unless (nelems @forms);
   if((nelems @forms) == 1) { # only the headword form specified
-    return $s ? @forms[0] :  @(@forms[0] . 's'); # very cheap hack.
+    return $s ?? @forms[0] !!  @(@forms[0] . 's'); # very cheap hack.
   } else { # sing and plural were specified
-    return $s ? @forms[0] : @forms[1];
+    return $s ?? @forms[0] !! @forms[1];
   }
 }
 
 #--------------------------------------------------------------------------
 
 sub numf {
-  my($handle, $num) = < @_[[@(0,1)]];
+  my@($handle, $num) =  @_[[@(0,1)]];
   if($num +< 10_000_000_000 and $num +> -10_000_000_000 and $num == int($num)) {
     $num += 0;  # Just use normal integer stringification.
          # Specifically, don't let %G turn ten million into 1E+007
@@ -73,14 +70,14 @@ sub numf {
    #  backtrack so it un-eats the rightmost three, and then we
    #  insert the comma there.
 
-  $num =~ s<(.,)><{$1 eq ',' ? '.' : ','}>g if ref($handle) and $handle->{'numf_comma'};
+  $num =~ s<(.,)><$($1 eq ',' ?? '.' !! ',')>g if ref($handle) and $handle->{?'numf_comma'};
    # This is just a lame hack instead of using Number::Format
   return $num;
 }
 
-sub sprintf {
+sub sprintf($handle, $format, @< @params) {
   no integer;
-  my($handle, $format, < @params) = < @_;
+
   return CORE::sprintf($format, < @params);
     # "CORE::" is there to avoid confusion with myself!
 }
@@ -100,7 +97,7 @@ sub language_tag {
 sub encoding {
   my $it = @_[0];
   return @(
-   (ref($it) && $it->{'encoding'})
+   (ref($it) && $it->{?'encoding'})
    || "iso-8859-1"   # Latin-1
   );
 } 
@@ -113,11 +110,10 @@ sub fallback_language_classes { return () }
 
 #--------------------------------------------------------------------------
 
-sub fail_with { # an actual attribute method!
-  my($handle, < @params) = < @_;
+sub fail_with($handle, @< @params) {
   return unless ref($handle);
-  $handle->{'fail'} = @params[0] if (nelems @params);
-  return $handle->{'fail'};
+  $handle->{+'fail'} = @params[0] if (nelems @params);
+  return $handle->{?'fail'};
 }
 
 #--------------------------------------------------------------------------
@@ -126,21 +122,21 @@ sub failure_handler_auto {
   # Meant to be used like:
   #  $handle->fail_with('failure_handler_auto')
 
-  my($handle, $phrase, < @params) = < @_;
-  $handle->{'failure_lex'} ||= \%();
-  my $lex = $handle->{'failure_lex'};
+  my@($handle, $phrase, @< @params) =  @_;
+  $handle->{+'failure_lex'} ||= \%();
+  my $lex = $handle->{?'failure_lex'};
 
   my $value;
-  $lex->{$phrase} ||= ($value = $handle->_compile($phrase));
+  $lex->{+$phrase} ||= ($value = $handle->_compile($phrase));
 
   # Dumbly copied from sub maketext:
-  {
+  do {
     try { $value = &$value($handle, < @_) };
-  }
+  };
   # If we make it here, there was an exception thrown in the
   #  call to $value, and so scream:
-  if($@) {
-    my $err = $@;
+  if($^EVAL_ERROR) {
+    my $err = $^EVAL_ERROR;
     # pretty up the error message
     $err =~ s<\s+at\s+\(eval\s+\d+\)\s+line\s+(\d+)\.?\n?>
              <\n in bracket code [compiled line $1],>s;
@@ -171,43 +167,43 @@ sub maketext {
   # Remember, this can fail.  Failure is controllable many ways.
   Carp::croak "maketext requires at least one parameter" unless (nelems @_) +> 1;
 
-  my($handle, $phrase) = splice(@_,0,2);
+  my@($handle, $phrase) = @: splice(@_,0,2);
 
   # Don't interefere with $@ in case that's being interpolated into the msg.
-  local $@;
+  local $^EVAL_ERROR;
 
   # Look up the value:
 
   my $value;
   foreach my $h_r (
-     @{  %isa_scan{ref($handle) || $handle} || $handle->_lex_refs  }
+     @{  %isa_scan{?ref($handle) || $handle} || $handle->_lex_refs  }
   ) {
-    print "* Looking up \"$phrase\" in $h_r\n" if DEBUG;
+    print $^STDOUT, "* Looking up \"$phrase\" in $h_r\n" if DEBUG;
     if(exists $h_r->{$phrase}) {
-      print "  Found \"$phrase\" in $h_r\n" if DEBUG;
-      unless(ref($value = $h_r->{$phrase})) {
+      print $^STDOUT, "  Found \"$phrase\" in $h_r\n" if DEBUG;
+      unless(ref($value = $h_r->{?$phrase})) {
         # Nonref means it's not yet compiled.  Compile and replace.
-        $value = $h_r->{$phrase} = $handle->_compile($value);
+        $value = $h_r->{+$phrase} = $handle->_compile($value);
       }
       last;
-    } elsif($phrase !~ m/^_/s and $h_r->{'_AUTO'}) {
+    } elsif($phrase !~ m/^_/s and $h_r->{?'_AUTO'}) {
       # it's an auto lex, and this is an autoable key!
-      print "  Automaking \"$phrase\" into $h_r\n" if DEBUG;
+      print $^STDOUT, "  Automaking \"$phrase\" into $h_r\n" if DEBUG;
       
-      $value = $h_r->{$phrase} = $handle->_compile($phrase);
+      $value = $h_r->{+$phrase} = $handle->_compile($phrase);
       last;
     }
-    print "  Not found in $h_r, nor automakable\n" if DEBUG +> 1;
+    print $^STDOUT, "  Not found in $h_r, nor automakable\n" if DEBUG +> 1;
     # else keep looking
   }
 
   unless(defined($value)) {
-    print "! Lookup of \"$phrase\" in/under ", ref($handle) || $handle,
+    print $^STDOUT, "! Lookup of \"$phrase\" in/under ", ref($handle) || $handle,
       " fails.\n" if DEBUG;
-    if(ref($handle) and $handle->{'fail'}) {
-      print "WARNING0: maketext fails looking for <$phrase>\n" if DEBUG;
+    if(ref($handle) and $handle->{?'fail'}) {
+      print $^STDOUT, "WARNING0: maketext fails looking for <$phrase>\n" if DEBUG;
       my $fail;
-      if(ref($fail = $handle->{'fail'}) eq 'CODE') { # it's a sub reference
+      if(ref($fail = $handle->{?'fail'}) eq 'CODE') { # it's a sub reference
         return &{$fail}($handle, $phrase, < @_);
          # If it ever returns, it should return a good value.
       } else { # It's a method name
@@ -223,13 +219,13 @@ sub maketext {
   return $$value if ref($value) eq 'SCALAR';
   return $value unless ref($value) eq 'CODE';
   
-  {
+  do {
     try { $value = &$value($handle, < @_) };
-  }
+  };
   # If we make it here, there was an exception thrown in the
   #  call to $value, and so scream:
-  if($@) {
-    my $err = $@->message;
+  if($^EVAL_ERROR) {
+    my $err = $^EVAL_ERROR->message;
     # pretty up the error message
     $err =~ s<\s+at\s+\(eval\s+\d+\)\s+line\s+(\d+)\.?\n?>
              <\n in bracket code [compiled line $1],>s;
@@ -244,20 +240,16 @@ sub maketext {
 
 ###########################################################################
 
-sub get_handle {  # This is a constructor and, yes, it CAN FAIL.
-  # Its class argument has to be the base class for the current
-  # application's l10n files.
-
-  my($base_class, < @languages) = < @_;
+sub get_handle($base_class, @< @languages) {
   $base_class = ref($base_class) || $base_class;
    # Complain if they use __PACKAGE__ as a project base class?
   
   if( (nelems @languages) ) {
-    DEBUG and print "Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
     if($USING_LANGUAGE_TAGS) {   # An explicit language-list was given!
-      @languages = map {; $_, < I18N::LangTags::alternate_language_tags($_) }
- map I18N::LangTags::locale2language_tag($_), @languages;
-      DEBUG and print "Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+      @languages = @+: map { @: $_, < I18N::LangTags::alternate_language_tags($_) },
+ map { I18N::LangTags::locale2language_tag($_) }, @languages;
+      DEBUG and print $^STDOUT, "Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
     }
   } else {
     @languages = $base_class->_ambient_langprefs;
@@ -266,9 +258,9 @@ sub get_handle {  # This is a constructor and, yes, it CAN FAIL.
   @languages = $base_class->_langtag_munging(< @languages);
 
   my %seen;
-  foreach my $module_name ( map { $base_class . "::" . $_ } @languages ) {
+  foreach my $module_name ( map { $base_class . "::" . $_ }, @languages ) {
     next unless length $module_name; # sanity
-    next if %seen{$module_name}++        # Already been here, and it was no-go
+    next if %seen{+$module_name}++        # Already been here, and it was no-go
             || ! _try_use($module_name); # Try to use() it, but can't it.
     return $module_name->new; # Make it!
   }
@@ -278,25 +270,24 @@ sub get_handle {  # This is a constructor and, yes, it CAN FAIL.
 
 ###########################################################################
 
-sub _langtag_munging {
-  my($base_class, < @languages) = < @_;
+sub _langtag_munging($base_class, @< @languages) {
 
   # We have all these DEBUG statements because otherwise it's hard as hell
   # to diagnose ifwhen something goes wrong.
 
-  DEBUG and print "Lgs1: ", < map("<$_>", @languages), "\n";
+  DEBUG and print $^STDOUT, "Lgs1: ", < map( {"<$_>" }, @languages), "\n";
 
   if($USING_LANGUAGE_TAGS) {
-    DEBUG and print "Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
     @languages     = $base_class->_add_supers( < @languages );
 
     push @languages, < I18N::LangTags::panic_languages(< @languages);
-    DEBUG and print "After adding panic languages:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "After adding panic languages:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
     push @languages, < $base_class->fallback_languages;
      # You are free to override fallback_languages to return empty-list!
-    DEBUG and print "Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
     @languages = map {
         my $it = $_;  # copy
@@ -304,23 +295,23 @@ sub _langtag_munging {
         $it =~ s<-><_>g; # lc, and turn - to _
         $it =~ s<[^_a-z0-9]><>g;  # remove all but a-z0-9_
         $it;
-      } @languages
+      }, @languages
     ;
-    DEBUG and print "Nearing end of munging:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Nearing end of munging:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
   } else {
-    DEBUG and print "Bypassing language-tags.\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Bypassing language-tags.\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
   }
 
-  DEBUG and print "Before adding fallback classes:\n", 
-    " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+  DEBUG and print $^STDOUT, "Before adding fallback classes:\n", 
+    " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
   push @languages, < $base_class->fallback_language_classes;
    # You are free to override that to return whatever.
 
-  DEBUG and print "Finally:\n", 
-    " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+  DEBUG and print $^STDOUT, "Finally:\n", 
+    " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
   return @languages;
 }
@@ -334,27 +325,26 @@ sub _ambient_langprefs {
 
 ###########################################################################
 
-sub _add_supers {
-  my($base_class, < @languages) = < @_;
+sub _add_supers($base_class, @< @languages) {
 
   if(!$MATCH_SUPERS) {
     # Nothing
-    DEBUG and print "Bypassing any super-matching.\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Bypassing any super-matching.\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
   } elsif( $MATCH_SUPERS_TIGHTLY ) {
-    DEBUG and print "Before adding new supers tightly:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Before adding new supers tightly:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
     @languages = I18N::LangTags::implicate_supers( < @languages );
-    DEBUG and print "After adding new supers tightly:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "After adding new supers tightly:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
 
   } else {
-    DEBUG and print "Before adding supers to end:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "Before adding supers to end:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
     @languages = I18N::LangTags::implicate_supers_strictly( < @languages );
-    DEBUG and print "After adding supers to end:\n", 
-      " Lgs\@", __LINE__, ": ", < map("<$_>", @languages), "\n";
+    DEBUG and print $^STDOUT, "After adding supers to end:\n", 
+      " Lgs\@", __LINE__, ": ", < map( {"<$_>" }, @languages), "\n";
   }
   
   return @languages;
@@ -375,25 +365,25 @@ my %tried = %( () );
 
 sub _try_use {   # Basically a wrapper around "require Modulename"
   # "Many men have tried..."  "They tried and failed?"  "They tried and died."
-  return %tried{@_[0]} if exists %tried{@_[0]};  # memoization
+  return %tried{?@_[0]} if exists %tried{@_[0]};  # memoization
 
   my $module = @_[0];   # ASSUME sane module name!
-  { no strict 'refs';
-    return (%tried{$module} = 1)
+  do {
+    return (%tried{+$module} = 1)
      if %{*{Symbol::fetch_glob($module . "::Lexicon")}} or @{*{Symbol::fetch_glob($module . "::ISA")}};
     # weird case: we never use'd it, but there it is!
-  }
+  };
 
-  print " About to use $module ...\n" if DEBUG;
-  {
+  print $^STDOUT, " About to use $module ...\n" if DEBUG;
+  do {
     eval "require $module"; # used to be "use $module", but no point in that.
-  }
-  if($@) {
-    print "Error using $module \: $@\n" if DEBUG +> 1;
-    return %tried{$module} = 0;
+  };
+  if($^EVAL_ERROR) {
+    print $^STDOUT, "Error using $module \: $^EVAL_ERROR\n" if DEBUG +> 1;
+    return (%tried{+$module} = 0);
   } else {
-    print " OK, $module is used\n" if DEBUG;
-    return %tried{$module} = 1;
+    print $^STDOUT, " OK, $module is used\n" if DEBUG;
+    return (%tried{+$module} = 1);
   }
 }
 
@@ -401,29 +391,28 @@ sub _try_use {   # Basically a wrapper around "require Modulename"
 
 sub _lex_refs {  # report the lexicon references for this handle's class
   # returns an arrayREF!
-  no strict 'refs';
   my $class = ref(@_[0]) || @_[0];
-  print "Lex refs lookup on $class\n" if DEBUG +> 1;
-  return %isa_scan{$class} if exists %isa_scan{$class};  # memoization!
+  print $^STDOUT, "Lex refs lookup on $class\n" if DEBUG +> 1;
+  return %isa_scan{?$class} if exists %isa_scan{$class};  # memoization!
 
   my @lex_refs;
-  my $seen_r = ref(@_[1]) ? @_[1] : \%();
+  my $seen_r = ref(@_[?1]) ?? @_[1] !! \%();
 
   if( defined( *{Symbol::fetch_glob($class . '::Lexicon')}{'HASH'} )) {
     push @lex_refs, *{Symbol::fetch_glob($class . '::Lexicon')}{'HASH'};
-    print "\%" . $class . "::Lexicon contains ",
+    print $^STDOUT, "\%" . $class . "::Lexicon contains ",
          scalar(keys %{*{Symbol::fetch_glob($class . '::Lexicon')}}), " entries\n" if DEBUG;
   }
 
   # Implements depth(height?)-first recursive searching of superclasses.
   # In hindsight, I suppose I could have just used Class::ISA!
   foreach my $superclass ( @{*{Symbol::fetch_glob($class . "::ISA")}}) {
-    print " Super-class search into $superclass\n" if DEBUG;
-    next if $seen_r->{$superclass}++;
+    print $^STDOUT, " Super-class search into $superclass\n" if DEBUG;
+    next if $seen_r->{+$superclass}++;
     push @lex_refs, < @{&_lex_refs($superclass, $seen_r)};  # call myself
   }
 
-  %isa_scan{$class} = \@lex_refs; # save for next time
+  %isa_scan{+$class} = \@lex_refs; # save for next time
   return \@lex_refs;
 }
 
