@@ -4,7 +4,7 @@ package PerlIO::via::QuotedPrint;
 # Make sure we do things by the book from now on
 
 our $VERSION = '0.06';
-use strict;
+
 
 # Make sure the encoding/decoding stuff is available
 
@@ -33,7 +33,7 @@ sub FILL {
 # Decode if there is something decode and return result or signal eof
 
     my $line = readline( @_[1] );
-    (defined $line) ? MIME::QuotedPrint::decode_qp( $line ) : undef;
+    (defined $line) ?? MIME::QuotedPrint::decode_qp( $line ) !! undef;
 } #FILL
 
 #-----------------------------------------------------------------------
@@ -46,7 +46,7 @@ sub WRITE {
 
 # Encode whatever needs to be encoded and write to handle: indicate result
 
-    (print {@_[2]} MIME::QuotedPrint::encode_qp(@_[1])) ? length(@_[1]) : -1;
+    (print @_[2] ,MIME::QuotedPrint::encode_qp(@_[1])) ?? length(@_[1]) !! -1;
 } #WRITE
 
 __END__
