@@ -3,7 +3,7 @@
 # Time-stamp: "2004-05-07 15:31:25 ADT"
 package Pod::Escapes;
 require Exporter;
-use strict;
+
 our @ISA = @('Exporter');
 our $VERSION = '1.04';
 our @EXPORT_OK = qw(
@@ -19,15 +19,15 @@ our %EXPORT_TAGS = %('ALL' => \@EXPORT_OK);
 
 #==========================================================================
 
-use vars < qw(
-  %Code2USASCII
-  %Name2character
-  %Name2character_number
-  %Latin1Code_to_fallback
-  %Latin1Char_to_fallback
-  $FAR_CHAR
-  $FAR_CHAR_NUMBER
-  $NOT_ASCII
+our (
+  %Code2USASCII,
+  %Name2character,
+  %Name2character_number,
+  %Latin1Code_to_fallback,
+  %Latin1Char_to_fallback,
+  $FAR_CHAR,
+  $FAR_CHAR_NUMBER,
+  $NOT_ASCII,
 );
 
 use utf8;
@@ -54,7 +54,7 @@ sub e2char {
     # Cope with US-ASCII codes, use fallbacks for Latin-1, or use FAR_CHAR.
     unless($in =~ m/^\d+$/s) {
       # It's a named character reference.  Get its numeric Unicode value.
-      $in = %Name2character{$in};
+      $in = %Name2character{?$in};
       return undef unless defined $in;  # (if there's no such name)
       $in = ord $in; # (All ents must be one character long.)
         # ...So $in holds the char's US-ASCII numeric value, which we'll
@@ -62,8 +62,8 @@ sub e2char {
     }
 
     # It's numeric, whether by origin or by mutation from a known name
-    return %Code2USASCII{$in} # so "65" => "A" everywhere
-        || %Latin1Code_to_fallback{$in} # Fallback.
+    return %Code2USASCII{?$in} # so "65" => "A" everywhere
+        || %Latin1Code_to_fallback{?$in} # Fallback.
         || $FAR_CHAR; # Fall further back
   }
   
@@ -71,7 +71,7 @@ sub e2char {
   if($in =~ m/^\d+$/s) {
       return chr($in);
   } else {
-    return %Name2character{$in}; # returns undef if unknown
+    return %Name2character{?$in}; # returns undef if unknown
   }
 }
 
@@ -90,7 +90,7 @@ sub e2charnum {
   if($in =~ m/^\d+$/s) {
     return 0 + $in;
   } else {
-    return %Name2character_number{$in}; # returns undef if unknown
+    return %Name2character_number{?$in}; # returns undef if unknown
   }
 }
 
@@ -370,22 +370,22 @@ sub e2charnum {
 
 
 # Fill out %Name2character...
-{
+do {
   %Name2character = %( () );
   my($name, $number);
-  while( ($name, $number) = each %Name2character_number) {
-      %Name2character{$name} = chr $number;
+  while( @(?$name, ?$number) =@( each %Name2character_number)) {
+      %Name2character{+$name} = chr $number;
       # normal case
   }
   # So they resolve 'right' even in EBCDIC-land
-  %Name2character{'lt'  }   = '<';
-  %Name2character{'gt'  }   = '>';
-  %Name2character{'quot'}   = '"';
-  %Name2character{'amp' }   = '&';
-  %Name2character{'apos'}   = "'";
-  %Name2character{'sol' }   = '/';
-  %Name2character{'verbar'} = '|';
-}
+  %Name2character{+'lt'  }   = '<';
+  %Name2character{+'gt'  }   = '>';
+  %Name2character{+'quot'}   = '"';
+  %Name2character{+'amp' }   = '&';
+  %Name2character{+'apos'}   = "'";
+  %Name2character{+'sol' }   = '/';
+  %Name2character{+'verbar'} = '|';
+};
 
 #--------------------------------------------------------------------------
 
@@ -492,7 +492,7 @@ sub e2charnum {
 #--------------------------------------------------------------------------
 
 %Latin1Code_to_fallback = %( () );
- <%Latin1Code_to_fallback{[0xA0 .. 0xFF]} = (
+ %Latin1Code_to_fallback{[0xA0 .. 0xFF]} = @(
 # Copied from Text/Unidecode/x00.pm:
 
 ' ', qq{!}, qq{C/}, 'PS', qq{\$?}, qq{Y=}, qq{|}, 'SS', qq{"}, qq{(c)}, 'a', qq{<<}, qq{!}, "", qq{(r)}, qq{-},
@@ -504,15 +504,15 @@ sub e2charnum {
 
 );
 
-{
+do {
   # Now stuff %Latin1Char_to_fallback:
   %Latin1Char_to_fallback = %( () );
   my($k,$v);
-  while( ($k,$v) = each %Latin1Code_to_fallback) {
-    %Latin1Char_to_fallback{chr $k} = $v;
+  while( @(?$k,?$v) =@( each %Latin1Code_to_fallback)) {
+    %Latin1Char_to_fallback{+chr $k} = $v;
     #print chr($k), ' => ', $v, "\n";
   }
-}
+};
 
 #--------------------------------------------------------------------------
 1;
