@@ -12,7 +12,7 @@
 
 package Pod::Find;
 
-use vars < qw($VERSION);
+our ($VERSION);
 $VERSION = 1.34;   ## Current version of this package
 
 #############################################################################
@@ -24,14 +24,14 @@ Pod::Find - find POD documents in directory trees
 =head1 SYNOPSIS
 
   use Pod::Find qw(pod_find simplify_name);
-  my %pods = pod_find({ -verbose => 1, -inc => 1 });
+  my %pods = pod_find({ verbose => 1, inc => 1 });
   foreach(keys %pods) {
      print "found library POD `$pods{$_}' in $_\n";
   }
 
   print "podname=",simplify_name('a/b/c/mymodule.pod'),"\n";
 
-  $location = pod_where( { -inc => 1 }, "Pod::Find" );
+  $location = pod_where( { inc => 1 }, "Pod::Find" );
 
 =head1 DESCRIPTION
 
@@ -46,14 +46,13 @@ files/directories like RCS, CVS, SCCS, .svn are ignored.
 
 =cut
 
-use strict;
 #use diagnostics;
 use Exporter;
 use File::Spec;
 use File::Find;
 use Cwd;
 
-use vars < qw(@ISA @EXPORT_OK $VERSION);
+our (@ISA, @EXPORT_OK, $VERSION);
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(&pod_find &simplify_name &pod_where &contains_pod);
 
@@ -77,7 +76,7 @@ Only text files containing at least one valid POD command are found.
 
 A warning is printed if more than one POD file with the same POD name
 is found, e.g. F<CPAN.pm> in different directories. This usually
-indicates duplicate occurrences of modules in the I<@INC> search path.
+indicates duplicate occurrences of modules in the I<$^INCLUDE_PATH> search path.
 
 B<OPTIONS> The first argument for B<pod_find> may be a hash reference
 with options. The rest are either directories that are searched
@@ -90,23 +89,23 @@ with any Perl-like extension (.pm, .pl, .pod) stripped.
 
 Print progress information while scanning.
 
-=item C<-perl =E<gt> 1>
+=item C<perl =E<gt> 1>
 
 Apply Perl-specific heuristics to find the correct PODs. This includes
 stripping Perl-like extensions, omitting subdirectories that are numeric
 but do I<not> match the current Perl interpreter's version id, suppressing
 F<site_perl> as a module hierarchy name etc.
 
-=item C<-script =E<gt> 1>
+=item C<script =E<gt> 1>
 
 Search for PODs in the current Perl interpreter's installation 
 B<scriptdir>. This is taken from the local L<Config|Config> module.
 
-=item C<-inc =E<gt> 1>
+=item C<inc =E<gt> 1>
 
-Search for PODs in the current Perl interpreter's I<@INC> paths. This
+Search for PODs in the current Perl interpreter's I<$^INCLUDE_PATH> paths. This
 automatically considers paths specified in the C<PERL5LIB> environment
-as this is prepended to I<@INC> by the Perl interpreter itself.
+as this is prepended to I<$^INCLUDE_PATH> by the Perl interpreter itself.
 
 =back
 
@@ -122,40 +121,40 @@ sub pod_find
         %opts = %( < %{shift()} );
     }
 
-    %opts{-verbose} ||= 0;
-    %opts{-perl}    ||= 0;
+    %opts{+verbose} ||= 0;
+    %opts{+perl}    ||= 0;
 
-    my (@search) = @_;
+    my @search = @_;
 
-    if(%opts{-script}) {
+    if(%opts{?script}) {
         require Config;
-        push(@search, %Config::Config{scriptdir})
-            if -d %Config::Config{scriptdir};
-        %opts{-perl} = 1;
+        push(@search, Config::config_value('scriptdir'))
+            if -d Config::config_value('scriptdir');
+        %opts{+perl} = 1;
     }
 
-    if(%opts{-inc}) {
-        if ($^O eq 'MacOS') {
+    if(%opts{?inc}) {
+        if ($^OS_NAME eq 'MacOS') {
             # tolerate '.', './some_dir' and '(../)+some_dir' on Mac OS
-            my @new_INC = @INC;
+            my @new_INC = $^INCLUDE_PATH;
             for ( @new_INC) {
                 if ( $_ eq '.' ) {
                     $_ = ':';
-                } elsif ( $_ =~ s|^((?:\.\./)+)|{':' x (length($1)/3)}| ) {
+                } elsif ( $_ =~ s|^((?:\.\./)+)|$(':' x (length($1)/3))| ) {
                     $_ = ':'. $_;
                 } else {
                     $_ =~ s|^\./|:|;
                 }
             }
-            push(@search, < grep($_ ne File::Spec->curdir, @new_INC));
+            push(@search, < grep( {$_ ne File::Spec->curdir }, @new_INC));
         } else {
-            push(@search, < grep($_ ne File::Spec->curdir, @INC));
+            push(@search, < grep( {$_ ne File::Spec->curdir }, $^INCLUDE_PATH));
         }
 
-        %opts{-perl} = 1;
+        %opts{+perl} = 1;
     }
 
-    if(%opts{-perl}) {
+    if(%opts{?perl}) {
         require Config;
         # this code simplifies the POD name for Perl modules:
         # * remove "site_perl"
@@ -167,12 +166,12 @@ sub pod_find
         # * remove ":?site_perl:"
         # * remove :?pod: if followed by *.pod (e.g. in :pod:perlfunc.pod)
 
-        if ($^O eq 'MacOS') {
+        if ($^OS_NAME eq 'MacOS') {
             $SIMPLIFY_RX =
               qq!^(?i:\:?site_perl\:|\:?pod\:(?=.*?\\.pod\\z))*!;
         } else {
             $SIMPLIFY_RX =
-              qq!^(?i:site(_perl)?/|\Q%Config::Config{archname}\E/|\\d+\\.\\d+([_.]?\\d+)?/|pod/(?=.*?\\.pod\\z))*!;
+              qq!^(?i:site(_perl)?/|\Q$(Config::config_value('archname'))\E/|\\d+\\.\\d+([_.]?\\d+)?/|pod/(?=.*?\\.pod\\z))*!;
         }
     }
 
@@ -181,7 +180,7 @@ sub pod_find
     my %names;
     my $pwd = cwd();
 
-    foreach my $try ( @search) {
+    foreach my $try (@search) {
         unless(File::Spec->file_name_is_absolute($try)) {
             # make path absolute
             $try = File::Spec->catfile($pwd,$try);
@@ -189,16 +188,16 @@ sub pod_find
         # simplify path
         # on VMS canonpath will vmsify:[the.path], but File::Find::find
         # wants /unixy/paths
-        $try = File::Spec->canonpath($try) if ($^O ne 'VMS');
-        $try = VMS::Filespec::unixify($try) if ($^O eq 'VMS');
+        $try = File::Spec->canonpath($try) if ($^OS_NAME ne 'VMS');
+        $try = VMS::Filespec::unixify($try) if ($^OS_NAME eq 'VMS');
         my $name;
         if(-f $try) {
-            if($name = _check_and_extract_name($try, %opts{-verbose})) {
+            if($name = _check_and_extract_name($try, %opts{?verbose})) {
                 _check_for_duplicates($try, $name, \%names, \%pods);
             }
             next;
         }
-        my $root_rx = $^O eq 'MacOS' ? qq!^\Q$try\E! : qq!^\Q$try\E/!;
+        my $root_rx = $^OS_NAME eq 'MacOS' ?? qq!^\Q$try\E! !! qq!^\Q$try\E/!;
         File::Find::find( sub {
             my $item = $File::Find::name;
             if(-d) {
@@ -206,23 +205,23 @@ sub pod_find
                     $File::Find::prune = 1;
                     return;
                 }
-                elsif(%dirs_visited{$item}) {
+                elsif(%dirs_visited{?$item}) {
                     warn "Directory '$item' already seen, skipping.\n"
-                        if(%opts{-verbose});
+                        if(%opts{?verbose});
                     $File::Find::prune = 1;
                     return;
                 }
                 else {
-                    %dirs_visited{$item} = 1;
+                    %dirs_visited{+$item} = 1;
                 }
-                if(%opts{-perl} && m/^(\d+\.[\d_]+)\z/s && eval "$1" != $^V) {
+                if(%opts{?perl} && m/^(\d+\.[\d_]+)\z/s && eval "$1" != $^PERL_VERSION) {
                     $File::Find::prune = 1;
-                    warn "Perl $^V version mismatch on $_, skipping.\n"
-                        if(%opts{-verbose});
+                    warn "Perl $^PERL_VERSION version mismatch on $_, skipping.\n"
+                        if(%opts{?verbose});
                 }
                 return;
             }
-            if($name = _check_and_extract_name($item, %opts{-verbose}, $root_rx)) {
+            if($name = _check_and_extract_name($item, %opts{?verbose}, $root_rx)) {
                 _check_for_duplicates($item, $name, \%names, \%pods);
             }
         }, $try); # end of File::Find::find
@@ -231,21 +230,19 @@ sub pod_find
     %pods;
 }
 
-sub _check_for_duplicates {
-    my ($file, $name, $names_ref, $pods_ref) = < @_;
-    if(%$names_ref{$name}) {
+sub _check_for_duplicates($file, $name, $names_ref, $pods_ref) {
+    if(%$names_ref{?$name}) {
         warn "Duplicate POD found (shadowing?): $name ($file)\n";
         warn "    Already seen in ",
-            join(' ', grep(%$pods_ref{$_} eq $name, keys %$pods_ref)),"\n";
+            join(' ', grep( {%$pods_ref{?$_} eq $name }, keys %$pods_ref)),"\n";
     }
     else {
-        %$names_ref{$name} = 1;
+        %$names_ref{+$name} = 1;
     }
-    %$pods_ref{$file} = $name;
+    %$pods_ref{+$file} = $name;
 }
 
-sub _check_and_extract_name {
-    my ($file, $verbose, $root_rx) = < @_;
+sub _check_and_extract_name($file, $verbose, $root_rx) {
 
     # check extension or executable flag
     # this involves testing the .bat extension on Win32!
@@ -263,7 +260,7 @@ sub _check_and_extract_name {
         $name =~ s!$SIMPLIFY_RX!!os if(defined $SIMPLIFY_RX);
     }
     else {
-        if ($^O eq 'MacOS') {
+        if ($^OS_NAME eq 'MacOS') {
             $name =~ s/^.*://s;
         } else {
             $name =~ s:^.*/::s;
@@ -271,7 +268,7 @@ sub _check_and_extract_name {
     }
     _simplify($name);
     $name =~ s!/+!::!g; #/
-    if ($^O eq 'MacOS') {
+    if ($^OS_NAME eq 'MacOS') {
         $name =~ s!:+!::!g; # : -> ::
     } else {
         $name =~ s!/+!::!g; # / -> ::
@@ -289,10 +286,9 @@ F<.bat>, F<.cmd> on Win32 and OS/2, or F<.com> on VMS, respectively.
 
 # basic simplification of the POD name:
 # basename & strip extension
-sub simplify_name {
-    my ($str) = < @_;
+sub simplify_name($str) {
     # remove all path components
-    if ($^O eq 'MacOS') {
+    if ($^OS_NAME eq 'MacOS') {
         $str =~ s/^.*://s;
     } else {
         $str =~ s:^.*/::s;
@@ -306,9 +302,9 @@ sub _simplify {
     # strip Perl's own extensions
     @_[0] =~ s/\.(pod|pm|plx?)\z//i;
     # strip meaningless extensions on Win32 and OS/2
-    @_[0] =~ s/\.(bat|exe|cmd)\z//i if($^O =~ m/mswin|os2/i);
+    @_[0] =~ s/\.(bat|exe|cmd)\z//i if($^OS_NAME =~ m/mswin|os2/i);
     # strip meaningless extensions on VMS
-    @_[0] =~ s/\.(com)\z//i if($^O eq 'VMS');
+    @_[0] =~ s/\.(com)\z//i if($^OS_NAME eq 'VMS');
 }
 
 # contribution from Tim Jenness <t.jenness@jach.hawaii.edu>
@@ -322,18 +318,18 @@ Options:
 
 =over 4
 
-=item C<-inc =E<gt> 1>
+=item C<inc =E<gt> 1>
 
-Search @INC for the pod and also the C<scriptdir> defined in the
+Search $^INCLUDE_PATH for the pod and also the C<scriptdir> defined in the
 L<Config|Config> module.
 
-=item C<-dirs =E<gt> [ $dir1, $dir2, ... ]>
+=item C<dirs =E<gt> [ $dir1, $dir2, ... ]>
 
 Reference to an array of search directories. These are searched in order
-before looking in C<@INC> (if B<-inc>). Current directory is used if
+before looking in C<$^INCLUDE_PATH> (if B<-inc>). Current directory is used if
 none are specified.
 
-=item C<-verbose =E<gt> 1>
+=item C<verbose =E<gt> 1>
 
 List directories as they are searched
 
@@ -362,9 +358,9 @@ sub pod_where {
 
   # default options
   my %options = %(
-         '-inc' => 0,
-         '-verbose' => 0,
-         '-dirs' => \@( File::Spec->curdir ),
+         'inc' => 0,
+         'verbose' => 0,
+         'dirs' => \@( File::Spec->curdir ),
         );
 
   # Check for an options hash as first argument
@@ -385,44 +381,44 @@ sub pod_where {
   my @parts = split (m/::/, $pod);
 
   # Get full directory list
-  my @search_dirs = @{ %options{'-dirs'} };
+  my @search_dirs = @{ %options{?'dirs'} };
 
-  if (%options{'-inc'}) {
+  if (%options{?'inc'}) {
 
     require Config;
 
-    # Add @INC
-    if ($^O eq 'MacOS' && %options{'-inc'}) {
+    # Add $^INCLUDE_PATH
+    if ($^OS_NAME eq 'MacOS' && %options{?'inc'}) {
         # tolerate '.', './some_dir' and '(../)+some_dir' on Mac OS
-        my @new_INC = @INC;
+        my @new_INC = $^INCLUDE_PATH;
         for ( @new_INC) {
             if ( $_ eq '.' ) {
                 $_ = ':';
-            } elsif ( $_ =~ s|^((?:\.\./)+)|{':' x (length($1)/3)}| ) {
+            } elsif ( $_ =~ s|^((?:\.\./)+)|$(':' x (length($1)/3))| ) {
                 $_ = ':'. $_;
             } else {
                 $_ =~ s|^\./|:|;
             }
         }
         push (@search_dirs, < @new_INC);
-    } elsif (%options{'-inc'}) {
-        push (@search_dirs, < @INC);
+    } elsif (%options{?'inc'}) {
+        push (@search_dirs, < $^INCLUDE_PATH);
     }
 
     # Add location of pod documentation for perl man pages (eg perlfunc)
     # This is a pod directory in the private install tree
-    #my $perlpoddir = File::Spec->catdir($Config::Config{'installprivlib'},
+    #my $perlpoddir = File::Spec->catdir(Config::config_value('installprivlib'),
     #					'pod');
     #push (@search_dirs, $perlpoddir)
     #  if -d $perlpoddir;
 
     # Add location of binaries such as pod2text
-    push (@search_dirs, %Config::Config{'scriptdir'})
-      if -d %Config::Config{'scriptdir'};
+    push (@search_dirs, Config::config_value('scriptdir'))
+      if -d Config::config_value('scriptdir');
   }
 
   warn "Search path is: ".join(' ', @search_dirs)."\n"
-        if %options{'-verbose'};
+        if %options{?'verbose'};
 
   # Loop over directories
   Dir: foreach my $dir (  @search_dirs ) {
@@ -430,25 +426,25 @@ sub pod_where {
     # Don't bother if can't find the directory
     if (-d $dir) {
       warn "Looking in directory $dir\n" 
-        if %options{'-verbose'};
+        if %options{'verbose'};
 
       # Now concatenate this directory with the pod we are searching for
       my $fullname = File::Spec->catfile($dir, < @parts);
       warn "Filename is now $fullname\n"
-        if %options{'-verbose'};
+        if %options{'verbose'};
 
       # Loop over possible extensions
       foreach my $ext (@('', '.pod', '.pm', '.pl')) {
         my $fullext = $fullname . $ext;
         if (-f $fullext && 
-         contains_pod($fullext, %options{'-verbose'}) ) {
-          warn "FOUND: $fullext\n" if %options{'-verbose'};
+         contains_pod($fullext, %options{'verbose'}) ) {
+          warn "FOUND: $fullext\n" if %options{'verbose'};
           return $fullext;
         }
       }
     } else {
       warn "Directory $dir does not exist\n"
-        if %options{'-verbose'};
+        if %options{'verbose'};
       next Dir;
     }
     # for some strange reason the path on MacOS/darwin/cygwin is
@@ -457,7 +453,7 @@ sub pod_where {
     # have a case-tolerant file system, but File::Spec
     # does not recognize 'darwin' yet. And cygwin also has "pods",
     # but is not case tolerant. Oh well...
-    if((File::Spec->case_tolerant || $^O =~ m/macos|darwin|cygwin/i)
+    if((File::Spec->case_tolerant || $^OS_NAME =~ m/macos|darwin|cygwin/i)
      && -d File::Spec->catdir($dir,'pods')) {
       $dir = File::Spec->catdir($dir,'pods');
       redo Dir;
@@ -484,14 +480,15 @@ sub contains_pod {
   $verbose = shift if (nelems @_);
 
   # check for one line of POD
-  unless(open(POD, "<","$file")) {
-    warn "Error: $file is unreadable: $!\n";
+  my $pod_fh;
+  unless(open($pod_fh, "<","$file")) {
+    warn "Error: $file is unreadable: $^OS_ERROR\n";
     return undef;
   }
   
-  local $/ = undef;
-  my $pod = ~< *POD;
-  close(POD) || die "Error closing $file: $!\n";
+  local $^INPUT_RECORD_SEPARATOR = undef;
+  my $pod = ~< $pod_fh;
+  close($pod_fh) || die "Error closing $file: $^OS_ERROR\n";
   unless($pod =~ m/^=(head\d|pod|over|item)\b/m) {
     warn "No POD in $file, skipping.\n"
       if($verbose);
