@@ -23,8 +23,7 @@
 package Pod::ParseLink;
 
 
-use strict;
-use vars < qw(@EXPORT @ISA $VERSION);
+our (@EXPORT, @ISA, $VERSION);
 
 use Exporter;
 @ISA    = qw(Exporter);
@@ -41,8 +40,7 @@ $VERSION = 1.06;
 ##############################################################################
 
 # Parse the name and section portion of a link into a name and section.
-sub _parse_section {
-    my ($link) = < @_;
+sub _parse_section($link) {
     $link =~ s/^\s+//;
     $link =~ s/\s+$//;
 
@@ -53,7 +51,7 @@ sub _parse_section {
     # Split into page and section on slash, and then clean up quoting in the
     # section.  If there is no section and the name contains spaces, also
     # guess that it's an old section link.
-    my ($page, $section) = < split (m/\s*\/\s*/, $link, 2);
+    my @($page, ?$section) =  split (m/\s*\/\s*/, $link, 2);
     $section =~ s/^"\s*(.*?)\s*"$/$1/ if $section;
     if ($page && $page =~ m/ / && !defined ($section)) {
         $section = $page;
@@ -66,8 +64,7 @@ sub _parse_section {
 }
 
 # Infer link text from the page and section.
-sub _infer_text {
-    my ($page, $section) = < @_;
+sub _infer_text($page, $section) {
     my $inferred;
     if ($page && !$section) {
         $inferred = $page;
@@ -82,19 +79,18 @@ sub _infer_text {
 # Given the contents of an L<> formatting code, parse it into the link text,
 # the possibly inferred link text, the name or URL, the section, and the type
 # of link (pod, man, or url).
-sub parselink {
-    my ($link) = < @_;
+sub parselink($link) {
     $link =~ s/\s+/ /g;
     if ($link =~ m/\A\w+:[^:\s]\S*\Z/) {
         return  @(undef, $link, $link, undef, 'url');
     } else {
         my $text;
         if ($link =~ m/\|/) {
-            ($text, $link) = < split (m/\|/, $link, 2);
+            @($text, $link) =  split (m/\|/, $link, 2);
         }
-        my ($name, $section) = < _parse_section ($link);
+        my @($name, $section) =  _parse_section ($link);
         my $inferred = $text || _infer_text ($name, $section);
-        my $type = ($name && $name =~ m/\(\S*\)/) ? 'man' : 'pod';
+        my $type = ($name && $name =~ m/\(\S*\)/) ?? 'man' !! 'pod';
         return  @($text, $inferred, $name, $section, $type);
     }
 }
