@@ -9,7 +9,7 @@
 
 package Pod::ParseUtils;
 
-use vars < qw($VERSION);
+our ($VERSION);
 $VERSION = 1.35;   ## Current version of this package
 
 =head1 NAME
@@ -69,11 +69,11 @@ sub new {
 
 sub initialize {
     my $self = shift;
-    $self->{-file} ||= 'unknown';
-    $self->{-start} ||= 'unknown';
-    $self->{-indent} ||= 4; # perlpod: "should be the default"
-    $self->{_items} = \@();
-    $self->{-type} ||= '';
+    $self->{+file} ||= 'unknown';
+    $self->{+start} ||= 'unknown';
+    $self->{+indent} ||= 4; # perlpod: "should be the default"
+    $self->{+_items} = \@();
+    $self->{+type} ||= '';
 }
 
 =item $list-E<gt>file()
@@ -86,7 +86,7 @@ method or by calling the B<file()> method with a scalar argument.
 
 # The POD file name the list appears in
 sub file {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-file} = @_[1]) : @_[0]->{-file};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{file} = @_[1]) !! @_[0]->{file};
 }
 
 =item $list-E<gt>start()
@@ -100,7 +100,7 @@ argument.
 
 # The line in the file the node appears
 sub start {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-start} = @_[1]) : @_[0]->{-start};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{start} = @_[1]) !! @_[0]->{start};
 }
 
 =item $list-E<gt>indent()
@@ -114,7 +114,7 @@ with a scalar argument.
 
 # indent level
 sub indent {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-indent} = @_[1]) : @_[0]->{-indent};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{indent} = @_[1]) !! @_[0]->{indent};
 }
 
 =item $list-E<gt>type()
@@ -129,7 +129,7 @@ with a scalar argument.
 
 # The type of the list (UL, OL, ...)
 sub type {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-type} = @_[1]) : @_[0]->{-type};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{type} = @_[1]) !! @_[0]->{type};
 }
 
 =item $list-E<gt>rx()
@@ -146,7 +146,7 @@ with a scalar argument.
 
 # The regular expression to simplify the items
 sub rx {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-rx} = @_[1]) : @_[0]->{-rx};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{rx} = @_[1]) !! @_[0]->{rx};
 }
 
 =item $list-E<gt>item()
@@ -158,8 +158,7 @@ If an argument has been given, it is pushed on the list of items.
 =cut
 
 # The individual =items of this list
-sub item {
-    my ($self,$item) = < @_;
+sub item($self, ?$item) {
     if(defined $item) {
         push(@{$self->{_items}}, $item);
         return $item;
@@ -182,7 +181,7 @@ with a scalar argument.
 # possibility for parsers/translators to store information about the
 # lists's parent object
 sub parent {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-parent} = @_[1]) : @_[0]->{-parent};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{parent} = @_[1]) !! @_[0]->{parent};
 }
 
 =item $list-E<gt>tag()
@@ -200,7 +199,7 @@ with a scalar argument.
 # possibility for parsers/translators to store information about the
 # list's object
 sub tag {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-tag} = @_[1]) : @_[0]->{-tag};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{tag} = @_[1]) !! @_[0]->{tag};
 }
 
 #-----------------------------------------------------------------------------
@@ -236,7 +235,7 @@ failure, the error message is stored in C<$@>.
 sub new {
     my $this = shift;
     my $class = ref($this) || $this;
-    my $self = +\%();
+    my $self = \%();
     bless $self, $class;
     $self->initialize();
     if(defined @_[0]) {
@@ -255,13 +254,13 @@ sub new {
 
 sub initialize {
     my $self = shift;
-    $self->{-line} ||= 'undef';
-    $self->{-file} ||= 'undef';
-    $self->{-page} ||= '';
-    $self->{-node} ||= '';
-    $self->{-alttext} ||= '';
-    $self->{-type} ||= 'undef';
-    $self->{_warnings} = \@();
+    $self->{+line} ||= 'undef';
+    $self->{+file} ||= 'undef';
+    $self->{+page} ||= '';
+    $self->{+node} ||= '';
+    $self->{+alttext} ||= '';
+    $self->{+type} ||= 'undef';
+    $self->{+_warnings} = \@();
 }
 
 =item $link-E<gt>parse($string)
@@ -279,9 +278,9 @@ sub parse {
     my $self = shift;
     local($_) = @_[0];
     # syntax check the link and extract destination
-    my ($alttext,$page,$node,$type,$quoted) = (undef,'','','',0);
+    my @($alttext,$page,$node,$type,$quoted) = @(undef,'','','',0);
 
-    $self->{_warnings} = \@();
+    $self->{+_warnings} = \@();
 
     # collapse newlines with whitespace
     s/\s*\n+\s*/ /g;
@@ -314,30 +313,30 @@ sub parse {
     }
     # alttext, page and "section"
     elsif(m!^(.*?)\s*[|]\s*($page_rx)\s*/\s*"(.+)"$!o) {
-        ($alttext, $page, $node) = ($1, $2, $3);
+        @($alttext, $page, $node) = @($1, $2, $3);
         $type = 'section';
         $quoted = 1; #... therefore | and / are allowed
     }
     # alttext and page
     elsif(m!^(.*?)\s*[|]\s*($page_rx)$!o) {
-        ($alttext, $page) = ($1, $2);
+        @($alttext, $page) = @($1, $2);
         $type = 'page';
     }
     # alttext and "section"
     elsif(m!^(.*?)\s*[|]\s*(?:/\s*|)"(.+)"$!) {
-        ($alttext, $node) = ($1,$2);
+        @($alttext, $node) = @($1,$2);
         $type = 'section';
         $quoted = 1;
     }
     # page and "section"
     elsif(m!^($page_rx)\s*/\s*"(.+)"$!o) {
-        ($page, $node) = ($1, $2);
+        @($page, $node) = @($1, $2);
         $type = 'section';
         $quoted = 1;
     }
     # page and item
     elsif(m!^($page_rx)\s*/\s*(.+)$!o) {
-        ($page, $node) = ($1, $2);
+        @($page, $node) = @($1, $2);
         $type = 'item';
     }
     # only "section"
@@ -354,7 +353,7 @@ sub parse {
 
     # non-standard: Hyperlink with alt-text - doesn't remove protocol prefix, maybe it should?
     elsif(m!^ \s* (.*?) \s* [|] \s* (\w+:[^:\s] [^\s|]*?) \s* $!ix) {
-      ($alttext,$node) = ($1,$2);
+      @($alttext,$node) = @($1,$2);
       $type = 'hyperlink';
     }
 
@@ -365,12 +364,12 @@ sub parse {
     }
     # alttext, page and item
     elsif(m!^(.*?)\s*[|]\s*($page_rx)\s*/\s*(.+)$!o) {
-        ($alttext, $page, $node) = ($1, $2, $3);
+        @($alttext, $page, $node) = @($1, $2, $3);
         $type = 'item';
     }
     # alttext and item
     elsif(m!^(.*?)\s*[|]\s*/(.+)$!) {
-        ($alttext, $node) = ($1,$2);
+        @($alttext, $node) = @($1,$2);
     }
     # must be an item or a "malformed" section (without "")
     else {
@@ -399,11 +398,11 @@ sub parse {
     if($alttext =~ m:[|/]:) {
         $self->warning("alternative text '$node' contains non-escaped | or /");
     }
-    $self->{-page} = $page;
-    $self->{-node} = $node;
-    $self->{-alttext} = $alttext;
+    $self->{+page} = $page;
+    $self->{+node} = $node;
+    $self->{+alttext} = $alttext;
     #warn "DEBUG: page=$page section=$section item=$item alttext=$alttext\n";
-    $self->{-type} = $type;
+    $self->{+type} = $type;
     $self->_construct_text();
     1;
 }
@@ -417,14 +416,14 @@ sub _construct_text {
     my $page_ext = '';
     $page =~ s/([(]\w*[)])$// && ($page_ext = $1);
     if($alttext) {
-        $self->{_text} = $alttext;
+        $self->{+_text} = $alttext;
     }
     elsif($type eq 'hyperlink') {
-        $self->{_text} = $section;
+        $self->{+_text} = $section;
     }
     else {
-        $self->{_text} = ($section || '') .
-            (($page && $section) ? ' in ' : '') .
+        $self->{+_text} = ($section || '') .
+            (($page && $section) ?? ' in ' !! '') .
             "$page$page_ext";
     }
     # for being marked up later
@@ -432,14 +431,14 @@ sub _construct_text {
     # text can be parsed by the translators. It's their job to put
     # the correct hypertext around the linktext
     if($alttext) {
-        $self->{_markup} = "Q<$alttext>";
+        $self->{+_markup} = "Q<$alttext>";
     }
     elsif($type eq 'hyperlink') {
-        $self->{_markup} = "Q<$section>";
+        $self->{+_markup} = "Q<$section>";
     }
     else {
-        $self->{_markup} = (!$section ? '' : "Q<$section>") .
-            ($page ? ($section ? ' in ':'') . "P<$page>$page_ext" : '');
+        $self->{+_markup} = (!$section ?? '' !! "Q<$section>") .
+            ($page ?? ($section ?? ' in '!!'') . "P<$page>$page_ext" !! '');
     }
 }
 
@@ -455,7 +454,7 @@ have to be implemented in the translator.
 
 #' retrieve/set markuped text
 sub markup {
-    return ((nelems @_) +> 1) ?  @(@_[0]->{_markup} = @_[1]) : @_[0]->{_markup};
+    return ((nelems @_) +> 1) ??  @(@_[0]->{+_markup} = @_[1]) !! @_[0]->{?_markup};
 }
 
 =item $link-E<gt>text()
@@ -474,7 +473,7 @@ that are marked up):
 
 # The complete link's text
 sub text {
-    @_[0]->{_text};
+    @_[0]->{?_text};
 }
 
 =item $link-E<gt>warning()
@@ -491,7 +490,7 @@ sub warning {
         push(@{$self->{_warnings}}, < @_);
         return @_;
     }
-    return @{$self->{_warnings}};
+    return @{$self->{?_warnings}};
 }
 
 =item $link-E<gt>file()
@@ -505,12 +504,12 @@ the link was encountered in. Has to be filled in manually.
 
 # The line in the file the link appears
 sub line {
-    return ((nelems @_) +> 1) ?  @(@_[0]->{-line} = @_[1]) : @_[0]->{-line};
+    return ((nelems @_) +> 1) ??  @(@_[0]->{+line} = @_[1]) !! @_[0]->{?line};
 }
 
 # The POD file name the link appears in
 sub file {
-    return ((nelems @_) +> 1) ?  @(@_[0]->{-file} = @_[1]) : @_[0]->{-file};
+    return ((nelems @_) +> 1) ??  @(@_[0]->{+file} = @_[1]) !! @_[0]->{?file};
 }
 
 =item $link-E<gt>page()
@@ -522,10 +521,10 @@ This method sets or returns the POD page this link points to.
 # The POD page the link appears on
 sub page {
     if ((nelems @_) +> 1) {
-        @_[0]->{-page} = @_[1];
+        @_[0]->{+page} = @_[1];
         @_[0]->_construct_text();
     }
-    @_[0]->{-page};
+    @_[0]->{?page};
 }
 
 =item $link-E<gt>node()
@@ -537,10 +536,10 @@ As above, but the destination node text of the link.
 # The link destination
 sub node {
     if ((nelems @_) +> 1) {
-        @_[0]->{-node} = @_[1];
+        @_[0]->{+node} = @_[1];
         @_[0]->_construct_text();
     }
-    @_[0]->{-node};
+    @_[0]->{?node};
 }
 
 =item $link-E<gt>alttext()
@@ -552,10 +551,10 @@ Sets or returns an alternative text specified in the link.
 # Potential alternative text
 sub alttext {
     if ((nelems @_) +> 1) {
-        @_[0]->{-alttext} = @_[1];
+        @_[0]->{+alttext} = @_[1];
         @_[0]->_construct_text();
     }
-    @_[0]->{-alttext};
+    @_[0]->{?alttext};
 }
 
 =item $link-E<gt>type()
@@ -567,7 +566,7 @@ there is also C<hyperlink>, derived from e.g. C<LE<lt>http://perl.comE<gt>>
 
 # The type: item or headn
 sub type {
-    return ((nelems @_) +> 1) ?  @(@_[0]->{-type} = @_[1]) : @_[0]->{-type};
+    return ((nelems @_) +> 1) ??  @(@_[0]->{+type} = @_[1]) !! @_[0]->{?type};
 }
 
 =item $link-E<gt>link()
@@ -585,7 +584,7 @@ sub link {
     if($self->node()) {
         my $node = $self->node();
         if($self->type() eq 'section') {
-            $link .= ($link ? '/' : '') . '"' . $node . '"';
+            $link .= ($link ?? '/' !! '') . '"' . $node . '"';
         }
         elsif($self->type() eq 'hyperlink') {
             $link = $self->node();
@@ -603,12 +602,11 @@ sub link {
     $link;
 }
 
-sub _invalid_link {
-    my ($msg) = < @_;
+sub _invalid_link($msg) {
     # this sets @_
     #try { die "$msg\n" };
     #chomp $@;
-    $@ = $msg; # this seems to work, too!
+    $^EVAL_ERROR = $msg; # this seems to work, too!
     undef;
 }
 
@@ -650,8 +648,7 @@ list of all cache elements.
 
 =cut
 
-sub item {
-    my ($self,< %param) = < @_;
+sub item($self,%< %param) {
     if(%param) {
         my $item = Pod::Cache::Item->new(< %param);
         push(@$self, $item);
@@ -672,8 +669,7 @@ not found.
 
 =cut
 
-sub find_page {
-    my ($self,$page) = < @_;
+sub find_page($self,$page) {
     foreach( @$self) {
         if($_->page() eq $page) {
             return $_;
@@ -712,7 +708,7 @@ sub new {
 
 sub initialize {
     my $self = shift;
-    $self->{-nodes} = \@() unless(defined $self->{-nodes});
+    $self->{+nodes} = \@() unless(defined $self->{?nodes});
 }
 
 =item $cacheitem-E<gt>page()
@@ -723,7 +719,7 @@ Set/retrieve the POD document name (e.g. "Pod::Parser").
 
 # The POD page
 sub page {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-page} = @_[1]) : @_[0]->{-page};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{+page} = @_[1]) !! @_[0]->{?page};
 }
 
 =item $cacheitem-E<gt>description()
@@ -735,7 +731,7 @@ section.
 
 # The POD description, taken out of NAME if present
 sub description {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-description} = @_[1]) : @_[0]->{-description};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{+description} = @_[1]) !! @_[0]->{?description};
 }
 
 =item $cacheitem-E<gt>path()
@@ -746,7 +742,7 @@ Set/retrieve the POD file storage path.
 
 # The file path
 sub path {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-path} = @_[1]) : @_[0]->{-path};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{+path} = @_[1]) !! @_[0]->{?path};
 }
 
 =item $cacheitem-E<gt>file()
@@ -757,7 +753,7 @@ Set/retrieve the POD file name.
 
 # The POD file name
 sub file {
-   return ((nelems @_) +> 1) ?  @(@_[0]->{-file} = @_[1]) : @_[0]->{-file};
+   return ((nelems @_) +> 1) ??  @(@_[0]->{+file} = @_[1]) !! @_[0]->{?file};
 }
 
 =item $cacheitem-E<gt>nodes()
@@ -772,14 +768,13 @@ unique id for the C<find_node> method to work correctly.
 =cut
 
 # The POD nodes
-sub nodes {
-    my ($self,< @nodes) = < @_;
+sub nodes($self,@< @nodes) {
     if((nelems @nodes)) {
-        push(@{$self->{-nodes}}, < @nodes);
+        push(@{$self->{nodes}}, < @nodes);
         return @nodes;
     }
     else {
-        return @{$self->{-nodes}};
+        return @{$self->{?nodes}};
     }
 }
 
@@ -791,11 +786,10 @@ stored in the node array) or undef if not found.
 
 =cut
 
-sub find_node {
-    my ($self,$node) = < @_;
+sub find_node($self,$node) {
     my @search;
-    push(@search, < @{$self->{-nodes}}) if($self->{-nodes});
-    push(@search, < @{$self->{-idx}}) if($self->{-idx});
+    push(@search, < @{$self->{?nodes}}) if($self->{?nodes});
+    push(@search, < @{$self->{?idx}}) if($self->{?idx});
     foreach( @search) {
         if($_->[0] eq $node) {
             return $_->[1]; # id
@@ -818,14 +812,13 @@ unique id.
 =cut
 
 # The POD index entries
-sub idx {
-    my ($self,< @idx) = < @_;
+sub idx($self,@< @idx) {
     if((nelems @idx)) {
-        push(@{$self->{-idx}}, < @idx);
+        push(@{$self->{idx}}, < @idx);
         return @idx;
     }
     else {
-        return @{$self->{-idx}};
+        return @{$self->{?idx}};
     }
 }
 
