@@ -1,6 +1,6 @@
 
 package Pod::Perldoc::BaseTo;
-use strict;
+
 use warnings;
 
 sub is_pageable        { '' }
@@ -14,11 +14,11 @@ sub output_extension   { 'txt' }  # override in subclass!
 #sub new { return bless {}, ref($_[0]) || $_[0] }
 
 sub _perldoc_elem {
-  my($self, $name) = splice @_,0,2;
+  my@($self, $name) =@( splice @_,0,2);
   if((nelems @_)) {
-    $self->{$name} = @_[0];
+    $self->{+$name} = @_[0];
   } else {
-    $self->{$name};
+    $self->{?$name};
   }
 }
 
