@@ -1,13 +1,13 @@
 
 package Pod::Perldoc::ToChecker;
-use strict;
+
 use warnings;
-use vars < qw(@ISA);
+our (@ISA);
 
 # Pick our superclass...
 #
 eval 'require Pod::Simple::Checker';
-if($@) {
+if($^EVAL_ERROR) {
   require Pod::Checker;
   @ISA = @('Pod::Checker');
 } else {
@@ -18,9 +18,8 @@ sub is_pageable        { 1 }
 sub write_with_binmode { 0 }
 sub output_extension   { 'txt' }
 
-sub if_zero_length {
-  my( $self, $file, $tmp, $tmpfd ) = < @_;
-  print "No Pod errors in $file\n";
+sub if_zero_length( $self, $file, $tmp, $tmpfd) {
+  print $^STDOUT, "No Pod errors in $file\n";
 }
 
 
