@@ -8,7 +8,7 @@
 
 
 package Pod::Perldoc::ToPod;
-use strict;
+
 use warnings;
 
 use base < qw(Pod::Perldoc::BaseTo);
@@ -19,9 +19,9 @@ sub output_extension   { 'pod' }
 sub new { return bless \%(), ref(@_[0]) || @_[0] }
 
 sub parse_from_file {
-  my( $self, $in, $outfh ) = < @_;
+  my@( $self, $in, $outfh ) =  @_;
 
-  open(IN, "<", $in) or die "Can't read-open $in: $!\nAborting";
+  open(IN, "<", $in) or die "Can't read-open $in: $^OS_ERROR\nAborting";
 
   my $cut_mode = 1;
   
@@ -36,10 +36,10 @@ sub parse_from_file {
       }
     }
     next if $cut_mode;
-    print $outfh $_ or die "Can't print to $outfh: $!";
+    print $outfh $_ or die "Can't print to $outfh: $^OS_ERROR";
   }
   
-  close IN or die "Can't close $in: $!";
+  close IN or die "Can't close $in: $^OS_ERROR";
   return;
 }
 
