@@ -1,8 +1,8 @@
 
 package Pod::Perldoc::ToRtf;
-use strict;
+
 use warnings;
-use vars < qw($VERSION);
+our ($VERSION);
 
 use base < qw( Pod::Simple::RTF );
 
@@ -16,11 +16,10 @@ sub is_pageable        { 0 }
 sub write_with_binmode { 0 }
 sub output_extension   { 'rtf' }
 
-sub page_for_perldoc {
-  my($self, $tempfile, $perldoc) = < @_;
+sub page_for_perldoc($self, $tempfile, $perldoc) {
   return unless $perldoc->IS_MSWin32;
   
-  my $rtf_pager = %ENV{'RTFREADER'} || 'write.exe';
+  my $rtf_pager = env::var('RTFREADER') || 'write.exe';
   
   $perldoc->aside( "About to launch <\"$rtf_pager\" \"$tempfile\">\n" );
   
