@@ -3,17 +3,16 @@
 # text comes out of Pod::BlackBox's _gen_errata
 
 package Pod::Simple::Checker;
-use strict;
+
 use utf8;
 use Carp ();
 use Pod::Simple::Methody ();
 use Pod::Simple ();
-use vars < qw( @ISA $VERSION );
-$VERSION = '2.02';
-@ISA = @('Pod::Simple::Methody');
+our $VERSION = '2.02';
+our @ISA = @('Pod::Simple::Methody');
 BEGIN { *DEBUG = defined(&Pod::Simple::DEBUG)
-          ? \&Pod::Simple::DEBUG
-          : sub() {0}
+          ?? \&Pod::Simple::DEBUG
+          !! sub() {0}
       }
 
 use Text::Wrap v98.112902 (); # was 2001.0131, but I don't think we need that
@@ -21,57 +20,57 @@ $Text::Wrap::wrap = 'overflow';
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub any_errata_seen {  # read-only accessor
-  return @_[1]->{'Errata_seen'};
+  return @_[1]->{?'Errata_seen'};
 }
 
 sub new {
   my $self = shift;
   my $new = $self->SUPER::new(< @_);
-  $new->{'output_fh'} ||= *STDOUT{IO};
+  $new->{+'output_fh'} ||= $^STDOUT{IO};
   $new->nix_X_codes(1);
   $new->nbsp_for_S(1);
-  $new->{'Thispara'} = '';
-  $new->{'Indent'} = 0;
-  $new->{'Indentstring'} = '   ';
-  $new->{'Errata_seen'} = 0;
+  $new->{+'Thispara'} = '';
+  $new->{+'Indent'} = 0;
+  $new->{+'Indentstring'} = '   ';
+  $new->{+'Errata_seen'} = 0;
   return $new;
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-sub handle_text {  @_[0]->{'Errata_seen'} and @_[0]->{'Thispara'} .= @_[1] }
+sub handle_text {  @_[0]->{?'Errata_seen'} and @_[0]->{+'Thispara'} .= @_[1] }
 
-sub start_Para  {  @_[0]->{'Thispara'} = '' }
+sub start_Para  {  @_[0]->{+'Thispara'} = '' }
 
 sub start_head1 {
-  if(@_[0]->{'Errata_seen'}) {
-    @_[0]->{'Thispara'} = '';
+  if(@_[0]->{?'Errata_seen'}) {
+    @_[0]->{+'Thispara'} = '';
   } else {
-    if(@_[1]->{'errata'}) { # start of errata!
-      @_[0]->{'Errata_seen'} = 1;
-      @_[0]->{'Thispara'} = @_[0]->{'source_filename'} ?
-        "@_[0]->{'source_filename'} -- " : ''
+    if(@_[1]->{?'errata'}) { # start of errata!
+      @_[0]->{+'Errata_seen'} = 1;
+      @_[0]->{+'Thispara'} = @_[0]->{?'source_filename'} ??
+        "@_[0]->{?'source_filename'} -- " !! ''
     }
   }
 }
-sub start_head2 {  @_[0]->{'Thispara'} = '' }
-sub start_head3 {  @_[0]->{'Thispara'} = '' }
-sub start_head4 {  @_[0]->{'Thispara'} = '' }
+sub start_head2 {  @_[0]->{+'Thispara'} = '' }
+sub start_head3 {  @_[0]->{+'Thispara'} = '' }
+sub start_head4 {  @_[0]->{+'Thispara'} = '' }
 
-sub start_Verbatim    { @_[0]->{'Thispara'} = ''   }
-sub start_item_bullet { @_[0]->{'Thispara'} = '* ' }
-sub start_item_number { @_[0]->{'Thispara'} = "@_[1]->{'number'}. "  }
-sub start_item_text   { @_[0]->{'Thispara'} = ''   }
+sub start_Verbatim    { @_[0]->{+'Thispara'} = ''   }
+sub start_item_bullet { @_[0]->{+'Thispara'} = '* ' }
+sub start_item_number { @_[0]->{+'Thispara'} = "@_[1]->{?'number'}. "  }
+sub start_item_text   { @_[0]->{+'Thispara'} = ''   }
 
-sub start_over_bullet  { ++@_[0]->{'Indent'} }
-sub start_over_number  { ++@_[0]->{'Indent'} }
-sub start_over_text    { ++@_[0]->{'Indent'} }
-sub start_over_block   { ++@_[0]->{'Indent'} }
+sub start_over_bullet  { ++@_[0]->{+'Indent'} }
+sub start_over_number  { ++@_[0]->{+'Indent'} }
+sub start_over_text    { ++@_[0]->{+'Indent'} }
+sub start_over_block   { ++@_[0]->{+'Indent'} }
 
-sub   end_over_bullet  { --@_[0]->{'Indent'} }
-sub   end_over_number  { --@_[0]->{'Indent'} }
-sub   end_over_text    { --@_[0]->{'Indent'} }
-sub   end_over_block   { --@_[0]->{'Indent'} }
+sub   end_over_bullet  { --@_[0]->{+'Indent'} }
+sub   end_over_number  { --@_[0]->{+'Indent'} }
+sub   end_over_text    { --@_[0]->{+'Indent'} }
+sub   end_over_block   { --@_[0]->{+'Indent'} }
 
 
 # . . . . . Now the actual formatters:
@@ -86,18 +85,18 @@ sub end_item_number { @_[0]->emit_par( 0) }
 sub end_item_text   { @_[0]->emit_par(-2) }
 
 sub emit_par {
-  return unless @_[0]->{'Errata_seen'};
-  my($self, $tweak_indent) = splice(@_,0,2);
-  my $indent = ' ' x ( 2 * $self->{'Indent'} + ($tweak_indent||0) );
+  return unless @_[0]->{?'Errata_seen'};
+  my@($self, $tweak_indent) = @: splice(@_,0,2);
+  my $indent = ' ' x ( 2 * $self->{?'Indent'} + ($tweak_indent||0) );
    # Yes, 'STRING' x NEGATIVE gives '', same as 'STRING' x 0
 
-  $self->{'Thispara'} =~ s/\x{AD}//g if Pod::Simple::ASCII;
-  my $out = Text::Wrap::wrap($indent, $indent, $self->{'Thispara'} .= "\n");
+  $self->{+'Thispara'} =~ s/\x{AD}//g if Pod::Simple::ASCII;
+  my $out = Text::Wrap::wrap($indent, $indent, ($self->{+'Thispara'} .= "\n"));
   $out =~ s/\x{A0}/ /g if Pod::Simple::ASCII;
-  print {$self->{'output_fh'}} $out,
+  print $self->{?'output_fh'} ,$out,
     #"\n"
   ;
-  $self->{'Thispara'} = '';
+  $self->{+'Thispara'} = '';
   
   return;
 }
@@ -105,22 +104,22 @@ sub emit_par {
 # . . . . . . . . . . And then off by its lonesome:
 
 sub end_Verbatim  {
-  return unless @_[0]->{'Errata_seen'};
+  return unless @_[0]->{?'Errata_seen'};
   my $self = shift;
   if(Pod::Simple::ASCII) {
-    $self->{'Thispara'} =~ s/\x{A0}/ /g;
-    $self->{'Thispara'} =~ s/\x{AD}//g;
+    $self->{+'Thispara'} =~ s/\x{A0}/ /g;
+    $self->{+'Thispara'} =~ s/\x{AD}//g;
   }
 
-  my $i = ' ' x ( 2 * $self->{'Indent'} + 4);
+  my $i = ' ' x ( 2 * $self->{?'Indent'} + 4);
   
-  $self->{'Thispara'} =~ s/^/$i/mg;
+  $self->{+'Thispara'} =~ s/^/$i/mg;
   
-  print { $self->{'output_fh'} }   '', 
-    $self->{'Thispara'},
+  print  $self->{?'output_fh'}    ,'', 
+    $self->{?'Thispara'},
     "\n\n"
   ;
-  $self->{'Thispara'} = '';
+  $self->{+'Thispara'} = '';
   return;
 }
 
