@@ -4,7 +4,6 @@ our $VERSION = '2.02';
 use Pod::Simple ();
 BEGIN {our @ISA = @('Pod::Simple')}
 
-use strict;
 
 use Carp ();
 
@@ -13,7 +12,7 @@ BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 sub new {
   my $self = shift;
   my $new = $self->SUPER::new(< @_);
-  $new->{'output_fh'} ||= *STDOUT{IO};
+  $new->{+'output_fh'} ||= $^STDOUT;
   $new->accept_codes('VerbatimFormatted');
   return $new;
 }
@@ -22,29 +21,29 @@ sub new {
 
 sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
-  my $fh = @_[0]->{'output_fh'};
+  my $fh = @_[0]->{?'output_fh'};
   my($key, $value);
-  DEBUG and print "++ @_[1]\n";
+  DEBUG and print $^STDOUT, "++ @_[1]\n";
   
-  print $fh   '  ' x (@_[0]->{'indent'} || 0),  "++", @_[1], "\n";
-  @_[0]->{'indent'}++;
-  while(($key,$value) = each %{@_[2]}) {
+  print $fh,   '  ' x (@_[0]->{?'indent'} || 0),  "++", @_[1], "\n";
+  @_[0]->{+'indent'}++;
+  while(@(?$key,?$value) =@( each %{@_[2]})) {
     unless($key =~ m/^~/s) {
-      next if $key eq 'start_line' and @_[0]->{'hide_line_numbers'};
+      next if $key eq 'start_line' and @_[0]->{?'hide_line_numbers'};
       _perly_escape($key);
       _perly_escape($value);
-      printf $fh qq{\%s \\ "\%s" => "\%s"\n},
-        '  ' x (@_[0]->{'indent'} || 0), $key, $value;
+      printf $fh, qq{\%s \\ "\%s" => "\%s"\n},
+        '  ' x (@_[0]->{?'indent'} || 0), $key, $value;
     }
   }
   return;
 }
 
 sub _handle_text {
-  DEBUG and print "== \"@_[1]\"\n";
+  DEBUG and print $^STDOUT, "== \"@_[1]\"\n";
   
   if(length @_[1]) {
-    my $indent = '  ' x @_[0]->{'indent'};
+    my $indent = '  ' x @_[0]->{?'indent'};
     my $text = @_[1];
     _perly_escape($text);
     $text =~  # A not-totally-brilliant wrapping algorithm:
@@ -56,15 +55,15 @@ sub _handle_text {
        /$1"\n$indent . "/gx     # => line-break here
     ;
     
-    print {@_[0]->{'output_fh'}} $indent, '* "', $text, "\"\n";
+    print @_[0]->{?'output_fh'} ,$indent, '* "', $text, "\"\n";
   }
   return;
 }
 
 sub _handle_element_end {
-  DEBUG and print "-- @_[1]\n";
-  print {@_[0]->{'output_fh'}}
-   '  ' x --@_[0]->{'indent'}, "--", @_[1], "\n";
+  DEBUG and print $^STDOUT, "-- @_[1]\n";
+  print @_[0]->{?'output_fh'}
+   ,'  ' x --@_[0]->{+'indent'}, "--", @_[1], "\n";
   return;
 }
 
@@ -73,7 +72,7 @@ sub _handle_element_end {
 sub _perly_escape {
   foreach my $x ( @_) {
     # Escape things very cautiously:
-    $x =~ s/([^-\n\t \&\<\>\'!\#\%\(\)\*\+,\.\/\:\;=\?\~\[\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{sprintf'\x{%X}',ord($1)}/g;
+    $x =~ s/([^-\n\t \&\<\>\'!\#\%\(\)\*\+,\.\/\:\;=\?\~\[\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/$(sprintf'\x{%X}',ord($1))/g;
   }
   return;
 }
