@@ -4,7 +4,6 @@ our $VERSION = '2.02';
 use Pod::Simple ();
 BEGIN {our @ISA = @('Pod::Simple')}
 
-use strict;
 use utf8;
 
 use Carp ();
@@ -14,7 +13,7 @@ BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 sub new {
   my $self = shift;
   my $new = $self->SUPER::new(< @_);
-  $new->{'output_fh'} ||= *STDOUT{IO};
+  $new->{+'output_fh'} ||= $^STDOUT;
   $new->accept_codes('VerbatimFormatted');
   return $new;
 }
@@ -23,33 +22,33 @@ sub new {
 
 sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
-  my $fh = @_[0]->{'output_fh'};
-  DEBUG and print "++ @_[1]\n";
+  my $fh = @_[0]->{?'output_fh'};
+  DEBUG and print $^STDOUT, "++ @_[1]\n";
   
-  print $fh   '  ' x (@_[0]->{'indent'} || 0),  "<", @_[1];
+  print $fh,   '  ' x (@_[0]->{?'indent'} || 0),  "<", @_[1];
 
   foreach my $key (sort keys %{@_[2]}) {
     unless($key =~ m/^~/s) {
-      next if $key eq 'start_line' and @_[0]->{'hide_line_numbers'};
-      my $value = @_[2]->{$key};
+      next if $key eq 'start_line' and @_[0]->{?'hide_line_numbers'};
+      my $value = @_[2]->{?$key};
       if (@_[1] eq 'L' and $key =~ m/^(?:section|to)$/) {
           $value = $value->as_string;
       }
       _xml_escape($value);
-      print $fh ' ', $key, '="', $value, '"';
+      print $fh, ' ', $key, '="', $value, '"';
     }
   }
 
 
-  print $fh ">\n";
-  @_[0]->{'indent'}++;
+  print $fh, ">\n";
+  @_[0]->{+'indent'}++;
   return;
 }
 
 sub _handle_text {
-  DEBUG and print "== \"@_[1]\"\n";
+  DEBUG and print $^STDOUT, "== \"@_[1]\"\n";
   if(length @_[1]) {
-    my $indent = '  ' x @_[0]->{'indent'};
+    my $indent = '  ' x @_[0]->{?'indent'};
     my $text = @_[1];
     _xml_escape($text);
     $text =~  # A not-totally-brilliant wrapping algorithm:
@@ -61,15 +60,15 @@ sub _handle_text {
        /$1\n$indent/gx     # => line-break here
     ;
     
-    print {@_[0]->{'output_fh'}} $indent, $text, "\n";
+    print @_[0]->{?'output_fh'} ,$indent, $text, "\n";
   }
   return;
 }
 
 sub _handle_element_end {
-  DEBUG and print "-- @_[1]\n";
-  print {@_[0]->{'output_fh'}}
-   '  ' x --@_[0]->{'indent'}, "</", @_[1], ">\n";
+  DEBUG and print $^STDOUT, "-- @_[1]\n";
+  print @_[0]->{?'output_fh'}
+   ,'  ' x --@_[0]->{+'indent'}, "</", @_[1], ">\n";
   return;
 }
 
@@ -78,8 +77,7 @@ sub _handle_element_end {
 sub _xml_escape {
   foreach my $x ( @_) {
     # Escape things very cautiously:
-    $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
-}/g;
+    $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/$('&#'.(ord($1)).';')/g;
     # Yes, stipulate the list without a range, so that this can work right on
     #  all charsets that this module happens to run under.
     # Altho, hmm, what about that ord?  Presumably that won't work right
