@@ -1,12 +1,12 @@
 
 package Pod::Simple::HTML;
-use strict;
+
 use Pod::Simple::PullParser ();
-use vars < qw(
-  @ISA %Tagmap $Computerese $LamePad $Linearization_Limit $VERSION
-  $Perldoc_URL_Prefix $Perldoc_URL_Postfix
-  $Title_Prefix $Title_Postfix $HTML_EXTENSION %ToIndex
-  $Doctype_decl  $Content_decl
+our (
+  @ISA, %Tagmap, $Computerese, $LamePad, $Linearization_Limit, $VERSION,
+  $Perldoc_URL_Prefix, $Perldoc_URL_Postfix,
+  $Title_Prefix, $Title_Postfix, $HTML_EXTENSION, %ToIndex,
+  $Doctype_decl,  $Content_decl,
 );
 @ISA = @('Pod::Simple::PullParser');
 $VERSION = '3.03';
@@ -38,7 +38,7 @@ $Perldoc_URL_Postfix = ''
 
 $Title_Prefix  = '' unless defined $Title_Prefix;
 $Title_Postfix = '' unless defined $Title_Postfix;
-%ToIndex = %( < map {; $_ => 1 } qw(head1 head2 head3 head4 ) ); # item-text
+%ToIndex = %( < @+: map { @: $_ => 1 }, qw(head1 head2 head3 head4 ) ); # item-text
   # 'item-text' stuff in the index doesn't quite work, and may
   # not be a good idea anyhow.
 
@@ -118,7 +118,7 @@ my @_to_accept;
     item-text=dt
   )), <
   changes2(
-    < map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ }
+    < map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ },
     qw[
       sample=samp
       definition=dfn
@@ -152,14 +152,14 @@ my @_to_accept;
 );
 
 sub changes {
-  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
-     ? ( $1, => "\n<$2>", "/$1", => "</$2>\n" ) : die "Funky $_"
-  } @_;
+  return @+: map { m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+     ?? @( $1, => "\n<$2>", "/$1", => "</$2>\n" ) !! die "Funky $_"
+  }, @_;
 }
 sub changes2 {
-  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
-     ? ( $1, => "<$2>", "/$1", => "</$2>" ) : die "Funky $_"
-  } @_;
+  return @+: map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+     ?? @( $1, => "<$2>", "/$1", => "</$2>" ) !! die "Funky $_"
+  }, @_;
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -175,7 +175,7 @@ sub new {
   $new->accept_targets( 'html', 'HTML' );
   $new->accept_codes('VerbatimFormatted');
   $new->accept_codes(< @_to_accept);
-  DEBUG +> 2 and print "To accept: ", join(' ', @_to_accept), "\n";
+  DEBUG +> 2 and print $^STDOUT, "To accept: ", join(' ', @_to_accept), "\n";
 
   $new->perldoc_url_prefix(  $Perldoc_URL_Prefix  );
   $new->perldoc_url_postfix( $Perldoc_URL_Postfix );
@@ -194,13 +194,12 @@ sub new {
   );
   $new->html_footer( qq[\n<!-- end doc -->\n\n</body></html>\n] );
 
-  $new->{'Tagmap'} = \%(< %Tagmap);
+  $new->{+'Tagmap'} = \%(< %Tagmap);
   return $new;
 }
 
-sub batch_mode_page_object_init {
-  my($self, $batchconvobj, $module, $infile, $outfile, $depth) = < @_;
-  DEBUG and print "Initting $self\n  for $module\n",
+sub batch_mode_page_object_init($self, $batchconvobj, $module, $infile, $outfile, $depth) {
+  DEBUG and print $^STDOUT, "Initting $self\n  for $module\n",
     "  in $infile\n  out $outfile\n  depth $depth\n";
   $self->batch_mode(1);
   $self->batch_mode_current_level($depth);
@@ -223,22 +222,22 @@ sub do_beginning {
   
   if(defined $self->force_title) {
     $title = $self->force_title;
-    DEBUG and print "Forcing title to be $title\n";
+    DEBUG and print $^STDOUT, "Forcing title to be $title\n";
   } else {
     # Actually try looking for the title in the document:
     $title = $self->get_short_title();
     unless($self->content_seen) {
-      DEBUG and print "No content seen in search for title.\n";
+      DEBUG and print $^STDOUT, "No content seen in search for title.\n";
       return;
     }
-    $self->{'Title'} = $title;
+    $self->{+'Title'} = $title;
 
     if(defined $title and $title =~ m/\S/) {
       $title = $self->title_prefix . esc($title) . $self->title_postfix;
     } else {
       $title = $self->default_title;    
       $title = '' unless defined $title;
-      DEBUG and print "Title defaults to $title\n";
+      DEBUG and print $^STDOUT, "Title defaults to $title\n";
     }
   }
 
@@ -247,8 +246,8 @@ sub do_beginning {
   if($self->html_css) {
     my $link =
     $self->html_css =~ m/</
-     ? $self->html_css # It's a big blob of markup, let's drop it in
-     : sprintf(        # It's just a URL, so let's wrap it up
+     ?? $self->html_css # It's a big blob of markup, let's drop it in
+     !! sprintf(        # It's just a URL, so let's wrap it up
       qq[<link rel="stylesheet" type="text/css" title="pod_stylesheet" href="\%s">\n], <
       $self->html_css,
     );
@@ -259,26 +258,25 @@ sub do_beginning {
   if($self->html_javascript) {
     my $link =
     $self->html_javascript =~ m/</
-     ? $self->html_javascript # It's a big blob of markup, let's drop it in
-     : sprintf(        # It's just a URL, so let's wrap it up
+     ?? $self->html_javascript # It's a big blob of markup, let's drop it in
+     !! sprintf(        # It's just a URL, so let's wrap it up
       qq[<script type="text/javascript" src="\%s"></script>\n], <
       $self->html_javascript,
     );
     $after =~ s{(</head>)}{$link\n$1}i;  # otherwise nevermind
   }
 
-  print {$self->{'output_fh'}}
-    $self->html_header_before_title || '',
+  print $self->{?'output_fh'}
+    ,$self->html_header_before_title || '',
     $title, # already escaped
     $after,
   ;
 
-  DEBUG and print "Returning from do_beginning...\n";
+  DEBUG and print $^STDOUT, "Returning from do_beginning...\n";
   return 1;
 }
 
-sub _add_top_anchor {
-  my($self, $text_r) = < @_;
+sub _add_top_anchor($self, $text_r) {
   unless($$text_r and $$text_r =~ m/name=['"]___top['"]/) { # a hack
     $$text_r .= "<a name='___top' class='dummyTopAnchor' ></a>\n";
   }
@@ -289,16 +287,16 @@ sub version_tag_comment {
   my $self = shift;
   return sprintf
    "<!--\n  generated by \%s v\%s,\n  using \%s v\%s,\n  under Perl v\%s at \%s GMT.\n\n \%s\n\n-->\n",
-   (< map { esc($_) }
+   (< map { esc($_) },
  @(    ref($self), $self->VERSION(), @ISA[0], @ISA[0]->VERSION(),
-    $^V, scalar(gmtime),)
+    $^PERL_VERSION, scalar(gmtime),)
    ), $self->_modnote(),
   ;
 }
 
 sub _modnote {
   my $class = ref(@_[0]) || @_[0];
-  return join "\n   ", grep m/\S/, split "\n",
+  return join "\n   ", grep { m/\S/ }, split "\n",
 
 qq{
 If you want to change this HTML document, you probably shouldn't do that
@@ -313,7 +311,7 @@ See 'perldoc $class' for more info.
 
 sub do_end {
   my $self = @_[0];
-  print {$self->{'output_fh'}}  $self->html_footer || '';
+  print $self->{?'output_fh'}  ,$self->html_footer || '';
   return 1;
 }
 
@@ -336,9 +334,9 @@ sub do_middle {
     my $index = $self->index_as_html();
     if( $$out =~ s/$sneakytag/$index/s ) {
       # Expected case
-      DEBUG and print "Inserted ", length($index), " bytes of index HTML into $out.\n";
+      DEBUG and print $^STDOUT, "Inserted ", length($index), " bytes of index HTML into $out.\n";
     } else {
-      DEBUG and print "Odd, couldn't find where to insert the index in the output!\n";
+      DEBUG and print $^STDOUT, "Odd, couldn't find where to insert the index in the output!\n";
       # I don't think this should ever happen.
     }
     return 1;
@@ -353,15 +351,15 @@ sub do_middle {
   # Namely, divert all content to a string, which we output after the index.
   my $fh = $self->output_fh;
   my $content = '';
-  {
+  do {
     # Our horrible bait and switch:
     $self->output_string( \$content );
     $self->_do_middle_main_loop;
     $self->abandon_output_string();
     $self->output_fh($fh);
-  }
-  print $fh $self->index_as_html();
-  print $fh $content;
+  };
+  print $fh, $self->index_as_html();
+  print $fh, $content;
 
   return 1;
 }
@@ -372,17 +370,17 @@ sub index_as_html {
   my $self = @_[0];
   # This is meant to be called AFTER the input document has been parsed!
 
-  my $points = $self->{'PSHTML_index_points'} || \@();
+  my $points = $self->{?'PSHTML_index_points'} || \@();
   
   (nelems @$points) +> 1 or return qq[<div class='indexgroupEmpty'></div>\n];
    # There's no point in having a 0-item or 1-item index, I dare say.
   
-  my(@out) = @( qq{\n<div class='indexgroup'>} );
+  my@(@out) =@( @( qq{\n<div class='indexgroup'>} ));
   my $level = 0;
 
   my( $target_level, $previous_tagname, $tagname, $text, $anchorname, $indent);
   foreach my $p ( @( < @$points, \@('head0', '(end)') ) ) {
-    ($tagname, $text) = < @$p;
+    @($tagname, $text) =  @$p;
     $anchorname = $self->section_escape($text);
     if( $tagname =~ m{^head(\d+)$} ) {
       $target_level = 0 + $1;
@@ -418,8 +416,8 @@ sub index_as_html {
 
 sub _do_middle_main_loop {
   my $self = @_[0];
-  my $fh = $self->{'output_fh'};
-  my $tagmap = $self->{'Tagmap'};
+  my $fh = $self->{?'output_fh'};
+  my $tagmap = $self->{?'Tagmap'};
   
   my($token, $type, $tagname, $linkto, $linktype);
   my @stack;
@@ -438,13 +436,13 @@ sub _do_middle_main_loop {
           $linkto = esc($linkto);
             #   (Yes, SGML-escaping applies on top of %-escaping!
             #   But it's rarely noticeable in practice.)
-          print $fh qq{<a href="$linkto" class="podlink$linktype"\n>};
+          print $fh, qq{<a href="$linkto" class="podlink$linktype"\n>};
         } else {
-          print $fh "<a>"; # Yes, an 'a' element with no attributes!
+          print $fh, "<a>"; # Yes, an 'a' element with no attributes!
         }
 
       } elsif ($tagname eq 'item-text' or $tagname =~ m/^head\d$/s) {
-        print $fh $tagmap->{$tagname} || next;
+        print $fh, $tagmap->{?$tagname} || next;
 
         my @to_unget;
         while(1) {
@@ -457,25 +455,25 @@ sub _do_middle_main_loop {
 
         my $name = $self->linearize_tokens(< @to_unget);
         
-        print $fh "<a ";
-        print $fh "class='u' href='#___top' title='click to go to top of document'\n"
+        print $fh, "<a ";
+        print $fh, "class='u' href='#___top' title='click to go to top of document'\n"
          if $tagname =~ m/^head\d$/s;
         
         if(defined $name) {
           my $esc = esc( $self->section_name_tidy( $name ) );
-          print $fh qq[name="$esc"];
-          DEBUG and print "Linearized ", scalar(nelems @to_unget),
+          print $fh, qq[name="$esc"];
+          DEBUG and print $^STDOUT, "Linearized ", scalar(nelems @to_unget),
            " tokens as \"$name\".\n";
-          push @{ $self->{'PSHTML_index_points'} }, \@($tagname, $name)
-           if %ToIndex{ $tagname };
+          push @{ $self->{+'PSHTML_index_points'} }, \@($tagname, $name)
+           if %ToIndex{?$tagname };
             # Obviously, this discards all formatting codes (saving
             #  just their content), but ahwell.
            
         } else {  # ludicrously long, so nevermind
-          DEBUG and print "Linearized ", scalar(nelems @to_unget),
+          DEBUG and print $^STDOUT, "Linearized ", scalar(nelems @to_unget),
            " tokens, but it was too long, so nevermind.\n";
         }
-        print $fh "\n>";
+        print $fh, "\n>";
         $self->unget_token(< @to_unget);
 
       } elsif ($tagname eq 'Data') {
@@ -485,18 +483,18 @@ sub _do_middle_main_loop {
           $self->unget_token($next);
           next;
         }
-        DEBUG and print "    raw text ", < $next->text, "\n";
-        printf $fh "\n" . $next->text . "\n";
+        DEBUG and print $^STDOUT, "    raw text ", < $next->text, "\n";
+        printf $fh, "\n" . $next->text . "\n";
         next;
        
       } else {
         if( $tagname =~ m/^over-/s ) {
           push @stack, '';
         } elsif( $tagname =~ m/^item-/s and nelems @stack and @stack[-1] ) {
-          print $fh @stack[-1];
+          print $fh, @stack[-1];
           @stack[-1] = '';
         }
-        print $fh $tagmap->{$tagname} || next;
+        print $fh, $tagmap->{?$tagname} || next;
         ++$dont_wrap if $tagname eq 'Verbatim' or $tagname eq "VerbatimFormatted"
           or $tagname eq 'X';
       }
@@ -505,27 +503,27 @@ sub _do_middle_main_loop {
     } elsif( $type eq 'end' ) {
       if( ($tagname = $token->tagname) =~ m/^over-/s ) {
         if( my $end = pop @stack ) {
-          print $fh $end;
+          print $fh, $end;
         }
       } elsif( $tagname =~ m/^item-/s and nelems @stack) {
-        @stack[-1] = $tagmap->{"/$tagname"};
+        @stack[-1] = $tagmap->{?"/$tagname"};
         if( $tagname eq 'item-text' and defined(my $next = $self->get_token) ) {
           $self->unget_token($next);
           if( $next->type eq 'start' and $next->tagname !~ m/^item-/s ) {
-            print $fh $tagmap->{"/item-text"},$tagmap->{"item-body"};
-            @stack[-1] = $tagmap->{"/item-body"};
+            print $fh, $tagmap->{?"/item-text"},$tagmap->{?"item-body"};
+            @stack[-1] = $tagmap->{?"/item-body"};
           }
         }
         next;
       }
-      print $fh $tagmap->{"/$tagname"} || next;
+      print $fh, $tagmap->{?"/$tagname"} || next;
       --$dont_wrap if $tagname eq 'Verbatim' or $tagname eq 'X';
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     } elsif( $type eq 'text' ) {
       $type = esc($token->text);  # reuse $type, why not
       $type =~ s/([\?\!\"\'\.\,]) /$1\n/g unless $dont_wrap;
-      print $fh $type;
+      print $fh, $type;
     }
 
   }
@@ -535,8 +533,7 @@ sub _do_middle_main_loop {
 ###########################################################################
 #
 
-sub do_link {
-  my($self, $token) = < @_;
+sub do_link($self, $token) {
   my $type = $token->attr('type');
   if(!defined $type) {
     $self->whine("Typeless L!?", < $token->attr('start_line'));
@@ -558,9 +555,7 @@ sub do_man_link { return undef }
  #  pages somewhere URL-accessible.
 
 
-sub do_pod_link {
-  # And now things get really messy...
-  my($self, $link) = < @_;
+sub do_pod_link($self, $link) {
   my $to = $link->attr('to');
   my $section = $link->attr('section');
   return undef unless(  # should never happen
@@ -571,36 +566,36 @@ sub do_pod_link {
   $section = $self->section_escape($section)
    if defined $section and length($section .= ''); # (stringify)
 
-  DEBUG and printf "Resolving \"\%s\" \"\%s\"...\n",
+  DEBUG and printf $^STDOUT, "Resolving \"\%s\" \"\%s\"...\n",
    $to || "(nil)",  $section || "(nil)";
    
-  {
+  do {
     # An early hack:
     my $complete_url = $self->resolve_pod_link_by_table($to, $section);
     if( $complete_url ) {
-      DEBUG +> 1 and print "resolve_pod_link_by_table(T,S) gives ",
+      DEBUG +> 1 and print $^STDOUT, "resolve_pod_link_by_table(T,S) gives ",
         $complete_url, "\n  (Returning that.)\n";
       return $complete_url;
     } else {
-      DEBUG +> 4 and print " resolve_pod_link_by_table(T,S)", 
+      DEBUG +> 4 and print $^STDOUT, " resolve_pod_link_by_table(T,S)", 
        " didn't return anything interesting.\n";
     }
-  }
+  };
 
   if(defined $to and length $to) {
     # Give this routine first hack again
     my $there = $self->resolve_pod_link_by_table($to);
     if(defined $there and length $there) {
       DEBUG +> 1
-       and print "resolve_pod_link_by_table(T) gives $there\n";
+       and print $^STDOUT, "resolve_pod_link_by_table(T) gives $there\n";
     } else {
       $there = 
         $self->resolve_pod_page_link($to, $section);
          # (I pass it the section value, but I don't see a
          #  particular reason it'd use it.)
-      DEBUG +> 1 and print "resolve_pod_page_link gives ", $to || "(nil)", "\n";
+      DEBUG +> 1 and print $^STDOUT, "resolve_pod_page_link gives ", $to || "(nil)", "\n";
       unless( defined $there and length $there ) {
-        DEBUG and print "Can't resolve $to\n";
+        DEBUG and print $^STDOUT, "Can't resolve $to\n";
         return undef;
       }
       # resolve_pod_page_link returning undef is how it
@@ -611,31 +606,29 @@ sub do_pod_link {
 
   #DEBUG and print "So far [", $to||'nil', "] [", $section||'nil', "]\n";
 
-  my $out = (defined $to and length $to) ? $to : '';
+  my $out = (defined $to and length $to) ?? $to !! '';
   $out .= "#" . $section if defined $section and length $section;
   
   unless(length $out) { # sanity check
-    DEBUG and printf "Oddly, couldn't resolve \"\%s\" \"\%s\"...\n",
+    DEBUG and printf $^STDOUT, "Oddly, couldn't resolve \"\%s\" \"\%s\"...\n",
      $to || "(nil)",  $section || "(nil)";
     return undef;
   }
 
-  DEBUG and print "Resolved to $out\n";
+  DEBUG and print $^STDOUT, "Resolved to $out\n";
   return $out;  
 }
 
 
 # . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .
 
-sub section_escape {
-  my($self, $section) = < @_;
+sub section_escape($self, $section) {
   return $self->section_url_escape(
     $self->section_name_tidy($section)
   );
 }
 
-sub section_name_tidy {
-  my($self, $section) = < @_;
+sub section_name_tidy($self, $section) {
   $section =~ s/ /_/g;
   $section =~ s/\x[00]-\x[1F]\x[80]-\x[9F]//g; # drop crazy characters
   $section = $self->unicode_escape_url($section);
@@ -646,16 +639,17 @@ sub section_name_tidy {
 sub section_url_escape  { shift->general_url_escape(< @_) }
 sub pagepath_url_escape { shift->general_url_escape(< @_) }
 
-sub general_url_escape {
-  my($self, $string) = < @_;
+sub general_url_escape($self, $string) {
  
-  $string =~ s/([^\x[00]-\x[FF]])/{join '', map sprintf('%%%02X',$_), @( unpack 'C*', $1)}/g;
+  $string =~ s/([^\x[00]-\x[FF]])/$(
+     join '', map { sprintf('%%%02X',$_) }, @( unpack 'C*', $1)
+    )/g;
      # express Unicode things as urlencode(utf(orig)).
   
   # A pretty conservative escaping, behoovey even for query components
   #  of a URL (see RFC 2396)
   
-  $string =~ s/([^-_\.!~*()abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{sprintf('%%%02X',ord($1))}/g;
+  $string =~ s/([^-_\.!~*()abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/$(sprintf('%%%02X',ord($1)))/g;
    # Yes, stipulate the list without a range, so that this can work right on
    #  all charsets that this module happens to run under.
    # Altho, hmm, what about that ord?  Presumably that won't work right
@@ -674,13 +668,12 @@ sub resolve_pod_page_link {
   # resolve_pod_page_link must return a properly escaped URL
   my $self = shift;
   return $self->batch_mode()
-   ? $self->resolve_pod_page_link_batch_mode(< @_)
-   : $self->resolve_pod_page_link_singleton_mode(< @_)
+   ?? $self->resolve_pod_page_link_batch_mode(< @_)
+   !! $self->resolve_pod_page_link_singleton_mode(< @_)
   ;
 }
 
-sub resolve_pod_page_link_singleton_mode {
-  my($self, $it) = < @_;
+sub resolve_pod_page_link_singleton_mode($self, $it) {
   return undef unless defined $it and length $it;
   my $url = $self->pagepath_url_escape($it);
   
@@ -691,23 +684,21 @@ sub resolve_pod_page_link_singleton_mode {
   return $self->perldoc_url_prefix . $url . $self->perldoc_url_postfix;
 }
 
-sub resolve_pod_page_link_batch_mode {
-  my($self, $to) = < @_;
-  DEBUG +> 1 and print " During batch mode, resolving $to ...\n";
-  my @path = grep length($_), split m/::/s, $to, -1;
+sub resolve_pod_page_link_batch_mode($self, $to) {
+  DEBUG +> 1 and print $^STDOUT, " During batch mode, resolving $to ...\n";
+  my @path = grep { length($_) }, split m/::/s, $to, -1;
   unless( nelems @path ) { # sanity
-    DEBUG and print "Very odd!  Splitting $to gives (nil)!\n";
+    DEBUG and print $^STDOUT, "Very odd!  Splitting $to gives (nil)!\n";
     return undef;
   }
   $self->batch_mode_rectify_path(\@path);
-  my $out = join('/', map < $self->pagepath_url_escape($_), @path)
+  my $out = join('/', map { < $self->pagepath_url_escape($_) }, @path)
     . $HTML_EXTENSION;
-  DEBUG +> 1 and print " => $out\n";
+  DEBUG +> 1 and print $^STDOUT, " => $out\n";
   return $out;
 }
 
-sub batch_mode_rectify_path {
-  my($self, $pathbits) = < @_;
+sub batch_mode_rectify_path($self, $pathbits) {
   my $level = $self->batch_mode_current_level;
   $level--; # how many levels up to go to get to the root
   if($level +< 1) {
@@ -723,17 +714,17 @@ sub batch_mode_rectify_path {
 sub resolve_pod_link_by_table {
   # A crazy hack to allow specifying custom L<foo> => URL mappings
 
-  return unless @_[0]->{'podhtml_LOT'};  # An optimizy shortcut
+  return unless @_[0]->{?'podhtml_LOT'};  # An optimizy shortcut
 
-  my($self, $to, $section) = < @_;
+  my@($self, $to, $section) =  @_;
 
   # TODO: add a method that actually populates podhtml_LOT from a file?
 
   if(defined $section) {
     $to = '' unless defined $to and length $to;
-    return $self->{'podhtml_LOT'}->{"$to#$section"}; # quite possibly undef!
+    return $self->{'podhtml_LOT'}->{?"$to#$section"}; # quite possibly undef!
   } else {
-    return $self->{'podhtml_LOT'}->{$to};            # quite possibly undef!
+    return $self->{'podhtml_LOT'}->{?$to};            # quite possibly undef!
   }
   return;
 }
@@ -766,9 +757,8 @@ sub linearize_tokens {  # self, tokens
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-sub unicode_escape_url {
-  my($self, $string) = < @_;
-  $string =~ s/([^\x[00]-\x[FF]])/{'('.ord($1).')'}/g;
+sub unicode_escape_url($self, $string) {
+  $string =~ s/([^\x[00]-\x[FF]])/$('('.ord($1).')')/g;
     #  Turn char 1234 into "(1234)"
   return $string;
 }
@@ -776,8 +766,7 @@ sub unicode_escape_url {
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 sub esc { # a function.
   my $x = shift;
-  $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
-}/g;
+  $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/$('&#'.(ord($1)).';')/g;
   return $x;
   # Leave out "- so that "--" won't make it thru in X-generated comments
   #  with text in them.
