@@ -1,11 +1,11 @@
 
 package Pod::Simple::HTMLBatch;
-use strict;
-use vars < qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
- $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
-);
+
+our ($VERSION, $HTML_RENDER_CLASS, $HTML_EXTENSION,
+     $CSS, $JAVASCRIPT, $SLEEPY, $SEARCH_CLASS, @ISA,
+ );
 $VERSION = '3.02';
-@ISA = @( () );  # Yup, we're NOT a subclass of Pod::Simple::HTML!
+@ISA = @();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
 
@@ -24,7 +24,7 @@ BEGIN {
   else { *DEBUG = sub () {0}; }
 }
 
-$SLEEPY = 1 if !defined $SLEEPY and $^O =~ m/mswin|mac/i;
+$SLEEPY = 1 if !defined $SLEEPY and $^OS_NAME =~ m/mswin|mac/i;
 # flag to occasionally sleep for $SLEEPY - 1 seconds.
 
 $HTML_RENDER_CLASS ||= "Pod::Simple::HTML";
@@ -51,7 +51,7 @@ Pod::Simple::_accessorize( __PACKAGE__,
 # Just so we can run from the command line more easily
 sub go {
   (nelems @ARGV) == 2 or die sprintf(
-    "Usage: perl -M\%s -e \%s:go indirs outdir\n  (or use \"\@INC\" for indirs)\n",
+    "Usage: perl -M\%s -e \%s:go indirs outdir\n  (or use \"\$^INCLUDE_PATH\" for indirs)\n",
     __PACKAGE__, __PACKAGE__, 
   );
   
@@ -82,7 +82,7 @@ sub new {
     'index' . ($HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION)
   );
   
-  $new->contents_page_start( join "\n", grep $_, @(
+  $new->contents_page_start( join "\n", grep { $_ }, @(
     $Pod::Simple::HTML::Doctype_decl,
     "<html><head>",
     "<title>Perl Documentation</title>",
@@ -94,10 +94,10 @@ sub new {
   
   $new->contents_page_end( sprintf(
     "\n\n<p class='contentsfooty'>Generated by \%s v\%s under Perl v\%s\n<br >At \%s GMT, which is \%s local time.</p>\n\n</body></html>\n",
-    (< map { esc($_) }
+    (< map { esc($_) },
  @(      ref($new),
       try {$new->VERSION} || $VERSION,
-      $^V, scalar(gmtime), scalar(localtime),) 
+      $^PERL_VERSION, scalar(gmtime), scalar(localtime),) 
   )));
 
   return $new;
@@ -108,29 +108,28 @@ sub new {
 sub muse {
   my $self = shift;
   if($self->verbose) {
-    print 'T+', int(time() - $self->{'_batch_start_time'}), "s: ", < @_, "\n";
+    print $^STDOUT, 'T+', int(time() - $self->{?'_batch_start_time'}), "s: ", < @_, "\n";
   }
   return 1;
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub batch_convert {
-  my($self, $dirs, $outdir) = < @_;
+sub batch_convert($self, $dirs, $outdir) {
   $self ||= __PACKAGE__; # tolerate being called as an optionless function
   $self = $self->new unless ref $self; # tolerate being used as a class method
 
   if(ref $dirs) {
     # OK, it's an explicit set of dirs to scan, specified as an arrayref.
-  } elsif(!defined($dirs)  or  $dirs eq ''  or  $dirs eq '@INC' ) {
+  } elsif(!defined($dirs)  or  $dirs eq ''  or  $dirs eq '$^INCLUDE_PATH' ) {
     $dirs = '';
   } else {
     # OK, it's an explicit set of dirs to scan, specified as a
     #  string like "/thing:/also:/whatever/perl" (":"-delim, as usual)
     #  or, under MSWin, like "c:/thing;d:/also;c:/whatever/perl" (";"-delim!)
     require Config;
-    my $ps = quotemeta( %Config::Config{'path_sep'} || ":" );
-    $dirs = \ grep length($_), split qr/$ps/, $dirs;
+    my $ps = quotemeta( config::config_value('path_sep') || ":" );
+    $dirs = \ grep { length($_) }, split qr/$ps/, $dirs;
   }
 
   $outdir = $self->filespecsys->curdir
@@ -141,12 +140,11 @@ sub batch_convert {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _batch_convert_main {
-  my($self, $dirs, $outdir) = < @_;
+sub _batch_convert_main($self, $dirs, $outdir) {
   # $dirs is either false, or an arrayref.    
   # $outdir is a pathspec.
   
-  $self->{'_batch_start_time'} ||= time();
+  $self->{+'_batch_start_time'} ||= time();
 
   $self->muse( "= ", scalar(localtime) );
   $self->muse( "Starting batch conversion to \"$outdir\"" );
@@ -155,19 +153,19 @@ sub _batch_convert_main {
   if(!$progress and $self->verbose +> 0 and $self->verbose() +<= 5) {
     require Pod::Simple::Progress;
     $progress = Pod::Simple::Progress->new(
-        ($self->verbose  +< 2) ? () # Default omission-delay
-      : ($self->verbose == 2) ? 1  # Reduce the omission-delay
-                              : 0  # Eliminate the omission-delay
+        ($self->verbose  +< 2) ?? () # Default omission-delay
+      !! ($self->verbose == 2) ?? 1  # Reduce the omission-delay
+                              !! 0  # Eliminate the omission-delay
     );
     $self->progress($progress);
   }
   
   if($dirs) {
-    $self->muse(scalar(nelems @$dirs), " dirs to scan: {join ' ',@$dirs}");
+    $self->muse(scalar(nelems @$dirs), " dirs to scan: $(join ' ',@$dirs)");
   } else {
-    $self->muse("Scanning \@INC.  This could take a minute or two.");
+    $self->muse("Scanning \$^INCLUDE_PATH.  This could take a minute or two.");
   }
-  my $mod2path = $self->find_all_pods($dirs ? $dirs : ());
+  my $mod2path = $self->find_all_pods($dirs ?? $dirs !! ());
   $self->muse("Done scanning.");
 
   my $total = nkeys %$mod2path;
@@ -178,7 +176,7 @@ sub _batch_convert_main {
 
   $progress and $progress->goal($total);
   $self->muse("Now converting pod files to HTML.",
-    ($total +> 25) ? "  This will take a while more." : ()
+    ($total +> 25) ?? "  This will take a while more." !! ()
   );
 
   $self->_spray_css(        $outdir );
@@ -194,11 +192,10 @@ sub _batch_convert_main {
 }
 
 
-sub _do_all_batch_conversions {
-  my($self, $mod2path, $outdir) = < @_;
-  $self->{"__batch_conv_page_count"} = 0;
+sub _do_all_batch_conversions($self, $mod2path, $outdir) {
+  $self->{+"__batch_conv_page_count"} = 0;
 
-  foreach my $module (sort {lc($a) cmp lc($b)} keys %$mod2path) {
+  foreach my $module (sort {lc($a) cmp lc($b)}, keys %$mod2path) {
     $self->_do_one_batch_conversion($module, $mod2path, $outdir);
     sleep($SLEEPY - 1) if $SLEEPY;
   }
@@ -206,10 +203,9 @@ sub _do_all_batch_conversions {
   return;
 }
 
-sub _batch_convert_finish {
-  my($self, $outdir) = < @_;
+sub _batch_convert_finish($self, $outdir) {
   $self->write_contents_file($outdir);
-  $self->muse("Done with batch conversion.  %$self{'__batch_conv_page_count'} files done.");
+  $self->muse("Done with batch conversion.  %$self{?'__batch_conv_page_count'} files done.");
   $self->muse( "= ", scalar(localtime) );
   $self->progress and $self->progress->done("All done!");
   return;
@@ -217,13 +213,12 @@ sub _batch_convert_finish {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _do_one_batch_conversion {
-  my($self, $module, $mod2path, $outdir, $outfile) = < @_;
+sub _do_one_batch_conversion($self, $module, $mod2path, $outdir, ?$outfile) {
 
   my $retval;
   my $total    = nkeys %$mod2path;
-  my $infile   = $mod2path->{$module};
-  my @namelets = grep m/\S/, split "::", $module;
+  my $infile   = $mod2path->{?$module};
+  my @namelets = grep { m/\S/ }, split "::", $module;
         # this can stick around in the contents LoL
   my $depth    = scalar nelems @namelets;
   die "Contentless thingie?! $module $infile" unless (nelems @namelets); #sanity
@@ -238,10 +233,10 @@ sub _do_one_batch_conversion {
 
   my $page = $self->html_render_class->new;
   if(DEBUG +> 5) {
-    $self->muse($self->{"__batch_conv_page_count"} + 1, "/$total: ",
+    $self->muse($self->{?"__batch_conv_page_count"} + 1, "/$total: ",
       ref($page), " render ($depth) $module => $outfile");
   } elsif(DEBUG +> 2) {
-    $self->muse($self->{"__batch_conv_page_count"} + 1, "/$total: $module => $outfile")
+    $self->muse($self->{?"__batch_conv_page_count"} + 1, "/$total: $module => $outfile")
   }
 
   # Give each class a chance to init the converter:
@@ -254,10 +249,10 @@ sub _do_one_batch_conversion {
   # Now get busy...
   $self->makepath($outdir => \@namelets);
 
-  $progress and $progress->reach($self->{"__batch_conv_page_count"}, "Rendering $module");
+  $progress and $progress->reach($self->{?"__batch_conv_page_count"}, "Rendering $module");
 
   if( $retval = $page->parse_from_file($infile, $outfile) ) {
-    ++ $self->{"__batch_conv_page_count"} ;
+    ++ $self->{+"__batch_conv_page_count"} ;
     $self->note_for_contents_file( \@namelets, $infile, $outfile );
   } else {
     $self->muse("Odd, parse_from_file(\"$infile\", \"$outfile\") returned false.");
@@ -269,7 +264,7 @@ sub _do_one_batch_conversion {
   $self->batch_mode_page_object_kill($page, $module, $infile, $outfile, $depth)
    if $self->can('batch_mode_page_object_kill');
     
-  DEBUG +> 4 and printf "\%s \%sb < $infile \%s \%sb\n",
+  DEBUG +> 4 and printf $^STDOUT, "\%s \%sb < $infile \%s \%sb\n",
      $outfile, -s $outfile, $infile, -s $infile
   ;
 
@@ -278,12 +273,11 @@ sub _do_one_batch_conversion {
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-sub filespecsys { @_[0]->{'_filespecsys'} || 'File::Spec' }
+sub filespecsys { @_[0]->{?'_filespecsys'} || 'File::Spec' }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub note_for_contents_file {
-  my($self, $namelets, $infile, $outfile) = < @_;
+sub note_for_contents_file($self, $namelets, $infile, $outfile) {
 
   # I think the infile and outfile parts are never used. -- SMB
   # But it's handy to have them around for debugging.
@@ -294,28 +288,27 @@ sub note_for_contents_file {
      \@( join("::", @$namelets), $infile, $outfile, $namelets )
      #            0               1         2         3
     ;
-    DEBUG +> 3 and print "Noting  <@$c[[@(-1)]]\n";
+    DEBUG +> 3 and print $^STDOUT, "Noting  <@$c[[@(-1)]]\n";
   }
   return;
 }
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
-sub write_contents_file {
-  my($self, $outdir) = < @_;
+sub write_contents_file($self, $outdir) {
   my $outfile  = $self->_contents_filespec($outdir) || return;
 
   $self->muse("Preparing list of modules for ToC");
 
-  my($toplevel,           # maps  toplevelbit => [all submodules]
+  my@($toplevel,           # maps  toplevelbit => [all submodules]
      $toplevel_form_freq, # ends up being  'foo' => 'Foo'
-    ) = < $self->_prep_contents_breakdown;
+    ) =  $self->_prep_contents_breakdown;
 
   my $Contents = try { $self->_wopen($outfile) };
   if( $Contents ) {
     $self->muse( "Writing contents file $outfile" );
   } else {
-    warn "Couldn't write-open contents file $outfile: $!\nAbort writing to $outfile at all";
+    warn "Couldn't write-open contents file $outfile: $^OS_ERROR\nAbort writing to $outfile at all";
     return;
   }
 
@@ -327,11 +320,10 @@ sub write_contents_file {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _write_contents_start {
-  my($self, $Contents, $outfile) = < @_;
+sub _write_contents_start($self, $Contents, $outfile) {
   my $starter = $self->contents_page_start || '';
   
-  {
+  do {
     my $css_wad = $self->_css_wad_to_markup(1);
     if( $css_wad ) {
       $starter =~ s{(</head>)}{\n$css_wad\n$1}i;  # otherwise nevermind
@@ -341,10 +333,10 @@ sub _write_contents_start {
     if( $javascript_wad ) {
       $starter =~ s{(</head>)}{\n$javascript_wad\n$1}i;   # otherwise nevermind
     }
-  }
+  };
 
-  unless(print $Contents $starter, "<dl class='superindex'>\n" ) {
-    warn "Couldn't print to $outfile: $!\nAbort writing to $outfile at all";
+  unless(print $Contents, $starter, "<dl class='superindex'>\n" ) {
+    warn "Couldn't print to $outfile: $^OS_ERROR\nAbort writing to $outfile at all";
     close($Contents);
     return 0;
   }
@@ -353,47 +345,44 @@ sub _write_contents_start {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _write_contents_middle {
-  my($self, $Contents, $outfile, $toplevel2submodules, $toplevel_form_freq) = < @_;
+sub _write_contents_middle($self, $Contents, $outfile, $toplevel2submodules, $toplevel_form_freq) {
 
   foreach my $t (sort keys %$toplevel2submodules) {
-    my @downlines = sort {$a->[-1] cmp $b->[-1]}
- @{ $toplevel2submodules->{$t} };
+    my @downlines = sort {$a->[-1] cmp $b->[-1]},
+ @{ $toplevel2submodules->{?$t} };
     
-    printf $Contents qq[<dt><a name="\%s">\%s</a></dt>\n<dd>\n],
-      esc( $t ), esc( $toplevel_form_freq->{$t} )
+    printf $Contents, qq[<dt><a name="\%s">\%s</a></dt>\n<dd>\n],
+      esc( $t ), esc( $toplevel_form_freq->{?$t} )
     ;
     
     my($path, $name);
     foreach my $e ( @downlines) {
       $name = $e->[0];
-      $path = join( "/", @( '.', < map { esc($_) } @{$e->[3]}) )
+      $path = join( "/", @( '.', < map { esc($_) }, @{$e->[3]}) )
         . ($HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION);
-      print $Contents qq{  <a href="$path">}, esc($name), "</a>&nbsp;&nbsp;\n";
+      print $Contents, qq{  <a href="$path">}, esc($name), "</a>&nbsp;&nbsp;\n";
     }
-    print $Contents "</dd>\n\n";
+    print $Contents, "</dd>\n\n";
   }
   return 1;
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _write_contents_end {
-  my($self, $Contents, $outfile) = < @_;
+sub _write_contents_end($self, $Contents, $outfile) {
   unless(
-    print $Contents "</dl>\n",
+    print $Contents, "</dl>\n",
       $self->contents_page_end || '',
   ) {
-    warn "Couldn't write to $outfile: $!";
+    warn "Couldn't write to $outfile: $^OS_ERROR";
   }
-  close($Contents) or warn "Couldn't close $outfile: $!";
+  close($Contents) or warn "Couldn't close $outfile: $^OS_ERROR";
   return 1;
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _prep_contents_breakdown {
-  my($self) = < @_;
+sub _prep_contents_breakdown($self) {
   my $contents = $self->_contents;
   my %toplevel; # maps  lctoplevelbit => [all submodules]
   my %toplevel_form_freq; # ends up being  'foo' => 'Foo'
@@ -401,20 +390,20 @@ sub _prep_contents_breakdown {
   
   foreach my $entry ( @$contents) {
     my $toplevel = 
-      $entry->[0] =~ m/^perl\w*$/ ? 'perl_core_docs'
+      $entry->[0] =~ m/^perl\w*$/ ?? 'perl_core_docs'
           # group all the perlwhatever docs together
-      : $entry->[3]->[0] # normal case
+      !! $entry->[3]->[0] # normal case
     ;
-    ++%toplevel_form_freq{ lc $toplevel }->{ $toplevel };
-    push @{ %toplevel{ lc $toplevel } }, $entry;
+    ++%toplevel_form_freq{ + lc $toplevel }->{+$toplevel };
+    push @{ %toplevel{ + lc $toplevel } }, $entry;
     push @$entry, lc($entry->[0]); # add a sort-order key to the end
   }
 
   foreach my $toplevel (sort keys %toplevel) {
-    my $fgroup = %toplevel_form_freq{$toplevel};
-    %toplevel_form_freq{$toplevel} =
+    my $fgroup = %toplevel_form_freq{?$toplevel};
+    %toplevel_form_freq{+$toplevel} =
     (
-      sort { $fgroup->{$b} <+> $fgroup->{$a}  or  $a cmp $b }
+      sort { $fgroup->{?$b} <+> $fgroup->{?$a}  or  $a cmp $b },
         keys %$fgroup
       # This hash is extremely unlikely to have more than 4 members, so this
       # sort isn't so very wasteful
@@ -426,8 +415,7 @@ sub _prep_contents_breakdown {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _contents_filespec {
-  my($self, $outdir) = < @_;
+sub _contents_filespec($self, $outdir) {
   my $outfile = $self->contents_file;
   return unless $outfile;
   return $self->filespecsys->catfile( $outdir, $outfile );
@@ -435,8 +423,7 @@ sub _contents_filespec {
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
-sub makepath {
-  my($self, $outdir, $namelets) = < @_;
+sub makepath($self, $outdir, $namelets) {
   return unless (nelems @$namelets) +> 1;
   for my $i (0 .. ((nelems @$namelets) - 2)) {
     my $dir = $self->filespecsys->catdir( $outdir, < @$namelets[[0 .. $i]] );
@@ -444,9 +431,9 @@ sub makepath {
       die "$dir exists but not as a directory!?" unless -d $dir;
       next;
     }
-    DEBUG +> 3 and print "  Making $dir\n";
+    DEBUG +> 3 and print $^STDOUT, "  Making $dir\n";
     mkdir $dir, 0777
-     or die "Can't mkdir $dir: $!\nAborting"
+     or die "Can't mkdir $dir: $^OS_ERROR\nAborting"
     ;
   }
   return;
@@ -454,10 +441,7 @@ sub makepath {
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
-sub batch_mode_page_object_init {
-  my $self = shift;
-  my($page, $module, $infile, $outfile, $depth) = < @_;
-  
+sub batch_mode_page_object_init($self, $page, $module, $infile, $outfile, $depth) {
   # TODO: any further options to percolate onto this new object here?
 
   $page->default_title($module);
@@ -475,10 +459,9 @@ sub batch_mode_page_object_init {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub add_header_backlink {
-  my $self = shift;
+sub add_header_backlink($self, $page, $module, $infile, $outfile, $depth) {
   return if $self->no_contents_links;
-  my($page, $module, $infile, $outfile, $depth) = < @_;
+
   $page->html_header_after_title( join '', @(
     $page->html_header_after_title || '',
 
@@ -491,10 +474,9 @@ sub add_header_backlink {
   return;
 }
 
-sub add_footer_backlink {
-  my $self = shift;
+sub add_footer_backlink($self, $page, $module, $infile, $outfile, $depth) {
   return if $self->no_contents_links;
-  my($page, $module, $infile, $outfile, $depth) = < @_;
+
   $page->html_footer( join '', @(
     qq[<p class="backlinkbottom"><b><a name="___bottom" href="],
     $self->url_up_to_contents($depth),
@@ -507,16 +489,14 @@ sub add_footer_backlink {
   return;
 }
 
-sub url_up_to_contents {
-  my($self, $depth) = < @_;
+sub url_up_to_contents($self, $depth) {
   --$depth;
   return join '/', @( ('..') x $depth, esc($self->contents_file));
 }
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
-sub find_all_pods {
-  my($self, $dirs) = < @_;
+sub find_all_pods($self, $dirs) {
   # You can override find_all_pods in a subclass if you want to
   #  do extra filtering or whatnot.  But for the moment, we just
   #  pass to modnames2paths:
@@ -525,31 +505,30 @@ sub find_all_pods {
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
-sub modnames2paths { # return a hashref mapping modulenames => paths
-  my($self, $dirs) = < @_;
+sub modnames2paths($self, $dirs) {
 
   my $m2p;
-  {
+  do {
     my $search = $SEARCH_CLASS->new;
-    DEBUG and print "Searching via $search\n";
+    DEBUG and print $^STDOUT, "Searching via $search\n";
     $search->verbose(1) if DEBUG +> 10;
     $search->progress( < $self->progress->copy->goal(0) ) if $self->progress;
     $search->shadows(0);  # don't bother noting shadowed files
-    $search->inc(     $dirs ? 0      :  1 );
-    $search->survey(  $dirs ? < @$dirs : () );
+    $search->inc(     $dirs ?? 0      !!  1 );
+    $search->survey(  $dirs ?? < @$dirs !! () );
     $m2p = $search->name2path;
     die "What, no name2path?!" unless $m2p;
-  }
+  };
 
   $self->muse("That's odd... no modules found!") unless %$m2p;
   if( DEBUG +> 4 ) {
-    print "Modules found (name => path):\n";
-    foreach my $m (sort {lc($a) cmp lc($b)} keys %$m2p) {
-      print "  $m  %$m2p{$m}\n";
+    print $^STDOUT, "Modules found (name => path):\n";
+    foreach my $m (sort {lc($a) cmp lc($b)}, keys %$m2p) {
+      print $^STDOUT, "  $m  %$m2p{?$m}\n";
     }
-    print "(total ",     nkeys %$m2p, ")\n\n";
+    print $^STDOUT, "(total ",     nkeys %$m2p, ")\n\n";
   } elsif( DEBUG ) {
-    print      "Found ", nkeys %$m2p, " modules.\n";
+    print $^STDOUT,      "Found ", nkeys %$m2p, " modules.\n";
   }
   $self->muse( "Found ", nkeys %$m2p, " modules." );
   
@@ -559,21 +538,18 @@ sub modnames2paths { # return a hashref mapping modulenames => paths
 
 #===========================================================================
 
-sub _wopen {
-  # this is abstracted out so that the daemon class can override it
-  my($self, $outpath) = < @_;
+sub _wopen($self, $outpath) {
   require Symbol;
   my $out_fh = Symbol::gensym();
-  DEBUG +> 5 and print "Write-opening to $outpath\n";
+  DEBUG +> 5 and print $^STDOUT, "Write-opening to $outpath\n";
   return $out_fh if open($out_fh, ">", "$outpath");
   require Carp;  
-  Carp::croak("Can't write-open $outpath: $!");
+  Carp::croak("Can't write-open $outpath: $^OS_ERROR");
 }
 
 #==========================================================================
 
-sub add_css {
-  my($self, $url, $is_default, $name, $content_type, $media, $_code) = < @_;
+sub add_css($self, $url, $is_default, $name, $content_type, $media, $_code) {
   return unless $url;
   unless($name) {
     # cook up a reasonable name based on the URL
@@ -594,8 +570,7 @@ sub add_css {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _spray_css {
-  my($self, $outdir) = < @_;
+sub _spray_css($self, $outdir) {
 
   return unless $self->css_flurry();
   $self->_gen_css_wad();
@@ -606,19 +581,19 @@ sub _spray_css {
     my $outfile;
     if( ref($chunk->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.css$)} ) {
       $outfile = $self->filespecsys->catfile( $outdir, $1 );
-      DEBUG +> 5 and print "Noting @$chunk[0] as a file I'll create.\n";
+      DEBUG +> 5 and print $^STDOUT, "Noting @$chunk[0] as a file I'll create.\n";
     } else {
-      DEBUG +> 5 and print "OK, noting @$chunk[0] as an external CSS.\n";
+      DEBUG +> 5 and print $^STDOUT, "OK, noting @$chunk[0] as an external CSS.\n";
       # Requires no further attention.
       next;
     }
     
     #$self->muse( "Writing autogenerated CSS file $outfile" );
     my $Cssout = $self->_wopen($outfile);
-    print $Cssout ${$chunk->[-1]}
-     or warn "Couldn't print to $outfile: $!\nAbort writing to $outfile at all";
+    print $Cssout, ${$chunk->[-1]}
+     or warn "Couldn't print to $outfile: $^OS_ERROR\nAbort writing to $outfile at all";
     close($Cssout);
-    DEBUG +> 5 and print "Wrote $outfile\n";
+    DEBUG +> 5 and print $^STDOUT, "Wrote $outfile\n";
   }
 
   return;
@@ -626,8 +601,7 @@ sub _spray_css {
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-sub _css_wad_to_markup {
-  my($self, $depth) = < @_;
+sub _css_wad_to_markup($self, $depth) {
   
   my @css  = @{ $self->_css_wad || return '' };
   return '' unless (nelems @css);
@@ -636,14 +610,14 @@ sub _css_wad_to_markup {
   my $out = '';
 
   --$depth;
-  my $uplink = $depth ? ('../' x $depth) : '';
+  my $uplink = $depth ?? ('../' x $depth) !! '';
 
   foreach my $chunk ( @css) {
     next unless $chunk and nelems @$chunk;
 
-    my( $url1, $url2, $title, $type, $media) = (
+    my@( $url1, $url2, $title, $type, $media) = @(
       $self->_maybe_uplink( $chunk->[0], $uplink ),
-      < map { esc($_) } @( (< grep !ref($_), @$chunk))
+      < map { esc($_) }, @( (< grep { !ref($_) }, @$chunk))
     );
 
     $out .= qq{<link rel="$rel" title="$title" type="$type" href="$url1$url2" media="$media" >\n};
@@ -654,13 +628,10 @@ sub _css_wad_to_markup {
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-sub _maybe_uplink {
-  # if the given URL looks relative, return the given uplink string --
-  # otherwise return emptystring
-  my($self, $url, $uplink) = < @_;
+sub _maybe_uplink($self, $url, $uplink) {
   ($url =~ m{^\./} or $url !~ m{[/\:]} )
-    ? $uplink
-    : ''
+    ?? $uplink
+    !! ''
     # qualify it, if/as needed
 }
 
@@ -695,7 +666,7 @@ sub _gen_css_wad {
   ]) {
 
     my $outname = $variation;
-    my($flipmode, < @swap) = ( ($4 || ''), $1,$2,$3)
+    my@($flipmode, @< @swap) = @( ($4 || ''), $1,$2,$3)
       if $outname =~ s/^([012])([012])([[012])([a-z]*)=?//s;
     @swap = @( () ) if '010' eq join '', @swap; # 010 is a swop-no-op!
   
@@ -705,11 +676,11 @@ sub _gen_css_wad {
 
     # Only look at three-digitty colors, for now at least.
     if( $flipmode =~ m/n/ ) {
-      $this_css =~ s/(#[0-9a-fA-F]{3})\b/{_color_negate($1)}/g;
+      $this_css =~ s/(#[0-9a-fA-F]{3})\b/$(_color_negate($1))/g;
       $this_css =~ s/\bthin\b/medium/g;
     }
     $this_css =~ s<#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])\b>
-                  |{ join '', @( '#', < @($1,$2,$3)[[@swap]]) }|g   if (nelems @swap);
+                  |$( join '', @( '#', < @($1,$2,$3)[[@swap]]) )|g   if (nelems @swap);
 
     if(   $flipmode =~ m/a/)
        { $this_css =~ s/#fff\b/#999/gi } # black -> dark grey
@@ -743,15 +714,14 @@ sub _gen_css_wad {
 
 sub _color_negate {
   my $x = lc @_[0];
-  $x =~ s/([0123456789abcdef])/{ 
-     %( < qw| 0 f 1 e 2 d 3 c 4 b 5 a 6 9 7 8 8 7 9 6 a 5 b 4 c 3 d 2 e 1 f 0 | ){$1} }/g;
+  $x =~ s/([0123456789abcdef])/$( 
+     %( < qw| 0 f 1 e 2 d 3 c 4 b 5 a 6 9 7 8 8 7 9 6 a 5 b 4 c 3 d 2 e 1 f 0 | ){?$1} )/g;
   return $x;
 }
 
 #===========================================================================
 
-sub add_javascript {
-  my($self, $url, $content_type, $_code) = < @_;
+sub add_javascript($self, $url, $content_type, $_code) {
   return unless $url;
   push  @{ $self->_javascript_wad }, \@(
     $url, $content_type || 'text/javascript', $_code
@@ -759,8 +729,7 @@ sub add_javascript {
   return;
 }
 
-sub _spray_javascript {
-  my($self, $outdir) = < @_;
+sub _spray_javascript($self, $outdir) {
   return unless $self->javascript_flurry();
   $self->_gen_javascript_wad();
 
@@ -771,19 +740,19 @@ sub _spray_javascript {
     
     if( ref($script->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.js$)} ) {
       $outfile = $self->filespecsys->catfile( $outdir, $1 );
-      DEBUG +> 5 and print "Noting @$script[0] as a file I'll create.\n";
+      DEBUG +> 5 and print $^STDOUT, "Noting @$script[0] as a file I'll create.\n";
     } else {
-      DEBUG +> 5 and print "OK, noting @$script[0] as an external JavaScript.\n";
+      DEBUG +> 5 and print $^STDOUT, "OK, noting @$script[0] as an external JavaScript.\n";
       next;
     }
     
     #$self->muse( "Writing JavaScript file $outfile" );
     my $Jsout = $self->_wopen($outfile);
 
-    print $Jsout ${$script->[-1]}
-     or warn "Couldn't print to $outfile: $!\nAbort writing to $outfile at all";
+    print $Jsout, ${$script->[-1]}
+     or warn "Couldn't print to $outfile: $^OS_ERROR\nAbort writing to $outfile at all";
     close($Jsout);
-    DEBUG +> 5 and print "Wrote $outfile\n";
+    DEBUG +> 5 and print $^STDOUT, "Wrote $outfile\n";
   }
 
   return;
@@ -796,8 +765,7 @@ sub _gen_javascript_wad {
   return;
 }
 
-sub _javascript_wad_to_markup {
-  my($self, $depth) = < @_;
+sub _javascript_wad_to_markup($self, $depth) {
   
   my @scripts  = @{ $self->_javascript_wad || return '' };
   return '' unless (nelems @scripts);
@@ -805,14 +773,14 @@ sub _javascript_wad_to_markup {
   my $out = '';
 
   --$depth;
-  my $uplink = $depth ? ('../' x $depth) : '';
+  my $uplink = $depth ?? ('../' x $depth) !! '';
 
   foreach my $s ( @scripts) {
     next unless $s and nelems @$s;
 
-    my( $url1, $url2, $type, $media) = (
+    my@( $url1, $url2, $type, ?$media) = @(
       $self->_maybe_uplink( $s->[0], $uplink ),
-      < map { esc($_) } @( (< grep !ref($_), @$s))
+      < map { esc($_) }, @( (< grep { !ref($_) }, @$s))
     );
 
     $out .= qq{<script type="$type" src="$url1$url2"></script>\n};
@@ -1080,14 +1048,14 @@ arguments, C<indirs> and C<outdir>.
 Example:
 
   % mkdir out_html
-  % perl -MPod::Simple::HTMLBatch -e Pod::Simple::HTMLBatch::go @INC out_html
-      (to convert the pod from Perl's @INC
+  % perl -MPod::Simple::HTMLBatch -e Pod::Simple::HTMLBatch::go $^INCLUDE_PATH out_html
+      (to convert the pod from Perl's $^INCLUDE_PATH
        files under the directory ../htmlversion)
 
 (Note that the command line there contains a literal atsign-I-N-C.  This
 is handled as a special case by batch_convert, in order to save you having
 to enter the odd-looking "" as the first command-line parameter when you
-mean "just use whatever's in @INC".)
+mean "just use whatever's in $^INCLUDE_PATH".)
 
 Example:
 
@@ -1119,9 +1087,9 @@ this TODO
 
 =item $batchconv->batch_convert( undef    , ...);
 
-=item $batchconv->batch_convert( q{@INC}, ...);
+=item $batchconv->batch_convert( q{$^INCLUDE_PATH}, ...);
 
-These two values for I<indirs> specify that the normal Perl @INC
+These two values for I<indirs> specify that the normal Perl $^INCLUDE_PATH
 
 =item $batchconv->batch_convert( \@dirs , ...);
 
@@ -1150,7 +1118,7 @@ I<that> is because ":" often comes up in paths, like
 C<"c:/perl/lib">.)
 
 (Exactly what separator character should be used, is gotten from
-C<$Config::Config{'path_sep'}>, via the L<Config> module.)
+C<config::config_value('path_sep')>, via the L<Config> module.)
 
 =item $batchconv->batch_convert( ... , undef );
 
@@ -1159,7 +1127,7 @@ directory.
 
 (Note that a missing or undefined value means a different thing in
 the first slot than in the second.  That's so that C<batch_convert()>
-with no arguments (or undef arguments) means "go from @INC, into
+with no arguments (or undef arguments) means "go from $^INCLUDE_PATH, into
 the current directory.)
 
 =item $batchconv->batch_convert( ... , 'somedir' );
