@@ -1,8 +1,8 @@
 
 package Pod::Simple::Methody;
-use strict;
+
 use Pod::Simple ();
-use vars < qw(@ISA $VERSION);
+our (@ISA, $VERSION);
 $VERSION = '2.02';
 @ISA = @('Pod::Simple');
 
