@@ -2,7 +2,7 @@
 package Pod::Simple::PullParserTextToken;
 use Pod::Simple::PullParserToken ();
 our @ISA = @('Pod::Simple::PullParserToken');
-use strict;
+
 
 sub new {  # Class->new(text);
   my $class = shift;
@@ -11,7 +11,7 @@ sub new {  # Class->new(text);
 
 # Purely accessors:
 
-sub text { ((nelems @_) == 2) ?  @(@_[0]->[1] = @_[1]) : @_[0]->[1] }
+sub text { ((nelems @_) == 2) ??  @(@_[0]->[1] = @_[1]) !! @_[0]->[1] }
 
 sub text_r { \ @_[0]->[1] }
 
