@@ -1,14 +1,14 @@
 
 package Pod::Simple::Search;
-use strict;
 
-use vars < qw($VERSION $MAX_VERSION_WITHIN $SLEEPY);
+
+our ($VERSION, $MAX_VERSION_WITHIN, $SLEEPY);
 $VERSION = 3.04;   ## Current version of this package
 
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG; }   # set DEBUG level
 use Carp ();
 
-$SLEEPY = 1 if !defined $SLEEPY and $^O =~ m/mswin|mac/i;
+$SLEEPY = 1 if !defined $SLEEPY and $^OS_NAME =~ m/mswin|mac/i;
   # flag to occasionally sleep for $SLEEPY - 1 seconds.
 
 $MAX_VERSION_WITHIN ||= 60;
@@ -44,21 +44,20 @@ sub init {
 
 #--------------------------------------------------------------------------
 
-sub survey {
-  my($self, < @search_dirs) = < @_;
+sub survey($self, @< @search_dirs) {
   $self = $self->new unless ref $self; # tolerate being a class method
 
   $self->_expand_inc( \@search_dirs );
 
 
-  $self->{'_scan_count'} = 0;
-  $self->{'_dirs_visited'} = \%();
+  $self->{+'_scan_count'} = 0;
+  $self->{+'_dirs_visited'} = \%();
   $self->path2name( \%() );
   $self->name2path( \%() );
-  $self->limit_re( $self->_limit_glob_to_limit_re ) if $self->{'limit_glob'};
+  $self->limit_re( $self->_limit_glob_to_limit_re ) if $self->{?'limit_glob'};
   my $cwd = cwd();
   my $verbose  = $self->verbose;
-  local $_; # don't clobber the caller's $_ !
+  local $_ = undef; # don't clobber the caller's $_ !
 
   foreach my $try ( @search_dirs) {
     unless( File::Spec->file_name_is_absolute($try) ) {
@@ -70,27 +69,27 @@ sub survey {
 
     my $start_in;
     my $modname_prefix;
-    if($self->{'dir_prefix'}) {
+    if($self->{?'dir_prefix'}) {
       $start_in = File::Spec->catdir(
         $try,
-        < grep length($_), split '[\/:]+', $self->{'dir_prefix'}
+        < grep { length($_) }, split '[\/:]+', $self->{?'dir_prefix'}
       );
-      $modname_prefix = \ grep length($_), split m{[:/\\]}, $self->{'dir_prefix'};
-      $verbose and print "Appending \"$self->{'dir_prefix'}\" to $try, ",
-        "giving $start_in (= {join ' ',@$modname_prefix})\n";
+      $modname_prefix = \ grep { length($_) }, split m{[:/\\]}, $self->{?'dir_prefix'};
+      $verbose and print $^STDOUT, "Appending \"$self->{?'dir_prefix'}\" to $try, ",
+        "giving $start_in (= $(join ' ',@$modname_prefix))\n";
     } else {
       $start_in = $try;
     }
 
-    if( $self->{'_dirs_visited'}->{$start_in} ) {
-      $verbose and print "Directory '$start_in' already seen, skipping.\n";
+    if( $self->{'_dirs_visited'}->{?$start_in} ) {
+      $verbose and print $^STDOUT, "Directory '$start_in' already seen, skipping.\n";
       next;
     } else {
-      $self->{'_dirs_visited'}->{$start_in} = 1;
+      $self->{'_dirs_visited'}->{+$start_in} = 1;
     }
   
     unless(-e $start_in) {
-      $verbose and print "Skipping non-existent $start_in\n";
+      $verbose and print $^STDOUT, "Skipping non-existent $start_in\n";
       next;
     }
 
@@ -98,22 +97,22 @@ sub survey {
     
     if(-d $start_in) {
       # Normal case:
-      $verbose and print "Beginning excursion under $start_in\n";
+      $verbose and print $^STDOUT, "Beginning excursion under $start_in\n";
       $self->_recurse_dir( $start_in, $closure, $modname_prefix );
-      $verbose and print "Back from excursion under $start_in\n\n";
+      $verbose and print $^STDOUT, "Back from excursion under $start_in\n\n";
         
     } elsif(-f _) {
       # A excursion consisting of just one file!
       $_ = basename($start_in);
-      $verbose and print "Pondering $start_in ($_)\n";
+      $verbose and print $^STDOUT, "Pondering $start_in ($_)\n";
       $closure->($start_in, $_, 0, \@());
         
     } else {
-      $verbose and print "Skipping mysterious $start_in\n";
+      $verbose and print $^STDOUT, "Skipping mysterious $start_in\n";
     }
   }
   $self->progress and $self->progress->done(
-   "Noted %$self{'_scan_count'} Pod files total");
+   "Noted %$self{?'_scan_count'} Pod files total");
 
   return $self->name2path;
 }
@@ -124,33 +123,33 @@ sub _make_search_callback {
   my $self = @_[0];
 
   # Put the options in variables, for easy access
-  my(  $laborious, $verbose, $shadows, $limit_re, $callback, $progress,$path2name,$name2path) =
-    < map scalar($self->?$_()),
+  my@(  $laborious, $verbose, $shadows, $limit_re, $callback, $progress,$path2name,$name2path) =
+     map { scalar($self->?$_()) },
      qw(laborious   verbose   shadows   limit_re   callback   progress  path2name  name2path);
 
   my($file, $shortname, $isdir, $modname_bits);
   return sub {
-    ($file, $shortname, $isdir, $modname_bits) = < @_;
+    @($file, $shortname, $isdir, $modname_bits) =  @_;
 
     if($isdir) { # this never gets called on the startdir itself, just subdirs
 
-      if( $self->{'_dirs_visited'}->{$file} ) {
-        $verbose and print "Directory '$file' already seen, skipping.\n";
+      if( $self->{'_dirs_visited'}->{?$file} ) {
+        $verbose and print $^STDOUT, "Directory '$file' already seen, skipping.\n";
         return 'PRUNE';
       }
 
-      print "Looking in dir $file\n" if $verbose;
+      print $^STDOUT, "Looking in dir $file\n" if $verbose;
 
       unless ($laborious) { # $laborious overrides pruning
         if( m/^([A-Za-z][a-zA-Z0-9_]*)\z/s ) {
-          $verbose and print "$_ is a well-named module subdir.  Looking....\n";
+          $verbose and print $^STDOUT, "$_ is a well-named module subdir.  Looking....\n";
         } else {
-          $verbose and print "$_ is a fishy directory name.  Skipping.\n";
+          $verbose and print $^STDOUT, "$_ is a fishy directory name.  Skipping.\n";
           return 'PRUNE';
         }
       } # end unless $laborious
 
-      $self->{'_dirs_visited'}->{$file} = 1;
+      $self->{'_dirs_visited'}->{+$file} = 1;
       return; # (not pruning);
     }
 
@@ -161,29 +160,29 @@ sub _make_search_callback {
         m/\.(pod|pm|plx?)\z/i || -x _ and -T _
          # Note that the cheapest operation (the RE) is run first.
       ) {
-        $verbose +> 1 and print " Brushing off uninteresting $file\n";
+        $verbose +> 1 and print $^STDOUT, " Brushing off uninteresting $file\n";
         return;
       }
     } else {
       unless( m/^[-_a-zA-Z0-9]+\.(?:pod|pm|plx?)\z/is ) {
-        $verbose +> 1 and print " Brushing off oddly-named $file\n";
+        $verbose +> 1 and print $^STDOUT, " Brushing off oddly-named $file\n";
         return;
       }
     }
 
-    $verbose and print "Considering item $file\n";
+    $verbose and print $^STDOUT, "Considering item $file\n";
     my $name = $self->_path2modname( $file, $shortname, $modname_bits );
-    $verbose +> 0.01 and print " Nominating $file as $name\n";
+    $verbose +> 0.01 and print $^STDOUT, " Nominating $file as $name\n";
         
     if($limit_re and $name !~ m/$limit_re/i) {
-      $verbose and print "Shunning $name as not matching $limit_re\n";
+      $verbose and print $^STDOUT, "Shunning $name as not matching $limit_re\n";
       return;
     }
 
-    if( !$shadows and $name2path->{$name} ) {
-      $verbose and print "Not worth considering $file ",
+    if( !$shadows and $name2path->{?$name} ) {
+      $verbose and print $^STDOUT, "Not worth considering $file ",
         "-- already saw $name as ",
-        join(' ', grep($path2name->{$_} eq $name, keys %$path2name)), "\n";
+        join(' ', grep( {$path2name->{?$_} eq $name }, keys %$path2name)), "\n";
       return;
     }
         
@@ -192,34 +191,33 @@ sub _make_search_callback {
     if( m/\.pod\z/is ) {
       # just assume it has pod, okay?
     } else {
-      $progress and $progress->reach($self->{'_scan_count'}, "Scanning $file");
+      $progress and $progress->reach($self->{?'_scan_count'}, "Scanning $file");
       return unless $self->contains_pod( $file );
     }
-    ++ $self->{'_scan_count'};
+    ++ $self->{+'_scan_count'};
 
     # Or finally take note of it:
-    if( $name2path->{$name} ) {
-      $verbose and print
+    if( $name2path->{?$name} ) {
+      $verbose and print $^STDOUT,
        "Duplicate POD found (shadowing?): $name ($file)\n",
        "    Already seen in ",
-       join(' ', grep($path2name->{$_} eq $name, keys %$path2name)), "\n";
+       join(' ', grep( {$path2name->{?$_} eq $name }, keys %$path2name)), "\n";
     } else {
-      $name2path->{$name} = $file; # Noting just the first occurrence
+      $name2path->{+$name} = $file; # Noting just the first occurrence
     }
-    $verbose and print "  Noting $name = $file\n";
+    $verbose and print $^STDOUT, "  Noting $name = $file\n";
     if( $callback ) {
       local $_ = $_; # insulate from changes, just in case
       $callback->($file, $name);
     }
-    $path2name->{$file} = $name;
+    $path2name->{+$file} = $name;
     return;
   }
 }
 
 #==========================================================================
 
-sub _path2modname {
-  my($self, $file, $shortname, $modname_bits) = < @_;
+sub _path2modname($self, $file, $shortname, $modname_bits) {
 
   # this code simplifies the POD name for Perl modules:
   # * remove "site_perl"
@@ -238,7 +236,7 @@ sub _path2modname {
     and(  $x eq 'site_perl'
        or($x eq 'pod' and (nelems @m) == 1 and $shortname =~ m{^perl.*\.pod$}s )
        or $x =~ m{\\d+\\.z\\d+([_.]?\\d+)?}  # if looks like a vernum
-       or $x eq lc( %Config::Config{'archname'} )
+       or $x eq lc( Config::config_value('archname') )
   )) { shift @m }
 
   my $name = join '::', @( < @m, $shortname);
@@ -247,12 +245,12 @@ sub _path2modname {
   # On VMS, case-preserved document names can't be constructed from
   # filenames, so try to extract them from the "=head1 NAME" tag in the
   # file instead.
-  if ($^O eq 'VMS' && ($name eq lc($name) || $name eq uc($name))) {
-      open PODFILE, "<", "$file" or die "_path2modname: Can't open $file: $!";
+  if ($^OS_NAME eq 'VMS' && ($name eq lc($name) || $name eq uc($name))) {
+      open my $podfile, "<", "$file" or die "_path2modname: Can't open $file: $^OS_ERROR";
       my $in_pod = 0;
       my $in_name = 0;
       my $line;
-      while ($line = ~< *PODFILE) {
+      while ($line = ~< $podfile) {
         chomp $line;
         $in_pod = 1 if ($line =~ m/^=\w/);
         $in_pod = 0 if ($line =~ m/^=cut/);
@@ -264,9 +262,9 @@ sub _path2modname {
             # substitute case-preserved version of name
             my $podname = $2;
             my $prefix = $1 || '';
-            $verbose and print "Attempting case restore of '$name' from '$prefix$podname'\n";
+            $verbose and print $^STDOUT, "Attempting case restore of '$name' from '$prefix$podname'\n";
             unless ($name =~ s/$prefix$podname/$prefix$podname/i) {
-              $verbose and print "Attempting case restore of '$name' from '$podname'\n";
+              $verbose and print $^STDOUT, "Attempting case restore of '$name' from '$podname'\n";
               $name =~ s/$podname/$podname/i;
             }
             last;
@@ -274,7 +272,7 @@ sub _path2modname {
         }
         $in_name = 1 if ($line =~ m/^=head1 NAME/);
     }
-    close PODFILE;
+    close $podfile;
   }
 
   return $name;
@@ -283,9 +281,9 @@ sub _path2modname {
 #==========================================================================
 
 sub _recurse_dir {
-  my($self, $startdir, $callback, $modname_bits) = < @_;
+  my@($self, $startdir, $callback, $modname_bits) =  @_;
 
-  my $maxdepth = $self->{'fs_recursion_maxdepth'} || 10;
+  my $maxdepth = $self->{?'fs_recursion_maxdepth'} || 10;
   my $verbose = $self->verbose;
 
   my $here_string = File::Spec->curdir;
@@ -294,23 +292,24 @@ sub _recurse_dir {
 
   my $recursor;
   $recursor = sub {
-    my($dir_long, $dir_bare) = < @_;
+    my@($dir_long, $dir_bare) =  @_;
     if( (nelems @$modname_bits) +>= 10 ) {
-      $verbose and print "Too deep! [{join ' ',@$modname_bits}]\n";
+      $verbose and print $^STDOUT, "Too deep! [$(join ' ',@$modname_bits)]\n";
       return;
     }
 
     unless(-d $dir_long) {
-      $verbose +> 2 and print "But it's not a dir! $dir_long\n";
+      $verbose +> 2 and print $^STDOUT, "But it's not a dir! $dir_long\n";
       return;
     }
-    unless( opendir(INDIR, $dir_long) ) {
-      $verbose +> 2 and print "Can't opendir $dir_long : $!\n";
-      closedir(INDIR);
+    my $indir;
+    unless( opendir($indir, $dir_long) ) {
+      $verbose +> 2 and print $^STDOUT, "Can't opendir $dir_long : $^OS_ERROR\n";
+      closedir($indir);
       return
     }
-    my @items = sort @( readdir(INDIR));
-    closedir(INDIR);
+    my @items = sort @( readdir($indir));
+    closedir($indir);
 
     push @$modname_bits, $dir_bare unless $dir_bare eq '';
 
@@ -320,32 +319,32 @@ sub _recurse_dir {
       $i_full = File::Spec->catfile( $dir_long, $i );
 
       if(!-r $i_full) {
-        $verbose and print "Skipping unreadable $i_full\n";
+        $verbose and print $^STDOUT, "Skipping unreadable $i_full\n";
        
       } elsif(-f $i_full) {
         $_ = $i;
         $callback->(          $i_full, $i, 0, $modname_bits );
 
       } elsif(-d _) {
-        $i =~ s/\.DIR\z//i if $^O eq 'VMS';
+        $i =~ s/\.DIR\z//i if $^OS_NAME eq 'VMS';
         $_ = $i;
         my $rv = $callback->( $i_full, $i, 1, $modname_bits ) || '';
 
         if($rv eq 'PRUNE') {
-          $verbose +> 1 and print "OK, pruning";
+          $verbose +> 1 and print $^STDOUT, "OK, pruning";
         } else {
           # Otherwise, recurse into it
           $recursor->( File::Spec->catdir($dir_long, $i) , $i);
         }
       } else {
-        $verbose +> 1 and print "Skipping oddity $i_full\n";
+        $verbose +> 1 and print $^STDOUT, "Skipping oddity $i_full\n";
       }
     }
     pop @$modname_bits;
     return;
   };;
 
-  local $_;
+  local $_ = undef;
   $recursor->($startdir, '');
 
   undef $recursor;  # allow it to be GC'd
@@ -356,32 +355,32 @@ sub _recurse_dir {
 
 #==========================================================================
 
-sub run {
+sub run(?$file, ?$name) {
   # A function, useful in one-liners
 
   my $self = __PACKAGE__->new;
   $self->limit_glob(@ARGV[0]) if (nelems @ARGV);
   $self->callback( sub {
-    my($file, $name) = < @_;
     my $version = '';
      
     # Yes, I know we won't catch the version in like a File/Thing.pm
     #  if we see File/Thing.pod first.  That's just the way the
     #  cookie crumbles.  -- SMB
      
+    my $inpod;
     if($file =~ m/\.pod$/i) {
       # Don't bother looking for $VERSION in .pod files
-      DEBUG and print "Not looking for \$VERSION in .pod $file\n";
-    } elsif( !open(INPOD, "<", $file) ) {
-      DEBUG and print "Couldn't open $file: $!\n";
-      close(INPOD);
+      DEBUG and print $^STDOUT, "Not looking for \$VERSION in .pod $file\n";
+    } elsif( !open($inpod, "<", $file) ) {
+      DEBUG and print $^STDOUT, "Couldn't open $file: $^OS_ERROR\n";
+      close($inpod);
     } else {
       # Sane case: file is readable
       my $lines = 0;
-      while( ~< *INPOD) {
+      while( ~< $inpod) {
         last if $lines++ +> $MAX_VERSION_WITHIN; # some degree of sanity
         if( s/^\s*\$VERSION\s*=\s*//s and m/\d/ ) {
-          DEBUG and print "Found version line (#$lines): $_";
+          DEBUG and print $^STDOUT, "Found version line (#$lines): $_";
           s/\s*\#.*//s;
           s/\;\s*$//s;
           s/\s+$//s;
@@ -396,18 +395,18 @@ sub run {
            
           # Like in sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_55-public $ =~ /-(\d+)_([\d_]+)/)
           $_ = sprintf("v\%d.\%s",
-            < map {s/_//g; $_}
+            < map {s/_//g; $_},
  @(              $1 =~ m/-(\d+)_([\d_]+)/)) # snare just the numeric part
            if m{\$Name:\s*([^\$]+)\$}s 
           ;
           $version = $_;
-          DEBUG and print "Noting $version as version\n";
+          DEBUG and print $^STDOUT, "Noting $version as version\n";
           last;
         }
       }
-      close(INPOD);
+      close($inpod);
     }
-    print "$name\t$version\t$file\n";
+    print $^STDOUT, "$name\t$version\t$file\n";
     return;
     # End of callback!
   });
@@ -417,13 +416,12 @@ sub run {
 
 #==========================================================================
 
-sub simplify_name {
-  my($self, $str) = < @_;
+sub simplify_name($self, $str) {
     
   # Remove all path components
   #                             XXX Why not just use basename()? -- SMB
 
-  if ($^O eq 'MacOS') { $str =~ s{^.*:+}{}s }
+  if ($^OS_NAME eq 'MacOS') { $str =~ s{^.*:+}{}s }
   else                { $str =~ s{^.*/+}{}s }
   
   $self->_simplify_base($str);
@@ -438,42 +436,41 @@ sub _simplify_base {   # Internal method only
   @_[1] =~ s/\.(pod|pm|plx?)\z//i;
 
   # strip meaningless extensions on Win32 and OS/2
-  @_[1] =~ s/\.(bat|exe|cmd)\z//i if $^O =~ m/mswin|os2/i;
+  @_[1] =~ s/\.(bat|exe|cmd)\z//i if $^OS_NAME =~ m/mswin|os2/i;
 
   # strip meaningless extensions on VMS
-  @_[1] =~ s/\.(com)\z//i if $^O eq 'VMS';
+  @_[1] =~ s/\.(com)\z//i if $^OS_NAME eq 'VMS';
 
   return;
 }
 
 #==========================================================================
 
-sub _expand_inc {
-  my($self, $search_dirs) = < @_;
+sub _expand_inc($self, $search_dirs) {
   
-  return unless $self->{'inc'};
+  return unless $self->{?'inc'};
 
-  if ($^O eq 'MacOS') {
+  if ($^OS_NAME eq 'MacOS') {
     push @$search_dirs,
-      < grep $_ ne File::Spec->curdir, $self->_mac_whammy(< @INC);
+      < grep { $_ ne File::Spec->curdir }, $self->_mac_whammy(< $^INCLUDE_PATH);
   # Any other OSs need custom handling here?
   } else {
-    push @$search_dirs, < grep $_ ne File::Spec->curdir, @INC;
+    push @$search_dirs, < grep { $_ ne File::Spec->curdir }, $^INCLUDE_PATH;
   }
 
-  $self->{'laborious'} = 0;   # Since inc said to use INC
+  $self->{+'laborious'} = 0;   # Since inc said to use INC
   return;
 }
 
 #==========================================================================
 
-sub _mac_whammy { # Tolerate '.', './some_dir' and '(../)+some_dir' on Mac OS
+sub _mac_whammy(_,@< @them) { # Tolerate '.', './some_dir' and '(../)+some_dir' on Mac OS
   my @them;
-  (undef,< @them) = < @_;
-  for $_ ( @them) {
+
+  for my $_ ( @them) {
     if ( $_ eq '.' ) {
       $_ = ':';
-    } elsif ( $_ =~ s|^((?:\.\./)+)|{':' x (length($1)/3)}| ) {
+    } elsif ( $_ =~ s|^((?:\.\./)+)|$(':' x (length($1)/3))| ) {
       $_ = ':'. $_;
     } else {
       $_ =~ s|^\./|:|;
@@ -486,22 +483,22 @@ sub _mac_whammy { # Tolerate '.', './some_dir' and '(../)+some_dir' on Mac OS
 
 sub _limit_glob_to_limit_re {
   my $self = @_[0];
-  my $limit_glob = $self->{'limit_glob'} || return;
+  my $limit_glob = $self->{?'limit_glob'} || return;
 
   my $limit_re = '^' . quotemeta($limit_glob) . '$';
   $limit_re =~ s/\\\?/./g;    # glob "?" => "."
   $limit_re =~ s/\\\*/.*?/g;  # glob "*" => ".*?"
   $limit_re =~ s/\.\*\?\$$//s; # final glob "*" => ".*?$" => ""
 
-  $self->{'verbose'} and print "Turning limit_glob $limit_glob into re $limit_re\n";
+  $self->{?'verbose'} and print $^STDOUT, "Turning limit_glob $limit_glob into re $limit_re\n";
 
   # A common optimization:
   if(!exists($self->{'dir_prefix'})
     and $limit_glob =~ m/^(?:\w+\:\:)+/s  # like "File::*" or "File::Thing*"
     # Optimize for sane and common cases (but not things like "*::File")
   ) {
-    $self->{'dir_prefix'} = join "::", @( $limit_glob =~ m/^(?:\w+::)+/sg);
-    $self->{'verbose'} and print " and setting dir_prefix to $self->{'dir_prefix'}\n";
+    $self->{+'dir_prefix'} = join "::", @( $limit_glob =~ m/^(?:\w+::)+/sg);
+    $self->{?'verbose'} and print $^STDOUT, " and setting dir_prefix to $self->{?'dir_prefix'}\n";
   }
 
   return $limit_re;
@@ -511,8 +508,7 @@ sub _limit_glob_to_limit_re {
 
 # contribution mostly from Tim Jenness <t.jenness@jach.hawaii.edu>
 
-sub find {
-  my($self, $pod, < @search_dirs) = < @_;
+sub find($self, $pod, @< @search_dirs) {
   $self = $self->new unless ref $self; # tolerate being a class method
 
   # Check usage
@@ -523,26 +519,26 @@ sub find {
 
   # Split on :: and then join the name together using File::Spec
   my @parts = split m/::/, $pod;
-  $verbose and print "Chomping \{$pod\} => \{{join ' ',@parts}\}\n";
+  $verbose and print $^STDOUT, "Chomping \{$pod\} => \{$(join ' ',@parts)\}\n";
 
   #@search_dirs = File::Spec->curdir unless @search_dirs;
   
   if( $self->inc ) {
-    if( $^O eq 'MacOS' ) {
-      push @search_dirs, < $self->_mac_whammy(< @INC);
+    if( $^OS_NAME eq 'MacOS' ) {
+      push @search_dirs, < $self->_mac_whammy(< $^INCLUDE_PATH);
     } else {
-      push @search_dirs,                    < @INC;
+      push @search_dirs,                    < $^INCLUDE_PATH;
     }
 
     # Add location of pod documentation for perl man pages (eg perlfunc)
     # This is a pod directory in the private install tree
-    #my $perlpoddir = File::Spec->catdir($Config::Config{'installprivlib'},
+    #my $perlpoddir = File::Spec->catdir(Config::config_value('installprivlib'),
     #					'pod');
     #push (@search_dirs, $perlpoddir)
     #  if -d $perlpoddir;
 
     # Add location of binaries such as pod2text:
-    push @search_dirs, %Config::Config{'scriptdir'};
+    push @search_dirs, Config::config_value('scriptdir');
      # and if that's undef or q{} or nonexistent, we just ignore it later
   }
 
@@ -550,27 +546,27 @@ sub find {
  Dir:
   foreach my $dir (  @search_dirs ) {
     next unless defined $dir and length $dir;
-    next if %seen_dir{$dir};
-    %seen_dir{$dir} = 1;
+    next if %seen_dir{?$dir};
+    %seen_dir{+$dir} = 1;
     unless(-d $dir) {
-      print "Directory $dir does not exist\n" if $verbose;
+      print $^STDOUT, "Directory $dir does not exist\n" if $verbose;
       next Dir;
     }
 
-    print "Looking in directory $dir\n" if $verbose;
+    print $^STDOUT, "Looking in directory $dir\n" if $verbose;
     my $fullname = File::Spec->catfile( $dir, < @parts );
-    print "Filename is now $fullname\n" if $verbose;
+    print $^STDOUT, "Filename is now $fullname\n" if $verbose;
 
     foreach my $ext (@('', '.pod', '.pm', '.pl')) {   # possible extensions
       my $fullext = $fullname . $ext;
       if( -f $fullext  and  $self->contains_pod( $fullext ) ){
-        print "FOUND: $fullext\n" if $verbose;
+        print $^STDOUT, "FOUND: $fullext\n" if $verbose;
         return $fullext;
       }
     }
     my $subdir = File::Spec->catdir($dir,'pod');
     if(-d $subdir) {  # slip in the ./pod dir too
-      $verbose and print "Noticing $subdir and stopping there...\n";
+      $verbose and print $^STDOUT, "Noticing $subdir and stopping there...\n";
       $dir = $subdir;
       redo Dir;
     }
@@ -581,31 +577,31 @@ sub find {
 
 #==========================================================================
 
-sub contains_pod {
-  my($self, $file) = < @_;
-  my $verbose = $self->{'verbose'};
+sub contains_pod($self, $file) {
+  my $verbose = $self->{?'verbose'};
 
   # check for one line of POD
-  $verbose +> 1 and print " Scanning $file for pod...\n";
-  unless( open(MAYBEPOD, "<","$file") ) {
-    print "Error: $file is unreadable: $!\n";
+  $verbose +> 1 and print $^STDOUT, " Scanning $file for pod...\n";
+  my $maybepod;
+  unless( open($maybepod, "<","$file") ) {
+    print $^STDOUT, "Error: $file is unreadable: $^OS_ERROR\n";
     return undef;
   }
 
   sleep($SLEEPY - 1) if $SLEEPY;
    # avoid totally hogging the processor on OSs with poor process control
   
-  local $_;
-  while( ~< *MAYBEPOD ) {
+  local $_ = undef;
+  while( ~< $maybepod ) {
     if(m/^=(head\d|pod|over|item)\b/s) {
-      close(MAYBEPOD) || die "Bizarre error closing $file: $!\nAborting";
+      close($maybepod) || die "Bizarre error closing $file: $^OS_ERROR\nAborting";
       chomp;
-      $verbose +> 1 and print "  Found some pod ($_) in $file\n";
+      $verbose +> 1 and print $^STDOUT, "  Found some pod ($_) in $file\n";
       return 1;
     }
   }
-  close(MAYBEPOD) || die "Bizarre error closing $file: $!\nAborting";
-  $verbose +> 1 and print "  No POD in $file, skipping.\n";
+  close($maybepod) || die "Bizarre error closing $file: $^OS_ERROR\nAborting";
+  $verbose +> 1 and print $^STDOUT, "  No POD in $file, skipping.\n";
   return 0;
 }
 
@@ -613,19 +609,18 @@ sub contains_pod {
 
 sub _accessorize {  # A simple-minded method-maker
   shift;
-  no strict 'refs';
   foreach my $attrname ( @_) {
     *{Symbol::fetch_glob(caller() . '::' . $attrname)} = sub {
-      use strict;
-      $Carp::CarpLevel = 1,  Carp::croak(
+      
+      ($Carp::CarpLevel = 1),  Carp::croak(
        "Accessor usage: \$obj->$attrname() or \$obj->$attrname(\$new_value)"
       ) unless ((nelems @_) == 1 or (nelems @_) == 2) and ref @_[0];
 
       # Read access:
-      return @_[0]->{$attrname} if (nelems @_) == 1;
+      return @_[0]->{?$attrname} if (nelems @_) == 1;
 
       # Write access:
-      @_[0]->{$attrname} = @_[1];
+      @_[0]->{+$attrname} = @_[1];
       return @_[0]; # RETURNS MYSELF!
     };
   }
@@ -637,9 +632,9 @@ sub _accessorize {  # A simple-minded method-maker
 sub _state_as_string {
   my $self = @_[0];
   return '' unless ref $self;
-  my @out = @( "\{\n  # State of {dump::view($self)} ...\n" );
+  my @out = @( "\{\n  # State of $(dump::view($self)) ...\n" );
   foreach my $k (sort keys %$self) {
-    push @out, "  {dump::view($k)} => {dump::view($self->{$k})}\n";
+    push @out, "  $(dump::view($k)) => $(dump::view($self->{?$k}))\n";
   }
   push @out, "\}\n";
   my $x = join '', @out;
@@ -723,9 +718,9 @@ together set-attribute calls like this:
 =item $search->inc( I<true-or-false> );
 
 This attribute, if set to a true value, means that searches should
-implicitly add perl's I<@INC> paths. This
+implicitly add perl's I<$^INCLUDE_PATH> paths. This
 automatically considers paths specified in the C<PERL5LIB> environment
-as this is prepended to I<@INC> by the Perl interpreter itself.
+as this is prepended to I<$^INCLUDE_PATH> by the Perl interpreter itself.
 This attribute's default value is B<TRUE>.  If you want to search
 only specific directories, set $self->inc(0) before calling
 $inc->survey or $inc->find.
@@ -868,7 +863,7 @@ in particular ways.
 The method C<survey> searches for POD documents in a given set of
 files and/or directories.  This runs the search according to the various
 options set by the accessors above.  (For example, if the C<inc> attribute
-is on, as it is by default, then the perl @INC directories are implicitly
+is on, as it is by default, then the perl $^INCLUDE_PATH directories are implicitly
 added to the list of directories (if any) that you specify.)
 
 The return value of C<survey> is two hashes:
@@ -908,7 +903,7 @@ Only text files containing at least one valid POD command are found.
 In verbose mode, a warning is printed if shadows are found (i.e., more
 than one POD file with the same POD name is found, e.g. F<CPAN.pm> in
 different directories).  This usually indicates duplicate occurrences of
-modules in the I<@INC> search path, which is occasionally inadvertent
+modules in the I<$^INCLUDE_PATH> search path, which is occasionally inadvertent
 (but is often simply a case of a user's path dir having a more recent
 version than the system's general path dirs in general.)
 
@@ -943,7 +938,7 @@ Returns the location of a Pod file, given a Pod/module/script name
 what files/directories to look in.
 It searches according to the various options set by the accessors above.
 (For example, if the C<inc> attribute is on, as it is by default, then
-the perl @INC directories are implicitly added to the list of
+the perl $^INCLUDE_PATH directories are implicitly added to the list of
 directories (if any) that you specify.)
 
 This returns the full path of the first occurrence to the file.
@@ -960,11 +955,11 @@ then it is searched.  (That's how we manage to find F<perlfunc>,
 for example, which is usually in F<pod/perlfunc> in most Perl dists.)
 
 The C<verbose> and C<inc> attributes influence the behavior of this
-search; notably, C<inc>, if true, adds @INC I<and also
-$Config::Config{'scriptdir'}> to the list of directories to search.
+search; notably, C<inc>, if true, adds $^INCLUDE_PATH I<and also
+Config::config_value('scriptdir')> to the list of directories to search.
 
 It is common to simply say C<< $filename = Pod::Simple::Search-> new 
-->find("perlvar") >> so that just the @INC (well, and scriptdir)
+->find("perlvar") >> so that just the $^INCLUDE_PATH (well, and scriptdir)
 directories are searched.  (This happens because the C<inc>
 attribute is true by default.)
 
