@@ -1,18 +1,17 @@
 
 package Pod::Simple::Text;
 
-use strict;
 use utf8;
 
 use Carp ();
 use Pod::Simple::Methody ();
 use Pod::Simple ();
-use vars < qw( @ISA $VERSION $FREAKYMODE);
+our (@ISA, $VERSION, $FREAKYMODE);
 $VERSION = '2.02';
 @ISA = @('Pod::Simple::Methody');
 BEGIN { *DEBUG = defined(&Pod::Simple::DEBUG)
-          ? \&Pod::Simple::DEBUG
-          : sub() {0}
+          ?? \&Pod::Simple::DEBUG
+          !! sub() {0}
       }
 
 use Text::Wrap v98.112902 ();
@@ -22,40 +21,40 @@ $Text::Wrap::huge = 'overflow';
 sub new {
   my $self = shift;
   my $new = $self->SUPER::new(< @_);
-  $new->{'output_fh'} ||= *STDOUT{IO};
+  $new->{+'output_fh'} ||= $^STDOUT;
   $new->accept_target_as_text( <qw( text plaintext plain ));
   $new->nix_X_codes(1);
   $new->nbsp_for_S(1);
-  $new->{'Thispara'} = '';
-  $new->{'Indent'} = 0;
-  $new->{'Indentstring'} = '   ';
+  $new->{+'Thispara'} = '';
+  $new->{+'Indent'} = 0;
+  $new->{+'Indentstring'} = '   ';
   return $new;
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-sub handle_text {  @_[0]->{'Thispara'} .= @_[1] }
+sub handle_text {  @_[0]->{+'Thispara'} .= @_[1] }
 
-sub start_Para  {  @_[0]->{'Thispara'} = '' }
-sub start_head1 {  @_[0]->{'Thispara'} = '' }
-sub start_head2 {  @_[0]->{'Thispara'} = '' }
-sub start_head3 {  @_[0]->{'Thispara'} = '' }
-sub start_head4 {  @_[0]->{'Thispara'} = '' }
+sub start_Para  {  @_[0]->{+'Thispara'} = '' }
+sub start_head1 {  @_[0]->{+'Thispara'} = '' }
+sub start_head2 {  @_[0]->{+'Thispara'} = '' }
+sub start_head3 {  @_[0]->{+'Thispara'} = '' }
+sub start_head4 {  @_[0]->{+'Thispara'} = '' }
 
-sub start_Verbatim    { @_[0]->{'Thispara'} = ''   }
-sub start_item_bullet { @_[0]->{'Thispara'} = $FREAKYMODE ? '' : '* ' }
-sub start_item_number { @_[0]->{'Thispara'} = $FREAKYMODE ? '' : "@_[1]->{'number'}. "  }
-sub start_item_text   { @_[0]->{'Thispara'} = ''   }
+sub start_Verbatim    { @_[0]->{+'Thispara'} = ''   }
+sub start_item_bullet { @_[0]->{+'Thispara'} = $FREAKYMODE ?? '' !! '* ' }
+sub start_item_number { @_[0]->{+'Thispara'} = $FREAKYMODE ?? '' !! "@_[1]->{?'number'}. "  }
+sub start_item_text   { @_[0]->{+'Thispara'} = ''   }
 
-sub start_over_bullet  { ++@_[0]->{'Indent'} }
-sub start_over_number  { ++@_[0]->{'Indent'} }
-sub start_over_text    { ++@_[0]->{'Indent'} }
-sub start_over_block   { ++@_[0]->{'Indent'} }
+sub start_over_bullet  { ++@_[0]->{+'Indent'} }
+sub start_over_number  { ++@_[0]->{+'Indent'} }
+sub start_over_text    { ++@_[0]->{+'Indent'} }
+sub start_over_block   { ++@_[0]->{+'Indent'} }
 
-sub   end_over_bullet  { --@_[0]->{'Indent'} }
-sub   end_over_number  { --@_[0]->{'Indent'} }
-sub   end_over_text    { --@_[0]->{'Indent'} }
-sub   end_over_block   { --@_[0]->{'Indent'} }
+sub   end_over_bullet  { --@_[0]->{+'Indent'} }
+sub   end_over_number  { --@_[0]->{+'Indent'} }
+sub   end_over_text    { --@_[0]->{+'Indent'} }
+sub   end_over_block   { --@_[0]->{+'Indent'} }
 
 
 # . . . . . Now the actual formatters:
@@ -70,16 +69,16 @@ sub end_item_number { @_[0]->emit_par( 0) }
 sub end_item_text   { @_[0]->emit_par(-2) }
 
 sub emit_par {
-  my($self, $tweak_indent) = splice(@_,0,2);
-  my $indent = ' ' x ( 2 * $self->{'Indent'} + 4 + ($tweak_indent||0) );
+  my@($self, $tweak_indent) = @: splice(@_,0,2);
+  my $indent = ' ' x ( 2 * $self->{?'Indent'} + 4 + ($tweak_indent||0) );
    # Yes, 'STRING' x NEGATIVE gives '', same as 'STRING' x 0
 
-  $self->{'Thispara'} =~ s/\x{AD}//g if Pod::Simple::ASCII;
-  my $out = Text::Wrap::wrap($indent, $indent, $self->{'Thispara'} .= "\n");
+  $self->{+'Thispara'} =~ s/\x{AD}//g if Pod::Simple::ASCII;
+  my $out = Text::Wrap::wrap($indent, $indent, ($self->{+'Thispara'} .= "\n"));
 
   $out =~ s/\x{A0}/ /g if Pod::Simple::ASCII;
-  print {$self->{'output_fh'}} $out, "\n";
-  $self->{'Thispara'} = '';
+  print $self->{?'output_fh'} ,$out, "\n";
+  $self->{+'Thispara'} = '';
   
   return;
 }
@@ -89,20 +88,20 @@ sub emit_par {
 sub end_Verbatim  {
   my $self = shift;
   if(Pod::Simple::ASCII) {
-    $self->{'Thispara'} =~ s/\x{A0}/ /g;
-    $self->{'Thispara'} =~ s/\x{AD}//g;
+    $self->{+'Thispara'} =~ s/\x{A0}/ /g;
+    $self->{+'Thispara'} =~ s/\x{AD}//g;
   }
 
-  my $i = ' ' x ( 2 * $self->{'Indent'} + 4);
+  my $i = ' ' x ( 2 * $self->{?'Indent'} + 4);
   #my $i = ' ' x (4 + $self->{'Indent'});
   
-  $self->{'Thispara'} =~ s/^/$i/mg;
+  $self->{+'Thispara'} =~ s/^/$i/mg;
   
-  print { $self->{'output_fh'} }   '', 
-    $self->{'Thispara'},
+  print  $self->{?'output_fh'}    ,'', 
+    $self->{?'Thispara'},
     "\n\n"
   ;
-  $self->{'Thispara'} = '';
+  $self->{+'Thispara'} = '';
   return;
 }
 
