@@ -20,8 +20,7 @@ package Pod::Text::Color;
 use Pod::Text ();
 use Term::ANSIColor < qw(colored);
 
-use strict;
-use vars < qw(@ISA $VERSION);
+our (@ISA, $VERSION);
 use utf8;
 
 @ISA = qw(Pod::Text);
@@ -36,15 +35,13 @@ $VERSION = 2.03;
 ##############################################################################
 
 # Make level one headings bold.
-sub cmd_head1 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head1($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $self->SUPER::cmd_head1 ($attrs, colored ($text, 'bold'));
 }
 
 # Make level two headings bold.
-sub cmd_head2 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head2($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $self->SUPER::cmd_head2 ($attrs, colored ($text, 'bold'));
 }
@@ -55,8 +52,7 @@ sub cmd_f { return colored (@_[2], 'cyan')   }
 sub cmd_i { return colored (@_[2], 'yellow') }
 
 # Output any included code in green.
-sub output_code {
-    my ($self, $code) = < @_;
+sub output_code($self, $code) {
     $code = colored ($code, 'green');
     $self->output ($code);
 }
@@ -67,8 +63,8 @@ sub wrap {
     my $self = shift;
     local $_ = shift;
     my $output = '';
-    my $spaces = ' ' x %$self{MARGIN};
-    my $width = %$self{opt_width} - %$self{MARGIN};
+    my $spaces = ' ' x %$self{?MARGIN};
+    my $width = %$self{?opt_width} - %$self{?MARGIN};
 
     # We have to do $shortchar and $longchar in variables because the
     # construct ${char}{0,$width} didn't do the right thing until Perl 5.8.x.
