@@ -27,8 +27,7 @@ package Pod::Text::Overstrike;
 
 use Pod::Text ();
 
-use strict;
-use vars < qw(@ISA $VERSION);
+our (@ISA, $VERSION);
 use utf8;
 
 @ISA = qw(Pod::Text);
@@ -43,8 +42,7 @@ $VERSION = 2.00;
 ##############################################################################
 
 # Make level one headings bold, overridding any existing formatting.
-sub cmd_head1 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head1($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $text = $self->strip_format ($text);
     $text =~ s/(.)/$1\b$1/g;
@@ -52,8 +50,7 @@ sub cmd_head1 {
 }
 
 # Make level two headings bold, overriding any existing formatting.
-sub cmd_head2 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head2($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $text = $self->strip_format ($text);
     $text =~ s/(.)/$1\b$1/g;
@@ -61,8 +58,7 @@ sub cmd_head2 {
 }
 
 # Make level three headings underscored, overriding any existing formatting.
-sub cmd_head3 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head3($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $text = $self->strip_format ($text);
     $text =~ s/(.)/_\b$1/g;
@@ -70,8 +66,7 @@ sub cmd_head3 {
 }
 
 # Level four headings look like level three headings.
-sub cmd_head4 {
-    my ($self, $attrs, $text) = < @_;
+sub cmd_head4($self, $attrs, $text) {
     $text =~ s/\s+$//;
     $text = $self->strip_format ($text);
     $text =~ s/(.)/_\b$1/g;
@@ -80,11 +75,10 @@ sub cmd_head4 {
 
 # The common code for handling all headers.  We have to override to avoid
 # interpolating twice and because we don't want to honor alt.
-sub heading {
-    my ($self, $text, $indent, $marker) = < @_;
-    $self->item ("\n\n") if defined %$self{ITEM};
-    $text .= "\n" if %$self{opt_loose};
-    my $margin = ' ' x (%$self{opt_margin} + $indent);
+sub heading($self, $text, $indent, $marker) {
+    $self->item ("\n\n") if defined %$self{?ITEM};
+    $text .= "\n" if %$self{?opt_loose};
+    my $margin = ' ' x (%$self{?opt_margin} + $indent);
     $self->output ($margin . $text . "\n");
     return '';
 }
@@ -95,8 +89,7 @@ sub cmd_f { local $_ = @_[0]->strip_format (@_[2]); s/(.)/_\b$1/g; $_ }
 sub cmd_i { local $_ = @_[0]->strip_format (@_[2]); s/(.)/_\b$1/g; $_ }
 
 # Output any included code in bold.
-sub output_code {
-    my ($self, $code) = < @_;
+sub output_code($self, $code) {
     $code =~ s/(.)/$1\b$1/g;
     $self->output ($code);
 }
@@ -107,8 +100,8 @@ sub wrap {
     my $self = shift;
     local $_ = shift;
     my $output = '';
-    my $spaces = ' ' x %$self{MARGIN};
-    my $width = %$self{opt_width} - %$self{MARGIN};
+    my $spaces = ' ' x %$self{?MARGIN};
+    my $width = %$self{?opt_width} - %$self{?MARGIN};
     while (length +> $width) {
         # This regex represents a single character, that's possibly underlined
         # or in bold (in which case, it's three characters; the character, a
@@ -132,8 +125,7 @@ sub wrap {
 
 # Strip all of the formatting from a provided string, returning the stripped
 # version.
-sub strip_format {
-    my ($self, $text) = < @_;
+sub strip_format($self, $text) {
     $text =~ s/(.)[\b]\1/$1/g;
     $text =~ s/_[\b]//g;
     return $text;
