@@ -1,6 +1,5 @@
 package Test::Builder::Module;
 
-use strict;
 
 use Test::Builder;
 
@@ -72,7 +71,7 @@ import_extra().
 =cut
 
 sub import {
-    my($class) = shift;
+    my@($class) =@( shift);
     
     # Don't run all this when loading ourself.
     return 1 if $class eq 'Test::Builder::Module';
@@ -84,9 +83,11 @@ sub import {
     $test->exported_to($caller);
 
     $class->import_extra(\@_);
-    my(@imports) = $class->_strip_imports(\@_);
+    my @imports = $class->_strip_imports(\@_);
 
-    $test->plan(< @_);
+    if (@_) {
+        $test->plan(< @_);
+    }
 
     $class->export_to_level(1, $class, < @imports);
 }
