@@ -7,8 +7,7 @@ sub new {
 
 
 package Overloaded::Compare;
-use vars < qw(@ISA);
-@ISA = qw(Overloaded);
+our @ISA = qw(Overloaded);
 
 # Sometimes objects have only comparison ops overloaded and nothing else.
 # For example, DateTime objects.
@@ -19,11 +18,10 @@ use overload
 
 
 package Overloaded::Ify;
-use vars < qw(@ISA);
-@ISA = qw(Overloaded);
+our @ISA = qw(Overloaded);
 
 use overload
         q{""}    => sub { @_[0]->{string} },
         q{0+}    => sub { @_[0]->{num} };
 
-1;
\ No newline at end of file
+1;
