@@ -1,5 +1,5 @@
 package User::grent;
-use strict;
+
 
 our $VERSION = '1.01';
 our(@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
@@ -9,10 +9,14 @@ BEGIN {
     @EXPORT_OK   = qw($gr_name $gr_gid $gr_passwd $gr_mem @gr_members);
     %EXPORT_TAGS = %( FIELDS => \@( < @EXPORT_OK, < @EXPORT ) );
 }
-use vars      < @EXPORT_OK;
+
+our ($gr_name, $gr_gid, $gr_passwd, $gr_mem, @gr_members);
 
 # Class::Struct forbids use of @ISA
-sub import { goto &Exporter::import }
+sub import {
+    local $Exporter::ExportLevel = $Exporter::ExportLevel + 1;
+    return Exporter::import(< @_);
+}
 
 use Class::Struct < qw(struct);
 struct 'User::grent' => \@(
@@ -22,18 +26,18 @@ struct 'User::grent' => \@(
     members => '@',
 );
 
-sub populate (@) {
+sub populate {
     return unless (nelems @_);
     my $gob = new();
-    ($gr_name, $gr_passwd, $gr_gid) = < @$gob[[@(0,1,2)]] = < @_[[@(0,1,2)]];
+    @($gr_name, $gr_passwd, $gr_gid) = @$gob[[@(0,1,2)]] =  @_[[@(0,1,2)]];
     @gr_members = @( @{$gob->[3]} = split ' ', @_[3] );
     return $gob;
 } 
 
 sub getgrent ( ) { populate(CORE::getgrent()) } 
-sub getgrnam ($) { populate(CORE::getgrnam(shift)) } 
-sub getgrgid ($) { populate(CORE::getgrgid(shift)) } 
-sub getgr    ($) { (@_[0] =~ m/^\d+/) ? &getgrgid : &getgrnam } 
+sub getgrnam ($v) { populate(CORE::getgrnam($v)) } 
+sub getgrgid ($v) { populate(CORE::getgrgid($v)) } 
+sub getgr    ($v) { ($v =~ m/^\d+/) ?? &getgrgid($v) !! &getgrnam($v) } 
 
 1;
 __END__
