@@ -1,5 +1,5 @@
 package charnames;
-use strict;
+
 use warnings;
 use File::Spec;
 our $VERSION = '1.06';
@@ -44,21 +44,21 @@ my %alias3 = %( (
 	    ) );
 my $txt;
 
-sub alias (@)
+sub alias
 {
   (nelems @_) or return %alias3;
-  my $alias = ref @_[0] ? @_[0] : \%( < @_ );
- <  %alias3{[keys %$alias]} = < values %$alias;
+  my $alias = ref @_[0] ?? @_[0] !! \%( < @_ );
+   %alias3{[keys %$alias]} =  values %$alias;
 } # alias
 
-sub alias_file ($)
+sub alias_file($arg)
 {
-  my ($arg, $file) = < @_;
+  my $file;
   if (-f $arg && File::Spec->file_name_is_absolute ($arg)) {
     $file = $arg;
   }
   elsif ($arg =~ m/^\w+$/) {
-    $file = "unicore/{$arg}_alias.pl";
+    $file = "unicore/$($arg)_alias.pl";
   }
   else {
     die "Charnames alias files can only have identifier characters";
@@ -81,15 +81,15 @@ sub charnames
   my $name = shift;
 
   if (exists %alias1{$name}) {
-    $name = %alias1{$name};
+    $name = %alias1{?$name};
   }
   elsif (exists %alias2{$name}) {
     require warnings;
-    warnings::warnif('deprecated', qq{Unicode character name "$name" is deprecated, use "%alias2{$name}" instead});
-    $name = %alias2{$name};
+    warnings::warnif('deprecated', qq{Unicode character name "$name" is deprecated, use "%alias2{?$name}" instead});
+    $name = %alias2{?$name};
   }
   elsif (exists %alias3{$name}) {
-    $name = %alias3{$name};
+    $name = %alias3{?$name};
   }
 
   my $ord;
@@ -107,16 +107,16 @@ sub charnames
 
     my $hexre = "[0-9A-Fa-f]+";
     ## If :full, look for the name exactly
-    if (%^H{charnames_full} and $txt =~ m/($hexre)\t\t\Q$name\E$/m) {
+    if ($^HINTS{?charnames_full} and $txt =~ m/($hexre)\t\t\Q$name\E$/m) {
         $hexstr = $1;
     }
 
     ## If we didn't get above, and :short allowed, look for the short name.
     ## The short name is like "greek:Sigma"
     unless (defined $hexstr) {
-      if (%^H{charnames_short} and $name =~ m/^(.+?):(.+)/s) {
-	my ($script, $cname) = ($1, $2);
-	my $case = $cname =~ m/[[:upper:]]/ ? "CAPITAL" : "SMALL";
+      if ($^HINTS{?charnames_short} and $name =~ m/^(.+?):(.+)/s) {
+	my @($script, $cname) = @($1, $2);
+	my $case = $cname =~ m/[[:upper:]]/ ?? "CAPITAL" !! "SMALL";
         my $uc_cname = uc($cname);
         my $uc_script = uc($script);
 	if ($txt =~ m/($hexre)\t\t$uc_script (?:$case )?LETTER \Q$uc_cname\E$/m) {
@@ -128,8 +128,8 @@ sub charnames
     ## If we still don't have it, check for the name among the loaded
     ## scripts.
     if (not defined $hexstr) {
-      my $case = $name =~ m/[[:upper:]]/ ? "CAPITAL" : "SMALL";
-      for my $script ( @{%^H{charnames_scripts}}) {
+      my $case = $name =~ m/[[:upper:]]/ ?? "CAPITAL" !! "SMALL";
+      for my $script ( @{$^HINTS{charnames_scripts}}) {
         my $ucname = uc($name);
 	if ($txt =~ m/($hexre)\t\t$script (?:$case )?LETTER \Q$ucname\E$/m) {
             $hexstr = $1;
@@ -160,12 +160,12 @@ sub import
   if (not nelems @_) {
     warn("`use charnames' needs explicit imports list");
   }
-  %^H{charnames} = \&charnames ;
+  $^HINTS{+charnames} = \&charnames ;
 
   ##
   ## fill %h keys with our @_ args.
   ##
-  my ($promote, %h, @args) = (0, %(), @());
+  my @($promote, %h, @args) = @(0, %(), @());
   while (my $arg = shift) {
     if ($arg eq ":alias") {
       (nelems @_) or
@@ -193,20 +193,20 @@ sub import
     push @args, $arg;
   }
   (nelems @args) == 0 && $promote and @args = @(":full");
- <  %h{[ @args]} = (1) x nelems @args;
+   %h{[ @args]} = @(1) x nelems @args;
 
-  %^H{charnames_full} = delete %h{':full'};
-  %^H{charnames_short} = delete %h{':short'};
-  %^H{charnames_scripts} = \ map uc, keys %h;
+  $^HINTS{+charnames_full} = delete %h{':full'};
+  $^HINTS{+charnames_short} = delete %h{':short'};
+  $^HINTS{+charnames_scripts} = \ map { uc }, keys %h;
 
   ##
   ## If utf8? warnings are enabled, and some scripts were given,
   ## see if at least we can find one letter of each script.
   ##
-  if (warnings::enabled('utf8') && nelems @{%^H{charnames_scripts}}) {
+  if (warnings::enabled('utf8') && nelems @{$^HINTS{?charnames_scripts}}) {
     $txt = do "unicore/Name.pl" unless $txt;
 
-    for my $script ( @{%^H{charnames_scripts}}) {
+    for my $script ( @{$^HINTS{charnames_scripts}}) {
       if (not $txt =~ m/\t\t$script (?:CAPITAL |SMALL )?LETTER /) {
 	warnings::warn('utf8',  "No such script: '$script'");
       }
@@ -243,13 +243,13 @@ sub viacode
     return;
   }
 
-  return %viacode{$hex} if exists %viacode{$hex};
+  return %viacode{?$hex} if exists %viacode{$hex};
 
   $txt = do "unicore/Name.pl" unless $txt;
 
   return unless $txt =~ m/^$hex\t\t(.+)/m;
 
-  %viacode{$hex} = $1;
+  %viacode{+$hex} = $1;
 } # viacode
 
 my %vianame;
@@ -265,7 +265,7 @@ sub vianame
 
   return chr CORE::hex $1 if $arg =~ m/^U\+([0-9a-fA-F]+)$/;
 
-  return %vianame{$arg} if exists %vianame{$arg};
+  return %vianame{?$arg} if exists %vianame{$arg};
 
   $txt = do "unicore/Name.pl" unless $txt;
 
@@ -273,7 +273,7 @@ sub vianame
   if ($pos +>= 0) {
     my $posLF = rindex $txt, "\n", $pos;
     (my $code = substr $txt, $posLF + 1, 6) =~ s/\t//g;
-    return %vianame{$arg} = CORE::hex $code;
+    return (%vianame{+$arg} = CORE::hex $code);
 
     # If $pos is at the 1st line, $posLF must be $[ - 1 (not found);
     # then $posLF + 1 equals to $[ (at the beginning of $txt).
@@ -419,7 +419,7 @@ or customized aliases to standard Unicode naming conventions (:full)
 
     use charnames ":full", ":alias" => "pro";
 
-    will try to read "unicore/pro_alias.pl" from the @INC path. This
+    will try to read "unicore/pro_alias.pl" from the $^INCLUDE_PATH path. This
     file should return a list in plain perl:
 
     (
