@@ -1,14 +1,12 @@
 package fields;
 
-use strict;
-no strict 'refs';
 unless( eval q{require warnings::register; warnings::register->import; 1} ) {
     *warnings::warnif = sub { 
         require Carp;
         Carp::carp(< @_);
     }
 }
-use vars < qw(%attr $VERSION);
+our (%attr, $VERSION);
 
 $VERSION = '2.13';
 
@@ -34,21 +32,21 @@ sub import {
     # avoid possible typo warnings
     %{*{Symbol::fetch_glob("$package\::FIELDS")}} = %( () ) unless %{*{Symbol::fetch_glob("$package\::FIELDS")}};
     my $fields = \%{*{Symbol::fetch_glob("$package\::FIELDS")}};
-    my $fattr = (%attr{$package} ||= \@(1));
+    my $fattr = (%attr{+$package} ||= \@(1));
     my $next = (nelems @$fattr);
 
     # Quiet pseudo-hash deprecation warning for uses of fields::new.
     bless \%{*{Symbol::fetch_glob("$package\::FIELDS")}}, 'pseudohash';
 
     if ($next +> $fattr->[0]
-        and ($fields->{@_[0]} || 0) +>= $fattr->[0])
+        and ($fields->{?@_[0]} || 0) +>= $fattr->[0])
     {
         # There are already fields not belonging to base classes.
         # Looks like a possible module reload...
         $next = $fattr->[0];
     }
     foreach my $f ( @_) {
-        my $fno = $fields->{$f};
+        my $fno = $fields->{?$f};
 
         # Allow the module to be reloaded so long as field positions
         # have not changed.
@@ -59,8 +57,8 @@ sub import {
                 die("Field name '$f' already in use");
             }
         }
-        $fields->{$f} = $next;
-        $fattr->[$next] = ($f =~ m/^_/) ? PRIVATE : PUBLIC;
+        $fields->{+$f} = $next;
+        $fattr->[+$next] = ($f =~ m/^_/) ?? PRIVATE !! PUBLIC;
         $next += 1;
     }
     if ((nelems @$fattr) +> $next) {
@@ -76,30 +74,30 @@ sub import {
 
 sub inherit {
     require base;
-    goto &base::inherit_fields;
+    base::inherit_fields(< @_);
 }
 
 sub _dump  # sometimes useful for debugging
 {
     for my $pkg (sort keys %attr) {
-        print "\n$pkg";
+        print $^STDOUT, "\n$pkg";
         if ((nelems @{*{Symbol::fetch_glob("$pkg\::ISA")}})) {
-            print " (", join(", ", @{*{Symbol::fetch_glob("$pkg\::ISA")}}), ")";
+            print $^STDOUT, " (", join(", ", @{*{Symbol::fetch_glob("$pkg\::ISA")}}), ")";
         }
-        print "\n";
+        print $^STDOUT, "\n";
         my $fields = \%{*{Symbol::fetch_glob("$pkg\::FIELDS")}};
-        for my $f (sort {$fields->{$a} <+> $fields->{$b}} keys %$fields) {
-            my $no = $fields->{$f};
-            print "   $no: $f";
+        for my $f (sort {$fields->{?$a} <+> $fields->{?$b}}, keys %$fields) {
+            my $no = $fields->{?$f};
+            print $^STDOUT, "   $no: $f";
             my $fattr = %attr{$pkg}->[$no];
             if (defined $fattr) {
                 my @a;
                 push(@a, "public")    if $fattr ^&^ PUBLIC;
                 push(@a, "private")   if $fattr ^&^ PRIVATE;
                 push(@a, "inherited") if $fattr ^&^ INHERITED;
-                print "\t(", join(", ", @a), ")";
+                print $^STDOUT, "\t(", join(", ", @a), ")";
             }
-            print "\n";
+            print $^STDOUT, "\n";
         }
     }
 }
@@ -115,11 +113,10 @@ sub new {
     return $self;
 }
 
-sub _accessible_keys {
-    my ($class) = < @_;
+sub _accessible_keys($class) {
     return  @( <
         keys %{*{Symbol::fetch_glob($class.'::FIELDS')}},
-        < map( <_accessible_keys($_), @{*{Symbol::fetch_glob($class.'::ISA')}}),
+        < @+: map( { _accessible_keys($_) }, @{*{Symbol::fetch_glob($class.'::ISA')}}),
     );
 }
 
