@@ -1,5 +1,5 @@
 package less;
-use strict;
+
 use warnings;
 
 our $VERSION = '0.02';
@@ -9,9 +9,9 @@ sub _pack_tags {
 }
 
 sub _unpack_tags {
-    return grep { defined and length }
- map  { < split ' ' }
- grep {defined} @_;
+    return grep { defined and length },
+      @+: map  { split ' ' },
+        grep {defined}, @_;
 }
 
 sub of {
@@ -20,10 +20,10 @@ sub of {
     # If no one wants the result, don't bother computing it.
     my $hinthash = @( caller 0 )[10];
     my %tags;
- <    %tags{[_unpack_tags( $hinthash->{$class} ) ]} = ();
+     %tags{[_unpack_tags( $hinthash->{?$class} ) ]} = @();
 
     if ((nelems @_)) {
-        exists %tags{$_} and return !!1 for  @_;
+        exists %tags{$_} and return ! ! 1 for  @_;
         return;
     }
     else {
@@ -36,9 +36,9 @@ sub import {
 
     @_ = @( 'please' ) if not nelems @_;
     my %tags;
- <    %tags{[_unpack_tags( < @_, %^H{$class} ) ]} = ();
+    %tags{[_unpack_tags( < @_, $^HINTS{?$class} ) ]} = @();
 
-    %^H{$class} = _pack_tags( < keys %tags );
+    $^HINTS{+$class} = _pack_tags( < keys %tags );
     return;
 }
 
@@ -47,19 +47,19 @@ sub unimport {
 
     if ((nelems @_)) {
         my %tags;
- <        %tags{[_unpack_tags( %^H{$class} ) ]} = ();
+         %tags{[_unpack_tags( $^HINTS{?$class} ) ]} = @();
         delete %tags{[ <_unpack_tags(< @_) ]};
         my $new = _pack_tags( < keys %tags );
 
         if ( not length $new ) {
-            delete %^H{$class};
+            delete $^HINTS{$class};
         }
         else {
-            %^H{$class} = $new;
+            $^HINTS{+$class} = $new;
         }
     }
     else {
-        delete %^H{$class};
+        delete $^HINTS{$class};
     }
 
     return;
