@@ -1,19 +1,16 @@
 #!perl -w
 package version;
 
-use strict;
 
-use vars < qw(@ISA $VERSION $CLASS *qv);
+our (@ISA, $VERSION, $CLASS);
 
 $VERSION = 0.73;
 
 $CLASS = 'version';
 
 # Preloaded methods go here.
-sub import {
-    my ($class) = < @_;
+sub import($class, ...) {
     my $callpkg = caller();
-    no strict 'refs';
     
     *{Symbol::fetch_glob($callpkg."::qv")} = 
 	    sub {return bless version::qv(shift), $class }
