@@ -23,12 +23,11 @@ usage.
 
 require warnings;
 
-sub mkMask
+sub mkMask($bit)
 {
-    my ($bit) = < @_;
     my $mask = "";
 
-    vec($mask, $bit, 1) = 1;
+    vec($mask, $bit, 1 => 1);
     return $mask;
 }
 
@@ -36,15 +35,15 @@ sub import
 {
     shift;
     my $package = @(caller(0))[0];
-    if (! defined %warnings::Bits{$package}) {
-        %warnings::Bits{$package}     = mkMask($warnings::LAST_BIT);
-        vec(%warnings::Bits{'all'}, $warnings::LAST_BIT, 1) = 1;
-        %warnings::Offsets{$package}  = $warnings::LAST_BIT ++;
+    if (! defined %warnings::Bits{?$package}) {
+        %warnings::Bits{+$package}     = mkMask($warnings::LAST_BIT);
+        vec(%warnings::Bits{?'all'}, $warnings::LAST_BIT, 1 => 1);
+        %warnings::Offsets{+$package}  = $warnings::LAST_BIT ++;
 	foreach my $k (keys %warnings::Bits) {
-	    vec(%warnings::Bits{$k}, $warnings::LAST_BIT, 1) = 0;
+	    vec(%warnings::Bits{?$k}, $warnings::LAST_BIT, 1 => 0);
 	}
-        %warnings::DeadBits{$package} = mkMask($warnings::LAST_BIT);
-        vec(%warnings::DeadBits{'all'}, $warnings::LAST_BIT++, 1) = 1;
+        %warnings::DeadBits{+$package} = mkMask($warnings::LAST_BIT);
+        vec(%warnings::DeadBits{?'all'}, $warnings::LAST_BIT++, 1 => 1);
     }
 }
 
