@@ -150,6 +150,7 @@ package P5AST::padop_svop; 	@ISA = 'P5AST::baseop';
 package P5AST::pmop; 		@ISA = 'P5AST::baseop';
 package P5AST::pvop_svop; 	@ISA = 'P5AST::baseop';
 package P5AST::unop; 		@ISA = 'P5AST::baseop';
+package P5AST::rootop; 		@ISA = 'P5AST::baseop';
 
 # Nothing.
 
@@ -165,6 +166,7 @@ package P5AST::op_const; 	@ISA = 'P5AST::padop_svop';
 package P5AST::op_gvsv; 	@ISA = 'P5AST::padop_svop';
 package P5AST::op_gv; 		@ISA = 'P5AST::padop_svop';
 package P5AST::op_gelem; 	@ISA = 'P5AST::binop';
+package P5AST::op_magicsv; 	@ISA = 'P5AST::baseop';
 package P5AST::op_padsv; 	@ISA = 'P5AST::baseop';
 package P5AST::op_padav; 	@ISA = 'P5AST::baseop';
 package P5AST::op_padhv; 	@ISA = 'P5AST::baseop';
@@ -194,6 +196,7 @@ package P5AST::op_subst; 	@ISA = 'P5AST::pmop';
 package P5AST::op_substcont; 	@ISA = 'P5AST::logop';
 package P5AST::op_trans; 	@ISA = 'P5AST::pvop_svop';
 package P5AST::op_sassign; 	@ISA = 'P5AST::baseop';
+package P5AST::op_logassign_assign; 	@ISA = 'P5AST::baseop';
 package P5AST::op_aassign; 	@ISA = 'P5AST::binop';
 package P5AST::op_chop; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_schop; 	@ISA = 'P5AST::baseop_unop';
@@ -201,6 +204,9 @@ package P5AST::op_chomp; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_schomp; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_defined; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_undef; 	@ISA = 'P5AST::baseop_unop';
+package P5AST::op_dotdotdot; 	@ISA = 'P5AST::baseop';
+package P5AST::op_placeholder; 	@ISA = 'P5AST::baseop';
+package P5AST::op_dynascope; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_study; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_pos; 		@ISA = 'P5AST::baseop_unop';
 package P5AST::op_preinc; 	@ISA = 'P5AST::unop';
@@ -224,6 +230,8 @@ package P5AST::op_i_add; 	@ISA = 'P5AST::binop';
 package P5AST::op_subtract; 	@ISA = 'P5AST::binop';
 package P5AST::op_i_subtract; 	@ISA = 'P5AST::binop';
 package P5AST::op_concat; 	@ISA = 'P5AST::binop';
+package P5AST::op_hashconcat; 	@ISA = 'P5AST::binop';
+package P5AST::op_arrayconcat; 	@ISA = 'P5AST::binop';
 package P5AST::op_stringify; 	@ISA = 'P5AST::listop';
 package P5AST::op_left_shift; 	@ISA = 'P5AST::binop';
 package P5AST::op_right_shift; 	@ISA = 'P5AST::binop';
@@ -294,6 +302,10 @@ package P5AST::op_keys; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_delete; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_exists; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_expand; 	@ISA = 'P5AST::baseop_unop';
+package P5AST::op_hashexpand; 	@ISA = 'P5AST::baseop_unop';
+package P5AST::op_arrayexpand; 	@ISA = 'P5AST::baseop_unop';
+package P5AST::op_enter_hashexpand_assign; 	@ISA = 'P5AST::baseop';
+package P5AST::op_enter_arrayexpand_assign; 	@ISA = 'P5AST::baseop';
 package P5AST::op_rv2hv; 	@ISA = 'P5AST::unop';
 package P5AST::op_helem; 	@ISA = 'P5AST::listop';
 package P5AST::op_hslice; 	@ISA = 'P5AST::listop';
@@ -301,11 +313,17 @@ package P5AST::op_unpack; 	@ISA = 'P5AST::listop';
 package P5AST::op_pack; 	@ISA = 'P5AST::listop';
 package P5AST::op_split; 	@ISA = 'P5AST::listop';
 package P5AST::op_join; 	@ISA = 'P5AST::listop';
+package P5AST::op_hashjoin; 	@ISA = 'P5AST::listop';
+package P5AST::op_arrayjoin; 	@ISA = 'P5AST::listop';
 package P5AST::op_say; 	        @ISA = 'P5AST::listop';
+package P5AST::op_listfirst; 	@ISA = 'P5AST::listop';
 package P5AST::op_list; 	@ISA = 'P5AST::listop';
 package P5AST::op_lslice; 	@ISA = 'P5AST::binop';
 package P5AST::op_anonlist; 	@ISA = 'P5AST::listop';
+package P5AST::op_anonarray; 	@ISA = 'P5AST::op_anonlist';
+package P5AST::op_enter_anonarray_assign; 	@ISA = 'P5AST::baseop';
 package P5AST::op_anonhash; 	@ISA = 'P5AST::listop';
+package P5AST::op_enter_anonhash_assign; 	@ISA = 'P5AST::baseop';
 package P5AST::op_splice; 	@ISA = 'P5AST::listop';
 package P5AST::op_push; 	@ISA = 'P5AST::listop';
 package P5AST::op_pop; 		@ISA = 'P5AST::baseop_unop';
@@ -542,3 +560,4 @@ package P5AST::preplus;		@ISA = 'P5AST::baseop';
 package P5AST::doblock;		@ISA = 'P5AST::baseop';
 package P5AST::cfor;		@ISA = 'P5AST::baseop';
 package P5AST::pmop;		@ISA = 'P5AST::baseop';
+package P5AST::op_root;		@ISA = 'P5AST::rootop';
