@@ -40,31 +40,6 @@ Perl_mro_meta_init(pTHX_ HV* stash)
     return newmeta;
 }
 
-#if defined(USE_ITHREADS)
-
-/* for sv_dup on new threads */
-struct mro_meta*
-Perl_mro_meta_dup(pTHX_ struct mro_meta* smeta, CLONE_PARAMS* param)
-{
-    struct mro_meta* newmeta;
-
-    PERL_ARGS_ASSERT_MRO_META_DUP;
-
-    Newx(newmeta, 1, struct mro_meta);
-    Copy(smeta, newmeta, 1, struct mro_meta);
-
-    if (newmeta->mro_linear_c3)
-	newmeta->mro_linear_c3
-	    = (AV*) SvREFCNT_inc(sv_dup((SV*)newmeta->mro_linear_c3, param));
-    if (newmeta->mro_nextmethod)
-	newmeta->mro_nextmethod
-	    = (HV*) SvREFCNT_inc(sv_dup((SV*)newmeta->mro_nextmethod, param));
-
-    return newmeta;
-}
-
-#endif /* USE_ITHREADS */
-
 /*
 =for apidoc mro_get_linear_isa_c3
 
@@ -155,11 +130,11 @@ S_mro_get_linear_isa_c3(pTHX_ HV* stash, I32 level)
 		else {
 		    /* recursion */
 		    AV* const isa_lin = mro_get_linear_isa_c3(isa_item_stash, level + 1);
-		    av_push(seqs, SvREFCNT_inc_simple_NN((SV*)isa_lin));
+		    av_push(seqs, SvREFCNT_inc_NN((SV*)isa_lin));
 		}
 	    }
         }
-        av_push(seqs, SvREFCNT_inc_simple_NN((SV*)isa));
+        av_push(seqs, SvREFCNT_inc_NN((SV*)isa));
 
         /* This builds "heads", which as an array of integer array
            indices, one per seq, which point at the virtual "head"
@@ -270,7 +245,7 @@ S_mro_get_linear_isa_c3(pTHX_ HV* stash, I32 level)
             if(!winner) {
                 /* we have to do some cleanup before we croak */
 
-                SvREFCNT_dec(retval);
+                AvREFCNT_dec(retval);
                 Safefree(heads);
 
                 Perl_croak(aTHX_ "Inconsistent hierarchy during C3 merge of class '%s': "
@@ -518,20 +493,6 @@ Perl_mro_method_changed_in(pTHX_ HV *stash)
     }
 }
 
-/* These two are static helpers for next::method and friends,
-   and re-implement a bunch of the code from pp_caller() in
-   a more efficient manner for this particular usage.
-*/
-
-STATIC I32
-__dopoptosub_at(const PERL_CONTEXT *cxstk, I32 startingblock) {
-    I32 i;
-    for (i = startingblock; i >= 0; i--) {
-        if(CxTYPE((PERL_CONTEXT*)(&cxstk[i])) == CXt_SUB) return i;
-    }
-    return i;
-}
-
 #include "XSUB.h"
 
 XS(XS_mro_get_linear_isa);
@@ -556,7 +517,6 @@ Perl_boot_core_mro(pTHX)
     newXSproto("mro::invalidate_all_method_caches", XS_mro_invalidate_method_caches, file, "");
     newXSproto("mro::method_changed_in", XS_mro_method_changed_in, file, "$");
     newXSproto("mro::get_pkg_gen", XS_mro_get_pkg_gen, file, "$");
-    newXS("mro::_nextcan", XS_mro_nextcan, file);
 }
 
 XS(XS_mro_get_linear_isa) {
@@ -715,200 +675,6 @@ XS(XS_mro_get_pkg_gen)
     return;
 }
 
-XS(XS_mro_nextcan)
-{
-    dVAR;
-    dXSARGS;
-    SV* self = ST(0);
-    const I32 throw_nomethod = SvIVX(ST(1));
-    register I32 cxix = cxstack_ix;
-    register const PERL_CONTEXT *ccstack = cxstack;
-    const PERL_SI *top_si = PL_curstackinfo;
-    HV* selfstash;
-    SV *stashname;
-    const char *fq_subname;
-    const char *subname;
-    STRLEN stashname_len;
-    STRLEN subname_len;
-    SV* sv;
-    GV** gvp;
-    AV* linear_av;
-    SV** linear_svp;
-    const char *hvname;
-    I32 entries;
-    struct mro_meta* selfmeta;
-    HV* nmcache;
-    I32 i;
-
-    PERL_UNUSED_ARG(cv);
-
-    SP -= items;
-
-    if(sv_isobject(self))
-        selfstash = SvSTASH(SvRV(self));
-    else
-        selfstash = gv_stashsv(self, GV_ADD);
-
-    assert(selfstash);
-
-    hvname = HvNAME_get(selfstash);
-    if (!hvname)
-        Perl_croak(aTHX_ "Can't use anonymous symbol table for method lookup");
-
-    /* This block finds the contextually-enclosing fully-qualified subname,
-       much like looking at (caller($i))[3] until you find a real sub that
-       isn't ANON, etc (also skips over pureperl next::method, etc) */
-    for(i = 0; i < 2; i++) {
-        cxix = __dopoptosub_at(ccstack, cxix);
-        for (;;) {
-	    GV* cvgv;
-	    STRLEN fq_subname_len;
-
-            /* we may be in a higher stacklevel, so dig down deeper */
-            while (cxix < 0) {
-                if(top_si->si_type == PERLSI_MAIN)
-                    Perl_croak(aTHX_ "next::method/next::can/maybe::next::method must be used in method context");
-                top_si = top_si->si_prev;
-                ccstack = top_si->si_cxstack;
-                cxix = __dopoptosub_at(ccstack, top_si->si_cxix);
-            }
-
-            if(CxTYPE((PERL_CONTEXT*)(&ccstack[cxix])) != CXt_SUB
-              || (PL_DBsub && GvCV(PL_DBsub) && ccstack[cxix].blk_sub.cv == GvCV(PL_DBsub))) {
-                cxix = __dopoptosub_at(ccstack, cxix - 1);
-                continue;
-            }
-
-            {
-                const I32 dbcxix = __dopoptosub_at(ccstack, cxix - 1);
-                if (PL_DBsub && GvCV(PL_DBsub) && dbcxix >= 0 && ccstack[dbcxix].blk_sub.cv == GvCV(PL_DBsub)) {
-                    if(CxTYPE((PERL_CONTEXT*)(&ccstack[dbcxix])) != CXt_SUB) {
-                        cxix = dbcxix;
-                        continue;
-                    }
-                }
-            }
-
-            cvgv = CvGV(ccstack[cxix].blk_sub.cv);
-
-            if(!isGV(cvgv)) {
-                cxix = __dopoptosub_at(ccstack, cxix - 1);
-                continue;
-            }
-
-            /* we found a real sub here */
-            sv = sv_2mortal(newSV(0));
-
-            gv_efullname3(sv, cvgv, NULL);
-
-            fq_subname = SvPVX(sv);
-            fq_subname_len = SvCUR(sv);
-
-            subname = strrchr(fq_subname, ':');
-            if(!subname)
-                Perl_croak(aTHX_ "next::method/next::can/maybe::next::method cannot find enclosing method");
-
-            subname++;
-            subname_len = fq_subname_len - (subname - fq_subname);
-            if(subname_len == 8 && strEQ(subname, "__ANON__")) {
-                cxix = __dopoptosub_at(ccstack, cxix - 1);
-                continue;
-            }
-            break;
-        }
-        cxix--;
-    }
-
-    /* If we made it to here, we found our context */
-
-    /* Initialize the next::method cache for this stash
-       if necessary */
-    selfmeta = HvMROMETA(selfstash);
-    if(!(nmcache = selfmeta->mro_nextmethod)) {
-        nmcache = selfmeta->mro_nextmethod = newHV();
-    }
-    else { /* Use the cached coderef if it exists */
-	HE* cache_entry = hv_fetch_ent(nmcache, sv, 0, 0);
-	if (cache_entry) {
-	    SV* const val = HeVAL(cache_entry);
-	    if(val == &PL_sv_undef) {
-		if(throw_nomethod)
-		    Perl_croak(aTHX_ "No next::method '%s' found for %s", subname, hvname);
-                XSRETURN_EMPTY;
-	    }
-	    mXPUSHs(newRV_inc(val));
-            XSRETURN(1);
-	}
-    }
-
-    /* beyond here is just for cache misses, so perf isn't as critical */
-
-    stashname_len = subname - fq_subname - 2;
-    stashname = newSVpvn_flags(fq_subname, stashname_len, SVs_TEMP);
-
-    linear_av = mro_get_linear_isa_c3(selfstash, 0); /* has ourselves at the top of the list */
-
-    linear_svp = AvARRAY(linear_av);
-    entries = AvFILLp(linear_av) + 1;
-
-    /* Walk down our MRO, skipping everything up
-       to the contextually enclosing class */
-    while (entries--) {
-        SV * const linear_sv = *linear_svp++;
-        assert(linear_sv);
-        if(sv_eq(linear_sv, stashname))
-            break;
-    }
-
-    /* Now search the remainder of the MRO for the
-       same method name as the contextually enclosing
-       method */
-    if(entries > 0) {
-        while (entries--) {
-            SV * const linear_sv = *linear_svp++;
-	    HV* curstash;
-	    GV* candidate;
-	    CV* cand_cv;
-
-            assert(linear_sv);
-            curstash = gv_stashsv(linear_sv, FALSE);
-
-            if (!curstash) {
-                if (ckWARN(WARN_SYNTAX))
-                    Perl_warner(aTHX_ packWARN(WARN_SYNTAX), "Can't locate package %"SVf" for @%s::ISA",
-                        (void*)linear_sv, hvname);
-                continue;
-            }
-
-            assert(curstash);
-
-            gvp = (GV**)hv_fetch(curstash, subname, subname_len, 0);
-            if (!gvp) continue;
-
-            candidate = *gvp;
-            assert(candidate);
-
-            if (SvTYPE(candidate) != SVt_PVGV)
-                gv_init(candidate, curstash, subname, subname_len, TRUE);
-
-            /* Notably, we only look for real entries, not method cache
-               entries, because in C3 the method cache of a parent is not
-               valid for the child */
-            if (SvTYPE(candidate) == SVt_PVGV && (cand_cv = GvCV(candidate)) && !GvCVGEN(candidate)) {
-                SvREFCNT_inc_simple_void_NN((SV*)cand_cv);
-                (void)hv_store_ent(nmcache, newSVsv(sv), (SV*)cand_cv, 0);
-                mXPUSHs(newRV_inc((SV*)cand_cv));
-                XSRETURN(1);
-            }
-        }
-    }
-
-    (void)hv_store_ent(nmcache, newSVsv(sv), &PL_sv_undef, 0);
-    if(throw_nomethod)
-        Perl_croak(aTHX_ "No next::method '%s' found for %s", subname, hvname);
-    XSRETURN_EMPTY;
-}
-
 /*
  * Local variables:
  * c-indentation-style: bsd
