@@ -453,9 +453,6 @@ EXTCONST regexp_engine PL_core_reg_engine = {
         Perl_reg_named_buff,
         Perl_reg_named_buff_iter,
         Perl_reg_qr_package,
-#if defined(USE_ITHREADS)        
-        Perl_regdupe_internal
-#endif        
 };
 #endif /* DOINIT */
 #endif /* PLUGGABLE_RE_EXTENSION */
@@ -740,15 +737,12 @@ re.pm, especially to the documentation.
         | RE_DEBUG_EXECUTE_TRIE )) x )
 
 /* initialization */
-/* get_sv() can return NULL during global destruction. */
 #define GET_RE_DEBUG_FLAGS DEBUG_r({ \
-        SV * re_debug_flags_sv = NULL; \
-        re_debug_flags_sv = get_sv(RE_DEBUG_FLAGS, 1); \
-        if (re_debug_flags_sv) { \
-            if (!SvIOK(re_debug_flags_sv)) \
-                sv_setuv(re_debug_flags_sv, RE_DEBUG_COMPILE_DUMP | RE_DEBUG_EXECUTE_MASK ); \
-            re_debug_flags=SvIV(re_debug_flags_sv); \
-        }\
+	SV * re_debug_flags_sv = sv_2mortal(newSV(0)); \
+        Perl_magic_get(RE_DEBUG_FLAGS, re_debug_flags_sv);	\
+        if (!SvIOK(re_debug_flags_sv)) \
+            sv_setuv(re_debug_flags_sv, RE_DEBUG_COMPILE_DUMP | RE_DEBUG_EXECUTE_MASK ); \
+        re_debug_flags=SvIV(re_debug_flags_sv); \
 })
 
 #ifdef DEBUGGING
