@@ -1,6 +1,6 @@
 package Moped::Msg;
-use strict;
-use vars < qw(@ISA $VERSION);
+
+our (@ISA, $VERSION);
 require DynaLoader;
 @ISA = qw(DynaLoader);
 $VERSION = '0.01';
