@@ -1,7 +1,6 @@
 
 use lib 't';
  
-use strict;
 use warnings;
 use bytes;
 
@@ -26,9 +25,8 @@ sub run
     my $Error           = getErrorRef($CompressClass);
     my $UnError         = getErrorRef($UncompressClass);
 
-    my $AnyConstruct = "IO::Uncompress::{$AnyClass}" ;
-    no strict 'refs';
-    my $AnyError = \${Symbol::fetch_glob( "IO::Uncompress::{$AnyClass}::{$AnyClass}Error") };
+    my $AnyConstruct = "IO::Uncompress::$($AnyClass)" ;
+    my $AnyError = \${Symbol::fetch_glob( "IO::Uncompress::$($AnyClass)::$($AnyClass)Error") };
 
     for my $trans (@( 0, 1) )
     {
@@ -54,13 +52,13 @@ sub run
                 $input = \$buffer;
             }
 
-            {
+            do {
                 my $unc = $AnyConstruct-> new( $input, Transparent => $trans,
                                            RawInflate => 1,
                                            Append => 1)  ;
 
                 ok $unc, "  Created $AnyClass object" 
-                    or print "# $$AnyError\n";
+                    or print $^STDOUT, "# $$AnyError\n";
                 my $uncomp ;
                 1 while  $unc->read($uncomp) +> 0 ;
                 #ok $unc->read($uncomp) > 0 
@@ -71,15 +69,15 @@ sub run
                 #ok $unc->type eq $Type;
 
                 is $uncomp, $string, "  expected output" ;
-            }
+            };
 
-            {
+            do {
                 my $unc = $AnyConstruct-> new( $input, Transparent => $trans,
                                            RawInflate => 1,
                                            Append => 1)  ;
 
                 ok $unc, "  Created $AnyClass object" 
-                    or print "# $$AnyError\n";
+                    or print $^STDOUT, "# $$AnyError\n";
                 my $uncomp ;
                 1 while  $unc->read($uncomp, 100) +> 0 ;
                 #ok $unc->read($uncomp) > 0 
@@ -90,7 +88,7 @@ sub run
                 #ok $unc->type eq $Type;
 
                 is $uncomp, $string, "  expected output" ;
-            }
+            };
         }
     }
 }
