@@ -16,6 +16,8 @@
 # In this file, we use the latter "Baby Perl" approach, and increment
 # will be worked over by t/op/inc.t
 
+use env;
+
 our ($Level, $TODO, $NO_ENDING);
 
 $Level = 1;
@@ -28,13 +30,13 @@ $NO_ENDING = 0;
 
 # Use this instead of print to avoid interference while testing globals.
 sub _print {
-    local($\, $", $,) = (undef, ' ', '');
-    print STDOUT < @_;
+    local@($^OUTPUT_RECORD_SEPARATOR, $^OUTPUT_FIELD_SEPARATOR) = @(undef, '');
+    print $^STDOUT, < @_;
 }
 
 sub _print_stderr {
-    local($\, $", $,) = (undef, ' ', '');
-    print STDERR < @_;
+    local@($^OUTPUT_RECORD_SEPARATOR, $^OUTPUT_FIELD_SEPARATOR) = @(undef, '');
+    print $^STDERR, < @_;
 }
 
 sub plan {
@@ -47,7 +49,7 @@ sub plan {
 	}
     } else {
 	my %plan = %( < @_ );
-	$n = %plan{tests};
+	$n = %plan{?tests};
     }
     _print "1..$n\n" unless $noplan;
     $planned = $n;
@@ -69,9 +71,9 @@ END {
 # messages
 sub _diag {
     return unless (nelems @_);
-    my @mess = map { m/^#/ ? "$_\n" : "# $_\n" }
- map { < split m/\n/ } @_;
-    my $func = $TODO ? \&_print : \&_print_stderr;
+    my @mess = map { m/^#/ ?? "$_\n" !! "# $_\n" },
+    @+: map { split m/\n/ }, @_;
+    my $func = $TODO ?? \&_print !! \&_print_stderr;
     $func->(< @mess);
 }
 
@@ -79,9 +81,15 @@ sub diag {
     _diag(< @_);
 }
 
+sub info {
+    my @mess = map { m/^#/ ?? "$_\n" !! "# $_\n" },
+      @+: map { split m/\n/ }, @_;
+    _print(< @mess);
+}
+
 sub skip_all {
     if ((nelems @_)) {
-	_print "1..0 # Skipped: {join ' ',@_}\n";
+	_print "1..0 # Skipped: $(join ' ',@_)\n";
     } else {
 	_print "1..0\n";
     }
@@ -89,16 +97,16 @@ sub skip_all {
 }
 
 sub _ok {
-    my ($pass, $where, $name, < @mess) = < @_;
+    my @($pass, $where, ?$name, @< @mess) =  @_;
     # Do not try to microoptimize by factoring out the "not ".
     # VMS will avenge.
     my $out;
     if ($name) {
         # escape out '#' or it will interfere with '# skip' and such
         $name =~ s/#/\\#/g;
-	$out = $pass ? "ok $test - $name" : "not ok $test - $name";
+	$out = $pass ?? "ok $test - $name" !! "not ok $test - $name";
     } else {
-	$out = $pass ? "ok $test" : "not ok $test";
+	$out = $pass ?? "ok $test" !! "not ok $test";
     }
 
     $out .= " # TODO $TODO" if $TODO;
@@ -122,8 +130,7 @@ sub _where {
 }
 
 # DON'T use this for matches. Use like() instead.
-sub ok ($@) {
-    my ($pass, $name, < @mess) = < @_;
+sub ok ($pass, ?$name, @< @mess) {
     _ok($pass, _where(), $name, < @mess);
 }
 
@@ -140,7 +147,7 @@ sub _qq {
 # keys are the codes \n etc map to, values are 2 char strings such as \n
 my %backslash_escape;
 foreach my $x (split m//, q|nrtfa\'"|) {
-    %backslash_escape{ord eval "\"\\$x\""} = "\\$x";
+    %backslash_escape{+ord eval "\"\\$x\""} = "\\$x";
 }
 # A way to display scalars containing control characters and Unicode.
 # Trying to avoid setting $_, or relying on local $_ to work.
@@ -148,8 +155,7 @@ sub display {
     return dump::view(@_[0]);
 }
 
-sub is ($$@) {
-    my ($got, $expected, $name, < @mess) = < @_;
+sub is ($got, $expected, ?$name, @< @mess) {
 
     my $pass;
     if( !defined $got || !defined $expected ) {
@@ -160,7 +166,7 @@ sub is ($$@) {
         $pass = $got \== $expected;
     }
     else {
-        local $@;
+        local $^EVAL_ERROR = undef;
         $pass = try { $got eq $expected };
     }
 
@@ -171,9 +177,7 @@ sub is ($$@) {
     _ok($pass, _where(), $name, < @mess);
 }
 
-sub isnt ($$@) {
-    my ($got, $isnt, $name, < @mess) = < @_;
-
+sub isnt ($got, $isnt, ?$name, @< @mess) {
     my $pass;
     if( !defined $got || !defined $isnt ) {
         # undef only matches undef
@@ -193,16 +197,14 @@ sub isnt ($$@) {
     _ok($pass, _where(), $name, < @mess);
 }
 
-sub cmp_ok ($$$@) {
-    my($got, $type, $expected, $name, < @mess) = < @_;
-
+sub cmp_ok ($got, $type, $expected, ?$name, @< @mess) {
     my $pass;
-    {
-        local $^W = 0;
-        local($@,$!);   # don't interfere with $@
+    do {
+        local $^WARNING = 0;
+        local($^EVAL_ERROR,$^OS_ERROR);   # don't interfere with $@
                         # eval() sometimes resets $!
         $pass = eval "\$got $type \$expected";
-    }
+    };
     unless ($pass) {
         # It seems Irix long doubles can have 2147483648 and 2147483648
         # that stringify to the same thing but are acutally numerically
@@ -227,8 +229,7 @@ sub cmp_ok ($$$@) {
 # otherwise $range is a fractional error.
 # Here $range must be numeric, >= 0
 # Non numeric ranges might be a useful future extension. (eg %)
-sub within ($$$@) {
-    my ($got, $expected, $range, $name, < @mess) = < @_;
+sub within ($got, $expected, $range, $name, @< @mess) {
     my $pass;
     if (!defined $got or !defined $expected or !defined $range) {
         # This is a fail, but doesn't need extra diagnostics
@@ -260,18 +261,17 @@ sub within ($$$@) {
 
 # Note: this isn't quite as fancy as Test::More::like().
 
-sub like   ($$@) { like_yn (0,< @_) }; # 0 for -
-sub unlike ($$@) { like_yn (1,< @_) }; # 1 for un-
+sub like   (@< @a) { like_yn (0,< @a) }; # 0 for -
+sub unlike (@< @a) { like_yn (1,< @a) }; # 1 for un-
 
-sub like_yn ($$$@) {
-    my ($flip, $got, $expected, $name, < @mess) = < @_;
+sub like_yn ($flip, $got, $expected, ?$name, @< @mess) {
     my $pass;
     $pass = $got =~ m/$expected/ if !$flip;
     $pass = $got !~ m/$expected/ if $flip;
     unless ($pass) {
 	unshift(@mess, "#      got '$got'\n",
 		$flip
-		? "# expected !~ m/$expected/\n" : "# expected m/$expected/\n");
+		?? "# expected !~ m/$expected/\n" !! "# expected m/$expected/\n");
     }
     local $Level = $Level + 1;
     _ok($pass, _where(), $name, < @mess);
@@ -300,29 +300,29 @@ sub next_test {
 # be compatible with Test::More::skip().
 sub skip {
     my $why = shift;
-    my $n    = (nelems @_) ? shift : 1;
+    my $n    = (nelems @_) ?? shift !! 1;
     for (1..$n) {
         _print "ok $test # skip: $why\n";
         $test = $test + 1;
     }
-    local $^W = 0;
+    local $^WARNING = 0;
     last SKIP;
 }
 
 sub todo_skip {
     my $why = shift;
-    my $n   = (nelems @_) ? shift : 1;
+    my $n   = (nelems @_) ?? shift !! 1;
 
     for (1..$n) {
         _print "not ok $test # TODO & SKIP: $why\n";
         $test = $test + 1;
     }
-    local $^W = 0;
+    local $^WARNING = 0;
     last TODO;
 }
 
 sub eq_array {
-    my ($ra, $rb) = < @_;
+    my @($ra, $rb) =  @_;
     return 0 unless (nelems @$ra) == nelems(@$rb);
     for my $i (0..(nelems @$ra)-1) {
 	next     if !defined $ra->[$i] && !defined $rb->[$i];
@@ -334,14 +334,14 @@ sub eq_array {
 }
 
 sub eq_hash {
-  my ($orig, $suspect) = < @_;
+  my @($orig, $suspect) =  @_;
   my $fail;
-  while (my ($key, $value) = each %$suspect) {
+  while (my @(?$key, ?$value) =@( each %$suspect)) {
     # Force a hash recompute if this perl's internals can cache the hash key.
     $key = "" . $key;
     if (exists $orig->{$key}) {
-      if ($orig->{$key} ne $value) {
-        _print "# key ", _qq($key), " was ", _qq($orig->{$key}),
+      if ($orig->{?$key} ne $value) {
+        _print "# key ", _qq($key), " was ", _qq($orig->{?$key}),
                      " now ", _qq($value), "\n";
         $fail = 1;
       }
@@ -355,26 +355,24 @@ sub eq_hash {
     # Force a hash recompute if this perl's internals can cache the hash key.
     $_ = "" . $_;
     next if (exists $suspect->{$_});
-    _print "# key ", < _qq($_), " was ", < _qq($orig->{$_}), " now missing.\n";
+    _print "# key ", < _qq($_), " was ", < _qq($orig->{?$_}), " now missing.\n";
     $fail = 1;
   }
   !$fail;
 }
 
-sub require_ok ($) {
-    my ($require) = < @_;
+sub require_ok ($require) {
     eval <<REQUIRE_OK;
 require $require;
 REQUIRE_OK
-    _ok(!$@, _where(), "require $require");
+    _ok(!$^EVAL_ERROR, _where(), "require $require");
 }
 
-sub use_ok ($) {
-    my ($use) = < @_;
+sub use_ok ($use) {
     eval <<USE_OK;
 use $use;
 USE_OK
-    _ok(!$@, _where(), "use $use");
+    _ok(!$^EVAL_ERROR, _where(), "use $use");
 }
 
 # runperl - Runs a separate perl interpreter.
@@ -389,14 +387,14 @@ USE_OK
 #   args     => [ command-line arguments to the perl program ]
 #   verbose  => print the command line
 
-my $is_mswin    = $^O eq 'MSWin32';
-my $is_netware  = $^O eq 'NetWare';
-my $is_macos    = $^O eq 'MacOS';
-my $is_vms      = $^O eq 'VMS';
-my $is_cygwin   = $^O eq 'cygwin';
+my $is_mswin    = $^OS_NAME eq 'MSWin32';
+my $is_netware  = $^OS_NAME eq 'NetWare';
+my $is_macos    = $^OS_NAME eq 'MacOS';
+my $is_vms      = $^OS_NAME eq 'VMS';
+my $is_cygwin   = $^OS_NAME eq 'cygwin';
 
 sub _quote_args {
-    my ($runperl, $args) = < @_;
+    my @($runperl, $args) =  @_;
 
     foreach ( @$args) {
 	# In VMS protect with doublequotes because otherwise
@@ -408,35 +406,35 @@ sub _quote_args {
 
 sub _create_runperl { # Create the string to qx in runperl().
     my %args = %( < @_ );
-    my $runperl = $^X =~ m/\s/ ? qq{"$^X"} : $^X;
+    my $runperl = $^EXECUTABLE_NAME =~ m/\s/ ?? qq{"$^EXECUTABLE_NAME"} !! $^EXECUTABLE_NAME;
     #- this allows, for example, to set PERL_RUNPERL_DEBUG=/usr/bin/valgrind
-    if (%ENV{PERL_RUNPERL_DEBUG}) {
-	$runperl = "%ENV{PERL_RUNPERL_DEBUG} $runperl";
+    if (env::var('PERL_RUNPERL_DEBUG')) {
+	$runperl = "$(env::var('PERL_RUNPERL_DEBUG')) $runperl";
     }
-    unless (%args{nolib}) {
+    unless (%args{?nolib}) {
 	if ($is_macos) {
 	    $runperl .= ' -I::lib';
 	    # Use UNIX style error messages instead of MPW style.
-	    $runperl .= ' -MMac::err=unix' if %args{stderr};
+	    $runperl .= ' -MMac::err=unix' if %args{?stderr};
 	}
 	else {
 	    $runperl .= ' "-I../lib"'; # doublequotes because of VMS
 	}
     }
-    if (%args{switches}) {
+    if (%args{?switches}) {
 	local $Level = 2;
 	die "test.pl:runperl(): 'switches' must be an ARRAYREF " . _where()
-	    unless ref %args{switches} eq "ARRAY";
-	_quote_args(\$runperl, %args{switches});
+	    unless ref %args{?switches} eq "ARRAY";
+	_quote_args(\$runperl, %args{?switches});
     }
-    if (defined %args{prog}) {
+    if (defined %args{?prog}) {
 	die "test.pl:runperl(): both 'prog' and 'progs' cannot be used " . _where()
-	    if defined %args{progs};
-        %args{progs} = \@(%args{prog})
+	    if defined %args{?progs};
+        %args{+progs} = \@(%args{?prog})
     }
-    if (defined %args{progs}) {
+    if (defined %args{?progs}) {
 	die "test.pl:runperl(): 'progs' must be an ARRAYREF " . _where()
-	    unless ref %args{progs} eq "ARRAY";
+	    unless ref %args{?progs} eq "ARRAY";
         foreach my $prog ( @{%args{progs}}) {
             if ($is_mswin || $is_netware || $is_vms) {
                 $runperl .= qq ( -e "$prog" );
@@ -445,31 +443,31 @@ sub _create_runperl { # Create the string to qx in runperl().
                 $runperl .= qq ( -e '$prog' );
             }
         }
-    } elsif (defined %args{progfile}) {
-	$runperl .= qq( "%args{progfile}");
+    } elsif (defined %args{?progfile}) {
+	$runperl .= qq( "%args{?progfile}");
     } else {
 	# You probaby didn't want to be sucking in from the upstream stdin
 	die "test.pl:runperl(): none of prog, progs, progfile, args, "
 	    . " switches or stdin specified"
-	    unless defined %args{args} or defined %args{switches}
-		or defined %args{stdin};
+	    unless defined %args{?args} or defined %args{?switches}
+		or defined %args{?stdin};
     }
-    if (defined %args{stdin}) {
+    if (defined %args{?stdin}) {
 	# so we don't try to put literal newlines and crs onto the
 	# command line.
-	%args{stdin} =~ s/\n/\\n/g;
-	%args{stdin} =~ s/\r/\\r/g;
+	%args{+stdin} =~ s/\n/\\n/g;
+	%args{+stdin} =~ s/\r/\\r/g;
 
 	if ($is_mswin || $is_netware || $is_vms) {
-	    $runperl = qq{$^X -e "print qq(} .
-		%args{stdin} . q{)" | } . $runperl;
+	    $runperl = qq{$^EXECUTABLE_NAME -e "print \\\$^STDOUT, qq(} .
+		%args{?stdin} . q{)" | } . $runperl;
 	}
 	elsif ($is_macos) {
 	    # MacOS can only do two processes under MPW at once;
 	    # the test itself is one; we can't do two more, so
 	    # write to temp file
-	    my $stdin = qq{$^X -e 'print qq(} . %args{stdin} . qq{)' > teststdin; };
-	    if (%args{verbose}) {
+	    my $stdin = qq{$^EXECUTABLE_NAME -e 'print \$^STDOUT, qq(} . %args{?stdin} . qq{)' > teststdin; };
+	    if (%args{?verbose}) {
 		my $stdindisplay = $stdin;
 		$stdindisplay =~ s/\n/\n\#/g;
 		_print_stderr "# $stdindisplay\n";
@@ -478,16 +476,16 @@ sub _create_runperl { # Create the string to qx in runperl().
 	    $runperl .= q{ < teststdin };
 	}
 	else {
-	    $runperl = qq{$^X -e 'print qq(} .
-		%args{stdin} . q{)' | } . $runperl;
+	    $runperl = qq{$^EXECUTABLE_NAME -e 'print \$^STDOUT, qq(} .
+		%args{?stdin} . q{)' | } . $runperl;
 	}
     }
-    if (defined %args{args}) {
-	_quote_args(\$runperl, %args{args});
+    if (defined %args{?args}) {
+	_quote_args(\$runperl, %args{?args});
     }
-    $runperl .= ' 2>&1'          if  %args{stderr} && !$is_macos;
-    $runperl .= " \x[B3] Dev:Null" if !%args{stderr} &&  $is_macos;
-    if (%args{verbose}) {
+    $runperl .= ' 2>&1'          if  %args{?stderr} && !$is_macos;
+    $runperl .= " \x[B3] Dev:Null" if !%args{?stderr} &&  $is_macos;
+    if (%args{?verbose}) {
 	my $runperldisplay = $runperl;
 	$runperldisplay =~ s/\n/\n\#/g;
 	_print_stderr "# $runperldisplay\n";
@@ -498,45 +496,8 @@ sub _create_runperl { # Create the string to qx in runperl().
 sub runperl {
     die "test.pl:runperl() does not take a hashref"
 	if ref @_[0] and ref @_[0] eq 'HASH';
-    my $runperl = &_create_runperl;
-    my $result;
-
-    my $tainted = $^TAINT;
-    my %args = %( < @_ );
-    exists %args{switches} && grep m/^-T$/, @{%args{switches}} and $tainted = $tainted + 1;
-
-    if ($tainted) {
-	# We will assume that if you're running under -T, you really mean to
-	# run a fresh perl, so we'll brute force launder everything for you
-	my $sep;
-
-        our %Config;
-	eval "require Config; Config->import";
-	if ($@) {
-	    warn "test.pl had problems loading Config: $@";
-	    $sep = ':';
-	} else {
-	    $sep = %Config{path_sep};
-	}
-
-	my @keys = grep {exists %ENV{$_}} qw(CDPATH IFS ENV BASH_ENV);
-	local %ENV{[ @keys]} = @();
-	# Untaint, plus take out . and empty string:
-	local %ENV{'DCL$PATH'} = $1 if $is_vms && (%ENV{'DCL$PATH'} =~ m/(.*)/s);
-	%ENV{PATH} =~ m/(.*)/s;
-	local %ENV{PATH} =
-	    join $sep, grep { $_ ne "" and $_ ne "." and -d $_ and
-		($is_mswin or $is_vms or !(stat && @(stat '_')[2]^&^0022)) }
-		    split quotemeta ($sep), $1;
-	%ENV{PATH} .= "$sep/bin" if $is_cygwin;  # Must have /bin under Cygwin
-
-	$runperl =~ m/(.*)/s;
-	$runperl = $1;
-
-	$result = `$runperl`;
-    } else {
-	$result = `$runperl`;
-    }
+    my $runperl = _create_runperl( < @_ );
+    my $result = `$runperl`;
     $result =~ s/\n\n/\n/ if $is_vms; # XXX pipes sometimes double these
     return $result;
 }
@@ -544,7 +505,7 @@ sub runperl {
 *run_perl = \&runperl; # Nice alias.
 
 sub DIE {
-    _print_stderr "# {join ' ',@_}\n";
+    _print_stderr "# $(join ' ',@_)\n";
     exit 1;
 }
 
@@ -552,19 +513,19 @@ sub DIE {
 my $Perl;
 sub which_perl {
     unless (defined $Perl) {
-	$Perl = $^X;
+	$Perl = $^EXECUTABLE_NAME;
 
 	# VMS should have 'perl' aliased properly
-	return $Perl if $^O eq 'VMS';
+	return $Perl if $^OS_NAME eq 'VMS';
 
 	my $exe;
         our %Config;
 	eval "require Config; Config->import";
-	if ($@) {
-	    warn "test.pl had problems loading Config: $@";
+	if ($^EVAL_ERROR) {
+	    warn "test.pl had problems loading Config: $^EVAL_ERROR";
 	    $exe = '';
 	} else {
-	    $exe = %Config{_exe};
+	    $exe = %Config{?_exe};
 	}
        $exe = '' unless defined $exe;
 
@@ -575,8 +536,8 @@ sub which_perl {
 	if ($Perl =~ m/^perl\Q$exe\E$/i) {
 	    my $perl = "perl$exe";
 	    eval "require File::Spec";
-	    if ($@) {
-		warn "test.pl had problems loading File::Spec: $@";
+	    if ($^EVAL_ERROR) {
+		warn "test.pl had problems loading File::Spec: $^EVAL_ERROR";
 		$Perl = "./$perl";
 	    } else {
 		$Perl = 'File::Spec'->catfile( <'File::Spec'->curdir(), $perl);
@@ -590,10 +551,10 @@ sub which_perl {
 	    $Perl .= $exe;
 	}
 
-	warn "which_perl: cannot find $Perl from $^X" unless -f $Perl;
+	warn "which_perl: cannot find $Perl from $^EXECUTABLE_NAME" unless -f $Perl;
 
 	# For subcommands to use.
-	%ENV{PERLEXE} = $Perl;
+	env::var('PERLEXE' ) = $Perl;
     }
     return $Perl;
 }
@@ -601,7 +562,7 @@ sub which_perl {
 sub unlink_all {
     foreach my $file ( @_) {
         1 while unlink $file;
-        _print_stderr "# Couldn't unlink '$file': $!\n" if -f $file;
+        _print_stderr "# Couldn't unlink '$file': $^OS_ERROR\n" if -f $file;
     }
 }
 
@@ -619,16 +580,16 @@ END { unlink_all $tmpfile }
 #
 
 sub _fresh_perl {
-    my($prog, $resolve, $runperl_args, $name) = < @_;
+    my@($prog, $resolve, $runperl_args, $name) =  @_;
 
     $runperl_args ||= \%();
-    $runperl_args->{progfile} = $tmpfile;
-    $runperl_args->{stderr} = 1;
+    $runperl_args->{+progfile} = $tmpfile;
+    $runperl_args->{+stderr} = 1;
 
-    open TEST, ">", "$tmpfile" or die "Cannot open $tmpfile: $!";
+    open my $test_fh, ">", "$tmpfile" or die "Cannot open $tmpfile: $^OS_ERROR";
 
     # VMS adjustments
-    if( $^O eq 'VMS' ) {
+    if( $^OS_NAME eq 'VMS' ) {
         $prog =~ s#/dev/null#NL:#;
 
         # VMS file locking
@@ -636,11 +597,11 @@ sub _fresh_perl {
                   {if (-e _ and -f _)}
     }
 
-    print TEST $prog;
-    close TEST or die "Cannot close $tmpfile: $!";
+    print $test_fh, $prog;
+    close $test_fh or die "Cannot close $tmpfile: $^OS_ERROR";
 
     my $results = runperl(< %$runperl_args);
-    my $status = $?;
+    my $status = $^CHILD_ERROR;
 
     # Clean up the results into something a bit more predictable.
     $results =~ s/\n+$//;
@@ -651,7 +612,7 @@ sub _fresh_perl {
     # various yaccs may or may not capitalize 'syntax'.
     $results =~ s/^(syntax|parse) error/syntax error/mig;
 
-    if ($^O eq 'VMS') {
+    if ($^OS_NAME eq 'VMS') {
         # some tests will trigger VMS messages that won't be expected
         $results =~ s/\n?%[A-Z]+-[SIWEF]-[A-Z]+,.*//;
 
@@ -670,7 +631,7 @@ sub _fresh_perl {
     # Use the first line of the program as a name if none was given
     unless( $name ) {
         my $first_line;
-        ($first_line, $name) = $prog =~ m/^((.{1,50}).*)/;
+        @($first_line, $name) = @: $prog =~ m/^((.{1,50}).*)/;
         $name .= '...' if length $first_line +> length $name;
     }
 
@@ -684,11 +645,11 @@ sub _fresh_perl {
 #
 
 sub fresh_perl_is {
-    my($prog, $expected, $runperl_args, $name) = < @_;
+    my@($prog, $expected, ?$runperl_args, ?$name) =  @_;
     local $Level = 2;
     $expected =~ s/\n+$//; # is also removed from program output
     _fresh_perl($prog,
-		sub { (nelems @_) ? @_[0] eq $expected : $expected },
+		sub { (nelems @_) ?? @_[0] eq $expected !! $expected },
 		$runperl_args, $name);
 }
 
@@ -699,17 +660,16 @@ sub fresh_perl_is {
 #
 
 sub fresh_perl_like {
-    my($prog, $expected, $runperl_args, $name) = < @_;
+    my@($prog, $expected, $runperl_args, $name) =  @_;
     local $Level = 2;
     _fresh_perl($prog,
-		sub { (nelems @_) ?
-			  @_[0] =~ (ref $expected ? $expected : m/$expected/) :
+		sub { (nelems @_) ??
+			  @_[0] =~ (ref $expected ?? $expected !! m/$expected/) !!
 		          $expected },
 		$runperl_args, $name);
 }
 
-sub can_ok ($@) {
-    my($proto, < @methods) = < @_;
+sub can_ok ($proto, @< @methods) {
     my $class = ref $proto || $proto;
 
     unless( nelems @methods ) {
@@ -718,21 +678,19 @@ sub can_ok ($@) {
 
     my @nok = @( () );
     foreach my $method ( @methods) {
-        local($!, $@);  # don't interfere with caller's $@
+        local($^OS_ERROR, $^EVAL_ERROR);  # don't interfere with caller's $@
                         # eval sometimes resets $!
         try { $proto->can($method) } || push @nok, $method;
     }
 
     my $name;
-    $name = (nelems @methods) == 1 ? "$class->can('@methods[0]')"
-                          : "$class->can(...)";
+    $name = (nelems @methods) == 1 ?? "$class->can('@methods[0]')"
+                          !! "$class->can(...)";
 
     _ok( !nelems @nok, _where(), $name );
 }
 
-sub isa_ok ($$;$) {
-    my($object, $class, $obj_name) = < @_;
-
+sub isa_ok ($object, $class, ?$obj_name) {
     my $diag;
     $obj_name = 'The object' unless defined $obj_name;
     my $name = "$obj_name isa $class";
@@ -744,10 +702,10 @@ sub isa_ok ($$;$) {
     }
     else {
         # We can't use UNIVERSAL::isa because we want to honor isa() overrides
-        local($@, $!);  # eval sometimes resets $!
+        local($^EVAL_ERROR, $^OS_ERROR);  # eval sometimes resets $!
         my $rslt = try { $object->isa($class) };
-        if( $@ ) {
-            if( $@->{description} =~ m/^Can't call method "isa" on unblessed reference/ ) {
+        if( $^EVAL_ERROR ) {
+            if( $^EVAL_ERROR->{?description} =~ m/^Can't call method "isa" on unblessed reference/ ) {
                 if( !UNIVERSAL::isa($object, $class) ) {
                     my $ref = ref $object;
                     $diag = "$obj_name isn't a '$class' it's a '$ref'";
@@ -757,7 +715,7 @@ sub isa_ok ($$;$) {
 WHOA! I tried to call ->isa on your object and got some weird error.
 This should never happen.  Please contact the author immediately.
 Here's the error.
-$@
+$^EVAL_ERROR
 WHOA
             }
         }
@@ -770,42 +728,39 @@ WHOA
     _ok( !$diag, _where(), $name );
 }
 
-sub dies_not(&;$) {
-    my ($e, $qr, $name) = < @_;
+sub dies_not ($e, ?$name) {
     local $Level = 2;
     if (try { $e->(); 1; }) {
         return ok(1, $name);
     }
-    diag $@->message;
+    diag $^EVAL_ERROR->message;
     return ok(0, $name);
 }
 
-sub dies_like(&$;$) {
-    my ($e, $qr, $name) = < @_;
+sub dies_like ($e, $qr, ?$name) {
     if (try { $e->(); 1; }) {
         local $Level = 2;
         diag "didn't die";
         return ok(0, $name);
     }
-    my $err = $@->{description};
+    my $err = $^EVAL_ERROR->{?description};
     return like_yn(0, $err, $qr );
 }
 
-sub eval_dies_like($$;$) {
-    my ($e, $qr, $name) = < @_;
+sub eval_dies_like ($e, $qr, ?$name) {
   TODO:
-    {
-        todo_skip("Compile time abortion are known to leak memory", 1) if %ENV{PERL_VALGRIND};
+    do {
+        todo_skip("Compile time abortion are known to leak memory", 1) if env::var('PERL_VALGRIND');
         
         eval "$e";
-        my $err = $@;
+        my $err = $^EVAL_ERROR;
         if (not $err) {
             local $Level = 2;
             diag "didn't die";
             return ok(0, $name);
         }
-        return like_yn(0, $err->{description}, $qr );
-    }
+        return like_yn(0, $err->{description}, $qr, $name );
+    };
 }
 
 1;
