@@ -4,10 +4,10 @@ our $VERSION = '1.02_02';
 
 BEGIN {
     require 'regen_lib.pl';
-    push @INC, './lib';
+    push $^INCLUDE_PATH, './lib';
 }
 use kurila;
-use strict ;
+ 
 
 sub DEFAULT_ON  () { 1 }
 sub DEFAULT_OFF () { 2 }
@@ -71,7 +71,7 @@ my $tree = \%(
 
 ###########################################################################
 sub tab {
-    my($l, $t) = < @_;
+    my@($l, $t) =  @_;
     $t .= "\t" x ($l - (length($t) + 1) / 8);
     $t;
 }
@@ -90,16 +90,16 @@ sub valueWalk
 {
     my $tre = shift ;
     my @list = @() ;
-    my ($k, $v) ;
 
-    foreach $k (sort keys %$tre) {
-	$v = $tre->{$k};
-	die "duplicate key $k\n" if defined %list{$k} ;
+    foreach my $k (sort keys %$tre) {
+	my $v = $tre->{?$k};
+	die "duplicate key $k\n" if defined %list{?$k} ;
 	die "Value associated with key '$k' is not an ARRAY reference"
 	    if !ref $v || ref $v ne 'ARRAY' ;
 
-	my ($ver, $rest) = < @{ $v } ;
-	push @{%v_list{$ver}}, $k;
+	my @($ver, $rest) =  @{ $v } ;
+        %v_list{+$ver} //= @: ;
+	push %v_list{+$ver}, $k;
 	
 	if (ref $rest)
 	  { valueWalk ($rest) }
@@ -111,10 +111,10 @@ sub valueWalk
 sub orderValues
 {
     my $index = 0;
-    foreach my $ver ( sort { $a <+> $b } keys %v_list ) {
-        foreach my $name (  @{ %v_list{$ver} } ) {
-	    %ValueToName{ $index } = \@( uc $name, $ver ) ;
-	    %NameToValue{ uc $name } = $index ++ ;
+    foreach my $ver ( sort { $a <+> $b }, keys %v_list ) {
+        foreach my $name ( %v_list{$ver} ) {
+	    %ValueToName{+$index } = \@( uc $name, $ver ) ;
+	    %NameToValue{+uc $name } = $index ++ ;
         }
     }
 
@@ -127,24 +127,23 @@ sub walk
 {
     my $tre = shift ;
     my @list = @() ;
-    my ($k, $v) ;
 
-    foreach $k (sort keys %$tre) {
-	$v = $tre->{$k};
-	die "duplicate key $k\n" if defined %list{$k} ;
+    foreach my $k (sort keys %$tre) {
+	my $v = $tre->{?$k};
+	die "duplicate key $k\n" if defined %list{?$k} ;
 	#$Value{$index} = uc $k ;
 	die "Can't find key '$k'"
-	    if ! defined %NameToValue{uc $k} ;
-        push @{ %list{$k} }, %NameToValue{uc $k} ;
+	    if ! defined %NameToValue{?uc $k} ;
+        push @{ %list{+$k} }, %NameToValue{?uc $k} ;
 	die "Value associated with key '$k' is not an ARRAY reference"
 	    if !ref $v || ref $v ne 'ARRAY' ;
 	
-	my ($ver, $rest) = < @{ $v } ;
+	my @($ver, $rest) =  @{ $v } ;
 	if (ref $rest) {
             push (@{ %list{$k} }, < walk ($rest));
         }
 
-	push @list, < @{ %list{$k} } ;
+	push @list, < @{ %list{?$k} } ;
     }
 
    return @list ;
@@ -156,11 +155,10 @@ sub mkRange
 {
     my @a = shift ;
     my @out = @a ;
-    my $i ;
 
-    for ($i = 1 ; $i +< nelems(@a); ++ $i) {
-      	@out[$i] = ".."
-          if @a[$i] == @a[$i - 1] + 1 && @a[$i] + 1 == @a[$i + 1] ;
+    for my $i (1..nelems(@a)-1) {
+      	@out[+$i] = ".."
+          if @a[$i] == @a[$i - 1] + 1 && @a[$i] + 1 == @a[?$i + 1] ;
     }
 
     my $out = join(",",@out);
@@ -176,34 +174,34 @@ sub printTree
     my $prefix = shift ;
     my ($k, $v) ;
 
-    my $max = ( <sort {$a <+> $b} map { length $_ } keys %$tre)[[-1]] ;
+    my $max = (sort {$a <+> $b}, map { length $_ }, keys %$tre)[-1] ;
     my @keys = sort keys %$tre ;
 
     while ($k = shift @keys) {
-	$v = $tre->{$k};
+	$v = $tre->{?$k};
 	die "Value associated with key '$k' is not an ARRAY reference"
 	    if !ref $v || ref $v ne 'ARRAY' ;
 	
         my $offset ;
 	if ($tre ne $tree) {
-	    print $prefix . "|\n" ;
-	    print $prefix . "+- $k" ;
+	    print \*STDOUT, $prefix . "|\n" ;
+	    print \*STDOUT, $prefix . "+- $k" ;
 	    $offset = ' ' x ($max + 4) ;
 	}
 	else {
-	    print $prefix . "$k" ;
+	    print \*STDOUT, $prefix . "$k" ;
 	    $offset = ' ' x ($max + 1) ;
 	}
 
-	my ($ver, $rest) = @{ $v } ;
+	my @($ver, $rest) = @{ $v } ;
 	if (ref $rest)
 	{
-	    my $bar = @keys ? "|" : " ";
-	    print " -" . "-" x ($max - length $k ) . "+\n" ;
+	    my $bar = @keys ?? "|" !! " ";
+	    print \*STDOUT, " -" . "-" x ($max - length $k ) . "+\n" ;
 	    printTree ($rest, $prefix . $bar . $offset )
 	}
 	else
-	  { print "\n" }
+	  { print \*STDOUT, "\n" }
     }
 
 }
@@ -212,12 +210,12 @@ sub printTree
 
 sub mkHex
 {
-    my ($max, < @a) = < @_ ;
+    my @($max, @< @a) =  @_ ;
     my $mask = "\x[00]" x $max;
     my $string = "" ;
 
     foreach ( @a) {
-	vec($mask, $_, 1) = 1 ;
+	vec($mask, $_, 1 => 1);
     }
 
     foreach (@(unpack("C*", $mask))) {
@@ -237,7 +235,7 @@ if (@ARGV && @ARGV[0] eq "tree")
 my $warn = safer_open("warnings.h-new");
 my $pm = safer_open("lib/warnings.pm-new");
 
-print $warn <<'EOM' ;
+print $warn, <<'EOM' ;
 /* -*- buffer-read-only: t -*-
    !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
    This file is built by warnings.pl
@@ -288,23 +286,22 @@ walk ($tree) ;
 $index *= 2 ;
 my $warn_size = int($index / 8) + ($index % 8 != 0) ;
 
-my $k ;
 my $last_ver = 0;
-foreach $k (sort { $a <+> $b } keys %ValueToName) {
-    my ($name, $version) = < @{ %ValueToName{$k} };
-    print $warn "\n/* Warnings Categories added in Perl $version */\n\n"
+foreach my $k (sort { $a <+> $b }, keys %ValueToName) {
+    my @($name, $version) =  @{ %ValueToName{?$k} };
+    print $warn, "\n/* Warnings Categories added in Perl $version */\n\n"
         if $last_ver != $version ;
-    print $warn tab(5, "#define WARN_$name"), "$k\n" ;
+    print $warn, tab(5, "#define WARN_$name"), "$k\n" ;
     $last_ver = $version ;
 }
-print $warn "\n" ;
+print $warn, "\n" ;
 
-print $warn tab(5, '#define WARNsize'),	"$warn_size\n" ;
+print $warn, tab(5, '#define WARNsize'),	"$warn_size\n" ;
 #print WARN tab(5, '#define WARN_ALLstring'), '"', ('\377' x $warn_size) , "\"\n" ;
-print $warn tab(5, '#define WARN_ALLstring'), '"', ('\125' x $warn_size) , "\"\n" ;
-print $warn tab(5, '#define WARN_NONEstring'), '"', ('\0' x $warn_size) , "\"\n" ;
+print $warn, tab(5, '#define WARN_ALLstring'), '"', ('\125' x $warn_size) , "\"\n" ;
+print $warn, tab(5, '#define WARN_NONEstring'), '"', ('\0' x $warn_size) , "\"\n" ;
 
-print $warn <<'EOM';
+print $warn, <<'EOM';
 
 #define isLEXWARN_on 	(PL_curcop->cop_warnings != pWARN_STD)
 #define isLEXWARN_off	(PL_curcop->cop_warnings == pWARN_STD)
@@ -354,63 +351,63 @@ rename_if_different("warnings.h-new", "warnings.h");
 
 while ( ~< *DATA) {
     last if m/^KEYWORDS$/ ;
-    print $pm $_ ;
+    print $pm, $_ ;
 }
 
 #$list{'all'} = [ $offset .. 8 * ($warn_size/2) - 1 ] ;
 
 $last_ver = 0;
-print $pm "our \%Offsets = \%(\n" ;
-foreach my $k (sort { $a <+> $b } keys %ValueToName) {
-    my ($name, $version) = < @{ %ValueToName{$k} };
+print $pm, "our \%Offsets = \%(\n" ;
+foreach my $k (sort { $a <+> $b }, keys %ValueToName) {
+    my @($name, $version) =  @{ %ValueToName{?$k} };
     $name = lc $name;
     $k *= 2 ;
     if ( $last_ver != $version ) {
-        print $pm "\n";
-        print $pm tab(4, "    # Warnings Categories added in Perl $version");
-        print $pm "\n\n";
+        print $pm, "\n";
+        print $pm, tab(4, "    # Warnings Categories added in Perl $version");
+        print $pm, "\n\n";
     }
-    print $pm tab(4, "    '$name'"), "=> $k,\n" ;
+    print $pm, tab(4, "    '$name'"), "=> $k,\n" ;
     $last_ver = $version;
 }
 
-print $pm "  );\n\n" ;
+print $pm, "  );\n\n" ;
 
-print $pm "our \%Bits = %(\n" ;
-foreach $k (sort keys  %list) {
+print $pm, "our \%Bits = %(\n" ;
+foreach my $k (sort keys  %list) {
 
-    my $v = %list{$k} ;
-    my @list = sort { $a <+> $b } @$v;
+    my $v = %list{?$k} ;
+    my @list = sort { $a <+> $b }, @$v;
 
-    print $pm tab(4, "    '$k'"), '=> "',
+    print $pm, tab(4, "    '$k'"), '=> "',
 		# mkHex($warn_size, @list),
-		mkHex($warn_size, < map $_ * 2, @list),
+		mkHex($warn_size, < map { $_ * 2 }, @list),
 		'", # [', mkRange(@list), "]\n" ;
 }
 
-print $pm "  );\n\n" ;
+print $pm, "  );\n\n" ;
 
-print $pm "our \%DeadBits = %(\n" ;
-foreach $k (sort keys  %list) {
+print $pm, "our \%DeadBits = %(\n" ;
+foreach my $k (sort keys  %list) {
 
-    my $v = %list{$k} ;
-    my @list = sort { $a <+> $b } @$v;
+    my $v = %list{?$k} ;
+    my @list = sort { $a <+> $b }, @$v;
 
-    print $pm tab(4, "    '$k'"), '=> "',
+    print $pm, tab(4, "    '$k'"), '=> "',
 		# mkHex($warn_size, @list),
-		mkHex($warn_size, < map $_ * 2 + 1, @list),
+		mkHex($warn_size, < map { $_ * 2 + 1 }, @list),
 		'", # [', mkRange(@list), "]\n" ;
 }
 
-print $pm "  );\n\n" ;
-print $pm 'our $NONE     = "', ('\0' x $warn_size) , "\";\n" ;
-print $pm 'our $LAST_BIT = ' . "$index ;\n" ;
-print $pm 'our $BYTES    = ' . "$warn_size ;\n" ;
+print $pm, "  );\n\n" ;
+print $pm, 'our $NONE     = "', ('\0' x $warn_size) , "\";\n" ;
+print $pm, 'our $LAST_BIT = ' . "$index ;\n" ;
+print $pm, 'our $BYTES    = ' . "$warn_size ;\n" ;
 while ( ~< *DATA) {
-    print $pm $_ ;
+    print $pm, $_ ;
 }
 
-print $pm "# ex: set ro:\n";
+print $pm, "# ex: set ro:\n";
 safer_close $pm;
 rename_if_different("lib/warnings.pm-new", "lib/warnings.pm");
 
@@ -429,8 +426,8 @@ our $VERSION = '1.06';
 # see also strict.pm.
 my $pkg = __PACKAGE__;
 unless ( __FILE__ =~ m/(^|[\/\\])\Q$pkg\E\.pmc?$/ ) {
-    my (undef, $f, $l) = caller;
-    die("Incorrect use of pragma '{__PACKAGE__}' at $f line $l.\n");
+    my @(_, $f, $l) = @: caller;
+    die("Incorrect use of pragma '$(__PACKAGE__)' at $f line $l.\n");
 }
 
 =head1 NAME
@@ -558,7 +555,7 @@ See L<perlmodlib/Pragmatic Modules> and L<perllexwarn>.
 
 KEYWORDS
 
-our $All = "" ; vec($All, %Offsets{'all'}, 2) = 3 ;
+our $All = "" ; vec($All, %Offsets{'all'}, 2 => 3);
 
 sub bits
 {
@@ -571,7 +568,7 @@ sub bits
     my $fatal = 0 ;
     my $no_fatal = 0 ;
 
-    foreach my $word ( < @_ ) {
+    foreach my $word ( @_ ) {
 	if ($word eq 'FATAL') {
 	    $fatal = 1;
 	    $no_fatal = 0;
@@ -580,7 +577,7 @@ sub bits
 	    $fatal = 0;
 	    $no_fatal = 1;
 	}
-	elsif ($catmask = %Bits{$word}) {
+	elsif ($catmask = %Bits{?$word}) {
 	    $mask ^|^= $catmask ;
 	    $mask ^|^= %DeadBits{$word} if $fatal ;
 	    $mask ^&^= ^~^(%DeadBits{$word}^|^$All) if $no_fatal ;
@@ -609,7 +606,7 @@ sub import
     
     push @_, 'all' unless @_;
 
-    foreach my $word ( < @_ ) {
+    foreach my $word ( @_ ) {
 	if ($word eq 'FATAL') {
 	    $fatal = 1;
 	    $no_fatal = 0;
@@ -618,7 +615,7 @@ sub import
 	    $fatal = 0;
 	    $no_fatal = 1;
 	}
-	elsif ($catmask = %Bits{$word}) {
+	elsif ($catmask = %Bits{?$word}) {
 	    $mask ^|^= $catmask ;
 	    $mask ^|^= %DeadBits{$word} if $fatal ;
 	    $mask ^&^= ^~^(%DeadBits{$word}^|^$All) if $no_fatal ;
@@ -644,11 +641,11 @@ sub unimport
 
     push @_, 'all' unless @_;
 
-    foreach my $word ( < @_ ) {
+    foreach my $word ( @_ ) {
 	if ($word eq 'FATAL') {
 	    next; 
 	}
-	elsif ($catmask = %Bits{$word}) {
+	elsif ($catmask = %Bits{?$word}) {
 	    $mask ^&^= ^~^($catmask ^|^ %DeadBits{$word} ^|^ $All);
 	}
 	else
@@ -658,7 +655,7 @@ sub unimport
     $^WARNING_BITS = $mask ;
 }
 
-my %builtin_type; %builtin_type{[qw(SCALAR ARRAY HASH CODE REF GLOB LVALUE Regexp)]} = ();
+my %builtin_type; %builtin_type{[qw(SCALAR ARRAY HASH CODE REF GLOB LVALUE Regexp)]} = @();
 
 sub __chk
 {
@@ -675,13 +672,13 @@ sub __chk
 	    $category = $type;
             $isobj = 1 ;
         }
-        $offset = %Offsets{$category};
+        $offset = %Offsets{?$category};
         die("Unknown warnings category '$category'")
 	    unless defined $offset;
     }
     else {
         $category = @(caller(1))[0] ;
-        $offset = %Offsets{$category};
+        $offset = %Offsets{?$category};
         die("package '$category' not registered for warnings")
 	    unless defined $offset ;
     }
@@ -691,7 +688,7 @@ sub __chk
     my $pkg ;
 
     if ($isobj) {
-        while (do { { package DB; $pkg = @(caller($i++))[0] } } ) {
+        while (do { package DB; $pkg = @(caller($i++))[0] } ) {
             last unless @DB::args && @DB::args[0] =~ m/^$category=/ ;
         }
 	$i -= 2 ;
@@ -709,7 +706,7 @@ sub enabled
     die("Usage: warnings::enabled([category])")
 	unless nelems(@_) == 1 || nelems(@_) == 0 ;
 
-    my ($callers_bitmask, $offset, $i) = < __chk(< @_) ;
+    my @($callers_bitmask, $offset, $i) = __chk(< @_) ;
 
     return 0 unless defined $callers_bitmask ;
     return vec($callers_bitmask, $offset, 1) ||
@@ -723,7 +720,7 @@ sub warn
 	unless nelems(@_) == 2 || nelems(@_) == 1 ;
 
     my $message = pop ;
-    my ($callers_bitmask, $offset, $i) = < __chk(<@_) ;
+    my @($callers_bitmask, $offset, $i) = __chk(<@_) ;
     die($message)
 	if vec($callers_bitmask, $offset+1, 1) ||
 	   vec($callers_bitmask, %Offsets{'all'}+1, 1) ;
@@ -736,7 +733,7 @@ sub warnif
 	unless nelems(@_) == 2 || nelems(@_) == 1 ;
 
     my $message = pop ;
-    my ($callers_bitmask, $offset, $i) = <__chk(<@_) ;
+    my @($callers_bitmask, $offset, $i) = __chk(<@_) ;
 
     return
         unless defined $callers_bitmask &&
