@@ -2,7 +2,6 @@ package FindExt;
 
 our $VERSION = '1.02';
 
-use strict;
 use warnings;
 
 my $no = join('|',qw(GDBM_File ODBM_File NDBM_File DB_File
@@ -17,7 +16,8 @@ sub getcwd {
     $_ = `cd`;
     chomp;
     s:\\:/:g ;
-    return %ENV{'PWD'} = $_;
+    env::var('PWD') = $_;
+    return $_;
 }
 
 sub set_static_extensions {
@@ -28,12 +28,12 @@ sub set_static_extensions {
     %static = %( () );
     my @list = @_;
     if (@_[0] eq '*') {
-	my %excl = %( < map {$_=>1} map {m/^!(.*)$/} @_[[1 .. ((nelems @_)-1)]] );
-	@list = grep {!exists %excl{$_}} keys %ext;
+	my %excl = %( < map {$_=>1}, map {m/^!(.*)$/}, @_[[1 .. ((nelems @_)-1)]] );
+	@list = grep {!exists %excl{$_}}, keys %ext;
     }
     for ( @list) {
-        %static{$_} = 1;
-        %ext{$_} = 'static' if %ext{$_} && %ext{$_} eq 'dynamic';
+        %static{+$_} = 1;
+        %ext{+$_} = 'static' if %ext{?$_} && %ext{?$_} eq 'dynamic';
     }
 }
 
@@ -50,33 +50,33 @@ sub scan_ext
 
 sub dynamic_ext
 {
- return sort grep %ext{$_} eq 'dynamic',keys %ext;
+ return sort grep { %ext{?$_} eq 'dynamic' },keys %ext;
 }
 
 sub static_ext
 {
- return sort grep %ext{$_} eq 'static',keys %ext;
+ return sort grep { %ext{?$_} eq 'static' },keys %ext;
 }
 
 sub nonxs_ext
 {
- return sort grep %ext{$_} eq 'nonxs',keys %ext;
+ return sort grep { %ext{?$_} eq 'nonxs' },keys %ext;
 }
 
 sub extensions
 {
- return sort grep %ext{$_} ne 'known',keys %ext;
+ return sort grep { %ext{?$_} ne 'known' },keys %ext;
 }
 
 sub known_extensions
 {
  # faithfully copy Configure in not including nonxs extensions for the nonce
- return sort grep %ext{$_} ne 'nonxs',keys %ext;
+ return sort grep { %ext{?$_} ne 'nonxs' },keys %ext;
 }
 
 sub is_static
 {
- return %ext{@_[0]} eq 'static'
+ return %ext{?@_[0]} eq 'static'
 }
 
 # Function to recursively find available extensions, ignoring DynaLoader
@@ -84,14 +84,14 @@ sub is_static
 sub find_ext
 {
     opendir my $dh, '.';
-    my @items = grep { !m/^\.\.?$/ } @( readdir $dh);
+    my @items = grep { !m/^\.\.?$/ }, @( readdir $dh);
     closedir $dh;
     for my $xxx ( @items) {
         if ($xxx ne "DynaLoader") {
             if (-f "$xxx/$xxx.xs" || -f "$xxx/$xxx.c" ) {
-                %ext{"@_[0]$xxx"} = %static{"@_[0]$xxx"} ? 'static' : 'dynamic';
+                %ext{+"@_[0]$xxx"} = %static{?"@_[0]$xxx"} ?? 'static' !! 'dynamic';
             } elsif (-f "$xxx/Makefile.PL") {
-                %ext{"@_[0]$xxx"} = 'nonxs';
+                %ext{+"@_[0]$xxx"} = 'nonxs';
             } else {
                 if (-d $xxx && (nelems @_) +< 10) {
                     chdir $xxx;
@@ -99,7 +99,7 @@ sub find_ext
                     chdir "..";
                 }
             }
-            %ext{"@_[0]$xxx"} = 'known' if %ext{"@_[0]$xxx"} && $xxx =~ $no;
+            %ext{+"@_[0]$xxx"} = 'known' if %ext{?"@_[0]$xxx"} && $xxx =~ $no;
         }
     }
 
@@ -110,10 +110,10 @@ sub find_ext
 # A.D. 20011025 (SDBM), ajgough 20071008 (FieldHash)
 
     if (!@_[0] && -d "threads/shared") {
-        %ext{"threads/shared"} = 'dynamic';
+        %ext{+"threads/shared"} = 'dynamic';
     }
     if (!@_[0] && -d "Hash/Util/FieldHash") {
-        %ext{"Hash/Util/FieldHash"} = 'dynamic';
+        %ext{+"Hash/Util/FieldHash"} = 'dynamic';
     }
 }
 
